# API Reference <a name="API Reference" id="api-reference"></a>

## Constructs <a name="Constructs" id="Constructs"></a>

### TypeSafeRestApi <a name="TypeSafeRestApi" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi"></a>

A construct for creating an api gateway rest api based on the definition in the OpenAPI spec.

#### Initializers <a name="Initializers" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.TypeSafeRestApi(
  scope: Construct,
  id: str,
  cloud_watch_role: bool = None,
  deploy: bool = None,
  deploy_options: StageOptions = None,
  description: str = None,
  disable_execute_api_endpoint: bool = None,
  domain_name: DomainNameOptions = None,
  endpoint_export_name: str = None,
  endpoint_types: typing.List[EndpointType] = None,
  fail_on_warnings: bool = None,
  parameters: typing.Mapping[str] = None,
  policy: PolicyDocument = None,
  rest_api_name: str = None,
  retain_deployments: bool = None,
  integrations: typing.Mapping[TypeSafeApiIntegration],
  operation_lookup: typing.Mapping[OperationDetails],
  api_key_options: ApiKeyOptions = None,
  cors_options: CorsOptions = None,
  default_authorizer: Authorizer = None,
  spec_path: str,
  min_compression_size: Size = None,
  web_acl_options: TypeSafeApiWebAclOptions = None
)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.id">id</a></code> | <code>str</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.cloudWatchRole">cloud_watch_role</a></code> | <code>bool</code> | Automatically configure an AWS CloudWatch role for API Gateway. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.deploy">deploy</a></code> | <code>bool</code> | Indicates if a Deployment should be automatically created for this API, and recreated when the API model (resources, methods) changes. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.deployOptions">deploy_options</a></code> | <code>aws_cdk.aws_apigateway.StageOptions</code> | Options for the API Gateway stage that will always point to the latest deployment when `deploy` is enabled. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.description">description</a></code> | <code>str</code> | A description of the RestApi construct. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.disableExecuteApiEndpoint">disable_execute_api_endpoint</a></code> | <code>bool</code> | Specifies whether clients can invoke the API using the default execute-api endpoint. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.domainName">domain_name</a></code> | <code>aws_cdk.aws_apigateway.DomainNameOptions</code> | Configure a custom domain name and map it to this API. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.endpointExportName">endpoint_export_name</a></code> | <code>str</code> | Export name for the CfnOutput containing the API endpoint. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.endpointTypes">endpoint_types</a></code> | <code>typing.List[aws_cdk.aws_apigateway.EndpointType]</code> | A list of the endpoint types of the API. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.failOnWarnings">fail_on_warnings</a></code> | <code>bool</code> | Indicates whether to roll back the resource if a warning occurs while API Gateway is creating the RestApi resource. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.parameters">parameters</a></code> | <code>typing.Mapping[str]</code> | Custom header parameters for the request. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.policy">policy</a></code> | <code>aws_cdk.aws_iam.PolicyDocument</code> | A policy document that contains the permissions for this RestApi. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.restApiName">rest_api_name</a></code> | <code>str</code> | A name for the API Gateway RestApi resource. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.retainDeployments">retain_deployments</a></code> | <code>bool</code> | Retains old deployment resources when the API changes. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.integrations">integrations</a></code> | <code>typing.Mapping[<a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiIntegration">TypeSafeApiIntegration</a>]</code> | A mapping of API operation to its integration. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.operationLookup">operation_lookup</a></code> | <code>typing.Mapping[<a href="#@aws-prototyping-sdk/type-safe-api.OperationDetails">OperationDetails</a>]</code> | Details about each operation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.apiKeyOptions">api_key_options</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiKeyOptions">ApiKeyOptions</a></code> | Options for API keys. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.corsOptions">cors_options</a></code> | <code>aws_cdk.aws_apigateway.CorsOptions</code> | Cross Origin Resource Sharing options for the API. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.defaultAuthorizer">default_authorizer</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.Authorizer">Authorizer</a></code> | The default authorizer to use for your api. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.specPath">spec_path</a></code> | <code>str</code> | Path to the JSON open api spec. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.minCompressionSize">min_compression_size</a></code> | <code>aws_cdk.Size</code> | A Size(in bytes, kibibytes, mebibytes etc) that is used to enable compression (with non-negative between 0 and 10485760 (10M) bytes, inclusive) or disable compression (when undefined) on an API. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.webAclOptions">web_acl_options</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiWebAclOptions">TypeSafeApiWebAclOptions</a></code> | Options for the AWS WAF v2 WebACL associated with the api. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

---

##### `id`<sup>Required</sup> <a name="id" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.id"></a>

- *Type:* str

---

##### `cloud_watch_role`<sup>Optional</sup> <a name="cloud_watch_role" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.cloudWatchRole"></a>

- *Type:* bool
- *Default:* false if `@aws-cdk/aws-apigateway:disableCloudWatchRole` is enabled, true otherwise

Automatically configure an AWS CloudWatch role for API Gateway.

---

##### `deploy`<sup>Optional</sup> <a name="deploy" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.deploy"></a>

- *Type:* bool
- *Default:* true

Indicates if a Deployment should be automatically created for this API, and recreated when the API model (resources, methods) changes.

Since API Gateway deployments are immutable, When this option is enabled
(by default), an AWS::ApiGateway::Deployment resource will automatically
created with a logical ID that hashes the API model (methods, resources
and options). This means that when the model changes, the logical ID of
this CloudFormation resource will change, and a new deployment will be
created.

If this is set, `latestDeployment` will refer to the `Deployment` object
and `deploymentStage` will refer to a `Stage` that points to this
deployment. To customize the stage options, use the `deployOptions`
property.

A CloudFormation Output will also be defined with the root URL endpoint
of this REST API.

---

##### `deploy_options`<sup>Optional</sup> <a name="deploy_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.deployOptions"></a>

- *Type:* aws_cdk.aws_apigateway.StageOptions
- *Default:* Based on defaults of `StageOptions`.

Options for the API Gateway stage that will always point to the latest deployment when `deploy` is enabled.

If `deploy` is disabled,
this value cannot be set.

---

##### `description`<sup>Optional</sup> <a name="description" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.description"></a>

- *Type:* str
- *Default:* 'Automatically created by the RestApi construct'

A description of the RestApi construct.

---

##### `disable_execute_api_endpoint`<sup>Optional</sup> <a name="disable_execute_api_endpoint" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.disableExecuteApiEndpoint"></a>

- *Type:* bool
- *Default:* false

Specifies whether clients can invoke the API using the default execute-api endpoint.

To require that clients use a custom domain name to invoke the
API, disable the default endpoint.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-restapi.html](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-restapi.html)

---

##### `domain_name`<sup>Optional</sup> <a name="domain_name" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.domainName"></a>

- *Type:* aws_cdk.aws_apigateway.DomainNameOptions
- *Default:* no domain name is defined, use `addDomainName` or directly define a `DomainName`.

Configure a custom domain name and map it to this API.

---

##### `endpoint_export_name`<sup>Optional</sup> <a name="endpoint_export_name" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.endpointExportName"></a>

- *Type:* str
- *Default:* when no export name is given, output will be created without export

Export name for the CfnOutput containing the API endpoint.

---

##### `endpoint_types`<sup>Optional</sup> <a name="endpoint_types" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.endpointTypes"></a>

- *Type:* typing.List[aws_cdk.aws_apigateway.EndpointType]
- *Default:* EndpointType.EDGE

A list of the endpoint types of the API.

Use this property when creating
an API.

---

##### `fail_on_warnings`<sup>Optional</sup> <a name="fail_on_warnings" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.failOnWarnings"></a>

- *Type:* bool
- *Default:* false

Indicates whether to roll back the resource if a warning occurs while API Gateway is creating the RestApi resource.

---

##### `parameters`<sup>Optional</sup> <a name="parameters" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.parameters"></a>

- *Type:* typing.Mapping[str]
- *Default:* No parameters.

Custom header parameters for the request.

> [https://docs.aws.amazon.com/cli/latest/reference/apigateway/import-rest-api.html](https://docs.aws.amazon.com/cli/latest/reference/apigateway/import-rest-api.html)

---

##### `policy`<sup>Optional</sup> <a name="policy" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.policy"></a>

- *Type:* aws_cdk.aws_iam.PolicyDocument
- *Default:* No policy.

A policy document that contains the permissions for this RestApi.

---

##### `rest_api_name`<sup>Optional</sup> <a name="rest_api_name" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.restApiName"></a>

- *Type:* str
- *Default:* ID of the RestApi construct.

A name for the API Gateway RestApi resource.

---

##### `retain_deployments`<sup>Optional</sup> <a name="retain_deployments" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.retainDeployments"></a>

- *Type:* bool
- *Default:* false

Retains old deployment resources when the API changes.

This allows
manually reverting stages to point to old deployments via the AWS
Console.

---

##### `integrations`<sup>Required</sup> <a name="integrations" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.integrations"></a>

- *Type:* typing.Mapping[<a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiIntegration">TypeSafeApiIntegration</a>]

A mapping of API operation to its integration.

---

##### `operation_lookup`<sup>Required</sup> <a name="operation_lookup" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.operationLookup"></a>

- *Type:* typing.Mapping[<a href="#@aws-prototyping-sdk/type-safe-api.OperationDetails">OperationDetails</a>]

Details about each operation.

---

##### `api_key_options`<sup>Optional</sup> <a name="api_key_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.apiKeyOptions"></a>

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.ApiKeyOptions">ApiKeyOptions</a>

Options for API keys.

---

##### `cors_options`<sup>Optional</sup> <a name="cors_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.corsOptions"></a>

- *Type:* aws_cdk.aws_apigateway.CorsOptions

Cross Origin Resource Sharing options for the API.

---

##### `default_authorizer`<sup>Optional</sup> <a name="default_authorizer" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.defaultAuthorizer"></a>

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.Authorizer">Authorizer</a>

The default authorizer to use for your api.

When omitted, no default authorizer is used.
Authorizers specified at the integration level will override this for that operation.

---

##### `spec_path`<sup>Required</sup> <a name="spec_path" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.specPath"></a>

- *Type:* str

Path to the JSON open api spec.

---

##### `min_compression_size`<sup>Optional</sup> <a name="min_compression_size" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.minCompressionSize"></a>

- *Type:* aws_cdk.Size
- *Default:* Compression is disabled.

A Size(in bytes, kibibytes, mebibytes etc) that is used to enable compression (with non-negative between 0 and 10485760 (10M) bytes, inclusive) or disable compression (when undefined) on an API.

When compression is enabled, compression or
decompression is not applied on the payload if the payload size is
smaller than this value. Setting it to zero allows compression for any
payload size.

---

##### `web_acl_options`<sup>Optional</sup> <a name="web_acl_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.webAclOptions"></a>

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiWebAclOptions">TypeSafeApiWebAclOptions</a>

Options for the AWS WAF v2 WebACL associated with the api.

By default, a Web ACL with the AWS default managed
rule set will be associated with the API. These options may disable or override the defaults.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.toString">to_string</a></code> | Returns a string representation of this construct. |

---

##### `to_string` <a name="to_string" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.toString"></a>

```python
def to_string() -> str
```

Returns a string representation of this construct.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.isConstruct">is_construct</a></code> | Checks if `x` is a construct. |

---

##### `is_construct` <a name="is_construct" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.isConstruct"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.TypeSafeRestApi.is_construct(
  x: typing.Any
)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.isConstruct.parameter.x"></a>

- *Type:* typing.Any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.property.api">api</a></code> | <code>aws_cdk.aws_apigateway.SpecRestApi</code> | Underlying API Gateway API construct. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.property.extendedApiSpecification">extended_api_specification</a></code> | <code>typing.Any</code> | The OpenAPI specification with applied API gateway extensions. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.property.ipSet">ip_set</a></code> | <code>aws_cdk.aws_wafv2.CfnIPSet</code> | Reference to the IP set if created. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.property.webAcl">web_acl</a></code> | <code>aws_cdk.aws_wafv2.CfnWebACL</code> | Reference to the webacl, if created. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.property.webAclAssociation">web_acl_association</a></code> | <code>aws_cdk.aws_wafv2.CfnWebACLAssociation</code> | Reference to the web acl association if created. |

---

##### `node`<sup>Required</sup> <a name="node" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.property.node"></a>

```python
node: Node
```

- *Type:* constructs.Node

The tree node.

---

##### `api`<sup>Required</sup> <a name="api" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.property.api"></a>

```python
api: SpecRestApi
```

- *Type:* aws_cdk.aws_apigateway.SpecRestApi

Underlying API Gateway API construct.

---

##### `extended_api_specification`<sup>Required</sup> <a name="extended_api_specification" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.property.extendedApiSpecification"></a>

```python
extended_api_specification: typing.Any
```

- *Type:* typing.Any

The OpenAPI specification with applied API gateway extensions.

---

##### `ip_set`<sup>Optional</sup> <a name="ip_set" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.property.ipSet"></a>

```python
ip_set: CfnIPSet
```

- *Type:* aws_cdk.aws_wafv2.CfnIPSet

Reference to the IP set if created.

---

##### `web_acl`<sup>Optional</sup> <a name="web_acl" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.property.webAcl"></a>

```python
web_acl: CfnWebACL
```

- *Type:* aws_cdk.aws_wafv2.CfnWebACL

Reference to the webacl, if created.

---

##### `web_acl_association`<sup>Optional</sup> <a name="web_acl_association" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.property.webAclAssociation"></a>

```python
web_acl_association: CfnWebACLAssociation
```

- *Type:* aws_cdk.aws_wafv2.CfnWebACLAssociation

Reference to the web acl association if created.

---


## Structs <a name="Structs" id="Structs"></a>

### ApiGatewayIntegration <a name="ApiGatewayIntegration" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration"></a>

Represents an api gateway integration.

> [https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-swagger-extensions-integration.html](https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-swagger-extensions-integration.html)

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.ApiGatewayIntegration(
  cache_key_parameters: typing.List[str] = None,
  cache_namespace: str = None,
  connection_id: str = None,
  connection_type: str = None,
  content_handling: str = None,
  credentials: str = None,
  http_method: str = None,
  passthrough_behavior: str = None,
  request_parameters: typing.Mapping[str] = None,
  request_templates: typing.Mapping[str] = None,
  responses: typing.Mapping[ApiGatewayIntegrationResponse] = None,
  timeout_in_millis: typing.Union[int, float] = None,
  tls_config: ApiGatewayIntegrationTlsConfig = None,
  type: str = None,
  uri: str = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.cacheKeyParameters">cache_key_parameters</a></code> | <code>typing.List[str]</code> | A list of request parameters whose values are to be cached. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.cacheNamespace">cache_namespace</a></code> | <code>str</code> | An API-specific tag group of related cached parameters. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.connectionId">connection_id</a></code> | <code>str</code> | The ID of a VpcLink for the private integration. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.connectionType">connection_type</a></code> | <code>str</code> | The integration connection type. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.contentHandling">content_handling</a></code> | <code>str</code> | Request payload encoding conversion types. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.credentials">credentials</a></code> | <code>str</code> | For AWS IAM role-based credentials, specify the ARN of an appropriate IAM role. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.httpMethod">http_method</a></code> | <code>str</code> | The HTTP method used in the integration request. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.passthroughBehavior">passthrough_behavior</a></code> | <code>str</code> | Specifies how a request payload of unmapped content type is passed through the integration request without modification. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.requestParameters">request_parameters</a></code> | <code>typing.Mapping[str]</code> | Specifies mappings from method request parameters to integration request parameters. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.requestTemplates">request_templates</a></code> | <code>typing.Mapping[str]</code> | Mapping templates for a request payload of specified MIME types. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.responses">responses</a></code> | <code>typing.Mapping[<a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegrationResponse">ApiGatewayIntegrationResponse</a>]</code> | Defines the method's responses and specifies desired parameter mappings or payload mappings from integration responses to method responses. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.timeoutInMillis">timeout_in_millis</a></code> | <code>typing.Union[int, float]</code> | Custom timeout between 50 and 29,000 milliseconds. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.tlsConfig">tls_config</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegrationTlsConfig">ApiGatewayIntegrationTlsConfig</a></code> | Specifies the TLS configuration for an integration. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.type">type</a></code> | <code>str</code> | The type of integration with the specified backend. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.uri">uri</a></code> | <code>str</code> | The endpoint URI of the backend. |

---

##### `cache_key_parameters`<sup>Optional</sup> <a name="cache_key_parameters" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.cacheKeyParameters"></a>

```python
cache_key_parameters: typing.List[str]
```

- *Type:* typing.List[str]

A list of request parameters whose values are to be cached.

---

##### `cache_namespace`<sup>Optional</sup> <a name="cache_namespace" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.cacheNamespace"></a>

```python
cache_namespace: str
```

- *Type:* str

An API-specific tag group of related cached parameters.

---

##### `connection_id`<sup>Optional</sup> <a name="connection_id" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.connectionId"></a>

```python
connection_id: str
```

- *Type:* str

The ID of a VpcLink for the private integration.

> [https://docs.aws.amazon.com/apigateway/latest/api/API_VpcLink.html](https://docs.aws.amazon.com/apigateway/latest/api/API_VpcLink.html)

---

##### `connection_type`<sup>Optional</sup> <a name="connection_type" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.connectionType"></a>

```python
connection_type: str
```

- *Type:* str

The integration connection type.

The valid value is "VPC_LINK" for private integration or "INTERNET", otherwise.

---

##### `content_handling`<sup>Optional</sup> <a name="content_handling" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.contentHandling"></a>

```python
content_handling: str
```

- *Type:* str

Request payload encoding conversion types.

Valid values are 1) CONVERT_TO_TEXT, for converting a binary payload
into a base64-encoded string or converting a text payload into a utf-8-encoded string or passing through the text
payload natively without modification, and 2) CONVERT_TO_BINARY, for converting a text payload into a
base64-decoded blob or passing through a binary payload natively without modification.

---

##### `credentials`<sup>Optional</sup> <a name="credentials" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.credentials"></a>

```python
credentials: str
```

- *Type:* str

For AWS IAM role-based credentials, specify the ARN of an appropriate IAM role.

If unspecified, credentials default
to resource-based permissions that must be added manually to allow the API to access the resource. For more
information, see Granting Permissions Using a Resource Policy.

Note: When using IAM credentials, make sure that AWS STS Regional endpoints are enabled for the Region where this
API is deployed for best performance.

---

##### `http_method`<sup>Optional</sup> <a name="http_method" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.httpMethod"></a>

```python
http_method: str
```

- *Type:* str

The HTTP method used in the integration request.

For Lambda function invocations, the value must be POST.

---

##### `passthrough_behavior`<sup>Optional</sup> <a name="passthrough_behavior" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.passthroughBehavior"></a>

```python
passthrough_behavior: str
```

- *Type:* str

Specifies how a request payload of unmapped content type is passed through the integration request without modification.

Supported values are when_no_templates, when_no_match, and never.

> [https://docs.aws.amazon.com/apigateway/latest/api/API_Integration.html#passthroughBehavior](https://docs.aws.amazon.com/apigateway/latest/api/API_Integration.html#passthroughBehavior)

---

##### `request_parameters`<sup>Optional</sup> <a name="request_parameters" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.requestParameters"></a>

```python
request_parameters: typing.Mapping[str]
```

- *Type:* typing.Mapping[str]

Specifies mappings from method request parameters to integration request parameters.

Supported request parameters
are querystring, path, header, and body.

> [https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-swagger-extensions-integration-requestParameters.html](https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-swagger-extensions-integration-requestParameters.html)

---

##### `request_templates`<sup>Optional</sup> <a name="request_templates" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.requestTemplates"></a>

```python
request_templates: typing.Mapping[str]
```

- *Type:* typing.Mapping[str]

Mapping templates for a request payload of specified MIME types.

> [https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-swagger-extensions-integration-requestTemplates.html](https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-swagger-extensions-integration-requestTemplates.html)

---

##### `responses`<sup>Optional</sup> <a name="responses" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.responses"></a>

```python
responses: typing.Mapping[ApiGatewayIntegrationResponse]
```

- *Type:* typing.Mapping[<a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegrationResponse">ApiGatewayIntegrationResponse</a>]

Defines the method's responses and specifies desired parameter mappings or payload mappings from integration responses to method responses.

> [https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-swagger-extensions-integration-responses.html](https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-swagger-extensions-integration-responses.html)

---

##### `timeout_in_millis`<sup>Optional</sup> <a name="timeout_in_millis" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.timeoutInMillis"></a>

```python
timeout_in_millis: typing.Union[int, float]
```

- *Type:* typing.Union[int, float]

Custom timeout between 50 and 29,000 milliseconds.

The default value is 29,000 milliseconds or 29 seconds.

---

##### `tls_config`<sup>Optional</sup> <a name="tls_config" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.tlsConfig"></a>

```python
tls_config: ApiGatewayIntegrationTlsConfig
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegrationTlsConfig">ApiGatewayIntegrationTlsConfig</a>

Specifies the TLS configuration for an integration.

> [https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-extensions-integration-tls-config.html](https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-extensions-integration-tls-config.html)

---

##### `type`<sup>Optional</sup> <a name="type" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.type"></a>

```python
type: str
```

- *Type:* str

The type of integration with the specified backend.

> [https://docs.aws.amazon.com/apigateway/latest/api/API_Integration.html#type](https://docs.aws.amazon.com/apigateway/latest/api/API_Integration.html#type)

---

##### `uri`<sup>Optional</sup> <a name="uri" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.uri"></a>

```python
uri: str
```

- *Type:* str

The endpoint URI of the backend.

For integrations of the aws type, this is an ARN value.
For the HTTP integration, this is the URL of the HTTP endpoint including the https or http scheme.

---

### ApiGatewayIntegrationResponse <a name="ApiGatewayIntegrationResponse" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegrationResponse"></a>

API Gateway integration response.

> [https://docs.aws.amazon.com/apigateway/latest/api/API_Integration.html](https://docs.aws.amazon.com/apigateway/latest/api/API_Integration.html)

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegrationResponse.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.ApiGatewayIntegrationResponse(
  response_parameters: typing.Mapping[str],
  response_templates: typing.Mapping[str],
  status_code: str,
  content_handling: str = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegrationResponse.property.responseParameters">response_parameters</a></code> | <code>typing.Mapping[str]</code> | Specifies parameter mappings for the response. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegrationResponse.property.responseTemplates">response_templates</a></code> | <code>typing.Mapping[str]</code> | Specifies MIME type-specific mapping templates for the response’s payload. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegrationResponse.property.statusCode">status_code</a></code> | <code>str</code> | HTTP status code for the method response. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegrationResponse.property.contentHandling">content_handling</a></code> | <code>str</code> | Response payload encoding conversion types. |

---

##### `response_parameters`<sup>Required</sup> <a name="response_parameters" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegrationResponse.property.responseParameters"></a>

```python
response_parameters: typing.Mapping[str]
```

- *Type:* typing.Mapping[str]

Specifies parameter mappings for the response.

---

##### `response_templates`<sup>Required</sup> <a name="response_templates" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegrationResponse.property.responseTemplates"></a>

```python
response_templates: typing.Mapping[str]
```

- *Type:* typing.Mapping[str]

Specifies MIME type-specific mapping templates for the response’s payload.

---

##### `status_code`<sup>Required</sup> <a name="status_code" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegrationResponse.property.statusCode"></a>

```python
status_code: str
```

- *Type:* str

HTTP status code for the method response.

---

##### `content_handling`<sup>Optional</sup> <a name="content_handling" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegrationResponse.property.contentHandling"></a>

```python
content_handling: str
```

- *Type:* str

Response payload encoding conversion types.

Valid values are 1) CONVERT_TO_TEXT, for converting a binary payload
into a base64-encoded string or converting a text payload into a utf-8-encoded string or passing through the text
payload natively without modification, and 2) CONVERT_TO_BINARY, for converting a text payload into a
base64-decoded blob or passing through a binary payload natively without modification.

---

### ApiGatewayIntegrationTlsConfig <a name="ApiGatewayIntegrationTlsConfig" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegrationTlsConfig"></a>

Specifies the TLS configuration for an integration.

> [https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-extensions-integration-tls-config.html](https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-extensions-integration-tls-config.html)

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegrationTlsConfig.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.ApiGatewayIntegrationTlsConfig(
  insecure_skip_verification: bool = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegrationTlsConfig.property.insecureSkipVerification">insecure_skip_verification</a></code> | <code>bool</code> | Specifies whether or not API Gateway skips verification that the certificate for an integration endpoint is issued by a supported certificate authority. |

---

##### `insecure_skip_verification`<sup>Optional</sup> <a name="insecure_skip_verification" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegrationTlsConfig.property.insecureSkipVerification"></a>

```python
insecure_skip_verification: bool
```

- *Type:* bool

Specifies whether or not API Gateway skips verification that the certificate for an integration endpoint is issued by a supported certificate authority.

This isn’t recommended, but it enables you to use certificates that are
signed by private certificate authorities, or certificates that are self-signed. If enabled, API Gateway still
performs basic certificate validation, which includes checking the certificate's expiration date, hostname, and
presence of a root certificate authority. Supported only for HTTP and HTTP_PROXY integrations.

---

### ApiKeyOptions <a name="ApiKeyOptions" id="@aws-prototyping-sdk/type-safe-api.ApiKeyOptions"></a>

Options for API keys.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.ApiKeyOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.ApiKeyOptions(
  source: ApiKeySourceType,
  required_by_default: bool = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiKeyOptions.property.source">source</a></code> | <code>aws_cdk.aws_apigateway.ApiKeySourceType</code> | Source type for an API key. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiKeyOptions.property.requiredByDefault">required_by_default</a></code> | <code>bool</code> | Set to true to require an API key on all operations by default. |

---

##### `source`<sup>Required</sup> <a name="source" id="@aws-prototyping-sdk/type-safe-api.ApiKeyOptions.property.source"></a>

```python
source: ApiKeySourceType
```

- *Type:* aws_cdk.aws_apigateway.ApiKeySourceType

Source type for an API key.

---

##### `required_by_default`<sup>Optional</sup> <a name="required_by_default" id="@aws-prototyping-sdk/type-safe-api.ApiKeyOptions.property.requiredByDefault"></a>

```python
required_by_default: bool
```

- *Type:* bool

Set to true to require an API key on all operations by default.

Only applicable when the source is HEADER.

---

### AuthorizerProps <a name="AuthorizerProps" id="@aws-prototyping-sdk/type-safe-api.AuthorizerProps"></a>

Properties for an authorizer.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.AuthorizerProps.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.AuthorizerProps(
  authorization_type: AuthorizationType,
  authorizer_id: str,
  authorization_scopes: typing.List[str] = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.AuthorizerProps.property.authorizationType">authorization_type</a></code> | <code>aws_cdk.aws_apigateway.AuthorizationType</code> | The type of the authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.AuthorizerProps.property.authorizerId">authorizer_id</a></code> | <code>str</code> | The unique identifier for the authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.AuthorizerProps.property.authorizationScopes">authorization_scopes</a></code> | <code>typing.List[str]</code> | Scopes for the authorizer, if any. |

---

##### `authorization_type`<sup>Required</sup> <a name="authorization_type" id="@aws-prototyping-sdk/type-safe-api.AuthorizerProps.property.authorizationType"></a>

```python
authorization_type: AuthorizationType
```

- *Type:* aws_cdk.aws_apigateway.AuthorizationType

The type of the authorizer.

---

##### `authorizer_id`<sup>Required</sup> <a name="authorizer_id" id="@aws-prototyping-sdk/type-safe-api.AuthorizerProps.property.authorizerId"></a>

```python
authorizer_id: str
```

- *Type:* str

The unique identifier for the authorizer.

---

##### `authorization_scopes`<sup>Optional</sup> <a name="authorization_scopes" id="@aws-prototyping-sdk/type-safe-api.AuthorizerProps.property.authorizationScopes"></a>

```python
authorization_scopes: typing.List[str]
```

- *Type:* typing.List[str]

Scopes for the authorizer, if any.

---

### CidrAllowList <a name="CidrAllowList" id="@aws-prototyping-sdk/type-safe-api.CidrAllowList"></a>

Representation of a CIDR range.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.CidrAllowList.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.CidrAllowList(
  cidr_ranges: typing.List[str],
  cidr_type: str
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CidrAllowList.property.cidrRanges">cidr_ranges</a></code> | <code>typing.List[str]</code> | Specify an IPv4 address by using CIDR notation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CidrAllowList.property.cidrType">cidr_type</a></code> | <code>str</code> | Type of CIDR range. |

---

##### `cidr_ranges`<sup>Required</sup> <a name="cidr_ranges" id="@aws-prototyping-sdk/type-safe-api.CidrAllowList.property.cidrRanges"></a>

```python
cidr_ranges: typing.List[str]
```

- *Type:* typing.List[str]

Specify an IPv4 address by using CIDR notation.

For example:
To configure AWS WAF to allow, block, or count requests that originated from the IP address 192.0.2.44, specify 192.0.2.44/32 .
To configure AWS WAF to allow, block, or count requests that originated from IP addresses from 192.0.2.0 to 192.0.2.255, specify 192.0.2.0/24 .

For more information about CIDR notation, see the Wikipedia entry Classless Inter-Domain Routing .

Specify an IPv6 address by using CIDR notation. For example:
To configure AWS WAF to allow, block, or count requests that originated from the IP address 1111:0000:0000:0000:0000:0000:0000:0111, specify 1111:0000:0000:0000:0000:0000:0000:0111/128 .
To configure AWS WAF to allow, block, or count requests that originated from IP addresses 1111:0000:0000:0000:0000:0000:0000:0000 to 1111:0000:0000:0000:ffff:ffff:ffff:ffff, specify 1111:0000:0000:0000:0000:0000:0000:0000/64 .

---

##### `cidr_type`<sup>Required</sup> <a name="cidr_type" id="@aws-prototyping-sdk/type-safe-api.CidrAllowList.property.cidrType"></a>

```python
cidr_type: str
```

- *Type:* str

Type of CIDR range.

---

### CognitoAuthorizerProps <a name="CognitoAuthorizerProps" id="@aws-prototyping-sdk/type-safe-api.CognitoAuthorizerProps"></a>

Properties used to configure a cognito authorizer.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.CognitoAuthorizerProps.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.CognitoAuthorizerProps(
  authorizer_id: str,
  user_pools: typing.List[IUserPool],
  authorization_scopes: typing.List[str] = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CognitoAuthorizerProps.property.authorizerId">authorizer_id</a></code> | <code>str</code> | Unique identifier for this authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CognitoAuthorizerProps.property.userPools">user_pools</a></code> | <code>typing.List[aws_cdk.aws_cognito.IUserPool]</code> | The Cognito user pools associated with this authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CognitoAuthorizerProps.property.authorizationScopes">authorization_scopes</a></code> | <code>typing.List[str]</code> | A list of authorization scopes configured on the method. |

---

##### `authorizer_id`<sup>Required</sup> <a name="authorizer_id" id="@aws-prototyping-sdk/type-safe-api.CognitoAuthorizerProps.property.authorizerId"></a>

```python
authorizer_id: str
```

- *Type:* str

Unique identifier for this authorizer.

---

##### `user_pools`<sup>Required</sup> <a name="user_pools" id="@aws-prototyping-sdk/type-safe-api.CognitoAuthorizerProps.property.userPools"></a>

```python
user_pools: typing.List[IUserPool]
```

- *Type:* typing.List[aws_cdk.aws_cognito.IUserPool]

The Cognito user pools associated with this authorizer.

---

##### `authorization_scopes`<sup>Optional</sup> <a name="authorization_scopes" id="@aws-prototyping-sdk/type-safe-api.CognitoAuthorizerProps.property.authorizationScopes"></a>

```python
authorization_scopes: typing.List[str]
```

- *Type:* typing.List[str]
- *Default:* []

A list of authorization scopes configured on the method.

When used as the default authorizer, these scopes will be
applied to all methods without an authorizer at the integration level.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-method.html#cfn-apigateway-method-authorizationscopes](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-method.html#cfn-apigateway-method-authorizationscopes)

---

### CustomAuthorizerProps <a name="CustomAuthorizerProps" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizerProps"></a>

Properties used to configure a custom authorizer.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizerProps.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.CustomAuthorizerProps(
  authorizer_id: str,
  function: IFunction,
  authorizer_result_ttl_in_seconds: typing.Union[int, float] = None,
  identity_source: str = None,
  type: CustomAuthorizerType = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizerProps.property.authorizerId">authorizer_id</a></code> | <code>str</code> | Unique identifier for this authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizerProps.property.function">function</a></code> | <code>aws_cdk.aws_lambda.IFunction</code> | The lambda function used to authorize requests. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizerProps.property.authorizerResultTtlInSeconds">authorizer_result_ttl_in_seconds</a></code> | <code>typing.Union[int, float]</code> | The number of seconds during which the authorizer result is cached. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizerProps.property.identitySource">identity_source</a></code> | <code>str</code> | The source of the identity in an incoming request. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizerProps.property.type">type</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizerType">CustomAuthorizerType</a></code> | The type of custom authorizer. |

---

##### `authorizer_id`<sup>Required</sup> <a name="authorizer_id" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizerProps.property.authorizerId"></a>

```python
authorizer_id: str
```

- *Type:* str

Unique identifier for this authorizer.

---

##### `function`<sup>Required</sup> <a name="function" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizerProps.property.function"></a>

```python
function: IFunction
```

- *Type:* aws_cdk.aws_lambda.IFunction

The lambda function used to authorize requests.

---

##### `authorizer_result_ttl_in_seconds`<sup>Optional</sup> <a name="authorizer_result_ttl_in_seconds" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizerProps.property.authorizerResultTtlInSeconds"></a>

```python
authorizer_result_ttl_in_seconds: typing.Union[int, float]
```

- *Type:* typing.Union[int, float]
- *Default:* 300

The number of seconds during which the authorizer result is cached.

---

##### `identity_source`<sup>Optional</sup> <a name="identity_source" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizerProps.property.identitySource"></a>

```python
identity_source: str
```

- *Type:* str
- *Default:* "method.request.header.Authorization"

The source of the identity in an incoming request.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-authorizer.html#cfn-apigateway-authorizer-identitysource](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-authorizer.html#cfn-apigateway-authorizer-identitysource)

---

##### `type`<sup>Optional</sup> <a name="type" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizerProps.property.type"></a>

```python
type: CustomAuthorizerType
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizerType">CustomAuthorizerType</a>
- *Default:* CustomAuthorizerType.TOKEN

The type of custom authorizer.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-authorizer.html#cfn-apigateway-authorizer-type](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-authorizer.html#cfn-apigateway-authorizer-type)

---

### DocumentationConfiguration <a name="DocumentationConfiguration" id="@aws-prototyping-sdk/type-safe-api.DocumentationConfiguration"></a>

Configuration for generated documentation.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.DocumentationConfiguration.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.DocumentationConfiguration(
  formats: typing.List[DocumentationFormat],
  options: GeneratedDocumentationOptions = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.DocumentationConfiguration.property.formats">formats</a></code> | <code>typing.List[<a href="#@aws-prototyping-sdk/type-safe-api.DocumentationFormat">DocumentationFormat</a>]</code> | Formats for generated documentation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.DocumentationConfiguration.property.options">options</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedDocumentationOptions">GeneratedDocumentationOptions</a></code> | Options for the generated documentation projects. |

---

##### `formats`<sup>Required</sup> <a name="formats" id="@aws-prototyping-sdk/type-safe-api.DocumentationConfiguration.property.formats"></a>

```python
formats: typing.List[DocumentationFormat]
```

- *Type:* typing.List[<a href="#@aws-prototyping-sdk/type-safe-api.DocumentationFormat">DocumentationFormat</a>]

Formats for generated documentation.

---

##### `options`<sup>Optional</sup> <a name="options" id="@aws-prototyping-sdk/type-safe-api.DocumentationConfiguration.property.options"></a>

```python
options: GeneratedDocumentationOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.GeneratedDocumentationOptions">GeneratedDocumentationOptions</a>

Options for the generated documentation projects.

Note that only those provided for the specified formats will apply

---

### GeneratedCodeProjects <a name="GeneratedCodeProjects" id="@aws-prototyping-sdk/type-safe-api.GeneratedCodeProjects"></a>

Generated code projects.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.GeneratedCodeProjects.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.GeneratedCodeProjects(
  java: JavaProject = None,
  python: PythonProject = None,
  typescript: TypeScriptProject = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedCodeProjects.property.java">java</a></code> | <code>projen.java.JavaProject</code> | Generated java project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedCodeProjects.property.python">python</a></code> | <code>projen.python.PythonProject</code> | Generated python project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedCodeProjects.property.typescript">typescript</a></code> | <code>projen.typescript.TypeScriptProject</code> | Generated typescript project. |

---

##### `java`<sup>Optional</sup> <a name="java" id="@aws-prototyping-sdk/type-safe-api.GeneratedCodeProjects.property.java"></a>

```python
java: JavaProject
```

- *Type:* projen.java.JavaProject

Generated java project.

---

##### `python`<sup>Optional</sup> <a name="python" id="@aws-prototyping-sdk/type-safe-api.GeneratedCodeProjects.property.python"></a>

```python
python: PythonProject
```

- *Type:* projen.python.PythonProject

Generated python project.

---

##### `typescript`<sup>Optional</sup> <a name="typescript" id="@aws-prototyping-sdk/type-safe-api.GeneratedCodeProjects.property.typescript"></a>

```python
typescript: TypeScriptProject
```

- *Type:* projen.typescript.TypeScriptProject

Generated typescript project.

---

### GeneratedDocumentationOptions <a name="GeneratedDocumentationOptions" id="@aws-prototyping-sdk/type-safe-api.GeneratedDocumentationOptions"></a>

Options for generated documentation projects.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.GeneratedDocumentationOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.GeneratedDocumentationOptions(
  html2: GeneratedHtml2DocumentationOptions = None,
  html_redoc: GeneratedHtmlRedocDocumentationOptions = None,
  markdown: GeneratedMarkdownDocumentationOptions = None,
  plantuml: GeneratedPlantumlDocumentationOptions = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedDocumentationOptions.property.html2">html2</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedHtml2DocumentationOptions">GeneratedHtml2DocumentationOptions</a></code> | Generated html2 documentation project options. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedDocumentationOptions.property.htmlRedoc">html_redoc</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedHtmlRedocDocumentationOptions">GeneratedHtmlRedocDocumentationOptions</a></code> | Generated html redoc documentation project options. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedDocumentationOptions.property.markdown">markdown</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedMarkdownDocumentationOptions">GeneratedMarkdownDocumentationOptions</a></code> | Generated markdown documentation project options. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedDocumentationOptions.property.plantuml">plantuml</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPlantumlDocumentationOptions">GeneratedPlantumlDocumentationOptions</a></code> | Generated plantuml documentation project options. |

---

##### `html2`<sup>Optional</sup> <a name="html2" id="@aws-prototyping-sdk/type-safe-api.GeneratedDocumentationOptions.property.html2"></a>

```python
html2: GeneratedHtml2DocumentationOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.GeneratedHtml2DocumentationOptions">GeneratedHtml2DocumentationOptions</a>

Generated html2 documentation project options.

---

##### `html_redoc`<sup>Optional</sup> <a name="html_redoc" id="@aws-prototyping-sdk/type-safe-api.GeneratedDocumentationOptions.property.htmlRedoc"></a>

```python
html_redoc: GeneratedHtmlRedocDocumentationOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.GeneratedHtmlRedocDocumentationOptions">GeneratedHtmlRedocDocumentationOptions</a>

Generated html redoc documentation project options.

---

##### `markdown`<sup>Optional</sup> <a name="markdown" id="@aws-prototyping-sdk/type-safe-api.GeneratedDocumentationOptions.property.markdown"></a>

```python
markdown: GeneratedMarkdownDocumentationOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.GeneratedMarkdownDocumentationOptions">GeneratedMarkdownDocumentationOptions</a>

Generated markdown documentation project options.

---

##### `plantuml`<sup>Optional</sup> <a name="plantuml" id="@aws-prototyping-sdk/type-safe-api.GeneratedDocumentationOptions.property.plantuml"></a>

```python
plantuml: GeneratedPlantumlDocumentationOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPlantumlDocumentationOptions">GeneratedPlantumlDocumentationOptions</a>

Generated plantuml documentation project options.

---

### GeneratedDocumentationProjects <a name="GeneratedDocumentationProjects" id="@aws-prototyping-sdk/type-safe-api.GeneratedDocumentationProjects"></a>

Generated documentation project references.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.GeneratedDocumentationProjects.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.GeneratedDocumentationProjects(
  html2: Project = None,
  html_redoc: Project = None,
  markdown: Project = None,
  plantuml: Project = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedDocumentationProjects.property.html2">html2</a></code> | <code>projen.Project</code> | Generated html2 documentation project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedDocumentationProjects.property.htmlRedoc">html_redoc</a></code> | <code>projen.Project</code> | Generated html redoc documentation project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedDocumentationProjects.property.markdown">markdown</a></code> | <code>projen.Project</code> | Generated markdown documentation project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedDocumentationProjects.property.plantuml">plantuml</a></code> | <code>projen.Project</code> | Generated plantuml documentation project. |

---

##### `html2`<sup>Optional</sup> <a name="html2" id="@aws-prototyping-sdk/type-safe-api.GeneratedDocumentationProjects.property.html2"></a>

```python
html2: Project
```

- *Type:* projen.Project

Generated html2 documentation project.

---

##### `html_redoc`<sup>Optional</sup> <a name="html_redoc" id="@aws-prototyping-sdk/type-safe-api.GeneratedDocumentationProjects.property.htmlRedoc"></a>

```python
html_redoc: Project
```

- *Type:* projen.Project

Generated html redoc documentation project.

---

##### `markdown`<sup>Optional</sup> <a name="markdown" id="@aws-prototyping-sdk/type-safe-api.GeneratedDocumentationProjects.property.markdown"></a>

```python
markdown: Project
```

- *Type:* projen.Project

Generated markdown documentation project.

---

##### `plantuml`<sup>Optional</sup> <a name="plantuml" id="@aws-prototyping-sdk/type-safe-api.GeneratedDocumentationProjects.property.plantuml"></a>

```python
plantuml: Project
```

- *Type:* projen.Project

Generated plantuml documentation project.

---

### GeneratedHtml2DocumentationOptions <a name="GeneratedHtml2DocumentationOptions" id="@aws-prototyping-sdk/type-safe-api.GeneratedHtml2DocumentationOptions"></a>

Options for the html2 documentation project.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.GeneratedHtml2DocumentationOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.GeneratedHtml2DocumentationOptions(
  open_api_generator_cli_config: OpenApiGeneratorCliConfig = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedHtml2DocumentationOptions.property.openApiGeneratorCliConfig">open_api_generator_cli_config</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfig">OpenApiGeneratorCliConfig</a></code> | Configuration for the OpenAPI Generator CLI. |

---

##### `open_api_generator_cli_config`<sup>Optional</sup> <a name="open_api_generator_cli_config" id="@aws-prototyping-sdk/type-safe-api.GeneratedHtml2DocumentationOptions.property.openApiGeneratorCliConfig"></a>

```python
open_api_generator_cli_config: OpenApiGeneratorCliConfig
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfig">OpenApiGeneratorCliConfig</a>

Configuration for the OpenAPI Generator CLI.

Overrides default values if specified.

> [https://github.com/OpenAPITools/openapi-generator-cli#configuration](https://github.com/OpenAPITools/openapi-generator-cli#configuration)

---

### GeneratedHtmlRedocDocumentationOptions <a name="GeneratedHtmlRedocDocumentationOptions" id="@aws-prototyping-sdk/type-safe-api.GeneratedHtmlRedocDocumentationOptions"></a>

Options for the html redoc documentation project.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.GeneratedHtmlRedocDocumentationOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.GeneratedHtmlRedocDocumentationOptions(
  open_api_generator_cli_config: OpenApiGeneratorCliConfig = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedHtmlRedocDocumentationOptions.property.openApiGeneratorCliConfig">open_api_generator_cli_config</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfig">OpenApiGeneratorCliConfig</a></code> | Configuration for the OpenAPI Generator CLI. |

---

##### `open_api_generator_cli_config`<sup>Optional</sup> <a name="open_api_generator_cli_config" id="@aws-prototyping-sdk/type-safe-api.GeneratedHtmlRedocDocumentationOptions.property.openApiGeneratorCliConfig"></a>

```python
open_api_generator_cli_config: OpenApiGeneratorCliConfig
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfig">OpenApiGeneratorCliConfig</a>

Configuration for the OpenAPI Generator CLI.

Overrides default values if specified.

> [https://github.com/OpenAPITools/openapi-generator-cli#configuration](https://github.com/OpenAPITools/openapi-generator-cli#configuration)

---

### GeneratedInfrastructureCodeOptions <a name="GeneratedInfrastructureCodeOptions" id="@aws-prototyping-sdk/type-safe-api.GeneratedInfrastructureCodeOptions"></a>

Options for generated clients.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.GeneratedInfrastructureCodeOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.GeneratedInfrastructureCodeOptions(
  java: GeneratedJavaInfrastructureOptions = None,
  python: GeneratedPythonInfrastructureOptions = None,
  typescript: GeneratedTypeScriptInfrastructureOptions = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedInfrastructureCodeOptions.property.java">java</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions">GeneratedJavaInfrastructureOptions</a></code> | Options for the generated java infrastructure project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedInfrastructureCodeOptions.property.python">python</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions">GeneratedPythonInfrastructureOptions</a></code> | Options for the generated python infrastructure project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedInfrastructureCodeOptions.property.typescript">typescript</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions">GeneratedTypeScriptInfrastructureOptions</a></code> | Options for the generated typescript infrastructure project. |

---

##### `java`<sup>Optional</sup> <a name="java" id="@aws-prototyping-sdk/type-safe-api.GeneratedInfrastructureCodeOptions.property.java"></a>

```python
java: GeneratedJavaInfrastructureOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions">GeneratedJavaInfrastructureOptions</a>

Options for the generated java infrastructure project.

These override the default inferred options.

---

##### `python`<sup>Optional</sup> <a name="python" id="@aws-prototyping-sdk/type-safe-api.GeneratedInfrastructureCodeOptions.property.python"></a>

```python
python: GeneratedPythonInfrastructureOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions">GeneratedPythonInfrastructureOptions</a>

Options for the generated python infrastructure project.

These override the default inferred options.

---

##### `typescript`<sup>Optional</sup> <a name="typescript" id="@aws-prototyping-sdk/type-safe-api.GeneratedInfrastructureCodeOptions.property.typescript"></a>

```python
typescript: GeneratedTypeScriptInfrastructureOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions">GeneratedTypeScriptInfrastructureOptions</a>

Options for the generated typescript infrastructure project.

These override the default inferred options.

---

### GeneratedJavaInfrastructureOptions <a name="GeneratedJavaInfrastructureOptions" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions"></a>

Options for configuring a generated java infrastructure project.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.GeneratedJavaInfrastructureOptions(
  name: str,
  commit_generated: bool = None,
  git_ignore_options: IgnoreFileOptions = None,
  git_options: GitOptions = None,
  logging: LoggerOptions = None,
  outdir: str = None,
  parent: Project = None,
  projen_command: str = None,
  projenrc_json: bool = None,
  projenrc_json_options: ProjenrcJsonOptions = None,
  renovatebot: bool = None,
  renovatebot_options: RenovatebotOptions = None,
  auto_approve_options: AutoApproveOptions = None,
  auto_merge: bool = None,
  auto_merge_options: AutoMergeOptions = None,
  clobber: bool = None,
  dev_container: bool = None,
  github: bool = None,
  github_options: GitHubOptions = None,
  gitpod: bool = None,
  mergify: bool = None,
  mergify_options: MergifyOptions = None,
  project_type: ProjectType = None,
  projen_credentials: GithubCredentials = None,
  projen_token_secret: str = None,
  readme: SampleReadmeProps = None,
  stale: bool = None,
  stale_options: StaleOptions = None,
  vscode: bool = None,
  artifact_id: str,
  group_id: str,
  version: str,
  description: str = None,
  packaging: str = None,
  url: str = None,
  compile_options: MavenCompileOptions = None,
  deps: typing.List[str] = None,
  distdir: str = None,
  junit: bool = None,
  junit_options: JunitOptions = None,
  packaging_options: MavenPackagingOptions = None,
  projenrc_java: bool = None,
  projenrc_java_options: ProjenrcOptions = None,
  test_deps: typing.List[str] = None,
  sample: bool = None,
  sample_java_package: str = None,
  open_api_generator_cli_config: OpenApiGeneratorCliConfig = None,
  mock_data_options: MockResponseDataGenerationOptions = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.name">name</a></code> | <code>str</code> | This is the name of your project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.commitGenerated">commit_generated</a></code> | <code>bool</code> | Whether to commit the managed files by default. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.gitIgnoreOptions">git_ignore_options</a></code> | <code>projen.IgnoreFileOptions</code> | Configuration options for .gitignore file. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.gitOptions">git_options</a></code> | <code>projen.GitOptions</code> | Configuration options for git. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.logging">logging</a></code> | <code>projen.LoggerOptions</code> | Configure logging options such as verbosity. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.outdir">outdir</a></code> | <code>str</code> | The root directory of the project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.parent">parent</a></code> | <code>projen.Project</code> | The parent project, if this project is part of a bigger project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.projenCommand">projen_command</a></code> | <code>str</code> | The shell command to use in order to run the projen CLI. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.projenrcJson">projenrc_json</a></code> | <code>bool</code> | Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.projenrcJsonOptions">projenrc_json_options</a></code> | <code>projen.ProjenrcJsonOptions</code> | Options for .projenrc.json. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.renovatebot">renovatebot</a></code> | <code>bool</code> | Use renovatebot to handle dependency upgrades. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.renovatebotOptions">renovatebot_options</a></code> | <code>projen.RenovatebotOptions</code> | Options for renovatebot. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.autoApproveOptions">auto_approve_options</a></code> | <code>projen.github.AutoApproveOptions</code> | Enable and configure the 'auto approve' workflow. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.autoMerge">auto_merge</a></code> | <code>bool</code> | Enable automatic merging on GitHub. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.autoMergeOptions">auto_merge_options</a></code> | <code>projen.github.AutoMergeOptions</code> | Configure options for automatic merging on GitHub. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.clobber">clobber</a></code> | <code>bool</code> | Add a `clobber` task which resets the repo to origin. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.devContainer">dev_container</a></code> | <code>bool</code> | Add a VSCode development environment (used for GitHub Codespaces). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.github">github</a></code> | <code>bool</code> | Enable GitHub integration. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.githubOptions">github_options</a></code> | <code>projen.github.GitHubOptions</code> | Options for GitHub integration. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.gitpod">gitpod</a></code> | <code>bool</code> | Add a Gitpod development environment. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.mergify">mergify</a></code> | <code>bool</code> | Whether mergify should be enabled on this repository or not. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.mergifyOptions">mergify_options</a></code> | <code>projen.github.MergifyOptions</code> | Options for mergify. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.projectType">project_type</a></code> | <code>projen.ProjectType</code> | Which type of project this is (library/app). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.projenCredentials">projen_credentials</a></code> | <code>projen.github.GithubCredentials</code> | Choose a method of providing GitHub API access for projen workflows. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.projenTokenSecret">projen_token_secret</a></code> | <code>str</code> | The name of a secret which includes a GitHub Personal Access Token to be used by projen workflows. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.readme">readme</a></code> | <code>projen.SampleReadmeProps</code> | The README setup. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.stale">stale</a></code> | <code>bool</code> | Auto-close of stale issues and pull request. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.staleOptions">stale_options</a></code> | <code>projen.github.StaleOptions</code> | Auto-close stale issues and pull requests. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.vscode">vscode</a></code> | <code>bool</code> | Enable VSCode integration. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.artifactId">artifact_id</a></code> | <code>str</code> | The artifactId is generally the name that the project is known by. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.groupId">group_id</a></code> | <code>str</code> | This is generally unique amongst an organization or a project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.version">version</a></code> | <code>str</code> | This is the last piece of the naming puzzle. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.description">description</a></code> | <code>str</code> | Description of a project is always good. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.packaging">packaging</a></code> | <code>str</code> | Project packaging format. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.url">url</a></code> | <code>str</code> | The URL, like the name, is not required. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.compileOptions">compile_options</a></code> | <code>projen.java.MavenCompileOptions</code> | Compile options. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.deps">deps</a></code> | <code>typing.List[str]</code> | List of runtime dependencies for this project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.distdir">distdir</a></code> | <code>str</code> | Final artifact output directory. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.junit">junit</a></code> | <code>bool</code> | Include junit tests. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.junitOptions">junit_options</a></code> | <code>projen.java.JunitOptions</code> | junit options. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.packagingOptions">packaging_options</a></code> | <code>projen.java.MavenPackagingOptions</code> | Packaging options. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.projenrcJava">projenrc_java</a></code> | <code>bool</code> | Use projenrc in java. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.projenrcJavaOptions">projenrc_java_options</a></code> | <code>projen.java.ProjenrcOptions</code> | Options related to projenrc in java. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.testDeps">test_deps</a></code> | <code>typing.List[str]</code> | List of test dependencies for this project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.sample">sample</a></code> | <code>bool</code> | Include sample code and test if the relevant directories don't exist. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.sampleJavaPackage">sample_java_package</a></code> | <code>str</code> | The java package to use for the code sample. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.openApiGeneratorCliConfig">open_api_generator_cli_config</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfig">OpenApiGeneratorCliConfig</a></code> | Configuration for the OpenAPI Generator CLI. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.mockDataOptions">mock_data_options</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.MockResponseDataGenerationOptions">MockResponseDataGenerationOptions</a></code> | Options for the generated mock response data. |

---

##### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.name"></a>

```python
name: str
```

- *Type:* str
- *Default:* $BASEDIR

This is the name of your project.

---

##### `commit_generated`<sup>Optional</sup> <a name="commit_generated" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.commitGenerated"></a>

```python
commit_generated: bool
```

- *Type:* bool
- *Default:* true

Whether to commit the managed files by default.

---

##### `git_ignore_options`<sup>Optional</sup> <a name="git_ignore_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.gitIgnoreOptions"></a>

```python
git_ignore_options: IgnoreFileOptions
```

- *Type:* projen.IgnoreFileOptions

Configuration options for .gitignore file.

---

##### `git_options`<sup>Optional</sup> <a name="git_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.gitOptions"></a>

```python
git_options: GitOptions
```

- *Type:* projen.GitOptions

Configuration options for git.

---

##### `logging`<sup>Optional</sup> <a name="logging" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.logging"></a>

```python
logging: LoggerOptions
```

- *Type:* projen.LoggerOptions
- *Default:* {}

Configure logging options such as verbosity.

---

##### `outdir`<sup>Optional</sup> <a name="outdir" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.outdir"></a>

```python
outdir: str
```

- *Type:* str
- *Default:* "."

The root directory of the project.

Relative to this directory, all files are synthesized.

If this project has a parent, this directory is relative to the parent
directory and it cannot be the same as the parent or any of it's other
sub-projects.

---

##### `parent`<sup>Optional</sup> <a name="parent" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.parent"></a>

```python
parent: Project
```

- *Type:* projen.Project

The parent project, if this project is part of a bigger project.

---

##### `projen_command`<sup>Optional</sup> <a name="projen_command" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.projenCommand"></a>

```python
projen_command: str
```

- *Type:* str
- *Default:* "npx projen"

The shell command to use in order to run the projen CLI.

Can be used to customize in special environments.

---

##### `projenrc_json`<sup>Optional</sup> <a name="projenrc_json" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.projenrcJson"></a>

```python
projenrc_json: bool
```

- *Type:* bool
- *Default:* false

Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation.

---

##### `projenrc_json_options`<sup>Optional</sup> <a name="projenrc_json_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.projenrcJsonOptions"></a>

```python
projenrc_json_options: ProjenrcJsonOptions
```

- *Type:* projen.ProjenrcJsonOptions
- *Default:* default options

Options for .projenrc.json.

---

##### `renovatebot`<sup>Optional</sup> <a name="renovatebot" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.renovatebot"></a>

```python
renovatebot: bool
```

- *Type:* bool
- *Default:* false

Use renovatebot to handle dependency upgrades.

---

##### `renovatebot_options`<sup>Optional</sup> <a name="renovatebot_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.renovatebotOptions"></a>

```python
renovatebot_options: RenovatebotOptions
```

- *Type:* projen.RenovatebotOptions
- *Default:* default options

Options for renovatebot.

---

##### `auto_approve_options`<sup>Optional</sup> <a name="auto_approve_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.autoApproveOptions"></a>

```python
auto_approve_options: AutoApproveOptions
```

- *Type:* projen.github.AutoApproveOptions
- *Default:* auto approve is disabled

Enable and configure the 'auto approve' workflow.

---

##### `auto_merge`<sup>Optional</sup> <a name="auto_merge" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.autoMerge"></a>

```python
auto_merge: bool
```

- *Type:* bool
- *Default:* true

Enable automatic merging on GitHub.

Has no effect if `github.mergify`
is set to false.

---

##### `auto_merge_options`<sup>Optional</sup> <a name="auto_merge_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.autoMergeOptions"></a>

```python
auto_merge_options: AutoMergeOptions
```

- *Type:* projen.github.AutoMergeOptions
- *Default:* see defaults in `AutoMergeOptions`

Configure options for automatic merging on GitHub.

Has no effect if
`github.mergify` or `autoMerge` is set to false.

---

##### `clobber`<sup>Optional</sup> <a name="clobber" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.clobber"></a>

```python
clobber: bool
```

- *Type:* bool
- *Default:* true, but false for subprojects

Add a `clobber` task which resets the repo to origin.

---

##### `dev_container`<sup>Optional</sup> <a name="dev_container" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.devContainer"></a>

```python
dev_container: bool
```

- *Type:* bool
- *Default:* false

Add a VSCode development environment (used for GitHub Codespaces).

---

##### `github`<sup>Optional</sup> <a name="github" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.github"></a>

```python
github: bool
```

- *Type:* bool
- *Default:* true

Enable GitHub integration.

Enabled by default for root projects. Disabled for non-root projects.

---

##### `github_options`<sup>Optional</sup> <a name="github_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.githubOptions"></a>

```python
github_options: GitHubOptions
```

- *Type:* projen.github.GitHubOptions
- *Default:* see GitHubOptions

Options for GitHub integration.

---

##### `gitpod`<sup>Optional</sup> <a name="gitpod" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.gitpod"></a>

```python
gitpod: bool
```

- *Type:* bool
- *Default:* false

Add a Gitpod development environment.

---

##### ~~`mergify`~~<sup>Optional</sup> <a name="mergify" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.mergify"></a>

- *Deprecated:* use `githubOptions.mergify` instead

```python
mergify: bool
```

- *Type:* bool
- *Default:* true

Whether mergify should be enabled on this repository or not.

---

##### ~~`mergify_options`~~<sup>Optional</sup> <a name="mergify_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.mergifyOptions"></a>

- *Deprecated:* use `githubOptions.mergifyOptions` instead

```python
mergify_options: MergifyOptions
```

- *Type:* projen.github.MergifyOptions
- *Default:* default options

Options for mergify.

---

##### ~~`project_type`~~<sup>Optional</sup> <a name="project_type" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.projectType"></a>

- *Deprecated:* no longer supported at the base project level

```python
project_type: ProjectType
```

- *Type:* projen.ProjectType
- *Default:* ProjectType.UNKNOWN

Which type of project this is (library/app).

---

##### `projen_credentials`<sup>Optional</sup> <a name="projen_credentials" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.projenCredentials"></a>

```python
projen_credentials: GithubCredentials
```

- *Type:* projen.github.GithubCredentials
- *Default:* use a personal access token named PROJEN_GITHUB_TOKEN

Choose a method of providing GitHub API access for projen workflows.

---

##### ~~`projen_token_secret`~~<sup>Optional</sup> <a name="projen_token_secret" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.projenTokenSecret"></a>

- *Deprecated:* use `projenCredentials`

```python
projen_token_secret: str
```

- *Type:* str
- *Default:* "PROJEN_GITHUB_TOKEN"

The name of a secret which includes a GitHub Personal Access Token to be used by projen workflows.

This token needs to have the `repo`, `workflows`
and `packages` scope.

---

##### `readme`<sup>Optional</sup> <a name="readme" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.readme"></a>

```python
readme: SampleReadmeProps
```

- *Type:* projen.SampleReadmeProps
- *Default:* { filename: 'README.md', contents: '# replace this' }

The README setup.

---

*Example*

```python
"{ filename: 'readme.md', contents: '# title' }"
```


##### `stale`<sup>Optional</sup> <a name="stale" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.stale"></a>

```python
stale: bool
```

- *Type:* bool
- *Default:* false

Auto-close of stale issues and pull request.

See `staleOptions` for options.

---

##### `stale_options`<sup>Optional</sup> <a name="stale_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.staleOptions"></a>

```python
stale_options: StaleOptions
```

- *Type:* projen.github.StaleOptions
- *Default:* see defaults in `StaleOptions`

Auto-close stale issues and pull requests.

To disable set `stale` to `false`.

---

##### `vscode`<sup>Optional</sup> <a name="vscode" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.vscode"></a>

```python
vscode: bool
```

- *Type:* bool
- *Default:* true

Enable VSCode integration.

Enabled by default for root projects. Disabled for non-root projects.

---

##### `artifact_id`<sup>Required</sup> <a name="artifact_id" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.artifactId"></a>

```python
artifact_id: str
```

- *Type:* str
- *Default:* "my-app"

The artifactId is generally the name that the project is known by.

Although
the groupId is important, people within the group will rarely mention the
groupId in discussion (they are often all be the same ID, such as the
MojoHaus project groupId: org.codehaus.mojo). It, along with the groupId,
creates a key that separates this project from every other project in the
world (at least, it should :) ). Along with the groupId, the artifactId
fully defines the artifact's living quarters within the repository. In the
case of the above project, my-project lives in
$M2_REPO/org/codehaus/mojo/my-project.

---

##### `group_id`<sup>Required</sup> <a name="group_id" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.groupId"></a>

```python
group_id: str
```

- *Type:* str
- *Default:* "org.acme"

This is generally unique amongst an organization or a project.

For example,
all core Maven artifacts do (well, should) live under the groupId
org.apache.maven. Group ID's do not necessarily use the dot notation, for
example, the junit project. Note that the dot-notated groupId does not have
to correspond to the package structure that the project contains. It is,
however, a good practice to follow. When stored within a repository, the
group acts much like the Java packaging structure does in an operating
system. The dots are replaced by OS specific directory separators (such as
'/' in Unix) which becomes a relative directory structure from the base
repository. In the example given, the org.codehaus.mojo group lives within
the directory $M2_REPO/org/codehaus/mojo.

---

##### `version`<sup>Required</sup> <a name="version" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.version"></a>

```python
version: str
```

- *Type:* str
- *Default:* "0.1.0"

This is the last piece of the naming puzzle.

groupId:artifactId denotes a
single project but they cannot delineate which incarnation of that project
we are talking about. Do we want the junit:junit of 2018 (version 4.12), or
of 2007 (version 3.8.2)? In short: code changes, those changes should be
versioned, and this element keeps those versions in line. It is also used
within an artifact's repository to separate versions from each other.
my-project version 1.0 files live in the directory structure
$M2_REPO/org/codehaus/mojo/my-project/1.0.

---

##### `description`<sup>Optional</sup> <a name="description" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.description"></a>

```python
description: str
```

- *Type:* str
- *Default:* undefined

Description of a project is always good.

Although this should not replace
formal documentation, a quick comment to any readers of the POM is always
helpful.

---

##### `packaging`<sup>Optional</sup> <a name="packaging" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.packaging"></a>

```python
packaging: str
```

- *Type:* str
- *Default:* "jar"

Project packaging format.

---

##### `url`<sup>Optional</sup> <a name="url" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.url"></a>

```python
url: str
```

- *Type:* str
- *Default:* undefined

The URL, like the name, is not required.

This is a nice gesture for
projects users, however, so that they know where the project lives.

---

##### `compile_options`<sup>Optional</sup> <a name="compile_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.compileOptions"></a>

```python
compile_options: MavenCompileOptions
```

- *Type:* projen.java.MavenCompileOptions
- *Default:* defaults

Compile options.

---

##### `deps`<sup>Optional</sup> <a name="deps" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.deps"></a>

```python
deps: typing.List[str]
```

- *Type:* typing.List[str]
- *Default:* []

List of runtime dependencies for this project.

Dependencies use the format: `<groupId>/<artifactId>@<semver>`

Additional dependencies can be added via `project.addDependency()`.

---

##### `distdir`<sup>Optional</sup> <a name="distdir" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.distdir"></a>

```python
distdir: str
```

- *Type:* str
- *Default:* "dist/java"

Final artifact output directory.

---

##### `junit`<sup>Optional</sup> <a name="junit" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.junit"></a>

```python
junit: bool
```

- *Type:* bool
- *Default:* true

Include junit tests.

---

##### `junit_options`<sup>Optional</sup> <a name="junit_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.junitOptions"></a>

```python
junit_options: JunitOptions
```

- *Type:* projen.java.JunitOptions
- *Default:* defaults

junit options.

---

##### `packaging_options`<sup>Optional</sup> <a name="packaging_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.packagingOptions"></a>

```python
packaging_options: MavenPackagingOptions
```

- *Type:* projen.java.MavenPackagingOptions
- *Default:* defaults

Packaging options.

---

##### `projenrc_java`<sup>Optional</sup> <a name="projenrc_java" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.projenrcJava"></a>

```python
projenrc_java: bool
```

- *Type:* bool
- *Default:* true

Use projenrc in java.

This will install `projen` as a java dependency and will add a `synth` task which
will compile & execute `main()` from `src/main/java/projenrc.java`.

---

##### `projenrc_java_options`<sup>Optional</sup> <a name="projenrc_java_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.projenrcJavaOptions"></a>

```python
projenrc_java_options: ProjenrcOptions
```

- *Type:* projen.java.ProjenrcOptions
- *Default:* default options

Options related to projenrc in java.

---

##### `test_deps`<sup>Optional</sup> <a name="test_deps" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.testDeps"></a>

```python
test_deps: typing.List[str]
```

- *Type:* typing.List[str]
- *Default:* []

List of test dependencies for this project.

Dependencies use the format: `<groupId>/<artifactId>@<semver>`

Additional dependencies can be added via `project.addTestDependency()`.

---

##### `sample`<sup>Optional</sup> <a name="sample" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.sample"></a>

```python
sample: bool
```

- *Type:* bool
- *Default:* true

Include sample code and test if the relevant directories don't exist.

---

##### `sample_java_package`<sup>Optional</sup> <a name="sample_java_package" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.sampleJavaPackage"></a>

```python
sample_java_package: str
```

- *Type:* str
- *Default:* "org.acme"

The java package to use for the code sample.

---

##### `open_api_generator_cli_config`<sup>Optional</sup> <a name="open_api_generator_cli_config" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.openApiGeneratorCliConfig"></a>

```python
open_api_generator_cli_config: OpenApiGeneratorCliConfig
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfig">OpenApiGeneratorCliConfig</a>

Configuration for the OpenAPI Generator CLI.

Overrides default values if specified.

> [https://github.com/OpenAPITools/openapi-generator-cli#configuration](https://github.com/OpenAPITools/openapi-generator-cli#configuration)

---

##### `mock_data_options`<sup>Optional</sup> <a name="mock_data_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaInfrastructureOptions.property.mockDataOptions"></a>

```python
mock_data_options: MockResponseDataGenerationOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.MockResponseDataGenerationOptions">MockResponseDataGenerationOptions</a>

Options for the generated mock response data.

---

### GeneratedJavaRuntimeOptions <a name="GeneratedJavaRuntimeOptions" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions"></a>

Options for configuring a generated java runtime project.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.GeneratedJavaRuntimeOptions(
  name: str,
  commit_generated: bool = None,
  git_ignore_options: IgnoreFileOptions = None,
  git_options: GitOptions = None,
  logging: LoggerOptions = None,
  outdir: str = None,
  parent: Project = None,
  projen_command: str = None,
  projenrc_json: bool = None,
  projenrc_json_options: ProjenrcJsonOptions = None,
  renovatebot: bool = None,
  renovatebot_options: RenovatebotOptions = None,
  auto_approve_options: AutoApproveOptions = None,
  auto_merge: bool = None,
  auto_merge_options: AutoMergeOptions = None,
  clobber: bool = None,
  dev_container: bool = None,
  github: bool = None,
  github_options: GitHubOptions = None,
  gitpod: bool = None,
  mergify: bool = None,
  mergify_options: MergifyOptions = None,
  project_type: ProjectType = None,
  projen_credentials: GithubCredentials = None,
  projen_token_secret: str = None,
  readme: SampleReadmeProps = None,
  stale: bool = None,
  stale_options: StaleOptions = None,
  vscode: bool = None,
  artifact_id: str,
  group_id: str,
  version: str,
  description: str = None,
  packaging: str = None,
  url: str = None,
  compile_options: MavenCompileOptions = None,
  deps: typing.List[str] = None,
  distdir: str = None,
  junit: bool = None,
  junit_options: JunitOptions = None,
  packaging_options: MavenPackagingOptions = None,
  projenrc_java: bool = None,
  projenrc_java_options: ProjenrcOptions = None,
  test_deps: typing.List[str] = None,
  sample: bool = None,
  sample_java_package: str = None,
  open_api_generator_cli_config: OpenApiGeneratorCliConfig = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.name">name</a></code> | <code>str</code> | This is the name of your project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.commitGenerated">commit_generated</a></code> | <code>bool</code> | Whether to commit the managed files by default. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.gitIgnoreOptions">git_ignore_options</a></code> | <code>projen.IgnoreFileOptions</code> | Configuration options for .gitignore file. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.gitOptions">git_options</a></code> | <code>projen.GitOptions</code> | Configuration options for git. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.logging">logging</a></code> | <code>projen.LoggerOptions</code> | Configure logging options such as verbosity. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.outdir">outdir</a></code> | <code>str</code> | The root directory of the project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.parent">parent</a></code> | <code>projen.Project</code> | The parent project, if this project is part of a bigger project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.projenCommand">projen_command</a></code> | <code>str</code> | The shell command to use in order to run the projen CLI. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.projenrcJson">projenrc_json</a></code> | <code>bool</code> | Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.projenrcJsonOptions">projenrc_json_options</a></code> | <code>projen.ProjenrcJsonOptions</code> | Options for .projenrc.json. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.renovatebot">renovatebot</a></code> | <code>bool</code> | Use renovatebot to handle dependency upgrades. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.renovatebotOptions">renovatebot_options</a></code> | <code>projen.RenovatebotOptions</code> | Options for renovatebot. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.autoApproveOptions">auto_approve_options</a></code> | <code>projen.github.AutoApproveOptions</code> | Enable and configure the 'auto approve' workflow. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.autoMerge">auto_merge</a></code> | <code>bool</code> | Enable automatic merging on GitHub. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.autoMergeOptions">auto_merge_options</a></code> | <code>projen.github.AutoMergeOptions</code> | Configure options for automatic merging on GitHub. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.clobber">clobber</a></code> | <code>bool</code> | Add a `clobber` task which resets the repo to origin. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.devContainer">dev_container</a></code> | <code>bool</code> | Add a VSCode development environment (used for GitHub Codespaces). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.github">github</a></code> | <code>bool</code> | Enable GitHub integration. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.githubOptions">github_options</a></code> | <code>projen.github.GitHubOptions</code> | Options for GitHub integration. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.gitpod">gitpod</a></code> | <code>bool</code> | Add a Gitpod development environment. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.mergify">mergify</a></code> | <code>bool</code> | Whether mergify should be enabled on this repository or not. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.mergifyOptions">mergify_options</a></code> | <code>projen.github.MergifyOptions</code> | Options for mergify. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.projectType">project_type</a></code> | <code>projen.ProjectType</code> | Which type of project this is (library/app). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.projenCredentials">projen_credentials</a></code> | <code>projen.github.GithubCredentials</code> | Choose a method of providing GitHub API access for projen workflows. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.projenTokenSecret">projen_token_secret</a></code> | <code>str</code> | The name of a secret which includes a GitHub Personal Access Token to be used by projen workflows. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.readme">readme</a></code> | <code>projen.SampleReadmeProps</code> | The README setup. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.stale">stale</a></code> | <code>bool</code> | Auto-close of stale issues and pull request. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.staleOptions">stale_options</a></code> | <code>projen.github.StaleOptions</code> | Auto-close stale issues and pull requests. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.vscode">vscode</a></code> | <code>bool</code> | Enable VSCode integration. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.artifactId">artifact_id</a></code> | <code>str</code> | The artifactId is generally the name that the project is known by. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.groupId">group_id</a></code> | <code>str</code> | This is generally unique amongst an organization or a project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.version">version</a></code> | <code>str</code> | This is the last piece of the naming puzzle. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.description">description</a></code> | <code>str</code> | Description of a project is always good. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.packaging">packaging</a></code> | <code>str</code> | Project packaging format. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.url">url</a></code> | <code>str</code> | The URL, like the name, is not required. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.compileOptions">compile_options</a></code> | <code>projen.java.MavenCompileOptions</code> | Compile options. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.deps">deps</a></code> | <code>typing.List[str]</code> | List of runtime dependencies for this project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.distdir">distdir</a></code> | <code>str</code> | Final artifact output directory. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.junit">junit</a></code> | <code>bool</code> | Include junit tests. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.junitOptions">junit_options</a></code> | <code>projen.java.JunitOptions</code> | junit options. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.packagingOptions">packaging_options</a></code> | <code>projen.java.MavenPackagingOptions</code> | Packaging options. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.projenrcJava">projenrc_java</a></code> | <code>bool</code> | Use projenrc in java. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.projenrcJavaOptions">projenrc_java_options</a></code> | <code>projen.java.ProjenrcOptions</code> | Options related to projenrc in java. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.testDeps">test_deps</a></code> | <code>typing.List[str]</code> | List of test dependencies for this project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.sample">sample</a></code> | <code>bool</code> | Include sample code and test if the relevant directories don't exist. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.sampleJavaPackage">sample_java_package</a></code> | <code>str</code> | The java package to use for the code sample. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.openApiGeneratorCliConfig">open_api_generator_cli_config</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfig">OpenApiGeneratorCliConfig</a></code> | Configuration for the OpenAPI Generator CLI. |

---

##### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.name"></a>

```python
name: str
```

- *Type:* str
- *Default:* $BASEDIR

This is the name of your project.

---

##### `commit_generated`<sup>Optional</sup> <a name="commit_generated" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.commitGenerated"></a>

```python
commit_generated: bool
```

- *Type:* bool
- *Default:* true

Whether to commit the managed files by default.

---

##### `git_ignore_options`<sup>Optional</sup> <a name="git_ignore_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.gitIgnoreOptions"></a>

```python
git_ignore_options: IgnoreFileOptions
```

- *Type:* projen.IgnoreFileOptions

Configuration options for .gitignore file.

---

##### `git_options`<sup>Optional</sup> <a name="git_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.gitOptions"></a>

```python
git_options: GitOptions
```

- *Type:* projen.GitOptions

Configuration options for git.

---

##### `logging`<sup>Optional</sup> <a name="logging" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.logging"></a>

```python
logging: LoggerOptions
```

- *Type:* projen.LoggerOptions
- *Default:* {}

Configure logging options such as verbosity.

---

##### `outdir`<sup>Optional</sup> <a name="outdir" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.outdir"></a>

```python
outdir: str
```

- *Type:* str
- *Default:* "."

The root directory of the project.

Relative to this directory, all files are synthesized.

If this project has a parent, this directory is relative to the parent
directory and it cannot be the same as the parent or any of it's other
sub-projects.

---

##### `parent`<sup>Optional</sup> <a name="parent" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.parent"></a>

```python
parent: Project
```

- *Type:* projen.Project

The parent project, if this project is part of a bigger project.

---

##### `projen_command`<sup>Optional</sup> <a name="projen_command" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.projenCommand"></a>

```python
projen_command: str
```

- *Type:* str
- *Default:* "npx projen"

The shell command to use in order to run the projen CLI.

Can be used to customize in special environments.

---

##### `projenrc_json`<sup>Optional</sup> <a name="projenrc_json" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.projenrcJson"></a>

```python
projenrc_json: bool
```

- *Type:* bool
- *Default:* false

Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation.

---

##### `projenrc_json_options`<sup>Optional</sup> <a name="projenrc_json_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.projenrcJsonOptions"></a>

```python
projenrc_json_options: ProjenrcJsonOptions
```

- *Type:* projen.ProjenrcJsonOptions
- *Default:* default options

Options for .projenrc.json.

---

##### `renovatebot`<sup>Optional</sup> <a name="renovatebot" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.renovatebot"></a>

```python
renovatebot: bool
```

- *Type:* bool
- *Default:* false

Use renovatebot to handle dependency upgrades.

---

##### `renovatebot_options`<sup>Optional</sup> <a name="renovatebot_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.renovatebotOptions"></a>

```python
renovatebot_options: RenovatebotOptions
```

- *Type:* projen.RenovatebotOptions
- *Default:* default options

Options for renovatebot.

---

##### `auto_approve_options`<sup>Optional</sup> <a name="auto_approve_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.autoApproveOptions"></a>

```python
auto_approve_options: AutoApproveOptions
```

- *Type:* projen.github.AutoApproveOptions
- *Default:* auto approve is disabled

Enable and configure the 'auto approve' workflow.

---

##### `auto_merge`<sup>Optional</sup> <a name="auto_merge" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.autoMerge"></a>

```python
auto_merge: bool
```

- *Type:* bool
- *Default:* true

Enable automatic merging on GitHub.

Has no effect if `github.mergify`
is set to false.

---

##### `auto_merge_options`<sup>Optional</sup> <a name="auto_merge_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.autoMergeOptions"></a>

```python
auto_merge_options: AutoMergeOptions
```

- *Type:* projen.github.AutoMergeOptions
- *Default:* see defaults in `AutoMergeOptions`

Configure options for automatic merging on GitHub.

Has no effect if
`github.mergify` or `autoMerge` is set to false.

---

##### `clobber`<sup>Optional</sup> <a name="clobber" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.clobber"></a>

```python
clobber: bool
```

- *Type:* bool
- *Default:* true, but false for subprojects

Add a `clobber` task which resets the repo to origin.

---

##### `dev_container`<sup>Optional</sup> <a name="dev_container" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.devContainer"></a>

```python
dev_container: bool
```

- *Type:* bool
- *Default:* false

Add a VSCode development environment (used for GitHub Codespaces).

---

##### `github`<sup>Optional</sup> <a name="github" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.github"></a>

```python
github: bool
```

- *Type:* bool
- *Default:* true

Enable GitHub integration.

Enabled by default for root projects. Disabled for non-root projects.

---

##### `github_options`<sup>Optional</sup> <a name="github_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.githubOptions"></a>

```python
github_options: GitHubOptions
```

- *Type:* projen.github.GitHubOptions
- *Default:* see GitHubOptions

Options for GitHub integration.

---

##### `gitpod`<sup>Optional</sup> <a name="gitpod" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.gitpod"></a>

```python
gitpod: bool
```

- *Type:* bool
- *Default:* false

Add a Gitpod development environment.

---

##### ~~`mergify`~~<sup>Optional</sup> <a name="mergify" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.mergify"></a>

- *Deprecated:* use `githubOptions.mergify` instead

```python
mergify: bool
```

- *Type:* bool
- *Default:* true

Whether mergify should be enabled on this repository or not.

---

##### ~~`mergify_options`~~<sup>Optional</sup> <a name="mergify_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.mergifyOptions"></a>

- *Deprecated:* use `githubOptions.mergifyOptions` instead

```python
mergify_options: MergifyOptions
```

- *Type:* projen.github.MergifyOptions
- *Default:* default options

Options for mergify.

---

##### ~~`project_type`~~<sup>Optional</sup> <a name="project_type" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.projectType"></a>

- *Deprecated:* no longer supported at the base project level

```python
project_type: ProjectType
```

- *Type:* projen.ProjectType
- *Default:* ProjectType.UNKNOWN

Which type of project this is (library/app).

---

##### `projen_credentials`<sup>Optional</sup> <a name="projen_credentials" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.projenCredentials"></a>

```python
projen_credentials: GithubCredentials
```

- *Type:* projen.github.GithubCredentials
- *Default:* use a personal access token named PROJEN_GITHUB_TOKEN

Choose a method of providing GitHub API access for projen workflows.

---

##### ~~`projen_token_secret`~~<sup>Optional</sup> <a name="projen_token_secret" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.projenTokenSecret"></a>

- *Deprecated:* use `projenCredentials`

```python
projen_token_secret: str
```

- *Type:* str
- *Default:* "PROJEN_GITHUB_TOKEN"

The name of a secret which includes a GitHub Personal Access Token to be used by projen workflows.

This token needs to have the `repo`, `workflows`
and `packages` scope.

---

##### `readme`<sup>Optional</sup> <a name="readme" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.readme"></a>

```python
readme: SampleReadmeProps
```

- *Type:* projen.SampleReadmeProps
- *Default:* { filename: 'README.md', contents: '# replace this' }

The README setup.

---

*Example*

```python
"{ filename: 'readme.md', contents: '# title' }"
```


##### `stale`<sup>Optional</sup> <a name="stale" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.stale"></a>

```python
stale: bool
```

- *Type:* bool
- *Default:* false

Auto-close of stale issues and pull request.

See `staleOptions` for options.

---

##### `stale_options`<sup>Optional</sup> <a name="stale_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.staleOptions"></a>

```python
stale_options: StaleOptions
```

- *Type:* projen.github.StaleOptions
- *Default:* see defaults in `StaleOptions`

Auto-close stale issues and pull requests.

To disable set `stale` to `false`.

---

##### `vscode`<sup>Optional</sup> <a name="vscode" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.vscode"></a>

```python
vscode: bool
```

- *Type:* bool
- *Default:* true

Enable VSCode integration.

Enabled by default for root projects. Disabled for non-root projects.

---

##### `artifact_id`<sup>Required</sup> <a name="artifact_id" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.artifactId"></a>

```python
artifact_id: str
```

- *Type:* str
- *Default:* "my-app"

The artifactId is generally the name that the project is known by.

Although
the groupId is important, people within the group will rarely mention the
groupId in discussion (they are often all be the same ID, such as the
MojoHaus project groupId: org.codehaus.mojo). It, along with the groupId,
creates a key that separates this project from every other project in the
world (at least, it should :) ). Along with the groupId, the artifactId
fully defines the artifact's living quarters within the repository. In the
case of the above project, my-project lives in
$M2_REPO/org/codehaus/mojo/my-project.

---

##### `group_id`<sup>Required</sup> <a name="group_id" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.groupId"></a>

```python
group_id: str
```

- *Type:* str
- *Default:* "org.acme"

This is generally unique amongst an organization or a project.

For example,
all core Maven artifacts do (well, should) live under the groupId
org.apache.maven. Group ID's do not necessarily use the dot notation, for
example, the junit project. Note that the dot-notated groupId does not have
to correspond to the package structure that the project contains. It is,
however, a good practice to follow. When stored within a repository, the
group acts much like the Java packaging structure does in an operating
system. The dots are replaced by OS specific directory separators (such as
'/' in Unix) which becomes a relative directory structure from the base
repository. In the example given, the org.codehaus.mojo group lives within
the directory $M2_REPO/org/codehaus/mojo.

---

##### `version`<sup>Required</sup> <a name="version" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.version"></a>

```python
version: str
```

- *Type:* str
- *Default:* "0.1.0"

This is the last piece of the naming puzzle.

groupId:artifactId denotes a
single project but they cannot delineate which incarnation of that project
we are talking about. Do we want the junit:junit of 2018 (version 4.12), or
of 2007 (version 3.8.2)? In short: code changes, those changes should be
versioned, and this element keeps those versions in line. It is also used
within an artifact's repository to separate versions from each other.
my-project version 1.0 files live in the directory structure
$M2_REPO/org/codehaus/mojo/my-project/1.0.

---

##### `description`<sup>Optional</sup> <a name="description" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.description"></a>

```python
description: str
```

- *Type:* str
- *Default:* undefined

Description of a project is always good.

Although this should not replace
formal documentation, a quick comment to any readers of the POM is always
helpful.

---

##### `packaging`<sup>Optional</sup> <a name="packaging" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.packaging"></a>

```python
packaging: str
```

- *Type:* str
- *Default:* "jar"

Project packaging format.

---

##### `url`<sup>Optional</sup> <a name="url" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.url"></a>

```python
url: str
```

- *Type:* str
- *Default:* undefined

The URL, like the name, is not required.

This is a nice gesture for
projects users, however, so that they know where the project lives.

---

##### `compile_options`<sup>Optional</sup> <a name="compile_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.compileOptions"></a>

```python
compile_options: MavenCompileOptions
```

- *Type:* projen.java.MavenCompileOptions
- *Default:* defaults

Compile options.

---

##### `deps`<sup>Optional</sup> <a name="deps" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.deps"></a>

```python
deps: typing.List[str]
```

- *Type:* typing.List[str]
- *Default:* []

List of runtime dependencies for this project.

Dependencies use the format: `<groupId>/<artifactId>@<semver>`

Additional dependencies can be added via `project.addDependency()`.

---

##### `distdir`<sup>Optional</sup> <a name="distdir" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.distdir"></a>

```python
distdir: str
```

- *Type:* str
- *Default:* "dist/java"

Final artifact output directory.

---

##### `junit`<sup>Optional</sup> <a name="junit" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.junit"></a>

```python
junit: bool
```

- *Type:* bool
- *Default:* true

Include junit tests.

---

##### `junit_options`<sup>Optional</sup> <a name="junit_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.junitOptions"></a>

```python
junit_options: JunitOptions
```

- *Type:* projen.java.JunitOptions
- *Default:* defaults

junit options.

---

##### `packaging_options`<sup>Optional</sup> <a name="packaging_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.packagingOptions"></a>

```python
packaging_options: MavenPackagingOptions
```

- *Type:* projen.java.MavenPackagingOptions
- *Default:* defaults

Packaging options.

---

##### `projenrc_java`<sup>Optional</sup> <a name="projenrc_java" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.projenrcJava"></a>

```python
projenrc_java: bool
```

- *Type:* bool
- *Default:* true

Use projenrc in java.

This will install `projen` as a java dependency and will add a `synth` task which
will compile & execute `main()` from `src/main/java/projenrc.java`.

---

##### `projenrc_java_options`<sup>Optional</sup> <a name="projenrc_java_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.projenrcJavaOptions"></a>

```python
projenrc_java_options: ProjenrcOptions
```

- *Type:* projen.java.ProjenrcOptions
- *Default:* default options

Options related to projenrc in java.

---

##### `test_deps`<sup>Optional</sup> <a name="test_deps" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.testDeps"></a>

```python
test_deps: typing.List[str]
```

- *Type:* typing.List[str]
- *Default:* []

List of test dependencies for this project.

Dependencies use the format: `<groupId>/<artifactId>@<semver>`

Additional dependencies can be added via `project.addTestDependency()`.

---

##### `sample`<sup>Optional</sup> <a name="sample" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.sample"></a>

```python
sample: bool
```

- *Type:* bool
- *Default:* true

Include sample code and test if the relevant directories don't exist.

---

##### `sample_java_package`<sup>Optional</sup> <a name="sample_java_package" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.sampleJavaPackage"></a>

```python
sample_java_package: str
```

- *Type:* str
- *Default:* "org.acme"

The java package to use for the code sample.

---

##### `open_api_generator_cli_config`<sup>Optional</sup> <a name="open_api_generator_cli_config" id="@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions.property.openApiGeneratorCliConfig"></a>

```python
open_api_generator_cli_config: OpenApiGeneratorCliConfig
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfig">OpenApiGeneratorCliConfig</a>

Configuration for the OpenAPI Generator CLI.

Overrides default values if specified.

> [https://github.com/OpenAPITools/openapi-generator-cli#configuration](https://github.com/OpenAPITools/openapi-generator-cli#configuration)

---

### GeneratedLibraryOptions <a name="GeneratedLibraryOptions" id="@aws-prototyping-sdk/type-safe-api.GeneratedLibraryOptions"></a>

Options for generated libraries.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.GeneratedLibraryOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.GeneratedLibraryOptions(
  typescript_react_query_hooks: GeneratedTypeScriptReactQueryHooksOptions = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedLibraryOptions.property.typescriptReactQueryHooks">typescript_react_query_hooks</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions">GeneratedTypeScriptReactQueryHooksOptions</a></code> | Options for the generated typescript react-query hooks library. |

---

##### `typescript_react_query_hooks`<sup>Optional</sup> <a name="typescript_react_query_hooks" id="@aws-prototyping-sdk/type-safe-api.GeneratedLibraryOptions.property.typescriptReactQueryHooks"></a>

```python
typescript_react_query_hooks: GeneratedTypeScriptReactQueryHooksOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions">GeneratedTypeScriptReactQueryHooksOptions</a>

Options for the generated typescript react-query hooks library.

These override the default inferred options.

---

### GeneratedLibraryProjects <a name="GeneratedLibraryProjects" id="@aws-prototyping-sdk/type-safe-api.GeneratedLibraryProjects"></a>

Generated library projects.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.GeneratedLibraryProjects.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.GeneratedLibraryProjects(
  typescript_react_query_hooks: TypeScriptProject = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedLibraryProjects.property.typescriptReactQueryHooks">typescript_react_query_hooks</a></code> | <code>projen.typescript.TypeScriptProject</code> | Generated typescript react-query hooks project. |

---

##### `typescript_react_query_hooks`<sup>Optional</sup> <a name="typescript_react_query_hooks" id="@aws-prototyping-sdk/type-safe-api.GeneratedLibraryProjects.property.typescriptReactQueryHooks"></a>

```python
typescript_react_query_hooks: TypeScriptProject
```

- *Type:* projen.typescript.TypeScriptProject

Generated typescript react-query hooks project.

---

### GeneratedMarkdownDocumentationOptions <a name="GeneratedMarkdownDocumentationOptions" id="@aws-prototyping-sdk/type-safe-api.GeneratedMarkdownDocumentationOptions"></a>

Options for the markdown documentation project.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.GeneratedMarkdownDocumentationOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.GeneratedMarkdownDocumentationOptions(
  open_api_generator_cli_config: OpenApiGeneratorCliConfig = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedMarkdownDocumentationOptions.property.openApiGeneratorCliConfig">open_api_generator_cli_config</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfig">OpenApiGeneratorCliConfig</a></code> | Configuration for the OpenAPI Generator CLI. |

---

##### `open_api_generator_cli_config`<sup>Optional</sup> <a name="open_api_generator_cli_config" id="@aws-prototyping-sdk/type-safe-api.GeneratedMarkdownDocumentationOptions.property.openApiGeneratorCliConfig"></a>

```python
open_api_generator_cli_config: OpenApiGeneratorCliConfig
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfig">OpenApiGeneratorCliConfig</a>

Configuration for the OpenAPI Generator CLI.

Overrides default values if specified.

> [https://github.com/OpenAPITools/openapi-generator-cli#configuration](https://github.com/OpenAPITools/openapi-generator-cli#configuration)

---

### GeneratedPlantumlDocumentationOptions <a name="GeneratedPlantumlDocumentationOptions" id="@aws-prototyping-sdk/type-safe-api.GeneratedPlantumlDocumentationOptions"></a>

Options for the plantuml documentation project.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.GeneratedPlantumlDocumentationOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.GeneratedPlantumlDocumentationOptions(
  open_api_generator_cli_config: OpenApiGeneratorCliConfig = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPlantumlDocumentationOptions.property.openApiGeneratorCliConfig">open_api_generator_cli_config</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfig">OpenApiGeneratorCliConfig</a></code> | Configuration for the OpenAPI Generator CLI. |

---

##### `open_api_generator_cli_config`<sup>Optional</sup> <a name="open_api_generator_cli_config" id="@aws-prototyping-sdk/type-safe-api.GeneratedPlantumlDocumentationOptions.property.openApiGeneratorCliConfig"></a>

```python
open_api_generator_cli_config: OpenApiGeneratorCliConfig
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfig">OpenApiGeneratorCliConfig</a>

Configuration for the OpenAPI Generator CLI.

Overrides default values if specified.

> [https://github.com/OpenAPITools/openapi-generator-cli#configuration](https://github.com/OpenAPITools/openapi-generator-cli#configuration)

---

### GeneratedPythonInfrastructureOptions <a name="GeneratedPythonInfrastructureOptions" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions"></a>

Options for configuring a generated python infrastructure project.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.GeneratedPythonInfrastructureOptions(
  name: str,
  commit_generated: bool = None,
  git_ignore_options: IgnoreFileOptions = None,
  git_options: GitOptions = None,
  logging: LoggerOptions = None,
  outdir: str = None,
  parent: Project = None,
  projen_command: str = None,
  projenrc_json: bool = None,
  projenrc_json_options: ProjenrcJsonOptions = None,
  renovatebot: bool = None,
  renovatebot_options: RenovatebotOptions = None,
  auto_approve_options: AutoApproveOptions = None,
  auto_merge: bool = None,
  auto_merge_options: AutoMergeOptions = None,
  clobber: bool = None,
  dev_container: bool = None,
  github: bool = None,
  github_options: GitHubOptions = None,
  gitpod: bool = None,
  mergify: bool = None,
  mergify_options: MergifyOptions = None,
  project_type: ProjectType = None,
  projen_credentials: GithubCredentials = None,
  projen_token_secret: str = None,
  readme: SampleReadmeProps = None,
  stale: bool = None,
  stale_options: StaleOptions = None,
  vscode: bool = None,
  author_email: str,
  author_name: str,
  version: str,
  classifiers: typing.List[str] = None,
  description: str = None,
  homepage: str = None,
  license: str = None,
  package_name: str = None,
  poetry_options: PoetryPyprojectOptionsWithoutDeps = None,
  setup_config: typing.Mapping[typing.Any] = None,
  module_name: str,
  deps: typing.List[str] = None,
  dev_deps: typing.List[str] = None,
  pip: bool = None,
  poetry: bool = None,
  projenrc_js: bool = None,
  projenrc_js_options: ProjenrcOptions = None,
  projenrc_python: bool = None,
  projenrc_python_options: ProjenrcOptions = None,
  projenrc_ts: bool = None,
  projenrc_ts_options: ProjenrcTsOptions = None,
  pytest: bool = None,
  pytest_options: PytestOptions = None,
  python_exec: str = None,
  sample: bool = None,
  setuptools: bool = None,
  venv: bool = None,
  venv_options: VenvOptions = None,
  open_api_generator_cli_config: OpenApiGeneratorCliConfig = None,
  mock_data_options: MockResponseDataGenerationOptions = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.name">name</a></code> | <code>str</code> | This is the name of your project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.commitGenerated">commit_generated</a></code> | <code>bool</code> | Whether to commit the managed files by default. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.gitIgnoreOptions">git_ignore_options</a></code> | <code>projen.IgnoreFileOptions</code> | Configuration options for .gitignore file. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.gitOptions">git_options</a></code> | <code>projen.GitOptions</code> | Configuration options for git. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.logging">logging</a></code> | <code>projen.LoggerOptions</code> | Configure logging options such as verbosity. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.outdir">outdir</a></code> | <code>str</code> | The root directory of the project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.parent">parent</a></code> | <code>projen.Project</code> | The parent project, if this project is part of a bigger project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.projenCommand">projen_command</a></code> | <code>str</code> | The shell command to use in order to run the projen CLI. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.projenrcJson">projenrc_json</a></code> | <code>bool</code> | Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.projenrcJsonOptions">projenrc_json_options</a></code> | <code>projen.ProjenrcJsonOptions</code> | Options for .projenrc.json. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.renovatebot">renovatebot</a></code> | <code>bool</code> | Use renovatebot to handle dependency upgrades. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.renovatebotOptions">renovatebot_options</a></code> | <code>projen.RenovatebotOptions</code> | Options for renovatebot. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.autoApproveOptions">auto_approve_options</a></code> | <code>projen.github.AutoApproveOptions</code> | Enable and configure the 'auto approve' workflow. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.autoMerge">auto_merge</a></code> | <code>bool</code> | Enable automatic merging on GitHub. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.autoMergeOptions">auto_merge_options</a></code> | <code>projen.github.AutoMergeOptions</code> | Configure options for automatic merging on GitHub. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.clobber">clobber</a></code> | <code>bool</code> | Add a `clobber` task which resets the repo to origin. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.devContainer">dev_container</a></code> | <code>bool</code> | Add a VSCode development environment (used for GitHub Codespaces). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.github">github</a></code> | <code>bool</code> | Enable GitHub integration. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.githubOptions">github_options</a></code> | <code>projen.github.GitHubOptions</code> | Options for GitHub integration. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.gitpod">gitpod</a></code> | <code>bool</code> | Add a Gitpod development environment. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.mergify">mergify</a></code> | <code>bool</code> | Whether mergify should be enabled on this repository or not. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.mergifyOptions">mergify_options</a></code> | <code>projen.github.MergifyOptions</code> | Options for mergify. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.projectType">project_type</a></code> | <code>projen.ProjectType</code> | Which type of project this is (library/app). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.projenCredentials">projen_credentials</a></code> | <code>projen.github.GithubCredentials</code> | Choose a method of providing GitHub API access for projen workflows. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.projenTokenSecret">projen_token_secret</a></code> | <code>str</code> | The name of a secret which includes a GitHub Personal Access Token to be used by projen workflows. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.readme">readme</a></code> | <code>projen.SampleReadmeProps</code> | The README setup. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.stale">stale</a></code> | <code>bool</code> | Auto-close of stale issues and pull request. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.staleOptions">stale_options</a></code> | <code>projen.github.StaleOptions</code> | Auto-close stale issues and pull requests. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.vscode">vscode</a></code> | <code>bool</code> | Enable VSCode integration. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.authorEmail">author_email</a></code> | <code>str</code> | Author's e-mail. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.authorName">author_name</a></code> | <code>str</code> | Author's name. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.version">version</a></code> | <code>str</code> | Version of the package. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.classifiers">classifiers</a></code> | <code>typing.List[str]</code> | A list of PyPI trove classifiers that describe the project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.description">description</a></code> | <code>str</code> | A short description of the package. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.homepage">homepage</a></code> | <code>str</code> | A URL to the website of the project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.license">license</a></code> | <code>str</code> | License of this package as an SPDX identifier. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.packageName">package_name</a></code> | <code>str</code> | Package name. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.poetryOptions">poetry_options</a></code> | <code>projen.python.PoetryPyprojectOptionsWithoutDeps</code> | Additional options to set for poetry if using poetry. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.setupConfig">setup_config</a></code> | <code>typing.Mapping[typing.Any]</code> | Additional fields to pass in the setup() function if using setuptools. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.moduleName">module_name</a></code> | <code>str</code> | Name of the python package as used in imports and filenames. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.deps">deps</a></code> | <code>typing.List[str]</code> | List of runtime dependencies for this project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.devDeps">dev_deps</a></code> | <code>typing.List[str]</code> | List of dev dependencies for this project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.pip">pip</a></code> | <code>bool</code> | Use pip with a requirements.txt file to track project dependencies. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.poetry">poetry</a></code> | <code>bool</code> | Use poetry to manage your project dependencies, virtual environment, and (optional) packaging/publishing. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.projenrcJs">projenrc_js</a></code> | <code>bool</code> | Use projenrc in javascript. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.projenrcJsOptions">projenrc_js_options</a></code> | <code>projen.javascript.ProjenrcOptions</code> | Options related to projenrc in JavaScript. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.projenrcPython">projenrc_python</a></code> | <code>bool</code> | Use projenrc in Python. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.projenrcPythonOptions">projenrc_python_options</a></code> | <code>projen.python.ProjenrcOptions</code> | Options related to projenrc in python. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.projenrcTs">projenrc_ts</a></code> | <code>bool</code> | Use projenrc in TypeScript. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.projenrcTsOptions">projenrc_ts_options</a></code> | <code>projen.typescript.ProjenrcTsOptions</code> | Options related to projenrc in TypeScript. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.pytest">pytest</a></code> | <code>bool</code> | Include pytest tests. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.pytestOptions">pytest_options</a></code> | <code>projen.python.PytestOptions</code> | pytest options. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.pythonExec">python_exec</a></code> | <code>str</code> | Path to the python executable to use. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.sample">sample</a></code> | <code>bool</code> | Include sample code and test if the relevant directories don't exist. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.setuptools">setuptools</a></code> | <code>bool</code> | Use setuptools with a setup.py script for packaging and publishing. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.venv">venv</a></code> | <code>bool</code> | Use venv to manage a virtual environment for installing dependencies inside. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.venvOptions">venv_options</a></code> | <code>projen.python.VenvOptions</code> | Venv options. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.openApiGeneratorCliConfig">open_api_generator_cli_config</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfig">OpenApiGeneratorCliConfig</a></code> | Configuration for the OpenAPI Generator CLI. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.mockDataOptions">mock_data_options</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.MockResponseDataGenerationOptions">MockResponseDataGenerationOptions</a></code> | Options for the generated mock response data. |

---

##### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.name"></a>

```python
name: str
```

- *Type:* str
- *Default:* $BASEDIR

This is the name of your project.

---

##### `commit_generated`<sup>Optional</sup> <a name="commit_generated" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.commitGenerated"></a>

```python
commit_generated: bool
```

- *Type:* bool
- *Default:* true

Whether to commit the managed files by default.

---

##### `git_ignore_options`<sup>Optional</sup> <a name="git_ignore_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.gitIgnoreOptions"></a>

```python
git_ignore_options: IgnoreFileOptions
```

- *Type:* projen.IgnoreFileOptions

Configuration options for .gitignore file.

---

##### `git_options`<sup>Optional</sup> <a name="git_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.gitOptions"></a>

```python
git_options: GitOptions
```

- *Type:* projen.GitOptions

Configuration options for git.

---

##### `logging`<sup>Optional</sup> <a name="logging" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.logging"></a>

```python
logging: LoggerOptions
```

- *Type:* projen.LoggerOptions
- *Default:* {}

Configure logging options such as verbosity.

---

##### `outdir`<sup>Optional</sup> <a name="outdir" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.outdir"></a>

```python
outdir: str
```

- *Type:* str
- *Default:* "."

The root directory of the project.

Relative to this directory, all files are synthesized.

If this project has a parent, this directory is relative to the parent
directory and it cannot be the same as the parent or any of it's other
sub-projects.

---

##### `parent`<sup>Optional</sup> <a name="parent" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.parent"></a>

```python
parent: Project
```

- *Type:* projen.Project

The parent project, if this project is part of a bigger project.

---

##### `projen_command`<sup>Optional</sup> <a name="projen_command" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.projenCommand"></a>

```python
projen_command: str
```

- *Type:* str
- *Default:* "npx projen"

The shell command to use in order to run the projen CLI.

Can be used to customize in special environments.

---

##### `projenrc_json`<sup>Optional</sup> <a name="projenrc_json" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.projenrcJson"></a>

```python
projenrc_json: bool
```

- *Type:* bool
- *Default:* false

Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation.

---

##### `projenrc_json_options`<sup>Optional</sup> <a name="projenrc_json_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.projenrcJsonOptions"></a>

```python
projenrc_json_options: ProjenrcJsonOptions
```

- *Type:* projen.ProjenrcJsonOptions
- *Default:* default options

Options for .projenrc.json.

---

##### `renovatebot`<sup>Optional</sup> <a name="renovatebot" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.renovatebot"></a>

```python
renovatebot: bool
```

- *Type:* bool
- *Default:* false

Use renovatebot to handle dependency upgrades.

---

##### `renovatebot_options`<sup>Optional</sup> <a name="renovatebot_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.renovatebotOptions"></a>

```python
renovatebot_options: RenovatebotOptions
```

- *Type:* projen.RenovatebotOptions
- *Default:* default options

Options for renovatebot.

---

##### `auto_approve_options`<sup>Optional</sup> <a name="auto_approve_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.autoApproveOptions"></a>

```python
auto_approve_options: AutoApproveOptions
```

- *Type:* projen.github.AutoApproveOptions
- *Default:* auto approve is disabled

Enable and configure the 'auto approve' workflow.

---

##### `auto_merge`<sup>Optional</sup> <a name="auto_merge" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.autoMerge"></a>

```python
auto_merge: bool
```

- *Type:* bool
- *Default:* true

Enable automatic merging on GitHub.

Has no effect if `github.mergify`
is set to false.

---

##### `auto_merge_options`<sup>Optional</sup> <a name="auto_merge_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.autoMergeOptions"></a>

```python
auto_merge_options: AutoMergeOptions
```

- *Type:* projen.github.AutoMergeOptions
- *Default:* see defaults in `AutoMergeOptions`

Configure options for automatic merging on GitHub.

Has no effect if
`github.mergify` or `autoMerge` is set to false.

---

##### `clobber`<sup>Optional</sup> <a name="clobber" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.clobber"></a>

```python
clobber: bool
```

- *Type:* bool
- *Default:* true, but false for subprojects

Add a `clobber` task which resets the repo to origin.

---

##### `dev_container`<sup>Optional</sup> <a name="dev_container" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.devContainer"></a>

```python
dev_container: bool
```

- *Type:* bool
- *Default:* false

Add a VSCode development environment (used for GitHub Codespaces).

---

##### `github`<sup>Optional</sup> <a name="github" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.github"></a>

```python
github: bool
```

- *Type:* bool
- *Default:* true

Enable GitHub integration.

Enabled by default for root projects. Disabled for non-root projects.

---

##### `github_options`<sup>Optional</sup> <a name="github_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.githubOptions"></a>

```python
github_options: GitHubOptions
```

- *Type:* projen.github.GitHubOptions
- *Default:* see GitHubOptions

Options for GitHub integration.

---

##### `gitpod`<sup>Optional</sup> <a name="gitpod" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.gitpod"></a>

```python
gitpod: bool
```

- *Type:* bool
- *Default:* false

Add a Gitpod development environment.

---

##### ~~`mergify`~~<sup>Optional</sup> <a name="mergify" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.mergify"></a>

- *Deprecated:* use `githubOptions.mergify` instead

```python
mergify: bool
```

- *Type:* bool
- *Default:* true

Whether mergify should be enabled on this repository or not.

---

##### ~~`mergify_options`~~<sup>Optional</sup> <a name="mergify_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.mergifyOptions"></a>

- *Deprecated:* use `githubOptions.mergifyOptions` instead

```python
mergify_options: MergifyOptions
```

- *Type:* projen.github.MergifyOptions
- *Default:* default options

Options for mergify.

---

##### ~~`project_type`~~<sup>Optional</sup> <a name="project_type" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.projectType"></a>

- *Deprecated:* no longer supported at the base project level

```python
project_type: ProjectType
```

- *Type:* projen.ProjectType
- *Default:* ProjectType.UNKNOWN

Which type of project this is (library/app).

---

##### `projen_credentials`<sup>Optional</sup> <a name="projen_credentials" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.projenCredentials"></a>

```python
projen_credentials: GithubCredentials
```

- *Type:* projen.github.GithubCredentials
- *Default:* use a personal access token named PROJEN_GITHUB_TOKEN

Choose a method of providing GitHub API access for projen workflows.

---

##### ~~`projen_token_secret`~~<sup>Optional</sup> <a name="projen_token_secret" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.projenTokenSecret"></a>

- *Deprecated:* use `projenCredentials`

```python
projen_token_secret: str
```

- *Type:* str
- *Default:* "PROJEN_GITHUB_TOKEN"

The name of a secret which includes a GitHub Personal Access Token to be used by projen workflows.

This token needs to have the `repo`, `workflows`
and `packages` scope.

---

##### `readme`<sup>Optional</sup> <a name="readme" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.readme"></a>

```python
readme: SampleReadmeProps
```

- *Type:* projen.SampleReadmeProps
- *Default:* { filename: 'README.md', contents: '# replace this' }

The README setup.

---

*Example*

```python
"{ filename: 'readme.md', contents: '# title' }"
```


##### `stale`<sup>Optional</sup> <a name="stale" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.stale"></a>

```python
stale: bool
```

- *Type:* bool
- *Default:* false

Auto-close of stale issues and pull request.

See `staleOptions` for options.

---

##### `stale_options`<sup>Optional</sup> <a name="stale_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.staleOptions"></a>

```python
stale_options: StaleOptions
```

- *Type:* projen.github.StaleOptions
- *Default:* see defaults in `StaleOptions`

Auto-close stale issues and pull requests.

To disable set `stale` to `false`.

---

##### `vscode`<sup>Optional</sup> <a name="vscode" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.vscode"></a>

```python
vscode: bool
```

- *Type:* bool
- *Default:* true

Enable VSCode integration.

Enabled by default for root projects. Disabled for non-root projects.

---

##### `author_email`<sup>Required</sup> <a name="author_email" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.authorEmail"></a>

```python
author_email: str
```

- *Type:* str
- *Default:* $GIT_USER_EMAIL

Author's e-mail.

---

##### `author_name`<sup>Required</sup> <a name="author_name" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.authorName"></a>

```python
author_name: str
```

- *Type:* str
- *Default:* $GIT_USER_NAME

Author's name.

---

##### `version`<sup>Required</sup> <a name="version" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.version"></a>

```python
version: str
```

- *Type:* str
- *Default:* "0.1.0"

Version of the package.

---

##### `classifiers`<sup>Optional</sup> <a name="classifiers" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.classifiers"></a>

```python
classifiers: typing.List[str]
```

- *Type:* typing.List[str]

A list of PyPI trove classifiers that describe the project.

> [https://pypi.org/classifiers/](https://pypi.org/classifiers/)

---

##### `description`<sup>Optional</sup> <a name="description" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.description"></a>

```python
description: str
```

- *Type:* str

A short description of the package.

---

##### `homepage`<sup>Optional</sup> <a name="homepage" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.homepage"></a>

```python
homepage: str
```

- *Type:* str

A URL to the website of the project.

---

##### `license`<sup>Optional</sup> <a name="license" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.license"></a>

```python
license: str
```

- *Type:* str

License of this package as an SPDX identifier.

---

##### `package_name`<sup>Optional</sup> <a name="package_name" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.packageName"></a>

```python
package_name: str
```

- *Type:* str

Package name.

---

##### `poetry_options`<sup>Optional</sup> <a name="poetry_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.poetryOptions"></a>

```python
poetry_options: PoetryPyprojectOptionsWithoutDeps
```

- *Type:* projen.python.PoetryPyprojectOptionsWithoutDeps

Additional options to set for poetry if using poetry.

---

##### `setup_config`<sup>Optional</sup> <a name="setup_config" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.setupConfig"></a>

```python
setup_config: typing.Mapping[typing.Any]
```

- *Type:* typing.Mapping[typing.Any]

Additional fields to pass in the setup() function if using setuptools.

---

##### `module_name`<sup>Required</sup> <a name="module_name" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.moduleName"></a>

```python
module_name: str
```

- *Type:* str
- *Default:* $PYTHON_MODULE_NAME

Name of the python package as used in imports and filenames.

Must only consist of alphanumeric characters and underscores.

---

##### `deps`<sup>Optional</sup> <a name="deps" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.deps"></a>

```python
deps: typing.List[str]
```

- *Type:* typing.List[str]
- *Default:* []

List of runtime dependencies for this project.

Dependencies use the format: `<module>@<semver>`

Additional dependencies can be added via `project.addDependency()`.

---

##### `dev_deps`<sup>Optional</sup> <a name="dev_deps" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.devDeps"></a>

```python
dev_deps: typing.List[str]
```

- *Type:* typing.List[str]
- *Default:* []

List of dev dependencies for this project.

Dependencies use the format: `<module>@<semver>`

Additional dependencies can be added via `project.addDevDependency()`.

---

##### `pip`<sup>Optional</sup> <a name="pip" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.pip"></a>

```python
pip: bool
```

- *Type:* bool
- *Default:* true, unless poetry is true, then false

Use pip with a requirements.txt file to track project dependencies.

---

##### `poetry`<sup>Optional</sup> <a name="poetry" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.poetry"></a>

```python
poetry: bool
```

- *Type:* bool
- *Default:* false

Use poetry to manage your project dependencies, virtual environment, and (optional) packaging/publishing.

This feature is incompatible with pip, setuptools, or venv.
If you set this option to `true`, then pip, setuptools, and venv must be set to `false`.

---

##### `projenrc_js`<sup>Optional</sup> <a name="projenrc_js" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.projenrcJs"></a>

```python
projenrc_js: bool
```

- *Type:* bool
- *Default:* false

Use projenrc in javascript.

This will install `projen` as a JavaScript dependency and add a `synth`
task which will run `.projenrc.js`.

---

##### `projenrc_js_options`<sup>Optional</sup> <a name="projenrc_js_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.projenrcJsOptions"></a>

```python
projenrc_js_options: ProjenrcOptions
```

- *Type:* projen.javascript.ProjenrcOptions
- *Default:* default options

Options related to projenrc in JavaScript.

---

##### `projenrc_python`<sup>Optional</sup> <a name="projenrc_python" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.projenrcPython"></a>

```python
projenrc_python: bool
```

- *Type:* bool
- *Default:* true

Use projenrc in Python.

This will install `projen` as a Python dependency and add a `synth`
task which will run `.projenrc.py`.

---

##### `projenrc_python_options`<sup>Optional</sup> <a name="projenrc_python_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.projenrcPythonOptions"></a>

```python
projenrc_python_options: ProjenrcOptions
```

- *Type:* projen.python.ProjenrcOptions
- *Default:* default options

Options related to projenrc in python.

---

##### `projenrc_ts`<sup>Optional</sup> <a name="projenrc_ts" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.projenrcTs"></a>

```python
projenrc_ts: bool
```

- *Type:* bool
- *Default:* false

Use projenrc in TypeScript.

This will create a tsconfig file (default: `tsconfig.projen.json`)
and use `ts-node` in the default task to parse the project source files.

---

##### `projenrc_ts_options`<sup>Optional</sup> <a name="projenrc_ts_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.projenrcTsOptions"></a>

```python
projenrc_ts_options: ProjenrcTsOptions
```

- *Type:* projen.typescript.ProjenrcTsOptions
- *Default:* default options

Options related to projenrc in TypeScript.

---

##### `pytest`<sup>Optional</sup> <a name="pytest" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.pytest"></a>

```python
pytest: bool
```

- *Type:* bool
- *Default:* true

Include pytest tests.

---

##### `pytest_options`<sup>Optional</sup> <a name="pytest_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.pytestOptions"></a>

```python
pytest_options: PytestOptions
```

- *Type:* projen.python.PytestOptions
- *Default:* defaults

pytest options.

---

##### `python_exec`<sup>Optional</sup> <a name="python_exec" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.pythonExec"></a>

```python
python_exec: str
```

- *Type:* str
- *Default:* "python"

Path to the python executable to use.

---

##### `sample`<sup>Optional</sup> <a name="sample" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.sample"></a>

```python
sample: bool
```

- *Type:* bool
- *Default:* true

Include sample code and test if the relevant directories don't exist.

---

##### `setuptools`<sup>Optional</sup> <a name="setuptools" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.setuptools"></a>

```python
setuptools: bool
```

- *Type:* bool
- *Default:* true, unless poetry is true, then false

Use setuptools with a setup.py script for packaging and publishing.

---

##### `venv`<sup>Optional</sup> <a name="venv" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.venv"></a>

```python
venv: bool
```

- *Type:* bool
- *Default:* true, unless poetry is true, then false

Use venv to manage a virtual environment for installing dependencies inside.

---

##### `venv_options`<sup>Optional</sup> <a name="venv_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.venvOptions"></a>

```python
venv_options: VenvOptions
```

- *Type:* projen.python.VenvOptions
- *Default:* defaults

Venv options.

---

##### `open_api_generator_cli_config`<sup>Optional</sup> <a name="open_api_generator_cli_config" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.openApiGeneratorCliConfig"></a>

```python
open_api_generator_cli_config: OpenApiGeneratorCliConfig
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfig">OpenApiGeneratorCliConfig</a>

Configuration for the OpenAPI Generator CLI.

Overrides default values if specified.

> [https://github.com/OpenAPITools/openapi-generator-cli#configuration](https://github.com/OpenAPITools/openapi-generator-cli#configuration)

---

##### `mock_data_options`<sup>Optional</sup> <a name="mock_data_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonInfrastructureOptions.property.mockDataOptions"></a>

```python
mock_data_options: MockResponseDataGenerationOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.MockResponseDataGenerationOptions">MockResponseDataGenerationOptions</a>

Options for the generated mock response data.

---

### GeneratedPythonRuntimeOptions <a name="GeneratedPythonRuntimeOptions" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions"></a>

Options for configuring a generated python runtime project.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.GeneratedPythonRuntimeOptions(
  name: str,
  commit_generated: bool = None,
  git_ignore_options: IgnoreFileOptions = None,
  git_options: GitOptions = None,
  logging: LoggerOptions = None,
  outdir: str = None,
  parent: Project = None,
  projen_command: str = None,
  projenrc_json: bool = None,
  projenrc_json_options: ProjenrcJsonOptions = None,
  renovatebot: bool = None,
  renovatebot_options: RenovatebotOptions = None,
  auto_approve_options: AutoApproveOptions = None,
  auto_merge: bool = None,
  auto_merge_options: AutoMergeOptions = None,
  clobber: bool = None,
  dev_container: bool = None,
  github: bool = None,
  github_options: GitHubOptions = None,
  gitpod: bool = None,
  mergify: bool = None,
  mergify_options: MergifyOptions = None,
  project_type: ProjectType = None,
  projen_credentials: GithubCredentials = None,
  projen_token_secret: str = None,
  readme: SampleReadmeProps = None,
  stale: bool = None,
  stale_options: StaleOptions = None,
  vscode: bool = None,
  author_email: str,
  author_name: str,
  version: str,
  classifiers: typing.List[str] = None,
  description: str = None,
  homepage: str = None,
  license: str = None,
  package_name: str = None,
  poetry_options: PoetryPyprojectOptionsWithoutDeps = None,
  setup_config: typing.Mapping[typing.Any] = None,
  module_name: str,
  deps: typing.List[str] = None,
  dev_deps: typing.List[str] = None,
  pip: bool = None,
  poetry: bool = None,
  projenrc_js: bool = None,
  projenrc_js_options: ProjenrcOptions = None,
  projenrc_python: bool = None,
  projenrc_python_options: ProjenrcOptions = None,
  projenrc_ts: bool = None,
  projenrc_ts_options: ProjenrcTsOptions = None,
  pytest: bool = None,
  pytest_options: PytestOptions = None,
  python_exec: str = None,
  sample: bool = None,
  setuptools: bool = None,
  venv: bool = None,
  venv_options: VenvOptions = None,
  open_api_generator_cli_config: OpenApiGeneratorCliConfig = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.name">name</a></code> | <code>str</code> | This is the name of your project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.commitGenerated">commit_generated</a></code> | <code>bool</code> | Whether to commit the managed files by default. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.gitIgnoreOptions">git_ignore_options</a></code> | <code>projen.IgnoreFileOptions</code> | Configuration options for .gitignore file. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.gitOptions">git_options</a></code> | <code>projen.GitOptions</code> | Configuration options for git. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.logging">logging</a></code> | <code>projen.LoggerOptions</code> | Configure logging options such as verbosity. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.outdir">outdir</a></code> | <code>str</code> | The root directory of the project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.parent">parent</a></code> | <code>projen.Project</code> | The parent project, if this project is part of a bigger project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.projenCommand">projen_command</a></code> | <code>str</code> | The shell command to use in order to run the projen CLI. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.projenrcJson">projenrc_json</a></code> | <code>bool</code> | Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.projenrcJsonOptions">projenrc_json_options</a></code> | <code>projen.ProjenrcJsonOptions</code> | Options for .projenrc.json. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.renovatebot">renovatebot</a></code> | <code>bool</code> | Use renovatebot to handle dependency upgrades. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.renovatebotOptions">renovatebot_options</a></code> | <code>projen.RenovatebotOptions</code> | Options for renovatebot. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.autoApproveOptions">auto_approve_options</a></code> | <code>projen.github.AutoApproveOptions</code> | Enable and configure the 'auto approve' workflow. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.autoMerge">auto_merge</a></code> | <code>bool</code> | Enable automatic merging on GitHub. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.autoMergeOptions">auto_merge_options</a></code> | <code>projen.github.AutoMergeOptions</code> | Configure options for automatic merging on GitHub. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.clobber">clobber</a></code> | <code>bool</code> | Add a `clobber` task which resets the repo to origin. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.devContainer">dev_container</a></code> | <code>bool</code> | Add a VSCode development environment (used for GitHub Codespaces). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.github">github</a></code> | <code>bool</code> | Enable GitHub integration. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.githubOptions">github_options</a></code> | <code>projen.github.GitHubOptions</code> | Options for GitHub integration. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.gitpod">gitpod</a></code> | <code>bool</code> | Add a Gitpod development environment. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.mergify">mergify</a></code> | <code>bool</code> | Whether mergify should be enabled on this repository or not. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.mergifyOptions">mergify_options</a></code> | <code>projen.github.MergifyOptions</code> | Options for mergify. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.projectType">project_type</a></code> | <code>projen.ProjectType</code> | Which type of project this is (library/app). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.projenCredentials">projen_credentials</a></code> | <code>projen.github.GithubCredentials</code> | Choose a method of providing GitHub API access for projen workflows. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.projenTokenSecret">projen_token_secret</a></code> | <code>str</code> | The name of a secret which includes a GitHub Personal Access Token to be used by projen workflows. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.readme">readme</a></code> | <code>projen.SampleReadmeProps</code> | The README setup. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.stale">stale</a></code> | <code>bool</code> | Auto-close of stale issues and pull request. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.staleOptions">stale_options</a></code> | <code>projen.github.StaleOptions</code> | Auto-close stale issues and pull requests. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.vscode">vscode</a></code> | <code>bool</code> | Enable VSCode integration. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.authorEmail">author_email</a></code> | <code>str</code> | Author's e-mail. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.authorName">author_name</a></code> | <code>str</code> | Author's name. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.version">version</a></code> | <code>str</code> | Version of the package. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.classifiers">classifiers</a></code> | <code>typing.List[str]</code> | A list of PyPI trove classifiers that describe the project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.description">description</a></code> | <code>str</code> | A short description of the package. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.homepage">homepage</a></code> | <code>str</code> | A URL to the website of the project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.license">license</a></code> | <code>str</code> | License of this package as an SPDX identifier. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.packageName">package_name</a></code> | <code>str</code> | Package name. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.poetryOptions">poetry_options</a></code> | <code>projen.python.PoetryPyprojectOptionsWithoutDeps</code> | Additional options to set for poetry if using poetry. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.setupConfig">setup_config</a></code> | <code>typing.Mapping[typing.Any]</code> | Additional fields to pass in the setup() function if using setuptools. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.moduleName">module_name</a></code> | <code>str</code> | Name of the python package as used in imports and filenames. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.deps">deps</a></code> | <code>typing.List[str]</code> | List of runtime dependencies for this project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.devDeps">dev_deps</a></code> | <code>typing.List[str]</code> | List of dev dependencies for this project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.pip">pip</a></code> | <code>bool</code> | Use pip with a requirements.txt file to track project dependencies. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.poetry">poetry</a></code> | <code>bool</code> | Use poetry to manage your project dependencies, virtual environment, and (optional) packaging/publishing. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.projenrcJs">projenrc_js</a></code> | <code>bool</code> | Use projenrc in javascript. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.projenrcJsOptions">projenrc_js_options</a></code> | <code>projen.javascript.ProjenrcOptions</code> | Options related to projenrc in JavaScript. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.projenrcPython">projenrc_python</a></code> | <code>bool</code> | Use projenrc in Python. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.projenrcPythonOptions">projenrc_python_options</a></code> | <code>projen.python.ProjenrcOptions</code> | Options related to projenrc in python. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.projenrcTs">projenrc_ts</a></code> | <code>bool</code> | Use projenrc in TypeScript. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.projenrcTsOptions">projenrc_ts_options</a></code> | <code>projen.typescript.ProjenrcTsOptions</code> | Options related to projenrc in TypeScript. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.pytest">pytest</a></code> | <code>bool</code> | Include pytest tests. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.pytestOptions">pytest_options</a></code> | <code>projen.python.PytestOptions</code> | pytest options. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.pythonExec">python_exec</a></code> | <code>str</code> | Path to the python executable to use. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.sample">sample</a></code> | <code>bool</code> | Include sample code and test if the relevant directories don't exist. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.setuptools">setuptools</a></code> | <code>bool</code> | Use setuptools with a setup.py script for packaging and publishing. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.venv">venv</a></code> | <code>bool</code> | Use venv to manage a virtual environment for installing dependencies inside. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.venvOptions">venv_options</a></code> | <code>projen.python.VenvOptions</code> | Venv options. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.openApiGeneratorCliConfig">open_api_generator_cli_config</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfig">OpenApiGeneratorCliConfig</a></code> | Configuration for the OpenAPI Generator CLI. |

---

##### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.name"></a>

```python
name: str
```

- *Type:* str
- *Default:* $BASEDIR

This is the name of your project.

---

##### `commit_generated`<sup>Optional</sup> <a name="commit_generated" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.commitGenerated"></a>

```python
commit_generated: bool
```

- *Type:* bool
- *Default:* true

Whether to commit the managed files by default.

---

##### `git_ignore_options`<sup>Optional</sup> <a name="git_ignore_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.gitIgnoreOptions"></a>

```python
git_ignore_options: IgnoreFileOptions
```

- *Type:* projen.IgnoreFileOptions

Configuration options for .gitignore file.

---

##### `git_options`<sup>Optional</sup> <a name="git_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.gitOptions"></a>

```python
git_options: GitOptions
```

- *Type:* projen.GitOptions

Configuration options for git.

---

##### `logging`<sup>Optional</sup> <a name="logging" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.logging"></a>

```python
logging: LoggerOptions
```

- *Type:* projen.LoggerOptions
- *Default:* {}

Configure logging options such as verbosity.

---

##### `outdir`<sup>Optional</sup> <a name="outdir" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.outdir"></a>

```python
outdir: str
```

- *Type:* str
- *Default:* "."

The root directory of the project.

Relative to this directory, all files are synthesized.

If this project has a parent, this directory is relative to the parent
directory and it cannot be the same as the parent or any of it's other
sub-projects.

---

##### `parent`<sup>Optional</sup> <a name="parent" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.parent"></a>

```python
parent: Project
```

- *Type:* projen.Project

The parent project, if this project is part of a bigger project.

---

##### `projen_command`<sup>Optional</sup> <a name="projen_command" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.projenCommand"></a>

```python
projen_command: str
```

- *Type:* str
- *Default:* "npx projen"

The shell command to use in order to run the projen CLI.

Can be used to customize in special environments.

---

##### `projenrc_json`<sup>Optional</sup> <a name="projenrc_json" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.projenrcJson"></a>

```python
projenrc_json: bool
```

- *Type:* bool
- *Default:* false

Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation.

---

##### `projenrc_json_options`<sup>Optional</sup> <a name="projenrc_json_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.projenrcJsonOptions"></a>

```python
projenrc_json_options: ProjenrcJsonOptions
```

- *Type:* projen.ProjenrcJsonOptions
- *Default:* default options

Options for .projenrc.json.

---

##### `renovatebot`<sup>Optional</sup> <a name="renovatebot" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.renovatebot"></a>

```python
renovatebot: bool
```

- *Type:* bool
- *Default:* false

Use renovatebot to handle dependency upgrades.

---

##### `renovatebot_options`<sup>Optional</sup> <a name="renovatebot_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.renovatebotOptions"></a>

```python
renovatebot_options: RenovatebotOptions
```

- *Type:* projen.RenovatebotOptions
- *Default:* default options

Options for renovatebot.

---

##### `auto_approve_options`<sup>Optional</sup> <a name="auto_approve_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.autoApproveOptions"></a>

```python
auto_approve_options: AutoApproveOptions
```

- *Type:* projen.github.AutoApproveOptions
- *Default:* auto approve is disabled

Enable and configure the 'auto approve' workflow.

---

##### `auto_merge`<sup>Optional</sup> <a name="auto_merge" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.autoMerge"></a>

```python
auto_merge: bool
```

- *Type:* bool
- *Default:* true

Enable automatic merging on GitHub.

Has no effect if `github.mergify`
is set to false.

---

##### `auto_merge_options`<sup>Optional</sup> <a name="auto_merge_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.autoMergeOptions"></a>

```python
auto_merge_options: AutoMergeOptions
```

- *Type:* projen.github.AutoMergeOptions
- *Default:* see defaults in `AutoMergeOptions`

Configure options for automatic merging on GitHub.

Has no effect if
`github.mergify` or `autoMerge` is set to false.

---

##### `clobber`<sup>Optional</sup> <a name="clobber" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.clobber"></a>

```python
clobber: bool
```

- *Type:* bool
- *Default:* true, but false for subprojects

Add a `clobber` task which resets the repo to origin.

---

##### `dev_container`<sup>Optional</sup> <a name="dev_container" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.devContainer"></a>

```python
dev_container: bool
```

- *Type:* bool
- *Default:* false

Add a VSCode development environment (used for GitHub Codespaces).

---

##### `github`<sup>Optional</sup> <a name="github" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.github"></a>

```python
github: bool
```

- *Type:* bool
- *Default:* true

Enable GitHub integration.

Enabled by default for root projects. Disabled for non-root projects.

---

##### `github_options`<sup>Optional</sup> <a name="github_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.githubOptions"></a>

```python
github_options: GitHubOptions
```

- *Type:* projen.github.GitHubOptions
- *Default:* see GitHubOptions

Options for GitHub integration.

---

##### `gitpod`<sup>Optional</sup> <a name="gitpod" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.gitpod"></a>

```python
gitpod: bool
```

- *Type:* bool
- *Default:* false

Add a Gitpod development environment.

---

##### ~~`mergify`~~<sup>Optional</sup> <a name="mergify" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.mergify"></a>

- *Deprecated:* use `githubOptions.mergify` instead

```python
mergify: bool
```

- *Type:* bool
- *Default:* true

Whether mergify should be enabled on this repository or not.

---

##### ~~`mergify_options`~~<sup>Optional</sup> <a name="mergify_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.mergifyOptions"></a>

- *Deprecated:* use `githubOptions.mergifyOptions` instead

```python
mergify_options: MergifyOptions
```

- *Type:* projen.github.MergifyOptions
- *Default:* default options

Options for mergify.

---

##### ~~`project_type`~~<sup>Optional</sup> <a name="project_type" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.projectType"></a>

- *Deprecated:* no longer supported at the base project level

```python
project_type: ProjectType
```

- *Type:* projen.ProjectType
- *Default:* ProjectType.UNKNOWN

Which type of project this is (library/app).

---

##### `projen_credentials`<sup>Optional</sup> <a name="projen_credentials" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.projenCredentials"></a>

```python
projen_credentials: GithubCredentials
```

- *Type:* projen.github.GithubCredentials
- *Default:* use a personal access token named PROJEN_GITHUB_TOKEN

Choose a method of providing GitHub API access for projen workflows.

---

##### ~~`projen_token_secret`~~<sup>Optional</sup> <a name="projen_token_secret" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.projenTokenSecret"></a>

- *Deprecated:* use `projenCredentials`

```python
projen_token_secret: str
```

- *Type:* str
- *Default:* "PROJEN_GITHUB_TOKEN"

The name of a secret which includes a GitHub Personal Access Token to be used by projen workflows.

This token needs to have the `repo`, `workflows`
and `packages` scope.

---

##### `readme`<sup>Optional</sup> <a name="readme" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.readme"></a>

```python
readme: SampleReadmeProps
```

- *Type:* projen.SampleReadmeProps
- *Default:* { filename: 'README.md', contents: '# replace this' }

The README setup.

---

*Example*

```python
"{ filename: 'readme.md', contents: '# title' }"
```


##### `stale`<sup>Optional</sup> <a name="stale" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.stale"></a>

```python
stale: bool
```

- *Type:* bool
- *Default:* false

Auto-close of stale issues and pull request.

See `staleOptions` for options.

---

##### `stale_options`<sup>Optional</sup> <a name="stale_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.staleOptions"></a>

```python
stale_options: StaleOptions
```

- *Type:* projen.github.StaleOptions
- *Default:* see defaults in `StaleOptions`

Auto-close stale issues and pull requests.

To disable set `stale` to `false`.

---

##### `vscode`<sup>Optional</sup> <a name="vscode" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.vscode"></a>

```python
vscode: bool
```

- *Type:* bool
- *Default:* true

Enable VSCode integration.

Enabled by default for root projects. Disabled for non-root projects.

---

##### `author_email`<sup>Required</sup> <a name="author_email" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.authorEmail"></a>

```python
author_email: str
```

- *Type:* str
- *Default:* $GIT_USER_EMAIL

Author's e-mail.

---

##### `author_name`<sup>Required</sup> <a name="author_name" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.authorName"></a>

```python
author_name: str
```

- *Type:* str
- *Default:* $GIT_USER_NAME

Author's name.

---

##### `version`<sup>Required</sup> <a name="version" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.version"></a>

```python
version: str
```

- *Type:* str
- *Default:* "0.1.0"

Version of the package.

---

##### `classifiers`<sup>Optional</sup> <a name="classifiers" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.classifiers"></a>

```python
classifiers: typing.List[str]
```

- *Type:* typing.List[str]

A list of PyPI trove classifiers that describe the project.

> [https://pypi.org/classifiers/](https://pypi.org/classifiers/)

---

##### `description`<sup>Optional</sup> <a name="description" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.description"></a>

```python
description: str
```

- *Type:* str

A short description of the package.

---

##### `homepage`<sup>Optional</sup> <a name="homepage" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.homepage"></a>

```python
homepage: str
```

- *Type:* str

A URL to the website of the project.

---

##### `license`<sup>Optional</sup> <a name="license" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.license"></a>

```python
license: str
```

- *Type:* str

License of this package as an SPDX identifier.

---

##### `package_name`<sup>Optional</sup> <a name="package_name" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.packageName"></a>

```python
package_name: str
```

- *Type:* str

Package name.

---

##### `poetry_options`<sup>Optional</sup> <a name="poetry_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.poetryOptions"></a>

```python
poetry_options: PoetryPyprojectOptionsWithoutDeps
```

- *Type:* projen.python.PoetryPyprojectOptionsWithoutDeps

Additional options to set for poetry if using poetry.

---

##### `setup_config`<sup>Optional</sup> <a name="setup_config" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.setupConfig"></a>

```python
setup_config: typing.Mapping[typing.Any]
```

- *Type:* typing.Mapping[typing.Any]

Additional fields to pass in the setup() function if using setuptools.

---

##### `module_name`<sup>Required</sup> <a name="module_name" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.moduleName"></a>

```python
module_name: str
```

- *Type:* str
- *Default:* $PYTHON_MODULE_NAME

Name of the python package as used in imports and filenames.

Must only consist of alphanumeric characters and underscores.

---

##### `deps`<sup>Optional</sup> <a name="deps" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.deps"></a>

```python
deps: typing.List[str]
```

- *Type:* typing.List[str]
- *Default:* []

List of runtime dependencies for this project.

Dependencies use the format: `<module>@<semver>`

Additional dependencies can be added via `project.addDependency()`.

---

##### `dev_deps`<sup>Optional</sup> <a name="dev_deps" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.devDeps"></a>

```python
dev_deps: typing.List[str]
```

- *Type:* typing.List[str]
- *Default:* []

List of dev dependencies for this project.

Dependencies use the format: `<module>@<semver>`

Additional dependencies can be added via `project.addDevDependency()`.

---

##### `pip`<sup>Optional</sup> <a name="pip" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.pip"></a>

```python
pip: bool
```

- *Type:* bool
- *Default:* true, unless poetry is true, then false

Use pip with a requirements.txt file to track project dependencies.

---

##### `poetry`<sup>Optional</sup> <a name="poetry" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.poetry"></a>

```python
poetry: bool
```

- *Type:* bool
- *Default:* false

Use poetry to manage your project dependencies, virtual environment, and (optional) packaging/publishing.

This feature is incompatible with pip, setuptools, or venv.
If you set this option to `true`, then pip, setuptools, and venv must be set to `false`.

---

##### `projenrc_js`<sup>Optional</sup> <a name="projenrc_js" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.projenrcJs"></a>

```python
projenrc_js: bool
```

- *Type:* bool
- *Default:* false

Use projenrc in javascript.

This will install `projen` as a JavaScript dependency and add a `synth`
task which will run `.projenrc.js`.

---

##### `projenrc_js_options`<sup>Optional</sup> <a name="projenrc_js_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.projenrcJsOptions"></a>

```python
projenrc_js_options: ProjenrcOptions
```

- *Type:* projen.javascript.ProjenrcOptions
- *Default:* default options

Options related to projenrc in JavaScript.

---

##### `projenrc_python`<sup>Optional</sup> <a name="projenrc_python" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.projenrcPython"></a>

```python
projenrc_python: bool
```

- *Type:* bool
- *Default:* true

Use projenrc in Python.

This will install `projen` as a Python dependency and add a `synth`
task which will run `.projenrc.py`.

---

##### `projenrc_python_options`<sup>Optional</sup> <a name="projenrc_python_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.projenrcPythonOptions"></a>

```python
projenrc_python_options: ProjenrcOptions
```

- *Type:* projen.python.ProjenrcOptions
- *Default:* default options

Options related to projenrc in python.

---

##### `projenrc_ts`<sup>Optional</sup> <a name="projenrc_ts" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.projenrcTs"></a>

```python
projenrc_ts: bool
```

- *Type:* bool
- *Default:* false

Use projenrc in TypeScript.

This will create a tsconfig file (default: `tsconfig.projen.json`)
and use `ts-node` in the default task to parse the project source files.

---

##### `projenrc_ts_options`<sup>Optional</sup> <a name="projenrc_ts_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.projenrcTsOptions"></a>

```python
projenrc_ts_options: ProjenrcTsOptions
```

- *Type:* projen.typescript.ProjenrcTsOptions
- *Default:* default options

Options related to projenrc in TypeScript.

---

##### `pytest`<sup>Optional</sup> <a name="pytest" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.pytest"></a>

```python
pytest: bool
```

- *Type:* bool
- *Default:* true

Include pytest tests.

---

##### `pytest_options`<sup>Optional</sup> <a name="pytest_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.pytestOptions"></a>

```python
pytest_options: PytestOptions
```

- *Type:* projen.python.PytestOptions
- *Default:* defaults

pytest options.

---

##### `python_exec`<sup>Optional</sup> <a name="python_exec" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.pythonExec"></a>

```python
python_exec: str
```

- *Type:* str
- *Default:* "python"

Path to the python executable to use.

---

##### `sample`<sup>Optional</sup> <a name="sample" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.sample"></a>

```python
sample: bool
```

- *Type:* bool
- *Default:* true

Include sample code and test if the relevant directories don't exist.

---

##### `setuptools`<sup>Optional</sup> <a name="setuptools" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.setuptools"></a>

```python
setuptools: bool
```

- *Type:* bool
- *Default:* true, unless poetry is true, then false

Use setuptools with a setup.py script for packaging and publishing.

---

##### `venv`<sup>Optional</sup> <a name="venv" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.venv"></a>

```python
venv: bool
```

- *Type:* bool
- *Default:* true, unless poetry is true, then false

Use venv to manage a virtual environment for installing dependencies inside.

---

##### `venv_options`<sup>Optional</sup> <a name="venv_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.venvOptions"></a>

```python
venv_options: VenvOptions
```

- *Type:* projen.python.VenvOptions
- *Default:* defaults

Venv options.

---

##### `open_api_generator_cli_config`<sup>Optional</sup> <a name="open_api_generator_cli_config" id="@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions.property.openApiGeneratorCliConfig"></a>

```python
open_api_generator_cli_config: OpenApiGeneratorCliConfig
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfig">OpenApiGeneratorCliConfig</a>

Configuration for the OpenAPI Generator CLI.

Overrides default values if specified.

> [https://github.com/OpenAPITools/openapi-generator-cli#configuration](https://github.com/OpenAPITools/openapi-generator-cli#configuration)

---

### GeneratedRuntimeCodeOptions <a name="GeneratedRuntimeCodeOptions" id="@aws-prototyping-sdk/type-safe-api.GeneratedRuntimeCodeOptions"></a>

Options for generated runtimes.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.GeneratedRuntimeCodeOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.GeneratedRuntimeCodeOptions(
  java: GeneratedJavaRuntimeOptions = None,
  python: GeneratedPythonRuntimeOptions = None,
  typescript: GeneratedTypeScriptRuntimeOptions = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedRuntimeCodeOptions.property.java">java</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions">GeneratedJavaRuntimeOptions</a></code> | Options for a generated java project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedRuntimeCodeOptions.property.python">python</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions">GeneratedPythonRuntimeOptions</a></code> | Options for a generated python project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedRuntimeCodeOptions.property.typescript">typescript</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions">GeneratedTypeScriptRuntimeOptions</a></code> | Options for a generated typescript project. |

---

##### `java`<sup>Optional</sup> <a name="java" id="@aws-prototyping-sdk/type-safe-api.GeneratedRuntimeCodeOptions.property.java"></a>

```python
java: GeneratedJavaRuntimeOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.GeneratedJavaRuntimeOptions">GeneratedJavaRuntimeOptions</a>

Options for a generated java project.

These override the default inferred options.

---

##### `python`<sup>Optional</sup> <a name="python" id="@aws-prototyping-sdk/type-safe-api.GeneratedRuntimeCodeOptions.property.python"></a>

```python
python: GeneratedPythonRuntimeOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.GeneratedPythonRuntimeOptions">GeneratedPythonRuntimeOptions</a>

Options for a generated python project.

These override the default inferred options.

---

##### `typescript`<sup>Optional</sup> <a name="typescript" id="@aws-prototyping-sdk/type-safe-api.GeneratedRuntimeCodeOptions.property.typescript"></a>

```python
typescript: GeneratedTypeScriptRuntimeOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions">GeneratedTypeScriptRuntimeOptions</a>

Options for a generated typescript project.

These override the default inferred options.

---

### GeneratedTypeScriptInfrastructureOptions <a name="GeneratedTypeScriptInfrastructureOptions" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions"></a>

Options for configuring a generated typescript infrastructure project.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.GeneratedTypeScriptInfrastructureOptions(
  name: str,
  commit_generated: bool = None,
  git_ignore_options: IgnoreFileOptions = None,
  git_options: GitOptions = None,
  logging: LoggerOptions = None,
  outdir: str = None,
  parent: Project = None,
  projen_command: str = None,
  projenrc_json: bool = None,
  projenrc_json_options: ProjenrcJsonOptions = None,
  renovatebot: bool = None,
  renovatebot_options: RenovatebotOptions = None,
  auto_approve_options: AutoApproveOptions = None,
  auto_merge: bool = None,
  auto_merge_options: AutoMergeOptions = None,
  clobber: bool = None,
  dev_container: bool = None,
  github: bool = None,
  github_options: GitHubOptions = None,
  gitpod: bool = None,
  mergify: bool = None,
  mergify_options: MergifyOptions = None,
  project_type: ProjectType = None,
  projen_credentials: GithubCredentials = None,
  projen_token_secret: str = None,
  readme: SampleReadmeProps = None,
  stale: bool = None,
  stale_options: StaleOptions = None,
  vscode: bool = None,
  allow_library_dependencies: bool = None,
  author_email: str = None,
  author_name: str = None,
  author_organization: bool = None,
  author_url: str = None,
  auto_detect_bin: bool = None,
  bin: typing.Mapping[str] = None,
  bugs_email: str = None,
  bugs_url: str = None,
  bundled_deps: typing.List[str] = None,
  code_artifact_options: CodeArtifactOptions = None,
  deps: typing.List[str] = None,
  description: str = None,
  dev_deps: typing.List[str] = None,
  entrypoint: str = None,
  homepage: str = None,
  keywords: typing.List[str] = None,
  license: str = None,
  licensed: bool = None,
  max_node_version: str = None,
  min_node_version: str = None,
  npm_access: NpmAccess = None,
  npm_registry: str = None,
  npm_registry_url: str = None,
  npm_token_secret: str = None,
  package_manager: NodePackageManager = None,
  package_name: str = None,
  peer_dependency_options: PeerDependencyOptions = None,
  peer_deps: typing.List[str] = None,
  pnpm_version: str = None,
  repository: str = None,
  repository_directory: str = None,
  scoped_packages_options: typing.List[ScopedPackagesOptions] = None,
  scripts: typing.Mapping[str] = None,
  stability: str = None,
  jsii_release_version: str = None,
  major_version: typing.Union[int, float] = None,
  min_major_version: typing.Union[int, float] = None,
  npm_dist_tag: str = None,
  post_build_steps: typing.List[JobStep] = None,
  prerelease: str = None,
  publish_dry_run: bool = None,
  publish_tasks: bool = None,
  release_branches: typing.Mapping[BranchOptions] = None,
  release_every_commit: bool = None,
  release_failure_issue: bool = None,
  release_failure_issue_label: str = None,
  release_schedule: str = None,
  release_tag_prefix: str = None,
  release_trigger: ReleaseTrigger = None,
  release_workflow_name: str = None,
  release_workflow_setup_steps: typing.List[JobStep] = None,
  versionrc_options: typing.Mapping[typing.Any] = None,
  workflow_container_image: str = None,
  workflow_runs_on: typing.List[str] = None,
  default_release_branch: str,
  artifacts_directory: str = None,
  auto_approve_upgrades: bool = None,
  build_workflow: bool = None,
  build_workflow_triggers: Triggers = None,
  bundler_options: BundlerOptions = None,
  code_cov: bool = None,
  code_cov_token_secret: str = None,
  copyright_owner: str = None,
  copyright_period: str = None,
  dependabot: bool = None,
  dependabot_options: DependabotOptions = None,
  deps_upgrade: bool = None,
  deps_upgrade_options: UpgradeDependenciesOptions = None,
  gitignore: typing.List[str] = None,
  jest: bool = None,
  jest_options: JestOptions = None,
  mutable_build: bool = None,
  npmignore: typing.List[str] = None,
  npmignore_enabled: bool = None,
  npm_ignore_options: IgnoreFileOptions = None,
  package: bool = None,
  prettier: bool = None,
  prettier_options: PrettierOptions = None,
  projen_dev_dependency: bool = None,
  projenrc_js: bool = None,
  projenrc_js_options: ProjenrcOptions = None,
  projen_version: str = None,
  pull_request_template: bool = None,
  pull_request_template_contents: typing.List[str] = None,
  release: bool = None,
  release_to_npm: bool = None,
  release_workflow: bool = None,
  workflow_bootstrap_steps: typing.List[JobStep] = None,
  workflow_git_identity: GitIdentity = None,
  workflow_node_version: str = None,
  workflow_package_cache: bool = None,
  disable_tsconfig: bool = None,
  disable_tsconfig_dev: bool = None,
  docgen: bool = None,
  docs_directory: str = None,
  entrypoint_types: str = None,
  eslint: bool = None,
  eslint_options: EslintOptions = None,
  libdir: str = None,
  projenrc_ts: bool = None,
  projenrc_ts_options: ProjenrcOptions = None,
  sample_code: bool = None,
  srcdir: str = None,
  testdir: str = None,
  tsconfig: TypescriptConfigOptions = None,
  tsconfig_dev: TypescriptConfigOptions = None,
  tsconfig_dev_file: str = None,
  typescript_version: str = None,
  open_api_generator_cli_config: OpenApiGeneratorCliConfig = None,
  mock_data_options: MockResponseDataGenerationOptions = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.name">name</a></code> | <code>str</code> | This is the name of your project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.commitGenerated">commit_generated</a></code> | <code>bool</code> | Whether to commit the managed files by default. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.gitIgnoreOptions">git_ignore_options</a></code> | <code>projen.IgnoreFileOptions</code> | Configuration options for .gitignore file. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.gitOptions">git_options</a></code> | <code>projen.GitOptions</code> | Configuration options for git. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.logging">logging</a></code> | <code>projen.LoggerOptions</code> | Configure logging options such as verbosity. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.outdir">outdir</a></code> | <code>str</code> | The root directory of the project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.parent">parent</a></code> | <code>projen.Project</code> | The parent project, if this project is part of a bigger project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.projenCommand">projen_command</a></code> | <code>str</code> | The shell command to use in order to run the projen CLI. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.projenrcJson">projenrc_json</a></code> | <code>bool</code> | Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.projenrcJsonOptions">projenrc_json_options</a></code> | <code>projen.ProjenrcJsonOptions</code> | Options for .projenrc.json. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.renovatebot">renovatebot</a></code> | <code>bool</code> | Use renovatebot to handle dependency upgrades. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.renovatebotOptions">renovatebot_options</a></code> | <code>projen.RenovatebotOptions</code> | Options for renovatebot. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.autoApproveOptions">auto_approve_options</a></code> | <code>projen.github.AutoApproveOptions</code> | Enable and configure the 'auto approve' workflow. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.autoMerge">auto_merge</a></code> | <code>bool</code> | Enable automatic merging on GitHub. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.autoMergeOptions">auto_merge_options</a></code> | <code>projen.github.AutoMergeOptions</code> | Configure options for automatic merging on GitHub. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.clobber">clobber</a></code> | <code>bool</code> | Add a `clobber` task which resets the repo to origin. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.devContainer">dev_container</a></code> | <code>bool</code> | Add a VSCode development environment (used for GitHub Codespaces). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.github">github</a></code> | <code>bool</code> | Enable GitHub integration. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.githubOptions">github_options</a></code> | <code>projen.github.GitHubOptions</code> | Options for GitHub integration. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.gitpod">gitpod</a></code> | <code>bool</code> | Add a Gitpod development environment. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.mergify">mergify</a></code> | <code>bool</code> | Whether mergify should be enabled on this repository or not. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.mergifyOptions">mergify_options</a></code> | <code>projen.github.MergifyOptions</code> | Options for mergify. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.projectType">project_type</a></code> | <code>projen.ProjectType</code> | Which type of project this is (library/app). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.projenCredentials">projen_credentials</a></code> | <code>projen.github.GithubCredentials</code> | Choose a method of providing GitHub API access for projen workflows. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.projenTokenSecret">projen_token_secret</a></code> | <code>str</code> | The name of a secret which includes a GitHub Personal Access Token to be used by projen workflows. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.readme">readme</a></code> | <code>projen.SampleReadmeProps</code> | The README setup. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.stale">stale</a></code> | <code>bool</code> | Auto-close of stale issues and pull request. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.staleOptions">stale_options</a></code> | <code>projen.github.StaleOptions</code> | Auto-close stale issues and pull requests. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.vscode">vscode</a></code> | <code>bool</code> | Enable VSCode integration. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.allowLibraryDependencies">allow_library_dependencies</a></code> | <code>bool</code> | Allow the project to include `peerDependencies` and `bundledDependencies`. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.authorEmail">author_email</a></code> | <code>str</code> | Author's e-mail. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.authorName">author_name</a></code> | <code>str</code> | Author's name. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.authorOrganization">author_organization</a></code> | <code>bool</code> | Is the author an organization. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.authorUrl">author_url</a></code> | <code>str</code> | Author's URL / Website. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.autoDetectBin">auto_detect_bin</a></code> | <code>bool</code> | Automatically add all executables under the `bin` directory to your `package.json` file under the `bin` section. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.bin">bin</a></code> | <code>typing.Mapping[str]</code> | Binary programs vended with your module. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.bugsEmail">bugs_email</a></code> | <code>str</code> | The email address to which issues should be reported. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.bugsUrl">bugs_url</a></code> | <code>str</code> | The url to your project's issue tracker. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.bundledDeps">bundled_deps</a></code> | <code>typing.List[str]</code> | List of dependencies to bundle into this module. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.codeArtifactOptions">code_artifact_options</a></code> | <code>projen.javascript.CodeArtifactOptions</code> | Options for npm packages using AWS CodeArtifact. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.deps">deps</a></code> | <code>typing.List[str]</code> | Runtime dependencies of this module. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.description">description</a></code> | <code>str</code> | The description is just a string that helps people understand the purpose of the package. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.devDeps">dev_deps</a></code> | <code>typing.List[str]</code> | Build dependencies for this module. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.entrypoint">entrypoint</a></code> | <code>str</code> | Module entrypoint (`main` in `package.json`). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.homepage">homepage</a></code> | <code>str</code> | Package's Homepage / Website. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.keywords">keywords</a></code> | <code>typing.List[str]</code> | Keywords to include in `package.json`. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.license">license</a></code> | <code>str</code> | License's SPDX identifier. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.licensed">licensed</a></code> | <code>bool</code> | Indicates if a license should be added. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.maxNodeVersion">max_node_version</a></code> | <code>str</code> | Minimum node.js version to require via `engines` (inclusive). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.minNodeVersion">min_node_version</a></code> | <code>str</code> | Minimum Node.js version to require via package.json `engines` (inclusive). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.npmAccess">npm_access</a></code> | <code>projen.javascript.NpmAccess</code> | Access level of the npm package. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.npmRegistry">npm_registry</a></code> | <code>str</code> | The host name of the npm registry to publish to. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.npmRegistryUrl">npm_registry_url</a></code> | <code>str</code> | The base URL of the npm package registry. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.npmTokenSecret">npm_token_secret</a></code> | <code>str</code> | GitHub secret which contains the NPM token to use when publishing packages. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.packageManager">package_manager</a></code> | <code>projen.javascript.NodePackageManager</code> | The Node Package Manager used to execute scripts. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.packageName">package_name</a></code> | <code>str</code> | The "name" in package.json. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.peerDependencyOptions">peer_dependency_options</a></code> | <code>projen.javascript.PeerDependencyOptions</code> | Options for `peerDeps`. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.peerDeps">peer_deps</a></code> | <code>typing.List[str]</code> | Peer dependencies for this module. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.pnpmVersion">pnpm_version</a></code> | <code>str</code> | The version of PNPM to use if using PNPM as a package manager. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.repository">repository</a></code> | <code>str</code> | The repository is the location where the actual code for your package lives. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.repositoryDirectory">repository_directory</a></code> | <code>str</code> | If the package.json for your package is not in the root directory (for example if it is part of a monorepo), you can specify the directory in which it lives. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.scopedPackagesOptions">scoped_packages_options</a></code> | <code>typing.List[projen.javascript.ScopedPackagesOptions]</code> | Options for privately hosted scoped packages. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.scripts">scripts</a></code> | <code>typing.Mapping[str]</code> | npm scripts to include. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.stability">stability</a></code> | <code>str</code> | Package's Stability. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.jsiiReleaseVersion">jsii_release_version</a></code> | <code>str</code> | Version requirement of `publib` which is used to publish modules to npm. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.majorVersion">major_version</a></code> | <code>typing.Union[int, float]</code> | Major version to release from the default branch. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.minMajorVersion">min_major_version</a></code> | <code>typing.Union[int, float]</code> | Minimal Major version to release. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.npmDistTag">npm_dist_tag</a></code> | <code>str</code> | The npmDistTag to use when publishing from the default branch. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.postBuildSteps">post_build_steps</a></code> | <code>typing.List[projen.github.workflows.JobStep]</code> | Steps to execute after build as part of the release workflow. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.prerelease">prerelease</a></code> | <code>str</code> | Bump versions from the default branch as pre-releases (e.g. "beta", "alpha", "pre"). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.publishDryRun">publish_dry_run</a></code> | <code>bool</code> | Instead of actually publishing to package managers, just print the publishing command. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.publishTasks">publish_tasks</a></code> | <code>bool</code> | Define publishing tasks that can be executed manually as well as workflows. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.releaseBranches">release_branches</a></code> | <code>typing.Mapping[projen.release.BranchOptions]</code> | Defines additional release branches. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.releaseEveryCommit">release_every_commit</a></code> | <code>bool</code> | Automatically release new versions every commit to one of branches in `releaseBranches`. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.releaseFailureIssue">release_failure_issue</a></code> | <code>bool</code> | Create a github issue on every failed publishing task. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.releaseFailureIssueLabel">release_failure_issue_label</a></code> | <code>str</code> | The label to apply to issues indicating publish failures. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.releaseSchedule">release_schedule</a></code> | <code>str</code> | CRON schedule to trigger new releases. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.releaseTagPrefix">release_tag_prefix</a></code> | <code>str</code> | Automatically add the given prefix to release tags. Useful if you are releasing on multiple branches with overlapping version numbers. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.releaseTrigger">release_trigger</a></code> | <code>projen.release.ReleaseTrigger</code> | The release trigger to use. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.releaseWorkflowName">release_workflow_name</a></code> | <code>str</code> | The name of the default release workflow. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.releaseWorkflowSetupSteps">release_workflow_setup_steps</a></code> | <code>typing.List[projen.github.workflows.JobStep]</code> | A set of workflow steps to execute in order to setup the workflow container. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.versionrcOptions">versionrc_options</a></code> | <code>typing.Mapping[typing.Any]</code> | Custom configuration used when creating changelog with standard-version package. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.workflowContainerImage">workflow_container_image</a></code> | <code>str</code> | Container image to use for GitHub workflows. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.workflowRunsOn">workflow_runs_on</a></code> | <code>typing.List[str]</code> | Github Runner selection labels. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.defaultReleaseBranch">default_release_branch</a></code> | <code>str</code> | The name of the main release branch. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.artifactsDirectory">artifacts_directory</a></code> | <code>str</code> | A directory which will contain build artifacts. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.autoApproveUpgrades">auto_approve_upgrades</a></code> | <code>bool</code> | Automatically approve deps upgrade PRs, allowing them to be merged by mergify (if configued). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.buildWorkflow">build_workflow</a></code> | <code>bool</code> | Define a GitHub workflow for building PRs. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.buildWorkflowTriggers">build_workflow_triggers</a></code> | <code>projen.github.workflows.Triggers</code> | Build workflow triggers. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.bundlerOptions">bundler_options</a></code> | <code>projen.javascript.BundlerOptions</code> | Options for `Bundler`. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.codeCov">code_cov</a></code> | <code>bool</code> | Define a GitHub workflow step for sending code coverage metrics to https://codecov.io/ Uses codecov/codecov-action@v3 A secret is required for private repos. Configured with `@codeCovTokenSecret`. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.codeCovTokenSecret">code_cov_token_secret</a></code> | <code>str</code> | Define the secret name for a specified https://codecov.io/ token A secret is required to send coverage for private repositories. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.copyrightOwner">copyright_owner</a></code> | <code>str</code> | License copyright owner. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.copyrightPeriod">copyright_period</a></code> | <code>str</code> | The copyright years to put in the LICENSE file. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.dependabot">dependabot</a></code> | <code>bool</code> | Use dependabot to handle dependency upgrades. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.dependabotOptions">dependabot_options</a></code> | <code>projen.github.DependabotOptions</code> | Options for dependabot. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.depsUpgrade">deps_upgrade</a></code> | <code>bool</code> | Use github workflows to handle dependency upgrades. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.depsUpgradeOptions">deps_upgrade_options</a></code> | <code>projen.javascript.UpgradeDependenciesOptions</code> | Options for `UpgradeDependencies`. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.gitignore">gitignore</a></code> | <code>typing.List[str]</code> | Additional entries to .gitignore. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.jest">jest</a></code> | <code>bool</code> | Setup jest unit tests. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.jestOptions">jest_options</a></code> | <code>projen.javascript.JestOptions</code> | Jest options. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.mutableBuild">mutable_build</a></code> | <code>bool</code> | Automatically update files modified during builds to pull-request branches. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.npmignore">npmignore</a></code> | <code>typing.List[str]</code> | Additional entries to .npmignore. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.npmignoreEnabled">npmignore_enabled</a></code> | <code>bool</code> | Defines an .npmignore file. Normally this is only needed for libraries that are packaged as tarballs. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.npmIgnoreOptions">npm_ignore_options</a></code> | <code>projen.IgnoreFileOptions</code> | Configuration options for .npmignore file. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.package">package</a></code> | <code>bool</code> | Defines a `package` task that will produce an npm tarball under the artifacts directory (e.g. `dist`). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.prettier">prettier</a></code> | <code>bool</code> | Setup prettier. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.prettierOptions">prettier_options</a></code> | <code>projen.javascript.PrettierOptions</code> | Prettier options. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.projenDevDependency">projen_dev_dependency</a></code> | <code>bool</code> | Indicates of "projen" should be installed as a devDependency. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.projenrcJs">projenrc_js</a></code> | <code>bool</code> | Generate (once) .projenrc.js (in JavaScript). Set to `false` in order to disable .projenrc.js generation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.projenrcJsOptions">projenrc_js_options</a></code> | <code>projen.javascript.ProjenrcOptions</code> | Options for .projenrc.js. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.projenVersion">projen_version</a></code> | <code>str</code> | Version of projen to install. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.pullRequestTemplate">pull_request_template</a></code> | <code>bool</code> | Include a GitHub pull request template. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.pullRequestTemplateContents">pull_request_template_contents</a></code> | <code>typing.List[str]</code> | The contents of the pull request template. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.release">release</a></code> | <code>bool</code> | Add release management to this project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.releaseToNpm">release_to_npm</a></code> | <code>bool</code> | Automatically release to npm when new versions are introduced. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.releaseWorkflow">release_workflow</a></code> | <code>bool</code> | DEPRECATED: renamed to `release`. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.workflowBootstrapSteps">workflow_bootstrap_steps</a></code> | <code>typing.List[projen.github.workflows.JobStep]</code> | Workflow steps to use in order to bootstrap this repo. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.workflowGitIdentity">workflow_git_identity</a></code> | <code>projen.github.GitIdentity</code> | The git identity to use in workflows. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.workflowNodeVersion">workflow_node_version</a></code> | <code>str</code> | The node version to use in GitHub workflows. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.workflowPackageCache">workflow_package_cache</a></code> | <code>bool</code> | Enable Node.js package cache in GitHub workflows. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.disableTsconfig">disable_tsconfig</a></code> | <code>bool</code> | Do not generate a `tsconfig.json` file (used by jsii projects since tsconfig.json is generated by the jsii compiler). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.disableTsconfigDev">disable_tsconfig_dev</a></code> | <code>bool</code> | Do not generate a `tsconfig.dev.json` file. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.docgen">docgen</a></code> | <code>bool</code> | Docgen by Typedoc. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.docsDirectory">docs_directory</a></code> | <code>str</code> | Docs directory. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.entrypointTypes">entrypoint_types</a></code> | <code>str</code> | The .d.ts file that includes the type declarations for this module. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.eslint">eslint</a></code> | <code>bool</code> | Setup eslint. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.eslintOptions">eslint_options</a></code> | <code>projen.javascript.EslintOptions</code> | Eslint options. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.libdir">libdir</a></code> | <code>str</code> | Typescript  artifacts output directory. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.projenrcTs">projenrc_ts</a></code> | <code>bool</code> | Use TypeScript for your projenrc file (`.projenrc.ts`). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.projenrcTsOptions">projenrc_ts_options</a></code> | <code>projen.typescript.ProjenrcOptions</code> | Options for .projenrc.ts. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.sampleCode">sample_code</a></code> | <code>bool</code> | Generate one-time sample in `src/` and `test/` if there are no files there. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.srcdir">srcdir</a></code> | <code>str</code> | Typescript sources directory. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.testdir">testdir</a></code> | <code>str</code> | Jest tests directory. Tests files should be named `xxx.test.ts`. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.tsconfig">tsconfig</a></code> | <code>projen.javascript.TypescriptConfigOptions</code> | Custom TSConfig. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.tsconfigDev">tsconfig_dev</a></code> | <code>projen.javascript.TypescriptConfigOptions</code> | Custom tsconfig options for the development tsconfig.json file (used for testing). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.tsconfigDevFile">tsconfig_dev_file</a></code> | <code>str</code> | The name of the development tsconfig.json file. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.typescriptVersion">typescript_version</a></code> | <code>str</code> | TypeScript version to use. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.openApiGeneratorCliConfig">open_api_generator_cli_config</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfig">OpenApiGeneratorCliConfig</a></code> | Configuration for the OpenAPI Generator CLI. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.mockDataOptions">mock_data_options</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.MockResponseDataGenerationOptions">MockResponseDataGenerationOptions</a></code> | Options for the generated mock response data. |

---

##### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.name"></a>

```python
name: str
```

- *Type:* str
- *Default:* $BASEDIR

This is the name of your project.

---

##### `commit_generated`<sup>Optional</sup> <a name="commit_generated" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.commitGenerated"></a>

```python
commit_generated: bool
```

- *Type:* bool
- *Default:* true

Whether to commit the managed files by default.

---

##### `git_ignore_options`<sup>Optional</sup> <a name="git_ignore_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.gitIgnoreOptions"></a>

```python
git_ignore_options: IgnoreFileOptions
```

- *Type:* projen.IgnoreFileOptions

Configuration options for .gitignore file.

---

##### `git_options`<sup>Optional</sup> <a name="git_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.gitOptions"></a>

```python
git_options: GitOptions
```

- *Type:* projen.GitOptions

Configuration options for git.

---

##### `logging`<sup>Optional</sup> <a name="logging" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.logging"></a>

```python
logging: LoggerOptions
```

- *Type:* projen.LoggerOptions
- *Default:* {}

Configure logging options such as verbosity.

---

##### `outdir`<sup>Optional</sup> <a name="outdir" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.outdir"></a>

```python
outdir: str
```

- *Type:* str
- *Default:* "."

The root directory of the project.

Relative to this directory, all files are synthesized.

If this project has a parent, this directory is relative to the parent
directory and it cannot be the same as the parent or any of it's other
sub-projects.

---

##### `parent`<sup>Optional</sup> <a name="parent" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.parent"></a>

```python
parent: Project
```

- *Type:* projen.Project

The parent project, if this project is part of a bigger project.

---

##### `projen_command`<sup>Optional</sup> <a name="projen_command" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.projenCommand"></a>

```python
projen_command: str
```

- *Type:* str
- *Default:* "npx projen"

The shell command to use in order to run the projen CLI.

Can be used to customize in special environments.

---

##### `projenrc_json`<sup>Optional</sup> <a name="projenrc_json" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.projenrcJson"></a>

```python
projenrc_json: bool
```

- *Type:* bool
- *Default:* false

Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation.

---

##### `projenrc_json_options`<sup>Optional</sup> <a name="projenrc_json_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.projenrcJsonOptions"></a>

```python
projenrc_json_options: ProjenrcJsonOptions
```

- *Type:* projen.ProjenrcJsonOptions
- *Default:* default options

Options for .projenrc.json.

---

##### `renovatebot`<sup>Optional</sup> <a name="renovatebot" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.renovatebot"></a>

```python
renovatebot: bool
```

- *Type:* bool
- *Default:* false

Use renovatebot to handle dependency upgrades.

---

##### `renovatebot_options`<sup>Optional</sup> <a name="renovatebot_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.renovatebotOptions"></a>

```python
renovatebot_options: RenovatebotOptions
```

- *Type:* projen.RenovatebotOptions
- *Default:* default options

Options for renovatebot.

---

##### `auto_approve_options`<sup>Optional</sup> <a name="auto_approve_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.autoApproveOptions"></a>

```python
auto_approve_options: AutoApproveOptions
```

- *Type:* projen.github.AutoApproveOptions
- *Default:* auto approve is disabled

Enable and configure the 'auto approve' workflow.

---

##### `auto_merge`<sup>Optional</sup> <a name="auto_merge" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.autoMerge"></a>

```python
auto_merge: bool
```

- *Type:* bool
- *Default:* true

Enable automatic merging on GitHub.

Has no effect if `github.mergify`
is set to false.

---

##### `auto_merge_options`<sup>Optional</sup> <a name="auto_merge_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.autoMergeOptions"></a>

```python
auto_merge_options: AutoMergeOptions
```

- *Type:* projen.github.AutoMergeOptions
- *Default:* see defaults in `AutoMergeOptions`

Configure options for automatic merging on GitHub.

Has no effect if
`github.mergify` or `autoMerge` is set to false.

---

##### `clobber`<sup>Optional</sup> <a name="clobber" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.clobber"></a>

```python
clobber: bool
```

- *Type:* bool
- *Default:* true, but false for subprojects

Add a `clobber` task which resets the repo to origin.

---

##### `dev_container`<sup>Optional</sup> <a name="dev_container" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.devContainer"></a>

```python
dev_container: bool
```

- *Type:* bool
- *Default:* false

Add a VSCode development environment (used for GitHub Codespaces).

---

##### `github`<sup>Optional</sup> <a name="github" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.github"></a>

```python
github: bool
```

- *Type:* bool
- *Default:* true

Enable GitHub integration.

Enabled by default for root projects. Disabled for non-root projects.

---

##### `github_options`<sup>Optional</sup> <a name="github_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.githubOptions"></a>

```python
github_options: GitHubOptions
```

- *Type:* projen.github.GitHubOptions
- *Default:* see GitHubOptions

Options for GitHub integration.

---

##### `gitpod`<sup>Optional</sup> <a name="gitpod" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.gitpod"></a>

```python
gitpod: bool
```

- *Type:* bool
- *Default:* false

Add a Gitpod development environment.

---

##### ~~`mergify`~~<sup>Optional</sup> <a name="mergify" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.mergify"></a>

- *Deprecated:* use `githubOptions.mergify` instead

```python
mergify: bool
```

- *Type:* bool
- *Default:* true

Whether mergify should be enabled on this repository or not.

---

##### ~~`mergify_options`~~<sup>Optional</sup> <a name="mergify_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.mergifyOptions"></a>

- *Deprecated:* use `githubOptions.mergifyOptions` instead

```python
mergify_options: MergifyOptions
```

- *Type:* projen.github.MergifyOptions
- *Default:* default options

Options for mergify.

---

##### ~~`project_type`~~<sup>Optional</sup> <a name="project_type" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.projectType"></a>

- *Deprecated:* no longer supported at the base project level

```python
project_type: ProjectType
```

- *Type:* projen.ProjectType
- *Default:* ProjectType.UNKNOWN

Which type of project this is (library/app).

---

##### `projen_credentials`<sup>Optional</sup> <a name="projen_credentials" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.projenCredentials"></a>

```python
projen_credentials: GithubCredentials
```

- *Type:* projen.github.GithubCredentials
- *Default:* use a personal access token named PROJEN_GITHUB_TOKEN

Choose a method of providing GitHub API access for projen workflows.

---

##### ~~`projen_token_secret`~~<sup>Optional</sup> <a name="projen_token_secret" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.projenTokenSecret"></a>

- *Deprecated:* use `projenCredentials`

```python
projen_token_secret: str
```

- *Type:* str
- *Default:* "PROJEN_GITHUB_TOKEN"

The name of a secret which includes a GitHub Personal Access Token to be used by projen workflows.

This token needs to have the `repo`, `workflows`
and `packages` scope.

---

##### `readme`<sup>Optional</sup> <a name="readme" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.readme"></a>

```python
readme: SampleReadmeProps
```

- *Type:* projen.SampleReadmeProps
- *Default:* { filename: 'README.md', contents: '# replace this' }

The README setup.

---

*Example*

```python
"{ filename: 'readme.md', contents: '# title' }"
```


##### `stale`<sup>Optional</sup> <a name="stale" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.stale"></a>

```python
stale: bool
```

- *Type:* bool
- *Default:* false

Auto-close of stale issues and pull request.

See `staleOptions` for options.

---

##### `stale_options`<sup>Optional</sup> <a name="stale_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.staleOptions"></a>

```python
stale_options: StaleOptions
```

- *Type:* projen.github.StaleOptions
- *Default:* see defaults in `StaleOptions`

Auto-close stale issues and pull requests.

To disable set `stale` to `false`.

---

##### `vscode`<sup>Optional</sup> <a name="vscode" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.vscode"></a>

```python
vscode: bool
```

- *Type:* bool
- *Default:* true

Enable VSCode integration.

Enabled by default for root projects. Disabled for non-root projects.

---

##### `allow_library_dependencies`<sup>Optional</sup> <a name="allow_library_dependencies" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.allowLibraryDependencies"></a>

```python
allow_library_dependencies: bool
```

- *Type:* bool
- *Default:* true

Allow the project to include `peerDependencies` and `bundledDependencies`.

This is normally only allowed for libraries. For apps, there's no meaning
for specifying these.

---

##### `author_email`<sup>Optional</sup> <a name="author_email" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.authorEmail"></a>

```python
author_email: str
```

- *Type:* str

Author's e-mail.

---

##### `author_name`<sup>Optional</sup> <a name="author_name" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.authorName"></a>

```python
author_name: str
```

- *Type:* str

Author's name.

---

##### `author_organization`<sup>Optional</sup> <a name="author_organization" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.authorOrganization"></a>

```python
author_organization: bool
```

- *Type:* bool

Is the author an organization.

---

##### `author_url`<sup>Optional</sup> <a name="author_url" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.authorUrl"></a>

```python
author_url: str
```

- *Type:* str

Author's URL / Website.

---

##### `auto_detect_bin`<sup>Optional</sup> <a name="auto_detect_bin" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.autoDetectBin"></a>

```python
auto_detect_bin: bool
```

- *Type:* bool
- *Default:* true

Automatically add all executables under the `bin` directory to your `package.json` file under the `bin` section.

---

##### `bin`<sup>Optional</sup> <a name="bin" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.bin"></a>

```python
bin: typing.Mapping[str]
```

- *Type:* typing.Mapping[str]

Binary programs vended with your module.

You can use this option to add/customize how binaries are represented in
your `package.json`, but unless `autoDetectBin` is `false`, every
executable file under `bin` will automatically be added to this section.

---

##### `bugs_email`<sup>Optional</sup> <a name="bugs_email" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.bugsEmail"></a>

```python
bugs_email: str
```

- *Type:* str

The email address to which issues should be reported.

---

##### `bugs_url`<sup>Optional</sup> <a name="bugs_url" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.bugsUrl"></a>

```python
bugs_url: str
```

- *Type:* str

The url to your project's issue tracker.

---

##### `bundled_deps`<sup>Optional</sup> <a name="bundled_deps" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.bundledDeps"></a>

```python
bundled_deps: typing.List[str]
```

- *Type:* typing.List[str]

List of dependencies to bundle into this module.

These modules will be
added both to the `dependencies` section and `bundledDependencies` section of
your `package.json`.

The recommendation is to only specify the module name here (e.g.
`express`). This will behave similar to `yarn add` or `npm install` in the
sense that it will add the module as a dependency to your `package.json`
file with the latest version (`^`). You can specify semver requirements in
the same syntax passed to `npm i` or `yarn add` (e.g. `express@^2`) and
this will be what you `package.json` will eventually include.

---

##### `code_artifact_options`<sup>Optional</sup> <a name="code_artifact_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.codeArtifactOptions"></a>

```python
code_artifact_options: CodeArtifactOptions
```

- *Type:* projen.javascript.CodeArtifactOptions
- *Default:* undefined

Options for npm packages using AWS CodeArtifact.

This is required if publishing packages to, or installing scoped packages from AWS CodeArtifact

---

##### `deps`<sup>Optional</sup> <a name="deps" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.deps"></a>

```python
deps: typing.List[str]
```

- *Type:* typing.List[str]
- *Default:* []

Runtime dependencies of this module.

The recommendation is to only specify the module name here (e.g.
`express`). This will behave similar to `yarn add` or `npm install` in the
sense that it will add the module as a dependency to your `package.json`
file with the latest version (`^`). You can specify semver requirements in
the same syntax passed to `npm i` or `yarn add` (e.g. `express@^2`) and
this will be what you `package.json` will eventually include.

---

*Example*

```python
[ 'express', 'lodash', 'foo@^2' ]
```


##### `description`<sup>Optional</sup> <a name="description" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.description"></a>

```python
description: str
```

- *Type:* str

The description is just a string that helps people understand the purpose of the package.

It can be used when searching for packages in a package manager as well.
See https://classic.yarnpkg.com/en/docs/package-json/#toc-description

---

##### `dev_deps`<sup>Optional</sup> <a name="dev_deps" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.devDeps"></a>

```python
dev_deps: typing.List[str]
```

- *Type:* typing.List[str]
- *Default:* []

Build dependencies for this module.

These dependencies will only be
available in your build environment but will not be fetched when this
module is consumed.

The recommendation is to only specify the module name here (e.g.
`express`). This will behave similar to `yarn add` or `npm install` in the
sense that it will add the module as a dependency to your `package.json`
file with the latest version (`^`). You can specify semver requirements in
the same syntax passed to `npm i` or `yarn add` (e.g. `express@^2`) and
this will be what you `package.json` will eventually include.

---

*Example*

```python
[ 'typescript', '@types/express' ]
```


##### `entrypoint`<sup>Optional</sup> <a name="entrypoint" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.entrypoint"></a>

```python
entrypoint: str
```

- *Type:* str
- *Default:* "lib/index.js"

Module entrypoint (`main` in `package.json`).

Set to an empty string to not include `main` in your package.json

---

##### `homepage`<sup>Optional</sup> <a name="homepage" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.homepage"></a>

```python
homepage: str
```

- *Type:* str

Package's Homepage / Website.

---

##### `keywords`<sup>Optional</sup> <a name="keywords" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.keywords"></a>

```python
keywords: typing.List[str]
```

- *Type:* typing.List[str]

Keywords to include in `package.json`.

---

##### `license`<sup>Optional</sup> <a name="license" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.license"></a>

```python
license: str
```

- *Type:* str
- *Default:* "Apache-2.0"

License's SPDX identifier.

See https://github.com/projen/projen/tree/main/license-text for a list of supported licenses.
Use the `licensed` option if you want to no license to be specified.

---

##### `licensed`<sup>Optional</sup> <a name="licensed" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.licensed"></a>

```python
licensed: bool
```

- *Type:* bool
- *Default:* true

Indicates if a license should be added.

---

##### `max_node_version`<sup>Optional</sup> <a name="max_node_version" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.maxNodeVersion"></a>

```python
max_node_version: str
```

- *Type:* str
- *Default:* no max

Minimum node.js version to require via `engines` (inclusive).

---

##### `min_node_version`<sup>Optional</sup> <a name="min_node_version" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.minNodeVersion"></a>

```python
min_node_version: str
```

- *Type:* str
- *Default:* no "engines" specified

Minimum Node.js version to require via package.json `engines` (inclusive).

---

##### `npm_access`<sup>Optional</sup> <a name="npm_access" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.npmAccess"></a>

```python
npm_access: NpmAccess
```

- *Type:* projen.javascript.NpmAccess
- *Default:* for scoped packages (e.g. `foo@bar`), the default is `NpmAccess.RESTRICTED`, for non-scoped packages, the default is `NpmAccess.PUBLIC`.

Access level of the npm package.

---

##### ~~`npm_registry`~~<sup>Optional</sup> <a name="npm_registry" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.npmRegistry"></a>

- *Deprecated:* use `npmRegistryUrl` instead

```python
npm_registry: str
```

- *Type:* str

The host name of the npm registry to publish to.

Cannot be set together with `npmRegistryUrl`.

---

##### `npm_registry_url`<sup>Optional</sup> <a name="npm_registry_url" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.npmRegistryUrl"></a>

```python
npm_registry_url: str
```

- *Type:* str
- *Default:* "https://registry.npmjs.org"

The base URL of the npm package registry.

Must be a URL (e.g. start with "https://" or "http://")

---

##### `npm_token_secret`<sup>Optional</sup> <a name="npm_token_secret" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.npmTokenSecret"></a>

```python
npm_token_secret: str
```

- *Type:* str
- *Default:* "NPM_TOKEN"

GitHub secret which contains the NPM token to use when publishing packages.

---

##### `package_manager`<sup>Optional</sup> <a name="package_manager" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.packageManager"></a>

```python
package_manager: NodePackageManager
```

- *Type:* projen.javascript.NodePackageManager
- *Default:* NodePackageManager.YARN

The Node Package Manager used to execute scripts.

---

##### `package_name`<sup>Optional</sup> <a name="package_name" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.packageName"></a>

```python
package_name: str
```

- *Type:* str
- *Default:* defaults to project name

The "name" in package.json.

---

##### `peer_dependency_options`<sup>Optional</sup> <a name="peer_dependency_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.peerDependencyOptions"></a>

```python
peer_dependency_options: PeerDependencyOptions
```

- *Type:* projen.javascript.PeerDependencyOptions

Options for `peerDeps`.

---

##### `peer_deps`<sup>Optional</sup> <a name="peer_deps" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.peerDeps"></a>

```python
peer_deps: typing.List[str]
```

- *Type:* typing.List[str]
- *Default:* []

Peer dependencies for this module.

Dependencies listed here are required to
be installed (and satisfied) by the _consumer_ of this library. Using peer
dependencies allows you to ensure that only a single module of a certain
library exists in the `node_modules` tree of your consumers.

Note that prior to npm@7, peer dependencies are _not_ automatically
installed, which means that adding peer dependencies to a library will be a
breaking change for your customers.

Unless `peerDependencyOptions.pinnedDevDependency` is disabled (it is
enabled by default), projen will automatically add a dev dependency with a
pinned version for each peer dependency. This will ensure that you build &
test your module against the lowest peer version required.

---

##### `pnpm_version`<sup>Optional</sup> <a name="pnpm_version" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.pnpmVersion"></a>

```python
pnpm_version: str
```

- *Type:* str
- *Default:* "7"

The version of PNPM to use if using PNPM as a package manager.

---

##### `repository`<sup>Optional</sup> <a name="repository" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.repository"></a>

```python
repository: str
```

- *Type:* str

The repository is the location where the actual code for your package lives.

See https://classic.yarnpkg.com/en/docs/package-json/#toc-repository

---

##### `repository_directory`<sup>Optional</sup> <a name="repository_directory" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.repositoryDirectory"></a>

```python
repository_directory: str
```

- *Type:* str

If the package.json for your package is not in the root directory (for example if it is part of a monorepo), you can specify the directory in which it lives.

---

##### `scoped_packages_options`<sup>Optional</sup> <a name="scoped_packages_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.scopedPackagesOptions"></a>

```python
scoped_packages_options: typing.List[ScopedPackagesOptions]
```

- *Type:* typing.List[projen.javascript.ScopedPackagesOptions]
- *Default:* fetch all scoped packages from the public npm registry

Options for privately hosted scoped packages.

---

##### ~~`scripts`~~<sup>Optional</sup> <a name="scripts" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.scripts"></a>

- *Deprecated:* use `project.addTask()` or `package.setScript()`

```python
scripts: typing.Mapping[str]
```

- *Type:* typing.Mapping[str]
- *Default:* {}

npm scripts to include.

If a script has the same name as a standard script,
the standard script will be overwritten.
Also adds the script as a task.

---

##### `stability`<sup>Optional</sup> <a name="stability" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.stability"></a>

```python
stability: str
```

- *Type:* str

Package's Stability.

---

##### `jsii_release_version`<sup>Optional</sup> <a name="jsii_release_version" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.jsiiReleaseVersion"></a>

```python
jsii_release_version: str
```

- *Type:* str
- *Default:* "latest"

Version requirement of `publib` which is used to publish modules to npm.

---

##### `major_version`<sup>Optional</sup> <a name="major_version" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.majorVersion"></a>

```python
major_version: typing.Union[int, float]
```

- *Type:* typing.Union[int, float]
- *Default:* Major version is not enforced.

Major version to release from the default branch.

If this is specified, we bump the latest version of this major version line.
If not specified, we bump the global latest version.

---

##### `min_major_version`<sup>Optional</sup> <a name="min_major_version" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.minMajorVersion"></a>

```python
min_major_version: typing.Union[int, float]
```

- *Type:* typing.Union[int, float]
- *Default:* No minimum version is being enforced

Minimal Major version to release.

This can be useful to set to 1, as breaking changes before the 1.x major
release are not incrementing the major version number.

Can not be set together with `majorVersion`.

---

##### `npm_dist_tag`<sup>Optional</sup> <a name="npm_dist_tag" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.npmDistTag"></a>

```python
npm_dist_tag: str
```

- *Type:* str
- *Default:* "latest"

The npmDistTag to use when publishing from the default branch.

To set the npm dist-tag for release branches, set the `npmDistTag` property
for each branch.

---

##### `post_build_steps`<sup>Optional</sup> <a name="post_build_steps" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.postBuildSteps"></a>

```python
post_build_steps: typing.List[JobStep]
```

- *Type:* typing.List[projen.github.workflows.JobStep]
- *Default:* []

Steps to execute after build as part of the release workflow.

---

##### `prerelease`<sup>Optional</sup> <a name="prerelease" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.prerelease"></a>

```python
prerelease: str
```

- *Type:* str
- *Default:* normal semantic versions

Bump versions from the default branch as pre-releases (e.g. "beta", "alpha", "pre").

---

##### `publish_dry_run`<sup>Optional</sup> <a name="publish_dry_run" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.publishDryRun"></a>

```python
publish_dry_run: bool
```

- *Type:* bool
- *Default:* false

Instead of actually publishing to package managers, just print the publishing command.

---

##### `publish_tasks`<sup>Optional</sup> <a name="publish_tasks" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.publishTasks"></a>

```python
publish_tasks: bool
```

- *Type:* bool
- *Default:* false

Define publishing tasks that can be executed manually as well as workflows.

Normally, publishing only happens within automated workflows. Enable this
in order to create a publishing task for each publishing activity.

---

##### `release_branches`<sup>Optional</sup> <a name="release_branches" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.releaseBranches"></a>

```python
release_branches: typing.Mapping[BranchOptions]
```

- *Type:* typing.Mapping[projen.release.BranchOptions]
- *Default:* no additional branches are used for release. you can use `addBranch()` to add additional branches.

Defines additional release branches.

A workflow will be created for each
release branch which will publish releases from commits in this branch.
Each release branch _must_ be assigned a major version number which is used
to enforce that versions published from that branch always use that major
version. If multiple branches are used, the `majorVersion` field must also
be provided for the default branch.

---

##### ~~`release_every_commit`~~<sup>Optional</sup> <a name="release_every_commit" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.releaseEveryCommit"></a>

- *Deprecated:* Use `releaseTrigger: ReleaseTrigger.continuous()` instead

```python
release_every_commit: bool
```

- *Type:* bool
- *Default:* true

Automatically release new versions every commit to one of branches in `releaseBranches`.

---

##### `release_failure_issue`<sup>Optional</sup> <a name="release_failure_issue" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.releaseFailureIssue"></a>

```python
release_failure_issue: bool
```

- *Type:* bool
- *Default:* false

Create a github issue on every failed publishing task.

---

##### `release_failure_issue_label`<sup>Optional</sup> <a name="release_failure_issue_label" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.releaseFailureIssueLabel"></a>

```python
release_failure_issue_label: str
```

- *Type:* str
- *Default:* "failed-release"

The label to apply to issues indicating publish failures.

Only applies if `releaseFailureIssue` is true.

---

##### ~~`release_schedule`~~<sup>Optional</sup> <a name="release_schedule" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.releaseSchedule"></a>

- *Deprecated:* Use `releaseTrigger: ReleaseTrigger.scheduled()` instead

```python
release_schedule: str
```

- *Type:* str
- *Default:* no scheduled releases

CRON schedule to trigger new releases.

---

##### `release_tag_prefix`<sup>Optional</sup> <a name="release_tag_prefix" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.releaseTagPrefix"></a>

```python
release_tag_prefix: str
```

- *Type:* str
- *Default:* "v"

Automatically add the given prefix to release tags. Useful if you are releasing on multiple branches with overlapping version numbers.

Note: this prefix is used to detect the latest tagged version
when bumping, so if you change this on a project with an existing version
history, you may need to manually tag your latest release
with the new prefix.

---

##### `release_trigger`<sup>Optional</sup> <a name="release_trigger" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.releaseTrigger"></a>

```python
release_trigger: ReleaseTrigger
```

- *Type:* projen.release.ReleaseTrigger
- *Default:* Continuous releases (`ReleaseTrigger.continuous()`)

The release trigger to use.

---

##### `release_workflow_name`<sup>Optional</sup> <a name="release_workflow_name" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.releaseWorkflowName"></a>

```python
release_workflow_name: str
```

- *Type:* str
- *Default:* "Release"

The name of the default release workflow.

---

##### `release_workflow_setup_steps`<sup>Optional</sup> <a name="release_workflow_setup_steps" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.releaseWorkflowSetupSteps"></a>

```python
release_workflow_setup_steps: typing.List[JobStep]
```

- *Type:* typing.List[projen.github.workflows.JobStep]

A set of workflow steps to execute in order to setup the workflow container.

---

##### `versionrc_options`<sup>Optional</sup> <a name="versionrc_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.versionrcOptions"></a>

```python
versionrc_options: typing.Mapping[typing.Any]
```

- *Type:* typing.Mapping[typing.Any]
- *Default:* standard configuration applicable for GitHub repositories

Custom configuration used when creating changelog with standard-version package.

Given values either append to default configuration or overwrite values in it.

---

##### `workflow_container_image`<sup>Optional</sup> <a name="workflow_container_image" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.workflowContainerImage"></a>

```python
workflow_container_image: str
```

- *Type:* str
- *Default:* default image

Container image to use for GitHub workflows.

---

##### `workflow_runs_on`<sup>Optional</sup> <a name="workflow_runs_on" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.workflowRunsOn"></a>

```python
workflow_runs_on: typing.List[str]
```

- *Type:* typing.List[str]
- *Default:* ["ubuntu-latest"]

Github Runner selection labels.

---

##### `default_release_branch`<sup>Required</sup> <a name="default_release_branch" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.defaultReleaseBranch"></a>

```python
default_release_branch: str
```

- *Type:* str
- *Default:* "main"

The name of the main release branch.

---

##### `artifacts_directory`<sup>Optional</sup> <a name="artifacts_directory" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.artifactsDirectory"></a>

```python
artifacts_directory: str
```

- *Type:* str
- *Default:* "dist"

A directory which will contain build artifacts.

---

##### `auto_approve_upgrades`<sup>Optional</sup> <a name="auto_approve_upgrades" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.autoApproveUpgrades"></a>

```python
auto_approve_upgrades: bool
```

- *Type:* bool
- *Default:* true

Automatically approve deps upgrade PRs, allowing them to be merged by mergify (if configued).

Throw if set to true but `autoApproveOptions` are not defined.

---

##### `build_workflow`<sup>Optional</sup> <a name="build_workflow" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.buildWorkflow"></a>

```python
build_workflow: bool
```

- *Type:* bool
- *Default:* true if not a subproject

Define a GitHub workflow for building PRs.

---

##### `build_workflow_triggers`<sup>Optional</sup> <a name="build_workflow_triggers" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.buildWorkflowTriggers"></a>

```python
build_workflow_triggers: Triggers
```

- *Type:* projen.github.workflows.Triggers
- *Default:* "{ pullRequest: {}, workflowDispatch: {} }"

Build workflow triggers.

---

##### `bundler_options`<sup>Optional</sup> <a name="bundler_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.bundlerOptions"></a>

```python
bundler_options: BundlerOptions
```

- *Type:* projen.javascript.BundlerOptions

Options for `Bundler`.

---

##### `code_cov`<sup>Optional</sup> <a name="code_cov" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.codeCov"></a>

```python
code_cov: bool
```

- *Type:* bool
- *Default:* false

Define a GitHub workflow step for sending code coverage metrics to https://codecov.io/ Uses codecov/codecov-action@v3 A secret is required for private repos. Configured with `@codeCovTokenSecret`.

---

##### `code_cov_token_secret`<sup>Optional</sup> <a name="code_cov_token_secret" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.codeCovTokenSecret"></a>

```python
code_cov_token_secret: str
```

- *Type:* str
- *Default:* if this option is not specified, only public repositories are supported

Define the secret name for a specified https://codecov.io/ token A secret is required to send coverage for private repositories.

---

##### `copyright_owner`<sup>Optional</sup> <a name="copyright_owner" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.copyrightOwner"></a>

```python
copyright_owner: str
```

- *Type:* str
- *Default:* defaults to the value of authorName or "" if `authorName` is undefined.

License copyright owner.

---

##### `copyright_period`<sup>Optional</sup> <a name="copyright_period" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.copyrightPeriod"></a>

```python
copyright_period: str
```

- *Type:* str
- *Default:* current year

The copyright years to put in the LICENSE file.

---

##### `dependabot`<sup>Optional</sup> <a name="dependabot" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.dependabot"></a>

```python
dependabot: bool
```

- *Type:* bool
- *Default:* false

Use dependabot to handle dependency upgrades.

Cannot be used in conjunction with `depsUpgrade`.

---

##### `dependabot_options`<sup>Optional</sup> <a name="dependabot_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.dependabotOptions"></a>

```python
dependabot_options: DependabotOptions
```

- *Type:* projen.github.DependabotOptions
- *Default:* default options

Options for dependabot.

---

##### `deps_upgrade`<sup>Optional</sup> <a name="deps_upgrade" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.depsUpgrade"></a>

```python
deps_upgrade: bool
```

- *Type:* bool
- *Default:* true

Use github workflows to handle dependency upgrades.

Cannot be used in conjunction with `dependabot`.

---

##### `deps_upgrade_options`<sup>Optional</sup> <a name="deps_upgrade_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.depsUpgradeOptions"></a>

```python
deps_upgrade_options: UpgradeDependenciesOptions
```

- *Type:* projen.javascript.UpgradeDependenciesOptions
- *Default:* default options

Options for `UpgradeDependencies`.

---

##### `gitignore`<sup>Optional</sup> <a name="gitignore" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.gitignore"></a>

```python
gitignore: typing.List[str]
```

- *Type:* typing.List[str]

Additional entries to .gitignore.

---

##### `jest`<sup>Optional</sup> <a name="jest" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.jest"></a>

```python
jest: bool
```

- *Type:* bool
- *Default:* true

Setup jest unit tests.

---

##### `jest_options`<sup>Optional</sup> <a name="jest_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.jestOptions"></a>

```python
jest_options: JestOptions
```

- *Type:* projen.javascript.JestOptions
- *Default:* default options

Jest options.

---

##### `mutable_build`<sup>Optional</sup> <a name="mutable_build" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.mutableBuild"></a>

```python
mutable_build: bool
```

- *Type:* bool
- *Default:* true

Automatically update files modified during builds to pull-request branches.

This means
that any files synthesized by projen or e.g. test snapshots will always be up-to-date
before a PR is merged.

Implies that PR builds do not have anti-tamper checks.

---

##### ~~`npmignore`~~<sup>Optional</sup> <a name="npmignore" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.npmignore"></a>

- *Deprecated:* - use `project.addPackageIgnore`

```python
npmignore: typing.List[str]
```

- *Type:* typing.List[str]

Additional entries to .npmignore.

---

##### `npmignore_enabled`<sup>Optional</sup> <a name="npmignore_enabled" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.npmignoreEnabled"></a>

```python
npmignore_enabled: bool
```

- *Type:* bool
- *Default:* true

Defines an .npmignore file. Normally this is only needed for libraries that are packaged as tarballs.

---

##### `npm_ignore_options`<sup>Optional</sup> <a name="npm_ignore_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.npmIgnoreOptions"></a>

```python
npm_ignore_options: IgnoreFileOptions
```

- *Type:* projen.IgnoreFileOptions

Configuration options for .npmignore file.

---

##### `package`<sup>Optional</sup> <a name="package" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.package"></a>

```python
package: bool
```

- *Type:* bool
- *Default:* true

Defines a `package` task that will produce an npm tarball under the artifacts directory (e.g. `dist`).

---

##### `prettier`<sup>Optional</sup> <a name="prettier" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.prettier"></a>

```python
prettier: bool
```

- *Type:* bool
- *Default:* false

Setup prettier.

---

##### `prettier_options`<sup>Optional</sup> <a name="prettier_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.prettierOptions"></a>

```python
prettier_options: PrettierOptions
```

- *Type:* projen.javascript.PrettierOptions
- *Default:* default options

Prettier options.

---

##### `projen_dev_dependency`<sup>Optional</sup> <a name="projen_dev_dependency" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.projenDevDependency"></a>

```python
projen_dev_dependency: bool
```

- *Type:* bool
- *Default:* true

Indicates of "projen" should be installed as a devDependency.

---

##### `projenrc_js`<sup>Optional</sup> <a name="projenrc_js" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.projenrcJs"></a>

```python
projenrc_js: bool
```

- *Type:* bool
- *Default:* true if projenrcJson is false

Generate (once) .projenrc.js (in JavaScript). Set to `false` in order to disable .projenrc.js generation.

---

##### `projenrc_js_options`<sup>Optional</sup> <a name="projenrc_js_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.projenrcJsOptions"></a>

```python
projenrc_js_options: ProjenrcOptions
```

- *Type:* projen.javascript.ProjenrcOptions
- *Default:* default options

Options for .projenrc.js.

---

##### `projen_version`<sup>Optional</sup> <a name="projen_version" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.projenVersion"></a>

```python
projen_version: str
```

- *Type:* str
- *Default:* Defaults to the latest version.

Version of projen to install.

---

##### `pull_request_template`<sup>Optional</sup> <a name="pull_request_template" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.pullRequestTemplate"></a>

```python
pull_request_template: bool
```

- *Type:* bool
- *Default:* true

Include a GitHub pull request template.

---

##### `pull_request_template_contents`<sup>Optional</sup> <a name="pull_request_template_contents" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.pullRequestTemplateContents"></a>

```python
pull_request_template_contents: typing.List[str]
```

- *Type:* typing.List[str]
- *Default:* default content

The contents of the pull request template.

---

##### `release`<sup>Optional</sup> <a name="release" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.release"></a>

```python
release: bool
```

- *Type:* bool
- *Default:* true (false for subprojects)

Add release management to this project.

---

##### `release_to_npm`<sup>Optional</sup> <a name="release_to_npm" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.releaseToNpm"></a>

```python
release_to_npm: bool
```

- *Type:* bool
- *Default:* false

Automatically release to npm when new versions are introduced.

---

##### ~~`release_workflow`~~<sup>Optional</sup> <a name="release_workflow" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.releaseWorkflow"></a>

- *Deprecated:* see `release`.

```python
release_workflow: bool
```

- *Type:* bool
- *Default:* true if not a subproject

DEPRECATED: renamed to `release`.

---

##### `workflow_bootstrap_steps`<sup>Optional</sup> <a name="workflow_bootstrap_steps" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.workflowBootstrapSteps"></a>

```python
workflow_bootstrap_steps: typing.List[JobStep]
```

- *Type:* typing.List[projen.github.workflows.JobStep]
- *Default:* "yarn install --frozen-lockfile && yarn projen"

Workflow steps to use in order to bootstrap this repo.

---

##### `workflow_git_identity`<sup>Optional</sup> <a name="workflow_git_identity" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.workflowGitIdentity"></a>

```python
workflow_git_identity: GitIdentity
```

- *Type:* projen.github.GitIdentity
- *Default:* GitHub Actions

The git identity to use in workflows.

---

##### `workflow_node_version`<sup>Optional</sup> <a name="workflow_node_version" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.workflowNodeVersion"></a>

```python
workflow_node_version: str
```

- *Type:* str
- *Default:* same as `minNodeVersion`

The node version to use in GitHub workflows.

---

##### `workflow_package_cache`<sup>Optional</sup> <a name="workflow_package_cache" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.workflowPackageCache"></a>

```python
workflow_package_cache: bool
```

- *Type:* bool
- *Default:* false

Enable Node.js package cache in GitHub workflows.

---

##### `disable_tsconfig`<sup>Optional</sup> <a name="disable_tsconfig" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.disableTsconfig"></a>

```python
disable_tsconfig: bool
```

- *Type:* bool
- *Default:* false

Do not generate a `tsconfig.json` file (used by jsii projects since tsconfig.json is generated by the jsii compiler).

---

##### `disable_tsconfig_dev`<sup>Optional</sup> <a name="disable_tsconfig_dev" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.disableTsconfigDev"></a>

```python
disable_tsconfig_dev: bool
```

- *Type:* bool
- *Default:* false

Do not generate a `tsconfig.dev.json` file.

---

##### `docgen`<sup>Optional</sup> <a name="docgen" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.docgen"></a>

```python
docgen: bool
```

- *Type:* bool
- *Default:* false

Docgen by Typedoc.

---

##### `docs_directory`<sup>Optional</sup> <a name="docs_directory" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.docsDirectory"></a>

```python
docs_directory: str
```

- *Type:* str
- *Default:* "docs"

Docs directory.

---

##### `entrypoint_types`<sup>Optional</sup> <a name="entrypoint_types" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.entrypointTypes"></a>

```python
entrypoint_types: str
```

- *Type:* str
- *Default:* .d.ts file derived from the project's entrypoint (usually lib/index.d.ts)

The .d.ts file that includes the type declarations for this module.

---

##### `eslint`<sup>Optional</sup> <a name="eslint" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.eslint"></a>

```python
eslint: bool
```

- *Type:* bool
- *Default:* true

Setup eslint.

---

##### `eslint_options`<sup>Optional</sup> <a name="eslint_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.eslintOptions"></a>

```python
eslint_options: EslintOptions
```

- *Type:* projen.javascript.EslintOptions
- *Default:* opinionated default options

Eslint options.

---

##### `libdir`<sup>Optional</sup> <a name="libdir" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.libdir"></a>

```python
libdir: str
```

- *Type:* str
- *Default:* "lib"

Typescript  artifacts output directory.

---

##### `projenrc_ts`<sup>Optional</sup> <a name="projenrc_ts" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.projenrcTs"></a>

```python
projenrc_ts: bool
```

- *Type:* bool
- *Default:* false

Use TypeScript for your projenrc file (`.projenrc.ts`).

---

##### `projenrc_ts_options`<sup>Optional</sup> <a name="projenrc_ts_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.projenrcTsOptions"></a>

```python
projenrc_ts_options: ProjenrcOptions
```

- *Type:* projen.typescript.ProjenrcOptions

Options for .projenrc.ts.

---

##### `sample_code`<sup>Optional</sup> <a name="sample_code" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.sampleCode"></a>

```python
sample_code: bool
```

- *Type:* bool
- *Default:* true

Generate one-time sample in `src/` and `test/` if there are no files there.

---

##### `srcdir`<sup>Optional</sup> <a name="srcdir" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.srcdir"></a>

```python
srcdir: str
```

- *Type:* str
- *Default:* "src"

Typescript sources directory.

---

##### `testdir`<sup>Optional</sup> <a name="testdir" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.testdir"></a>

```python
testdir: str
```

- *Type:* str
- *Default:* "test"

Jest tests directory. Tests files should be named `xxx.test.ts`.

If this directory is under `srcdir` (e.g. `src/test`, `src/__tests__`),
then tests are going to be compiled into `lib/` and executed as javascript.
If the test directory is outside of `src`, then we configure jest to
compile the code in-memory.

---

##### `tsconfig`<sup>Optional</sup> <a name="tsconfig" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.tsconfig"></a>

```python
tsconfig: TypescriptConfigOptions
```

- *Type:* projen.javascript.TypescriptConfigOptions
- *Default:* default options

Custom TSConfig.

---

##### `tsconfig_dev`<sup>Optional</sup> <a name="tsconfig_dev" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.tsconfigDev"></a>

```python
tsconfig_dev: TypescriptConfigOptions
```

- *Type:* projen.javascript.TypescriptConfigOptions
- *Default:* use the production tsconfig options

Custom tsconfig options for the development tsconfig.json file (used for testing).

---

##### `tsconfig_dev_file`<sup>Optional</sup> <a name="tsconfig_dev_file" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.tsconfigDevFile"></a>

```python
tsconfig_dev_file: str
```

- *Type:* str
- *Default:* "tsconfig.dev.json"

The name of the development tsconfig.json file.

---

##### `typescript_version`<sup>Optional</sup> <a name="typescript_version" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.typescriptVersion"></a>

```python
typescript_version: str
```

- *Type:* str
- *Default:* "latest"

TypeScript version to use.

NOTE: Typescript is not semantically versioned and should remain on the
same minor, so we recommend using a `~` dependency (e.g. `~1.2.3`).

---

##### `open_api_generator_cli_config`<sup>Optional</sup> <a name="open_api_generator_cli_config" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.openApiGeneratorCliConfig"></a>

```python
open_api_generator_cli_config: OpenApiGeneratorCliConfig
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfig">OpenApiGeneratorCliConfig</a>

Configuration for the OpenAPI Generator CLI.

Overrides default values if specified.

> [https://github.com/OpenAPITools/openapi-generator-cli#configuration](https://github.com/OpenAPITools/openapi-generator-cli#configuration)

---

##### `mock_data_options`<sup>Optional</sup> <a name="mock_data_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptInfrastructureOptions.property.mockDataOptions"></a>

```python
mock_data_options: MockResponseDataGenerationOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.MockResponseDataGenerationOptions">MockResponseDataGenerationOptions</a>

Options for the generated mock response data.

---

### GeneratedTypeScriptReactQueryHooksOptions <a name="GeneratedTypeScriptReactQueryHooksOptions" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions"></a>

Options for configuring a generated typescript hooks library project.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.GeneratedTypeScriptReactQueryHooksOptions(
  name: str,
  commit_generated: bool = None,
  git_ignore_options: IgnoreFileOptions = None,
  git_options: GitOptions = None,
  logging: LoggerOptions = None,
  outdir: str = None,
  parent: Project = None,
  projen_command: str = None,
  projenrc_json: bool = None,
  projenrc_json_options: ProjenrcJsonOptions = None,
  renovatebot: bool = None,
  renovatebot_options: RenovatebotOptions = None,
  auto_approve_options: AutoApproveOptions = None,
  auto_merge: bool = None,
  auto_merge_options: AutoMergeOptions = None,
  clobber: bool = None,
  dev_container: bool = None,
  github: bool = None,
  github_options: GitHubOptions = None,
  gitpod: bool = None,
  mergify: bool = None,
  mergify_options: MergifyOptions = None,
  project_type: ProjectType = None,
  projen_credentials: GithubCredentials = None,
  projen_token_secret: str = None,
  readme: SampleReadmeProps = None,
  stale: bool = None,
  stale_options: StaleOptions = None,
  vscode: bool = None,
  allow_library_dependencies: bool = None,
  author_email: str = None,
  author_name: str = None,
  author_organization: bool = None,
  author_url: str = None,
  auto_detect_bin: bool = None,
  bin: typing.Mapping[str] = None,
  bugs_email: str = None,
  bugs_url: str = None,
  bundled_deps: typing.List[str] = None,
  code_artifact_options: CodeArtifactOptions = None,
  deps: typing.List[str] = None,
  description: str = None,
  dev_deps: typing.List[str] = None,
  entrypoint: str = None,
  homepage: str = None,
  keywords: typing.List[str] = None,
  license: str = None,
  licensed: bool = None,
  max_node_version: str = None,
  min_node_version: str = None,
  npm_access: NpmAccess = None,
  npm_registry: str = None,
  npm_registry_url: str = None,
  npm_token_secret: str = None,
  package_manager: NodePackageManager = None,
  package_name: str = None,
  peer_dependency_options: PeerDependencyOptions = None,
  peer_deps: typing.List[str] = None,
  pnpm_version: str = None,
  repository: str = None,
  repository_directory: str = None,
  scoped_packages_options: typing.List[ScopedPackagesOptions] = None,
  scripts: typing.Mapping[str] = None,
  stability: str = None,
  jsii_release_version: str = None,
  major_version: typing.Union[int, float] = None,
  min_major_version: typing.Union[int, float] = None,
  npm_dist_tag: str = None,
  post_build_steps: typing.List[JobStep] = None,
  prerelease: str = None,
  publish_dry_run: bool = None,
  publish_tasks: bool = None,
  release_branches: typing.Mapping[BranchOptions] = None,
  release_every_commit: bool = None,
  release_failure_issue: bool = None,
  release_failure_issue_label: str = None,
  release_schedule: str = None,
  release_tag_prefix: str = None,
  release_trigger: ReleaseTrigger = None,
  release_workflow_name: str = None,
  release_workflow_setup_steps: typing.List[JobStep] = None,
  versionrc_options: typing.Mapping[typing.Any] = None,
  workflow_container_image: str = None,
  workflow_runs_on: typing.List[str] = None,
  default_release_branch: str,
  artifacts_directory: str = None,
  auto_approve_upgrades: bool = None,
  build_workflow: bool = None,
  build_workflow_triggers: Triggers = None,
  bundler_options: BundlerOptions = None,
  code_cov: bool = None,
  code_cov_token_secret: str = None,
  copyright_owner: str = None,
  copyright_period: str = None,
  dependabot: bool = None,
  dependabot_options: DependabotOptions = None,
  deps_upgrade: bool = None,
  deps_upgrade_options: UpgradeDependenciesOptions = None,
  gitignore: typing.List[str] = None,
  jest: bool = None,
  jest_options: JestOptions = None,
  mutable_build: bool = None,
  npmignore: typing.List[str] = None,
  npmignore_enabled: bool = None,
  npm_ignore_options: IgnoreFileOptions = None,
  package: bool = None,
  prettier: bool = None,
  prettier_options: PrettierOptions = None,
  projen_dev_dependency: bool = None,
  projenrc_js: bool = None,
  projenrc_js_options: ProjenrcOptions = None,
  projen_version: str = None,
  pull_request_template: bool = None,
  pull_request_template_contents: typing.List[str] = None,
  release: bool = None,
  release_to_npm: bool = None,
  release_workflow: bool = None,
  workflow_bootstrap_steps: typing.List[JobStep] = None,
  workflow_git_identity: GitIdentity = None,
  workflow_node_version: str = None,
  workflow_package_cache: bool = None,
  disable_tsconfig: bool = None,
  disable_tsconfig_dev: bool = None,
  docgen: bool = None,
  docs_directory: str = None,
  entrypoint_types: str = None,
  eslint: bool = None,
  eslint_options: EslintOptions = None,
  libdir: str = None,
  projenrc_ts: bool = None,
  projenrc_ts_options: ProjenrcOptions = None,
  sample_code: bool = None,
  srcdir: str = None,
  testdir: str = None,
  tsconfig: TypescriptConfigOptions = None,
  tsconfig_dev: TypescriptConfigOptions = None,
  tsconfig_dev_file: str = None,
  typescript_version: str = None,
  open_api_generator_cli_config: OpenApiGeneratorCliConfig = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.name">name</a></code> | <code>str</code> | This is the name of your project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.commitGenerated">commit_generated</a></code> | <code>bool</code> | Whether to commit the managed files by default. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.gitIgnoreOptions">git_ignore_options</a></code> | <code>projen.IgnoreFileOptions</code> | Configuration options for .gitignore file. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.gitOptions">git_options</a></code> | <code>projen.GitOptions</code> | Configuration options for git. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.logging">logging</a></code> | <code>projen.LoggerOptions</code> | Configure logging options such as verbosity. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.outdir">outdir</a></code> | <code>str</code> | The root directory of the project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.parent">parent</a></code> | <code>projen.Project</code> | The parent project, if this project is part of a bigger project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.projenCommand">projen_command</a></code> | <code>str</code> | The shell command to use in order to run the projen CLI. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.projenrcJson">projenrc_json</a></code> | <code>bool</code> | Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.projenrcJsonOptions">projenrc_json_options</a></code> | <code>projen.ProjenrcJsonOptions</code> | Options for .projenrc.json. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.renovatebot">renovatebot</a></code> | <code>bool</code> | Use renovatebot to handle dependency upgrades. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.renovatebotOptions">renovatebot_options</a></code> | <code>projen.RenovatebotOptions</code> | Options for renovatebot. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.autoApproveOptions">auto_approve_options</a></code> | <code>projen.github.AutoApproveOptions</code> | Enable and configure the 'auto approve' workflow. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.autoMerge">auto_merge</a></code> | <code>bool</code> | Enable automatic merging on GitHub. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.autoMergeOptions">auto_merge_options</a></code> | <code>projen.github.AutoMergeOptions</code> | Configure options for automatic merging on GitHub. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.clobber">clobber</a></code> | <code>bool</code> | Add a `clobber` task which resets the repo to origin. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.devContainer">dev_container</a></code> | <code>bool</code> | Add a VSCode development environment (used for GitHub Codespaces). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.github">github</a></code> | <code>bool</code> | Enable GitHub integration. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.githubOptions">github_options</a></code> | <code>projen.github.GitHubOptions</code> | Options for GitHub integration. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.gitpod">gitpod</a></code> | <code>bool</code> | Add a Gitpod development environment. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.mergify">mergify</a></code> | <code>bool</code> | Whether mergify should be enabled on this repository or not. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.mergifyOptions">mergify_options</a></code> | <code>projen.github.MergifyOptions</code> | Options for mergify. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.projectType">project_type</a></code> | <code>projen.ProjectType</code> | Which type of project this is (library/app). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.projenCredentials">projen_credentials</a></code> | <code>projen.github.GithubCredentials</code> | Choose a method of providing GitHub API access for projen workflows. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.projenTokenSecret">projen_token_secret</a></code> | <code>str</code> | The name of a secret which includes a GitHub Personal Access Token to be used by projen workflows. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.readme">readme</a></code> | <code>projen.SampleReadmeProps</code> | The README setup. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.stale">stale</a></code> | <code>bool</code> | Auto-close of stale issues and pull request. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.staleOptions">stale_options</a></code> | <code>projen.github.StaleOptions</code> | Auto-close stale issues and pull requests. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.vscode">vscode</a></code> | <code>bool</code> | Enable VSCode integration. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.allowLibraryDependencies">allow_library_dependencies</a></code> | <code>bool</code> | Allow the project to include `peerDependencies` and `bundledDependencies`. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.authorEmail">author_email</a></code> | <code>str</code> | Author's e-mail. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.authorName">author_name</a></code> | <code>str</code> | Author's name. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.authorOrganization">author_organization</a></code> | <code>bool</code> | Is the author an organization. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.authorUrl">author_url</a></code> | <code>str</code> | Author's URL / Website. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.autoDetectBin">auto_detect_bin</a></code> | <code>bool</code> | Automatically add all executables under the `bin` directory to your `package.json` file under the `bin` section. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.bin">bin</a></code> | <code>typing.Mapping[str]</code> | Binary programs vended with your module. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.bugsEmail">bugs_email</a></code> | <code>str</code> | The email address to which issues should be reported. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.bugsUrl">bugs_url</a></code> | <code>str</code> | The url to your project's issue tracker. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.bundledDeps">bundled_deps</a></code> | <code>typing.List[str]</code> | List of dependencies to bundle into this module. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.codeArtifactOptions">code_artifact_options</a></code> | <code>projen.javascript.CodeArtifactOptions</code> | Options for npm packages using AWS CodeArtifact. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.deps">deps</a></code> | <code>typing.List[str]</code> | Runtime dependencies of this module. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.description">description</a></code> | <code>str</code> | The description is just a string that helps people understand the purpose of the package. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.devDeps">dev_deps</a></code> | <code>typing.List[str]</code> | Build dependencies for this module. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.entrypoint">entrypoint</a></code> | <code>str</code> | Module entrypoint (`main` in `package.json`). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.homepage">homepage</a></code> | <code>str</code> | Package's Homepage / Website. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.keywords">keywords</a></code> | <code>typing.List[str]</code> | Keywords to include in `package.json`. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.license">license</a></code> | <code>str</code> | License's SPDX identifier. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.licensed">licensed</a></code> | <code>bool</code> | Indicates if a license should be added. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.maxNodeVersion">max_node_version</a></code> | <code>str</code> | Minimum node.js version to require via `engines` (inclusive). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.minNodeVersion">min_node_version</a></code> | <code>str</code> | Minimum Node.js version to require via package.json `engines` (inclusive). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.npmAccess">npm_access</a></code> | <code>projen.javascript.NpmAccess</code> | Access level of the npm package. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.npmRegistry">npm_registry</a></code> | <code>str</code> | The host name of the npm registry to publish to. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.npmRegistryUrl">npm_registry_url</a></code> | <code>str</code> | The base URL of the npm package registry. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.npmTokenSecret">npm_token_secret</a></code> | <code>str</code> | GitHub secret which contains the NPM token to use when publishing packages. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.packageManager">package_manager</a></code> | <code>projen.javascript.NodePackageManager</code> | The Node Package Manager used to execute scripts. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.packageName">package_name</a></code> | <code>str</code> | The "name" in package.json. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.peerDependencyOptions">peer_dependency_options</a></code> | <code>projen.javascript.PeerDependencyOptions</code> | Options for `peerDeps`. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.peerDeps">peer_deps</a></code> | <code>typing.List[str]</code> | Peer dependencies for this module. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.pnpmVersion">pnpm_version</a></code> | <code>str</code> | The version of PNPM to use if using PNPM as a package manager. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.repository">repository</a></code> | <code>str</code> | The repository is the location where the actual code for your package lives. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.repositoryDirectory">repository_directory</a></code> | <code>str</code> | If the package.json for your package is not in the root directory (for example if it is part of a monorepo), you can specify the directory in which it lives. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.scopedPackagesOptions">scoped_packages_options</a></code> | <code>typing.List[projen.javascript.ScopedPackagesOptions]</code> | Options for privately hosted scoped packages. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.scripts">scripts</a></code> | <code>typing.Mapping[str]</code> | npm scripts to include. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.stability">stability</a></code> | <code>str</code> | Package's Stability. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.jsiiReleaseVersion">jsii_release_version</a></code> | <code>str</code> | Version requirement of `publib` which is used to publish modules to npm. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.majorVersion">major_version</a></code> | <code>typing.Union[int, float]</code> | Major version to release from the default branch. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.minMajorVersion">min_major_version</a></code> | <code>typing.Union[int, float]</code> | Minimal Major version to release. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.npmDistTag">npm_dist_tag</a></code> | <code>str</code> | The npmDistTag to use when publishing from the default branch. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.postBuildSteps">post_build_steps</a></code> | <code>typing.List[projen.github.workflows.JobStep]</code> | Steps to execute after build as part of the release workflow. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.prerelease">prerelease</a></code> | <code>str</code> | Bump versions from the default branch as pre-releases (e.g. "beta", "alpha", "pre"). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.publishDryRun">publish_dry_run</a></code> | <code>bool</code> | Instead of actually publishing to package managers, just print the publishing command. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.publishTasks">publish_tasks</a></code> | <code>bool</code> | Define publishing tasks that can be executed manually as well as workflows. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.releaseBranches">release_branches</a></code> | <code>typing.Mapping[projen.release.BranchOptions]</code> | Defines additional release branches. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.releaseEveryCommit">release_every_commit</a></code> | <code>bool</code> | Automatically release new versions every commit to one of branches in `releaseBranches`. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.releaseFailureIssue">release_failure_issue</a></code> | <code>bool</code> | Create a github issue on every failed publishing task. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.releaseFailureIssueLabel">release_failure_issue_label</a></code> | <code>str</code> | The label to apply to issues indicating publish failures. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.releaseSchedule">release_schedule</a></code> | <code>str</code> | CRON schedule to trigger new releases. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.releaseTagPrefix">release_tag_prefix</a></code> | <code>str</code> | Automatically add the given prefix to release tags. Useful if you are releasing on multiple branches with overlapping version numbers. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.releaseTrigger">release_trigger</a></code> | <code>projen.release.ReleaseTrigger</code> | The release trigger to use. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.releaseWorkflowName">release_workflow_name</a></code> | <code>str</code> | The name of the default release workflow. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.releaseWorkflowSetupSteps">release_workflow_setup_steps</a></code> | <code>typing.List[projen.github.workflows.JobStep]</code> | A set of workflow steps to execute in order to setup the workflow container. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.versionrcOptions">versionrc_options</a></code> | <code>typing.Mapping[typing.Any]</code> | Custom configuration used when creating changelog with standard-version package. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.workflowContainerImage">workflow_container_image</a></code> | <code>str</code> | Container image to use for GitHub workflows. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.workflowRunsOn">workflow_runs_on</a></code> | <code>typing.List[str]</code> | Github Runner selection labels. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.defaultReleaseBranch">default_release_branch</a></code> | <code>str</code> | The name of the main release branch. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.artifactsDirectory">artifacts_directory</a></code> | <code>str</code> | A directory which will contain build artifacts. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.autoApproveUpgrades">auto_approve_upgrades</a></code> | <code>bool</code> | Automatically approve deps upgrade PRs, allowing them to be merged by mergify (if configued). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.buildWorkflow">build_workflow</a></code> | <code>bool</code> | Define a GitHub workflow for building PRs. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.buildWorkflowTriggers">build_workflow_triggers</a></code> | <code>projen.github.workflows.Triggers</code> | Build workflow triggers. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.bundlerOptions">bundler_options</a></code> | <code>projen.javascript.BundlerOptions</code> | Options for `Bundler`. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.codeCov">code_cov</a></code> | <code>bool</code> | Define a GitHub workflow step for sending code coverage metrics to https://codecov.io/ Uses codecov/codecov-action@v3 A secret is required for private repos. Configured with `@codeCovTokenSecret`. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.codeCovTokenSecret">code_cov_token_secret</a></code> | <code>str</code> | Define the secret name for a specified https://codecov.io/ token A secret is required to send coverage for private repositories. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.copyrightOwner">copyright_owner</a></code> | <code>str</code> | License copyright owner. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.copyrightPeriod">copyright_period</a></code> | <code>str</code> | The copyright years to put in the LICENSE file. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.dependabot">dependabot</a></code> | <code>bool</code> | Use dependabot to handle dependency upgrades. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.dependabotOptions">dependabot_options</a></code> | <code>projen.github.DependabotOptions</code> | Options for dependabot. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.depsUpgrade">deps_upgrade</a></code> | <code>bool</code> | Use github workflows to handle dependency upgrades. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.depsUpgradeOptions">deps_upgrade_options</a></code> | <code>projen.javascript.UpgradeDependenciesOptions</code> | Options for `UpgradeDependencies`. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.gitignore">gitignore</a></code> | <code>typing.List[str]</code> | Additional entries to .gitignore. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.jest">jest</a></code> | <code>bool</code> | Setup jest unit tests. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.jestOptions">jest_options</a></code> | <code>projen.javascript.JestOptions</code> | Jest options. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.mutableBuild">mutable_build</a></code> | <code>bool</code> | Automatically update files modified during builds to pull-request branches. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.npmignore">npmignore</a></code> | <code>typing.List[str]</code> | Additional entries to .npmignore. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.npmignoreEnabled">npmignore_enabled</a></code> | <code>bool</code> | Defines an .npmignore file. Normally this is only needed for libraries that are packaged as tarballs. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.npmIgnoreOptions">npm_ignore_options</a></code> | <code>projen.IgnoreFileOptions</code> | Configuration options for .npmignore file. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.package">package</a></code> | <code>bool</code> | Defines a `package` task that will produce an npm tarball under the artifacts directory (e.g. `dist`). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.prettier">prettier</a></code> | <code>bool</code> | Setup prettier. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.prettierOptions">prettier_options</a></code> | <code>projen.javascript.PrettierOptions</code> | Prettier options. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.projenDevDependency">projen_dev_dependency</a></code> | <code>bool</code> | Indicates of "projen" should be installed as a devDependency. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.projenrcJs">projenrc_js</a></code> | <code>bool</code> | Generate (once) .projenrc.js (in JavaScript). Set to `false` in order to disable .projenrc.js generation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.projenrcJsOptions">projenrc_js_options</a></code> | <code>projen.javascript.ProjenrcOptions</code> | Options for .projenrc.js. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.projenVersion">projen_version</a></code> | <code>str</code> | Version of projen to install. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.pullRequestTemplate">pull_request_template</a></code> | <code>bool</code> | Include a GitHub pull request template. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.pullRequestTemplateContents">pull_request_template_contents</a></code> | <code>typing.List[str]</code> | The contents of the pull request template. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.release">release</a></code> | <code>bool</code> | Add release management to this project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.releaseToNpm">release_to_npm</a></code> | <code>bool</code> | Automatically release to npm when new versions are introduced. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.releaseWorkflow">release_workflow</a></code> | <code>bool</code> | DEPRECATED: renamed to `release`. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.workflowBootstrapSteps">workflow_bootstrap_steps</a></code> | <code>typing.List[projen.github.workflows.JobStep]</code> | Workflow steps to use in order to bootstrap this repo. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.workflowGitIdentity">workflow_git_identity</a></code> | <code>projen.github.GitIdentity</code> | The git identity to use in workflows. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.workflowNodeVersion">workflow_node_version</a></code> | <code>str</code> | The node version to use in GitHub workflows. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.workflowPackageCache">workflow_package_cache</a></code> | <code>bool</code> | Enable Node.js package cache in GitHub workflows. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.disableTsconfig">disable_tsconfig</a></code> | <code>bool</code> | Do not generate a `tsconfig.json` file (used by jsii projects since tsconfig.json is generated by the jsii compiler). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.disableTsconfigDev">disable_tsconfig_dev</a></code> | <code>bool</code> | Do not generate a `tsconfig.dev.json` file. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.docgen">docgen</a></code> | <code>bool</code> | Docgen by Typedoc. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.docsDirectory">docs_directory</a></code> | <code>str</code> | Docs directory. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.entrypointTypes">entrypoint_types</a></code> | <code>str</code> | The .d.ts file that includes the type declarations for this module. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.eslint">eslint</a></code> | <code>bool</code> | Setup eslint. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.eslintOptions">eslint_options</a></code> | <code>projen.javascript.EslintOptions</code> | Eslint options. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.libdir">libdir</a></code> | <code>str</code> | Typescript  artifacts output directory. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.projenrcTs">projenrc_ts</a></code> | <code>bool</code> | Use TypeScript for your projenrc file (`.projenrc.ts`). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.projenrcTsOptions">projenrc_ts_options</a></code> | <code>projen.typescript.ProjenrcOptions</code> | Options for .projenrc.ts. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.sampleCode">sample_code</a></code> | <code>bool</code> | Generate one-time sample in `src/` and `test/` if there are no files there. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.srcdir">srcdir</a></code> | <code>str</code> | Typescript sources directory. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.testdir">testdir</a></code> | <code>str</code> | Jest tests directory. Tests files should be named `xxx.test.ts`. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.tsconfig">tsconfig</a></code> | <code>projen.javascript.TypescriptConfigOptions</code> | Custom TSConfig. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.tsconfigDev">tsconfig_dev</a></code> | <code>projen.javascript.TypescriptConfigOptions</code> | Custom tsconfig options for the development tsconfig.json file (used for testing). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.tsconfigDevFile">tsconfig_dev_file</a></code> | <code>str</code> | The name of the development tsconfig.json file. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.typescriptVersion">typescript_version</a></code> | <code>str</code> | TypeScript version to use. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.openApiGeneratorCliConfig">open_api_generator_cli_config</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfig">OpenApiGeneratorCliConfig</a></code> | Configuration for the OpenAPI Generator CLI. |

---

##### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.name"></a>

```python
name: str
```

- *Type:* str
- *Default:* $BASEDIR

This is the name of your project.

---

##### `commit_generated`<sup>Optional</sup> <a name="commit_generated" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.commitGenerated"></a>

```python
commit_generated: bool
```

- *Type:* bool
- *Default:* true

Whether to commit the managed files by default.

---

##### `git_ignore_options`<sup>Optional</sup> <a name="git_ignore_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.gitIgnoreOptions"></a>

```python
git_ignore_options: IgnoreFileOptions
```

- *Type:* projen.IgnoreFileOptions

Configuration options for .gitignore file.

---

##### `git_options`<sup>Optional</sup> <a name="git_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.gitOptions"></a>

```python
git_options: GitOptions
```

- *Type:* projen.GitOptions

Configuration options for git.

---

##### `logging`<sup>Optional</sup> <a name="logging" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.logging"></a>

```python
logging: LoggerOptions
```

- *Type:* projen.LoggerOptions
- *Default:* {}

Configure logging options such as verbosity.

---

##### `outdir`<sup>Optional</sup> <a name="outdir" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.outdir"></a>

```python
outdir: str
```

- *Type:* str
- *Default:* "."

The root directory of the project.

Relative to this directory, all files are synthesized.

If this project has a parent, this directory is relative to the parent
directory and it cannot be the same as the parent or any of it's other
sub-projects.

---

##### `parent`<sup>Optional</sup> <a name="parent" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.parent"></a>

```python
parent: Project
```

- *Type:* projen.Project

The parent project, if this project is part of a bigger project.

---

##### `projen_command`<sup>Optional</sup> <a name="projen_command" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.projenCommand"></a>

```python
projen_command: str
```

- *Type:* str
- *Default:* "npx projen"

The shell command to use in order to run the projen CLI.

Can be used to customize in special environments.

---

##### `projenrc_json`<sup>Optional</sup> <a name="projenrc_json" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.projenrcJson"></a>

```python
projenrc_json: bool
```

- *Type:* bool
- *Default:* false

Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation.

---

##### `projenrc_json_options`<sup>Optional</sup> <a name="projenrc_json_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.projenrcJsonOptions"></a>

```python
projenrc_json_options: ProjenrcJsonOptions
```

- *Type:* projen.ProjenrcJsonOptions
- *Default:* default options

Options for .projenrc.json.

---

##### `renovatebot`<sup>Optional</sup> <a name="renovatebot" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.renovatebot"></a>

```python
renovatebot: bool
```

- *Type:* bool
- *Default:* false

Use renovatebot to handle dependency upgrades.

---

##### `renovatebot_options`<sup>Optional</sup> <a name="renovatebot_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.renovatebotOptions"></a>

```python
renovatebot_options: RenovatebotOptions
```

- *Type:* projen.RenovatebotOptions
- *Default:* default options

Options for renovatebot.

---

##### `auto_approve_options`<sup>Optional</sup> <a name="auto_approve_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.autoApproveOptions"></a>

```python
auto_approve_options: AutoApproveOptions
```

- *Type:* projen.github.AutoApproveOptions
- *Default:* auto approve is disabled

Enable and configure the 'auto approve' workflow.

---

##### `auto_merge`<sup>Optional</sup> <a name="auto_merge" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.autoMerge"></a>

```python
auto_merge: bool
```

- *Type:* bool
- *Default:* true

Enable automatic merging on GitHub.

Has no effect if `github.mergify`
is set to false.

---

##### `auto_merge_options`<sup>Optional</sup> <a name="auto_merge_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.autoMergeOptions"></a>

```python
auto_merge_options: AutoMergeOptions
```

- *Type:* projen.github.AutoMergeOptions
- *Default:* see defaults in `AutoMergeOptions`

Configure options for automatic merging on GitHub.

Has no effect if
`github.mergify` or `autoMerge` is set to false.

---

##### `clobber`<sup>Optional</sup> <a name="clobber" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.clobber"></a>

```python
clobber: bool
```

- *Type:* bool
- *Default:* true, but false for subprojects

Add a `clobber` task which resets the repo to origin.

---

##### `dev_container`<sup>Optional</sup> <a name="dev_container" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.devContainer"></a>

```python
dev_container: bool
```

- *Type:* bool
- *Default:* false

Add a VSCode development environment (used for GitHub Codespaces).

---

##### `github`<sup>Optional</sup> <a name="github" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.github"></a>

```python
github: bool
```

- *Type:* bool
- *Default:* true

Enable GitHub integration.

Enabled by default for root projects. Disabled for non-root projects.

---

##### `github_options`<sup>Optional</sup> <a name="github_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.githubOptions"></a>

```python
github_options: GitHubOptions
```

- *Type:* projen.github.GitHubOptions
- *Default:* see GitHubOptions

Options for GitHub integration.

---

##### `gitpod`<sup>Optional</sup> <a name="gitpod" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.gitpod"></a>

```python
gitpod: bool
```

- *Type:* bool
- *Default:* false

Add a Gitpod development environment.

---

##### ~~`mergify`~~<sup>Optional</sup> <a name="mergify" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.mergify"></a>

- *Deprecated:* use `githubOptions.mergify` instead

```python
mergify: bool
```

- *Type:* bool
- *Default:* true

Whether mergify should be enabled on this repository or not.

---

##### ~~`mergify_options`~~<sup>Optional</sup> <a name="mergify_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.mergifyOptions"></a>

- *Deprecated:* use `githubOptions.mergifyOptions` instead

```python
mergify_options: MergifyOptions
```

- *Type:* projen.github.MergifyOptions
- *Default:* default options

Options for mergify.

---

##### ~~`project_type`~~<sup>Optional</sup> <a name="project_type" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.projectType"></a>

- *Deprecated:* no longer supported at the base project level

```python
project_type: ProjectType
```

- *Type:* projen.ProjectType
- *Default:* ProjectType.UNKNOWN

Which type of project this is (library/app).

---

##### `projen_credentials`<sup>Optional</sup> <a name="projen_credentials" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.projenCredentials"></a>

```python
projen_credentials: GithubCredentials
```

- *Type:* projen.github.GithubCredentials
- *Default:* use a personal access token named PROJEN_GITHUB_TOKEN

Choose a method of providing GitHub API access for projen workflows.

---

##### ~~`projen_token_secret`~~<sup>Optional</sup> <a name="projen_token_secret" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.projenTokenSecret"></a>

- *Deprecated:* use `projenCredentials`

```python
projen_token_secret: str
```

- *Type:* str
- *Default:* "PROJEN_GITHUB_TOKEN"

The name of a secret which includes a GitHub Personal Access Token to be used by projen workflows.

This token needs to have the `repo`, `workflows`
and `packages` scope.

---

##### `readme`<sup>Optional</sup> <a name="readme" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.readme"></a>

```python
readme: SampleReadmeProps
```

- *Type:* projen.SampleReadmeProps
- *Default:* { filename: 'README.md', contents: '# replace this' }

The README setup.

---

*Example*

```python
"{ filename: 'readme.md', contents: '# title' }"
```


##### `stale`<sup>Optional</sup> <a name="stale" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.stale"></a>

```python
stale: bool
```

- *Type:* bool
- *Default:* false

Auto-close of stale issues and pull request.

See `staleOptions` for options.

---

##### `stale_options`<sup>Optional</sup> <a name="stale_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.staleOptions"></a>

```python
stale_options: StaleOptions
```

- *Type:* projen.github.StaleOptions
- *Default:* see defaults in `StaleOptions`

Auto-close stale issues and pull requests.

To disable set `stale` to `false`.

---

##### `vscode`<sup>Optional</sup> <a name="vscode" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.vscode"></a>

```python
vscode: bool
```

- *Type:* bool
- *Default:* true

Enable VSCode integration.

Enabled by default for root projects. Disabled for non-root projects.

---

##### `allow_library_dependencies`<sup>Optional</sup> <a name="allow_library_dependencies" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.allowLibraryDependencies"></a>

```python
allow_library_dependencies: bool
```

- *Type:* bool
- *Default:* true

Allow the project to include `peerDependencies` and `bundledDependencies`.

This is normally only allowed for libraries. For apps, there's no meaning
for specifying these.

---

##### `author_email`<sup>Optional</sup> <a name="author_email" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.authorEmail"></a>

```python
author_email: str
```

- *Type:* str

Author's e-mail.

---

##### `author_name`<sup>Optional</sup> <a name="author_name" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.authorName"></a>

```python
author_name: str
```

- *Type:* str

Author's name.

---

##### `author_organization`<sup>Optional</sup> <a name="author_organization" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.authorOrganization"></a>

```python
author_organization: bool
```

- *Type:* bool

Is the author an organization.

---

##### `author_url`<sup>Optional</sup> <a name="author_url" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.authorUrl"></a>

```python
author_url: str
```

- *Type:* str

Author's URL / Website.

---

##### `auto_detect_bin`<sup>Optional</sup> <a name="auto_detect_bin" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.autoDetectBin"></a>

```python
auto_detect_bin: bool
```

- *Type:* bool
- *Default:* true

Automatically add all executables under the `bin` directory to your `package.json` file under the `bin` section.

---

##### `bin`<sup>Optional</sup> <a name="bin" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.bin"></a>

```python
bin: typing.Mapping[str]
```

- *Type:* typing.Mapping[str]

Binary programs vended with your module.

You can use this option to add/customize how binaries are represented in
your `package.json`, but unless `autoDetectBin` is `false`, every
executable file under `bin` will automatically be added to this section.

---

##### `bugs_email`<sup>Optional</sup> <a name="bugs_email" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.bugsEmail"></a>

```python
bugs_email: str
```

- *Type:* str

The email address to which issues should be reported.

---

##### `bugs_url`<sup>Optional</sup> <a name="bugs_url" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.bugsUrl"></a>

```python
bugs_url: str
```

- *Type:* str

The url to your project's issue tracker.

---

##### `bundled_deps`<sup>Optional</sup> <a name="bundled_deps" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.bundledDeps"></a>

```python
bundled_deps: typing.List[str]
```

- *Type:* typing.List[str]

List of dependencies to bundle into this module.

These modules will be
added both to the `dependencies` section and `bundledDependencies` section of
your `package.json`.

The recommendation is to only specify the module name here (e.g.
`express`). This will behave similar to `yarn add` or `npm install` in the
sense that it will add the module as a dependency to your `package.json`
file with the latest version (`^`). You can specify semver requirements in
the same syntax passed to `npm i` or `yarn add` (e.g. `express@^2`) and
this will be what you `package.json` will eventually include.

---

##### `code_artifact_options`<sup>Optional</sup> <a name="code_artifact_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.codeArtifactOptions"></a>

```python
code_artifact_options: CodeArtifactOptions
```

- *Type:* projen.javascript.CodeArtifactOptions
- *Default:* undefined

Options for npm packages using AWS CodeArtifact.

This is required if publishing packages to, or installing scoped packages from AWS CodeArtifact

---

##### `deps`<sup>Optional</sup> <a name="deps" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.deps"></a>

```python
deps: typing.List[str]
```

- *Type:* typing.List[str]
- *Default:* []

Runtime dependencies of this module.

The recommendation is to only specify the module name here (e.g.
`express`). This will behave similar to `yarn add` or `npm install` in the
sense that it will add the module as a dependency to your `package.json`
file with the latest version (`^`). You can specify semver requirements in
the same syntax passed to `npm i` or `yarn add` (e.g. `express@^2`) and
this will be what you `package.json` will eventually include.

---

*Example*

```python
[ 'express', 'lodash', 'foo@^2' ]
```


##### `description`<sup>Optional</sup> <a name="description" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.description"></a>

```python
description: str
```

- *Type:* str

The description is just a string that helps people understand the purpose of the package.

It can be used when searching for packages in a package manager as well.
See https://classic.yarnpkg.com/en/docs/package-json/#toc-description

---

##### `dev_deps`<sup>Optional</sup> <a name="dev_deps" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.devDeps"></a>

```python
dev_deps: typing.List[str]
```

- *Type:* typing.List[str]
- *Default:* []

Build dependencies for this module.

These dependencies will only be
available in your build environment but will not be fetched when this
module is consumed.

The recommendation is to only specify the module name here (e.g.
`express`). This will behave similar to `yarn add` or `npm install` in the
sense that it will add the module as a dependency to your `package.json`
file with the latest version (`^`). You can specify semver requirements in
the same syntax passed to `npm i` or `yarn add` (e.g. `express@^2`) and
this will be what you `package.json` will eventually include.

---

*Example*

```python
[ 'typescript', '@types/express' ]
```


##### `entrypoint`<sup>Optional</sup> <a name="entrypoint" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.entrypoint"></a>

```python
entrypoint: str
```

- *Type:* str
- *Default:* "lib/index.js"

Module entrypoint (`main` in `package.json`).

Set to an empty string to not include `main` in your package.json

---

##### `homepage`<sup>Optional</sup> <a name="homepage" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.homepage"></a>

```python
homepage: str
```

- *Type:* str

Package's Homepage / Website.

---

##### `keywords`<sup>Optional</sup> <a name="keywords" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.keywords"></a>

```python
keywords: typing.List[str]
```

- *Type:* typing.List[str]

Keywords to include in `package.json`.

---

##### `license`<sup>Optional</sup> <a name="license" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.license"></a>

```python
license: str
```

- *Type:* str
- *Default:* "Apache-2.0"

License's SPDX identifier.

See https://github.com/projen/projen/tree/main/license-text for a list of supported licenses.
Use the `licensed` option if you want to no license to be specified.

---

##### `licensed`<sup>Optional</sup> <a name="licensed" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.licensed"></a>

```python
licensed: bool
```

- *Type:* bool
- *Default:* true

Indicates if a license should be added.

---

##### `max_node_version`<sup>Optional</sup> <a name="max_node_version" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.maxNodeVersion"></a>

```python
max_node_version: str
```

- *Type:* str
- *Default:* no max

Minimum node.js version to require via `engines` (inclusive).

---

##### `min_node_version`<sup>Optional</sup> <a name="min_node_version" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.minNodeVersion"></a>

```python
min_node_version: str
```

- *Type:* str
- *Default:* no "engines" specified

Minimum Node.js version to require via package.json `engines` (inclusive).

---

##### `npm_access`<sup>Optional</sup> <a name="npm_access" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.npmAccess"></a>

```python
npm_access: NpmAccess
```

- *Type:* projen.javascript.NpmAccess
- *Default:* for scoped packages (e.g. `foo@bar`), the default is `NpmAccess.RESTRICTED`, for non-scoped packages, the default is `NpmAccess.PUBLIC`.

Access level of the npm package.

---

##### ~~`npm_registry`~~<sup>Optional</sup> <a name="npm_registry" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.npmRegistry"></a>

- *Deprecated:* use `npmRegistryUrl` instead

```python
npm_registry: str
```

- *Type:* str

The host name of the npm registry to publish to.

Cannot be set together with `npmRegistryUrl`.

---

##### `npm_registry_url`<sup>Optional</sup> <a name="npm_registry_url" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.npmRegistryUrl"></a>

```python
npm_registry_url: str
```

- *Type:* str
- *Default:* "https://registry.npmjs.org"

The base URL of the npm package registry.

Must be a URL (e.g. start with "https://" or "http://")

---

##### `npm_token_secret`<sup>Optional</sup> <a name="npm_token_secret" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.npmTokenSecret"></a>

```python
npm_token_secret: str
```

- *Type:* str
- *Default:* "NPM_TOKEN"

GitHub secret which contains the NPM token to use when publishing packages.

---

##### `package_manager`<sup>Optional</sup> <a name="package_manager" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.packageManager"></a>

```python
package_manager: NodePackageManager
```

- *Type:* projen.javascript.NodePackageManager
- *Default:* NodePackageManager.YARN

The Node Package Manager used to execute scripts.

---

##### `package_name`<sup>Optional</sup> <a name="package_name" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.packageName"></a>

```python
package_name: str
```

- *Type:* str
- *Default:* defaults to project name

The "name" in package.json.

---

##### `peer_dependency_options`<sup>Optional</sup> <a name="peer_dependency_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.peerDependencyOptions"></a>

```python
peer_dependency_options: PeerDependencyOptions
```

- *Type:* projen.javascript.PeerDependencyOptions

Options for `peerDeps`.

---

##### `peer_deps`<sup>Optional</sup> <a name="peer_deps" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.peerDeps"></a>

```python
peer_deps: typing.List[str]
```

- *Type:* typing.List[str]
- *Default:* []

Peer dependencies for this module.

Dependencies listed here are required to
be installed (and satisfied) by the _consumer_ of this library. Using peer
dependencies allows you to ensure that only a single module of a certain
library exists in the `node_modules` tree of your consumers.

Note that prior to npm@7, peer dependencies are _not_ automatically
installed, which means that adding peer dependencies to a library will be a
breaking change for your customers.

Unless `peerDependencyOptions.pinnedDevDependency` is disabled (it is
enabled by default), projen will automatically add a dev dependency with a
pinned version for each peer dependency. This will ensure that you build &
test your module against the lowest peer version required.

---

##### `pnpm_version`<sup>Optional</sup> <a name="pnpm_version" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.pnpmVersion"></a>

```python
pnpm_version: str
```

- *Type:* str
- *Default:* "7"

The version of PNPM to use if using PNPM as a package manager.

---

##### `repository`<sup>Optional</sup> <a name="repository" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.repository"></a>

```python
repository: str
```

- *Type:* str

The repository is the location where the actual code for your package lives.

See https://classic.yarnpkg.com/en/docs/package-json/#toc-repository

---

##### `repository_directory`<sup>Optional</sup> <a name="repository_directory" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.repositoryDirectory"></a>

```python
repository_directory: str
```

- *Type:* str

If the package.json for your package is not in the root directory (for example if it is part of a monorepo), you can specify the directory in which it lives.

---

##### `scoped_packages_options`<sup>Optional</sup> <a name="scoped_packages_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.scopedPackagesOptions"></a>

```python
scoped_packages_options: typing.List[ScopedPackagesOptions]
```

- *Type:* typing.List[projen.javascript.ScopedPackagesOptions]
- *Default:* fetch all scoped packages from the public npm registry

Options for privately hosted scoped packages.

---

##### ~~`scripts`~~<sup>Optional</sup> <a name="scripts" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.scripts"></a>

- *Deprecated:* use `project.addTask()` or `package.setScript()`

```python
scripts: typing.Mapping[str]
```

- *Type:* typing.Mapping[str]
- *Default:* {}

npm scripts to include.

If a script has the same name as a standard script,
the standard script will be overwritten.
Also adds the script as a task.

---

##### `stability`<sup>Optional</sup> <a name="stability" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.stability"></a>

```python
stability: str
```

- *Type:* str

Package's Stability.

---

##### `jsii_release_version`<sup>Optional</sup> <a name="jsii_release_version" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.jsiiReleaseVersion"></a>

```python
jsii_release_version: str
```

- *Type:* str
- *Default:* "latest"

Version requirement of `publib` which is used to publish modules to npm.

---

##### `major_version`<sup>Optional</sup> <a name="major_version" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.majorVersion"></a>

```python
major_version: typing.Union[int, float]
```

- *Type:* typing.Union[int, float]
- *Default:* Major version is not enforced.

Major version to release from the default branch.

If this is specified, we bump the latest version of this major version line.
If not specified, we bump the global latest version.

---

##### `min_major_version`<sup>Optional</sup> <a name="min_major_version" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.minMajorVersion"></a>

```python
min_major_version: typing.Union[int, float]
```

- *Type:* typing.Union[int, float]
- *Default:* No minimum version is being enforced

Minimal Major version to release.

This can be useful to set to 1, as breaking changes before the 1.x major
release are not incrementing the major version number.

Can not be set together with `majorVersion`.

---

##### `npm_dist_tag`<sup>Optional</sup> <a name="npm_dist_tag" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.npmDistTag"></a>

```python
npm_dist_tag: str
```

- *Type:* str
- *Default:* "latest"

The npmDistTag to use when publishing from the default branch.

To set the npm dist-tag for release branches, set the `npmDistTag` property
for each branch.

---

##### `post_build_steps`<sup>Optional</sup> <a name="post_build_steps" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.postBuildSteps"></a>

```python
post_build_steps: typing.List[JobStep]
```

- *Type:* typing.List[projen.github.workflows.JobStep]
- *Default:* []

Steps to execute after build as part of the release workflow.

---

##### `prerelease`<sup>Optional</sup> <a name="prerelease" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.prerelease"></a>

```python
prerelease: str
```

- *Type:* str
- *Default:* normal semantic versions

Bump versions from the default branch as pre-releases (e.g. "beta", "alpha", "pre").

---

##### `publish_dry_run`<sup>Optional</sup> <a name="publish_dry_run" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.publishDryRun"></a>

```python
publish_dry_run: bool
```

- *Type:* bool
- *Default:* false

Instead of actually publishing to package managers, just print the publishing command.

---

##### `publish_tasks`<sup>Optional</sup> <a name="publish_tasks" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.publishTasks"></a>

```python
publish_tasks: bool
```

- *Type:* bool
- *Default:* false

Define publishing tasks that can be executed manually as well as workflows.

Normally, publishing only happens within automated workflows. Enable this
in order to create a publishing task for each publishing activity.

---

##### `release_branches`<sup>Optional</sup> <a name="release_branches" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.releaseBranches"></a>

```python
release_branches: typing.Mapping[BranchOptions]
```

- *Type:* typing.Mapping[projen.release.BranchOptions]
- *Default:* no additional branches are used for release. you can use `addBranch()` to add additional branches.

Defines additional release branches.

A workflow will be created for each
release branch which will publish releases from commits in this branch.
Each release branch _must_ be assigned a major version number which is used
to enforce that versions published from that branch always use that major
version. If multiple branches are used, the `majorVersion` field must also
be provided for the default branch.

---

##### ~~`release_every_commit`~~<sup>Optional</sup> <a name="release_every_commit" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.releaseEveryCommit"></a>

- *Deprecated:* Use `releaseTrigger: ReleaseTrigger.continuous()` instead

```python
release_every_commit: bool
```

- *Type:* bool
- *Default:* true

Automatically release new versions every commit to one of branches in `releaseBranches`.

---

##### `release_failure_issue`<sup>Optional</sup> <a name="release_failure_issue" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.releaseFailureIssue"></a>

```python
release_failure_issue: bool
```

- *Type:* bool
- *Default:* false

Create a github issue on every failed publishing task.

---

##### `release_failure_issue_label`<sup>Optional</sup> <a name="release_failure_issue_label" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.releaseFailureIssueLabel"></a>

```python
release_failure_issue_label: str
```

- *Type:* str
- *Default:* "failed-release"

The label to apply to issues indicating publish failures.

Only applies if `releaseFailureIssue` is true.

---

##### ~~`release_schedule`~~<sup>Optional</sup> <a name="release_schedule" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.releaseSchedule"></a>

- *Deprecated:* Use `releaseTrigger: ReleaseTrigger.scheduled()` instead

```python
release_schedule: str
```

- *Type:* str
- *Default:* no scheduled releases

CRON schedule to trigger new releases.

---

##### `release_tag_prefix`<sup>Optional</sup> <a name="release_tag_prefix" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.releaseTagPrefix"></a>

```python
release_tag_prefix: str
```

- *Type:* str
- *Default:* "v"

Automatically add the given prefix to release tags. Useful if you are releasing on multiple branches with overlapping version numbers.

Note: this prefix is used to detect the latest tagged version
when bumping, so if you change this on a project with an existing version
history, you may need to manually tag your latest release
with the new prefix.

---

##### `release_trigger`<sup>Optional</sup> <a name="release_trigger" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.releaseTrigger"></a>

```python
release_trigger: ReleaseTrigger
```

- *Type:* projen.release.ReleaseTrigger
- *Default:* Continuous releases (`ReleaseTrigger.continuous()`)

The release trigger to use.

---

##### `release_workflow_name`<sup>Optional</sup> <a name="release_workflow_name" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.releaseWorkflowName"></a>

```python
release_workflow_name: str
```

- *Type:* str
- *Default:* "Release"

The name of the default release workflow.

---

##### `release_workflow_setup_steps`<sup>Optional</sup> <a name="release_workflow_setup_steps" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.releaseWorkflowSetupSteps"></a>

```python
release_workflow_setup_steps: typing.List[JobStep]
```

- *Type:* typing.List[projen.github.workflows.JobStep]

A set of workflow steps to execute in order to setup the workflow container.

---

##### `versionrc_options`<sup>Optional</sup> <a name="versionrc_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.versionrcOptions"></a>

```python
versionrc_options: typing.Mapping[typing.Any]
```

- *Type:* typing.Mapping[typing.Any]
- *Default:* standard configuration applicable for GitHub repositories

Custom configuration used when creating changelog with standard-version package.

Given values either append to default configuration or overwrite values in it.

---

##### `workflow_container_image`<sup>Optional</sup> <a name="workflow_container_image" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.workflowContainerImage"></a>

```python
workflow_container_image: str
```

- *Type:* str
- *Default:* default image

Container image to use for GitHub workflows.

---

##### `workflow_runs_on`<sup>Optional</sup> <a name="workflow_runs_on" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.workflowRunsOn"></a>

```python
workflow_runs_on: typing.List[str]
```

- *Type:* typing.List[str]
- *Default:* ["ubuntu-latest"]

Github Runner selection labels.

---

##### `default_release_branch`<sup>Required</sup> <a name="default_release_branch" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.defaultReleaseBranch"></a>

```python
default_release_branch: str
```

- *Type:* str
- *Default:* "main"

The name of the main release branch.

---

##### `artifacts_directory`<sup>Optional</sup> <a name="artifacts_directory" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.artifactsDirectory"></a>

```python
artifacts_directory: str
```

- *Type:* str
- *Default:* "dist"

A directory which will contain build artifacts.

---

##### `auto_approve_upgrades`<sup>Optional</sup> <a name="auto_approve_upgrades" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.autoApproveUpgrades"></a>

```python
auto_approve_upgrades: bool
```

- *Type:* bool
- *Default:* true

Automatically approve deps upgrade PRs, allowing them to be merged by mergify (if configued).

Throw if set to true but `autoApproveOptions` are not defined.

---

##### `build_workflow`<sup>Optional</sup> <a name="build_workflow" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.buildWorkflow"></a>

```python
build_workflow: bool
```

- *Type:* bool
- *Default:* true if not a subproject

Define a GitHub workflow for building PRs.

---

##### `build_workflow_triggers`<sup>Optional</sup> <a name="build_workflow_triggers" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.buildWorkflowTriggers"></a>

```python
build_workflow_triggers: Triggers
```

- *Type:* projen.github.workflows.Triggers
- *Default:* "{ pullRequest: {}, workflowDispatch: {} }"

Build workflow triggers.

---

##### `bundler_options`<sup>Optional</sup> <a name="bundler_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.bundlerOptions"></a>

```python
bundler_options: BundlerOptions
```

- *Type:* projen.javascript.BundlerOptions

Options for `Bundler`.

---

##### `code_cov`<sup>Optional</sup> <a name="code_cov" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.codeCov"></a>

```python
code_cov: bool
```

- *Type:* bool
- *Default:* false

Define a GitHub workflow step for sending code coverage metrics to https://codecov.io/ Uses codecov/codecov-action@v3 A secret is required for private repos. Configured with `@codeCovTokenSecret`.

---

##### `code_cov_token_secret`<sup>Optional</sup> <a name="code_cov_token_secret" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.codeCovTokenSecret"></a>

```python
code_cov_token_secret: str
```

- *Type:* str
- *Default:* if this option is not specified, only public repositories are supported

Define the secret name for a specified https://codecov.io/ token A secret is required to send coverage for private repositories.

---

##### `copyright_owner`<sup>Optional</sup> <a name="copyright_owner" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.copyrightOwner"></a>

```python
copyright_owner: str
```

- *Type:* str
- *Default:* defaults to the value of authorName or "" if `authorName` is undefined.

License copyright owner.

---

##### `copyright_period`<sup>Optional</sup> <a name="copyright_period" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.copyrightPeriod"></a>

```python
copyright_period: str
```

- *Type:* str
- *Default:* current year

The copyright years to put in the LICENSE file.

---

##### `dependabot`<sup>Optional</sup> <a name="dependabot" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.dependabot"></a>

```python
dependabot: bool
```

- *Type:* bool
- *Default:* false

Use dependabot to handle dependency upgrades.

Cannot be used in conjunction with `depsUpgrade`.

---

##### `dependabot_options`<sup>Optional</sup> <a name="dependabot_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.dependabotOptions"></a>

```python
dependabot_options: DependabotOptions
```

- *Type:* projen.github.DependabotOptions
- *Default:* default options

Options for dependabot.

---

##### `deps_upgrade`<sup>Optional</sup> <a name="deps_upgrade" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.depsUpgrade"></a>

```python
deps_upgrade: bool
```

- *Type:* bool
- *Default:* true

Use github workflows to handle dependency upgrades.

Cannot be used in conjunction with `dependabot`.

---

##### `deps_upgrade_options`<sup>Optional</sup> <a name="deps_upgrade_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.depsUpgradeOptions"></a>

```python
deps_upgrade_options: UpgradeDependenciesOptions
```

- *Type:* projen.javascript.UpgradeDependenciesOptions
- *Default:* default options

Options for `UpgradeDependencies`.

---

##### `gitignore`<sup>Optional</sup> <a name="gitignore" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.gitignore"></a>

```python
gitignore: typing.List[str]
```

- *Type:* typing.List[str]

Additional entries to .gitignore.

---

##### `jest`<sup>Optional</sup> <a name="jest" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.jest"></a>

```python
jest: bool
```

- *Type:* bool
- *Default:* true

Setup jest unit tests.

---

##### `jest_options`<sup>Optional</sup> <a name="jest_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.jestOptions"></a>

```python
jest_options: JestOptions
```

- *Type:* projen.javascript.JestOptions
- *Default:* default options

Jest options.

---

##### `mutable_build`<sup>Optional</sup> <a name="mutable_build" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.mutableBuild"></a>

```python
mutable_build: bool
```

- *Type:* bool
- *Default:* true

Automatically update files modified during builds to pull-request branches.

This means
that any files synthesized by projen or e.g. test snapshots will always be up-to-date
before a PR is merged.

Implies that PR builds do not have anti-tamper checks.

---

##### ~~`npmignore`~~<sup>Optional</sup> <a name="npmignore" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.npmignore"></a>

- *Deprecated:* - use `project.addPackageIgnore`

```python
npmignore: typing.List[str]
```

- *Type:* typing.List[str]

Additional entries to .npmignore.

---

##### `npmignore_enabled`<sup>Optional</sup> <a name="npmignore_enabled" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.npmignoreEnabled"></a>

```python
npmignore_enabled: bool
```

- *Type:* bool
- *Default:* true

Defines an .npmignore file. Normally this is only needed for libraries that are packaged as tarballs.

---

##### `npm_ignore_options`<sup>Optional</sup> <a name="npm_ignore_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.npmIgnoreOptions"></a>

```python
npm_ignore_options: IgnoreFileOptions
```

- *Type:* projen.IgnoreFileOptions

Configuration options for .npmignore file.

---

##### `package`<sup>Optional</sup> <a name="package" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.package"></a>

```python
package: bool
```

- *Type:* bool
- *Default:* true

Defines a `package` task that will produce an npm tarball under the artifacts directory (e.g. `dist`).

---

##### `prettier`<sup>Optional</sup> <a name="prettier" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.prettier"></a>

```python
prettier: bool
```

- *Type:* bool
- *Default:* false

Setup prettier.

---

##### `prettier_options`<sup>Optional</sup> <a name="prettier_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.prettierOptions"></a>

```python
prettier_options: PrettierOptions
```

- *Type:* projen.javascript.PrettierOptions
- *Default:* default options

Prettier options.

---

##### `projen_dev_dependency`<sup>Optional</sup> <a name="projen_dev_dependency" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.projenDevDependency"></a>

```python
projen_dev_dependency: bool
```

- *Type:* bool
- *Default:* true

Indicates of "projen" should be installed as a devDependency.

---

##### `projenrc_js`<sup>Optional</sup> <a name="projenrc_js" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.projenrcJs"></a>

```python
projenrc_js: bool
```

- *Type:* bool
- *Default:* true if projenrcJson is false

Generate (once) .projenrc.js (in JavaScript). Set to `false` in order to disable .projenrc.js generation.

---

##### `projenrc_js_options`<sup>Optional</sup> <a name="projenrc_js_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.projenrcJsOptions"></a>

```python
projenrc_js_options: ProjenrcOptions
```

- *Type:* projen.javascript.ProjenrcOptions
- *Default:* default options

Options for .projenrc.js.

---

##### `projen_version`<sup>Optional</sup> <a name="projen_version" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.projenVersion"></a>

```python
projen_version: str
```

- *Type:* str
- *Default:* Defaults to the latest version.

Version of projen to install.

---

##### `pull_request_template`<sup>Optional</sup> <a name="pull_request_template" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.pullRequestTemplate"></a>

```python
pull_request_template: bool
```

- *Type:* bool
- *Default:* true

Include a GitHub pull request template.

---

##### `pull_request_template_contents`<sup>Optional</sup> <a name="pull_request_template_contents" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.pullRequestTemplateContents"></a>

```python
pull_request_template_contents: typing.List[str]
```

- *Type:* typing.List[str]
- *Default:* default content

The contents of the pull request template.

---

##### `release`<sup>Optional</sup> <a name="release" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.release"></a>

```python
release: bool
```

- *Type:* bool
- *Default:* true (false for subprojects)

Add release management to this project.

---

##### `release_to_npm`<sup>Optional</sup> <a name="release_to_npm" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.releaseToNpm"></a>

```python
release_to_npm: bool
```

- *Type:* bool
- *Default:* false

Automatically release to npm when new versions are introduced.

---

##### ~~`release_workflow`~~<sup>Optional</sup> <a name="release_workflow" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.releaseWorkflow"></a>

- *Deprecated:* see `release`.

```python
release_workflow: bool
```

- *Type:* bool
- *Default:* true if not a subproject

DEPRECATED: renamed to `release`.

---

##### `workflow_bootstrap_steps`<sup>Optional</sup> <a name="workflow_bootstrap_steps" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.workflowBootstrapSteps"></a>

```python
workflow_bootstrap_steps: typing.List[JobStep]
```

- *Type:* typing.List[projen.github.workflows.JobStep]
- *Default:* "yarn install --frozen-lockfile && yarn projen"

Workflow steps to use in order to bootstrap this repo.

---

##### `workflow_git_identity`<sup>Optional</sup> <a name="workflow_git_identity" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.workflowGitIdentity"></a>

```python
workflow_git_identity: GitIdentity
```

- *Type:* projen.github.GitIdentity
- *Default:* GitHub Actions

The git identity to use in workflows.

---

##### `workflow_node_version`<sup>Optional</sup> <a name="workflow_node_version" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.workflowNodeVersion"></a>

```python
workflow_node_version: str
```

- *Type:* str
- *Default:* same as `minNodeVersion`

The node version to use in GitHub workflows.

---

##### `workflow_package_cache`<sup>Optional</sup> <a name="workflow_package_cache" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.workflowPackageCache"></a>

```python
workflow_package_cache: bool
```

- *Type:* bool
- *Default:* false

Enable Node.js package cache in GitHub workflows.

---

##### `disable_tsconfig`<sup>Optional</sup> <a name="disable_tsconfig" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.disableTsconfig"></a>

```python
disable_tsconfig: bool
```

- *Type:* bool
- *Default:* false

Do not generate a `tsconfig.json` file (used by jsii projects since tsconfig.json is generated by the jsii compiler).

---

##### `disable_tsconfig_dev`<sup>Optional</sup> <a name="disable_tsconfig_dev" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.disableTsconfigDev"></a>

```python
disable_tsconfig_dev: bool
```

- *Type:* bool
- *Default:* false

Do not generate a `tsconfig.dev.json` file.

---

##### `docgen`<sup>Optional</sup> <a name="docgen" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.docgen"></a>

```python
docgen: bool
```

- *Type:* bool
- *Default:* false

Docgen by Typedoc.

---

##### `docs_directory`<sup>Optional</sup> <a name="docs_directory" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.docsDirectory"></a>

```python
docs_directory: str
```

- *Type:* str
- *Default:* "docs"

Docs directory.

---

##### `entrypoint_types`<sup>Optional</sup> <a name="entrypoint_types" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.entrypointTypes"></a>

```python
entrypoint_types: str
```

- *Type:* str
- *Default:* .d.ts file derived from the project's entrypoint (usually lib/index.d.ts)

The .d.ts file that includes the type declarations for this module.

---

##### `eslint`<sup>Optional</sup> <a name="eslint" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.eslint"></a>

```python
eslint: bool
```

- *Type:* bool
- *Default:* true

Setup eslint.

---

##### `eslint_options`<sup>Optional</sup> <a name="eslint_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.eslintOptions"></a>

```python
eslint_options: EslintOptions
```

- *Type:* projen.javascript.EslintOptions
- *Default:* opinionated default options

Eslint options.

---

##### `libdir`<sup>Optional</sup> <a name="libdir" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.libdir"></a>

```python
libdir: str
```

- *Type:* str
- *Default:* "lib"

Typescript  artifacts output directory.

---

##### `projenrc_ts`<sup>Optional</sup> <a name="projenrc_ts" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.projenrcTs"></a>

```python
projenrc_ts: bool
```

- *Type:* bool
- *Default:* false

Use TypeScript for your projenrc file (`.projenrc.ts`).

---

##### `projenrc_ts_options`<sup>Optional</sup> <a name="projenrc_ts_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.projenrcTsOptions"></a>

```python
projenrc_ts_options: ProjenrcOptions
```

- *Type:* projen.typescript.ProjenrcOptions

Options for .projenrc.ts.

---

##### `sample_code`<sup>Optional</sup> <a name="sample_code" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.sampleCode"></a>

```python
sample_code: bool
```

- *Type:* bool
- *Default:* true

Generate one-time sample in `src/` and `test/` if there are no files there.

---

##### `srcdir`<sup>Optional</sup> <a name="srcdir" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.srcdir"></a>

```python
srcdir: str
```

- *Type:* str
- *Default:* "src"

Typescript sources directory.

---

##### `testdir`<sup>Optional</sup> <a name="testdir" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.testdir"></a>

```python
testdir: str
```

- *Type:* str
- *Default:* "test"

Jest tests directory. Tests files should be named `xxx.test.ts`.

If this directory is under `srcdir` (e.g. `src/test`, `src/__tests__`),
then tests are going to be compiled into `lib/` and executed as javascript.
If the test directory is outside of `src`, then we configure jest to
compile the code in-memory.

---

##### `tsconfig`<sup>Optional</sup> <a name="tsconfig" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.tsconfig"></a>

```python
tsconfig: TypescriptConfigOptions
```

- *Type:* projen.javascript.TypescriptConfigOptions
- *Default:* default options

Custom TSConfig.

---

##### `tsconfig_dev`<sup>Optional</sup> <a name="tsconfig_dev" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.tsconfigDev"></a>

```python
tsconfig_dev: TypescriptConfigOptions
```

- *Type:* projen.javascript.TypescriptConfigOptions
- *Default:* use the production tsconfig options

Custom tsconfig options for the development tsconfig.json file (used for testing).

---

##### `tsconfig_dev_file`<sup>Optional</sup> <a name="tsconfig_dev_file" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.tsconfigDevFile"></a>

```python
tsconfig_dev_file: str
```

- *Type:* str
- *Default:* "tsconfig.dev.json"

The name of the development tsconfig.json file.

---

##### `typescript_version`<sup>Optional</sup> <a name="typescript_version" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.typescriptVersion"></a>

```python
typescript_version: str
```

- *Type:* str
- *Default:* "latest"

TypeScript version to use.

NOTE: Typescript is not semantically versioned and should remain on the
same minor, so we recommend using a `~` dependency (e.g. `~1.2.3`).

---

##### `open_api_generator_cli_config`<sup>Optional</sup> <a name="open_api_generator_cli_config" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptReactQueryHooksOptions.property.openApiGeneratorCliConfig"></a>

```python
open_api_generator_cli_config: OpenApiGeneratorCliConfig
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfig">OpenApiGeneratorCliConfig</a>

Configuration for the OpenAPI Generator CLI.

Overrides default values if specified.

> [https://github.com/OpenAPITools/openapi-generator-cli#configuration](https://github.com/OpenAPITools/openapi-generator-cli#configuration)

---

### GeneratedTypeScriptRuntimeOptions <a name="GeneratedTypeScriptRuntimeOptions" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions"></a>

Options for configuring a generated typescript runtime project.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.GeneratedTypeScriptRuntimeOptions(
  name: str,
  commit_generated: bool = None,
  git_ignore_options: IgnoreFileOptions = None,
  git_options: GitOptions = None,
  logging: LoggerOptions = None,
  outdir: str = None,
  parent: Project = None,
  projen_command: str = None,
  projenrc_json: bool = None,
  projenrc_json_options: ProjenrcJsonOptions = None,
  renovatebot: bool = None,
  renovatebot_options: RenovatebotOptions = None,
  auto_approve_options: AutoApproveOptions = None,
  auto_merge: bool = None,
  auto_merge_options: AutoMergeOptions = None,
  clobber: bool = None,
  dev_container: bool = None,
  github: bool = None,
  github_options: GitHubOptions = None,
  gitpod: bool = None,
  mergify: bool = None,
  mergify_options: MergifyOptions = None,
  project_type: ProjectType = None,
  projen_credentials: GithubCredentials = None,
  projen_token_secret: str = None,
  readme: SampleReadmeProps = None,
  stale: bool = None,
  stale_options: StaleOptions = None,
  vscode: bool = None,
  allow_library_dependencies: bool = None,
  author_email: str = None,
  author_name: str = None,
  author_organization: bool = None,
  author_url: str = None,
  auto_detect_bin: bool = None,
  bin: typing.Mapping[str] = None,
  bugs_email: str = None,
  bugs_url: str = None,
  bundled_deps: typing.List[str] = None,
  code_artifact_options: CodeArtifactOptions = None,
  deps: typing.List[str] = None,
  description: str = None,
  dev_deps: typing.List[str] = None,
  entrypoint: str = None,
  homepage: str = None,
  keywords: typing.List[str] = None,
  license: str = None,
  licensed: bool = None,
  max_node_version: str = None,
  min_node_version: str = None,
  npm_access: NpmAccess = None,
  npm_registry: str = None,
  npm_registry_url: str = None,
  npm_token_secret: str = None,
  package_manager: NodePackageManager = None,
  package_name: str = None,
  peer_dependency_options: PeerDependencyOptions = None,
  peer_deps: typing.List[str] = None,
  pnpm_version: str = None,
  repository: str = None,
  repository_directory: str = None,
  scoped_packages_options: typing.List[ScopedPackagesOptions] = None,
  scripts: typing.Mapping[str] = None,
  stability: str = None,
  jsii_release_version: str = None,
  major_version: typing.Union[int, float] = None,
  min_major_version: typing.Union[int, float] = None,
  npm_dist_tag: str = None,
  post_build_steps: typing.List[JobStep] = None,
  prerelease: str = None,
  publish_dry_run: bool = None,
  publish_tasks: bool = None,
  release_branches: typing.Mapping[BranchOptions] = None,
  release_every_commit: bool = None,
  release_failure_issue: bool = None,
  release_failure_issue_label: str = None,
  release_schedule: str = None,
  release_tag_prefix: str = None,
  release_trigger: ReleaseTrigger = None,
  release_workflow_name: str = None,
  release_workflow_setup_steps: typing.List[JobStep] = None,
  versionrc_options: typing.Mapping[typing.Any] = None,
  workflow_container_image: str = None,
  workflow_runs_on: typing.List[str] = None,
  default_release_branch: str,
  artifacts_directory: str = None,
  auto_approve_upgrades: bool = None,
  build_workflow: bool = None,
  build_workflow_triggers: Triggers = None,
  bundler_options: BundlerOptions = None,
  code_cov: bool = None,
  code_cov_token_secret: str = None,
  copyright_owner: str = None,
  copyright_period: str = None,
  dependabot: bool = None,
  dependabot_options: DependabotOptions = None,
  deps_upgrade: bool = None,
  deps_upgrade_options: UpgradeDependenciesOptions = None,
  gitignore: typing.List[str] = None,
  jest: bool = None,
  jest_options: JestOptions = None,
  mutable_build: bool = None,
  npmignore: typing.List[str] = None,
  npmignore_enabled: bool = None,
  npm_ignore_options: IgnoreFileOptions = None,
  package: bool = None,
  prettier: bool = None,
  prettier_options: PrettierOptions = None,
  projen_dev_dependency: bool = None,
  projenrc_js: bool = None,
  projenrc_js_options: ProjenrcOptions = None,
  projen_version: str = None,
  pull_request_template: bool = None,
  pull_request_template_contents: typing.List[str] = None,
  release: bool = None,
  release_to_npm: bool = None,
  release_workflow: bool = None,
  workflow_bootstrap_steps: typing.List[JobStep] = None,
  workflow_git_identity: GitIdentity = None,
  workflow_node_version: str = None,
  workflow_package_cache: bool = None,
  disable_tsconfig: bool = None,
  disable_tsconfig_dev: bool = None,
  docgen: bool = None,
  docs_directory: str = None,
  entrypoint_types: str = None,
  eslint: bool = None,
  eslint_options: EslintOptions = None,
  libdir: str = None,
  projenrc_ts: bool = None,
  projenrc_ts_options: ProjenrcOptions = None,
  sample_code: bool = None,
  srcdir: str = None,
  testdir: str = None,
  tsconfig: TypescriptConfigOptions = None,
  tsconfig_dev: TypescriptConfigOptions = None,
  tsconfig_dev_file: str = None,
  typescript_version: str = None,
  open_api_generator_cli_config: OpenApiGeneratorCliConfig = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.name">name</a></code> | <code>str</code> | This is the name of your project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.commitGenerated">commit_generated</a></code> | <code>bool</code> | Whether to commit the managed files by default. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.gitIgnoreOptions">git_ignore_options</a></code> | <code>projen.IgnoreFileOptions</code> | Configuration options for .gitignore file. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.gitOptions">git_options</a></code> | <code>projen.GitOptions</code> | Configuration options for git. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.logging">logging</a></code> | <code>projen.LoggerOptions</code> | Configure logging options such as verbosity. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.outdir">outdir</a></code> | <code>str</code> | The root directory of the project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.parent">parent</a></code> | <code>projen.Project</code> | The parent project, if this project is part of a bigger project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.projenCommand">projen_command</a></code> | <code>str</code> | The shell command to use in order to run the projen CLI. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.projenrcJson">projenrc_json</a></code> | <code>bool</code> | Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.projenrcJsonOptions">projenrc_json_options</a></code> | <code>projen.ProjenrcJsonOptions</code> | Options for .projenrc.json. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.renovatebot">renovatebot</a></code> | <code>bool</code> | Use renovatebot to handle dependency upgrades. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.renovatebotOptions">renovatebot_options</a></code> | <code>projen.RenovatebotOptions</code> | Options for renovatebot. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.autoApproveOptions">auto_approve_options</a></code> | <code>projen.github.AutoApproveOptions</code> | Enable and configure the 'auto approve' workflow. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.autoMerge">auto_merge</a></code> | <code>bool</code> | Enable automatic merging on GitHub. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.autoMergeOptions">auto_merge_options</a></code> | <code>projen.github.AutoMergeOptions</code> | Configure options for automatic merging on GitHub. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.clobber">clobber</a></code> | <code>bool</code> | Add a `clobber` task which resets the repo to origin. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.devContainer">dev_container</a></code> | <code>bool</code> | Add a VSCode development environment (used for GitHub Codespaces). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.github">github</a></code> | <code>bool</code> | Enable GitHub integration. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.githubOptions">github_options</a></code> | <code>projen.github.GitHubOptions</code> | Options for GitHub integration. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.gitpod">gitpod</a></code> | <code>bool</code> | Add a Gitpod development environment. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.mergify">mergify</a></code> | <code>bool</code> | Whether mergify should be enabled on this repository or not. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.mergifyOptions">mergify_options</a></code> | <code>projen.github.MergifyOptions</code> | Options for mergify. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.projectType">project_type</a></code> | <code>projen.ProjectType</code> | Which type of project this is (library/app). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.projenCredentials">projen_credentials</a></code> | <code>projen.github.GithubCredentials</code> | Choose a method of providing GitHub API access for projen workflows. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.projenTokenSecret">projen_token_secret</a></code> | <code>str</code> | The name of a secret which includes a GitHub Personal Access Token to be used by projen workflows. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.readme">readme</a></code> | <code>projen.SampleReadmeProps</code> | The README setup. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.stale">stale</a></code> | <code>bool</code> | Auto-close of stale issues and pull request. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.staleOptions">stale_options</a></code> | <code>projen.github.StaleOptions</code> | Auto-close stale issues and pull requests. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.vscode">vscode</a></code> | <code>bool</code> | Enable VSCode integration. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.allowLibraryDependencies">allow_library_dependencies</a></code> | <code>bool</code> | Allow the project to include `peerDependencies` and `bundledDependencies`. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.authorEmail">author_email</a></code> | <code>str</code> | Author's e-mail. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.authorName">author_name</a></code> | <code>str</code> | Author's name. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.authorOrganization">author_organization</a></code> | <code>bool</code> | Is the author an organization. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.authorUrl">author_url</a></code> | <code>str</code> | Author's URL / Website. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.autoDetectBin">auto_detect_bin</a></code> | <code>bool</code> | Automatically add all executables under the `bin` directory to your `package.json` file under the `bin` section. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.bin">bin</a></code> | <code>typing.Mapping[str]</code> | Binary programs vended with your module. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.bugsEmail">bugs_email</a></code> | <code>str</code> | The email address to which issues should be reported. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.bugsUrl">bugs_url</a></code> | <code>str</code> | The url to your project's issue tracker. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.bundledDeps">bundled_deps</a></code> | <code>typing.List[str]</code> | List of dependencies to bundle into this module. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.codeArtifactOptions">code_artifact_options</a></code> | <code>projen.javascript.CodeArtifactOptions</code> | Options for npm packages using AWS CodeArtifact. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.deps">deps</a></code> | <code>typing.List[str]</code> | Runtime dependencies of this module. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.description">description</a></code> | <code>str</code> | The description is just a string that helps people understand the purpose of the package. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.devDeps">dev_deps</a></code> | <code>typing.List[str]</code> | Build dependencies for this module. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.entrypoint">entrypoint</a></code> | <code>str</code> | Module entrypoint (`main` in `package.json`). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.homepage">homepage</a></code> | <code>str</code> | Package's Homepage / Website. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.keywords">keywords</a></code> | <code>typing.List[str]</code> | Keywords to include in `package.json`. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.license">license</a></code> | <code>str</code> | License's SPDX identifier. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.licensed">licensed</a></code> | <code>bool</code> | Indicates if a license should be added. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.maxNodeVersion">max_node_version</a></code> | <code>str</code> | Minimum node.js version to require via `engines` (inclusive). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.minNodeVersion">min_node_version</a></code> | <code>str</code> | Minimum Node.js version to require via package.json `engines` (inclusive). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.npmAccess">npm_access</a></code> | <code>projen.javascript.NpmAccess</code> | Access level of the npm package. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.npmRegistry">npm_registry</a></code> | <code>str</code> | The host name of the npm registry to publish to. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.npmRegistryUrl">npm_registry_url</a></code> | <code>str</code> | The base URL of the npm package registry. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.npmTokenSecret">npm_token_secret</a></code> | <code>str</code> | GitHub secret which contains the NPM token to use when publishing packages. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.packageManager">package_manager</a></code> | <code>projen.javascript.NodePackageManager</code> | The Node Package Manager used to execute scripts. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.packageName">package_name</a></code> | <code>str</code> | The "name" in package.json. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.peerDependencyOptions">peer_dependency_options</a></code> | <code>projen.javascript.PeerDependencyOptions</code> | Options for `peerDeps`. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.peerDeps">peer_deps</a></code> | <code>typing.List[str]</code> | Peer dependencies for this module. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.pnpmVersion">pnpm_version</a></code> | <code>str</code> | The version of PNPM to use if using PNPM as a package manager. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.repository">repository</a></code> | <code>str</code> | The repository is the location where the actual code for your package lives. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.repositoryDirectory">repository_directory</a></code> | <code>str</code> | If the package.json for your package is not in the root directory (for example if it is part of a monorepo), you can specify the directory in which it lives. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.scopedPackagesOptions">scoped_packages_options</a></code> | <code>typing.List[projen.javascript.ScopedPackagesOptions]</code> | Options for privately hosted scoped packages. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.scripts">scripts</a></code> | <code>typing.Mapping[str]</code> | npm scripts to include. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.stability">stability</a></code> | <code>str</code> | Package's Stability. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.jsiiReleaseVersion">jsii_release_version</a></code> | <code>str</code> | Version requirement of `publib` which is used to publish modules to npm. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.majorVersion">major_version</a></code> | <code>typing.Union[int, float]</code> | Major version to release from the default branch. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.minMajorVersion">min_major_version</a></code> | <code>typing.Union[int, float]</code> | Minimal Major version to release. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.npmDistTag">npm_dist_tag</a></code> | <code>str</code> | The npmDistTag to use when publishing from the default branch. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.postBuildSteps">post_build_steps</a></code> | <code>typing.List[projen.github.workflows.JobStep]</code> | Steps to execute after build as part of the release workflow. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.prerelease">prerelease</a></code> | <code>str</code> | Bump versions from the default branch as pre-releases (e.g. "beta", "alpha", "pre"). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.publishDryRun">publish_dry_run</a></code> | <code>bool</code> | Instead of actually publishing to package managers, just print the publishing command. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.publishTasks">publish_tasks</a></code> | <code>bool</code> | Define publishing tasks that can be executed manually as well as workflows. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.releaseBranches">release_branches</a></code> | <code>typing.Mapping[projen.release.BranchOptions]</code> | Defines additional release branches. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.releaseEveryCommit">release_every_commit</a></code> | <code>bool</code> | Automatically release new versions every commit to one of branches in `releaseBranches`. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.releaseFailureIssue">release_failure_issue</a></code> | <code>bool</code> | Create a github issue on every failed publishing task. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.releaseFailureIssueLabel">release_failure_issue_label</a></code> | <code>str</code> | The label to apply to issues indicating publish failures. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.releaseSchedule">release_schedule</a></code> | <code>str</code> | CRON schedule to trigger new releases. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.releaseTagPrefix">release_tag_prefix</a></code> | <code>str</code> | Automatically add the given prefix to release tags. Useful if you are releasing on multiple branches with overlapping version numbers. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.releaseTrigger">release_trigger</a></code> | <code>projen.release.ReleaseTrigger</code> | The release trigger to use. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.releaseWorkflowName">release_workflow_name</a></code> | <code>str</code> | The name of the default release workflow. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.releaseWorkflowSetupSteps">release_workflow_setup_steps</a></code> | <code>typing.List[projen.github.workflows.JobStep]</code> | A set of workflow steps to execute in order to setup the workflow container. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.versionrcOptions">versionrc_options</a></code> | <code>typing.Mapping[typing.Any]</code> | Custom configuration used when creating changelog with standard-version package. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.workflowContainerImage">workflow_container_image</a></code> | <code>str</code> | Container image to use for GitHub workflows. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.workflowRunsOn">workflow_runs_on</a></code> | <code>typing.List[str]</code> | Github Runner selection labels. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.defaultReleaseBranch">default_release_branch</a></code> | <code>str</code> | The name of the main release branch. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.artifactsDirectory">artifacts_directory</a></code> | <code>str</code> | A directory which will contain build artifacts. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.autoApproveUpgrades">auto_approve_upgrades</a></code> | <code>bool</code> | Automatically approve deps upgrade PRs, allowing them to be merged by mergify (if configued). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.buildWorkflow">build_workflow</a></code> | <code>bool</code> | Define a GitHub workflow for building PRs. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.buildWorkflowTriggers">build_workflow_triggers</a></code> | <code>projen.github.workflows.Triggers</code> | Build workflow triggers. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.bundlerOptions">bundler_options</a></code> | <code>projen.javascript.BundlerOptions</code> | Options for `Bundler`. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.codeCov">code_cov</a></code> | <code>bool</code> | Define a GitHub workflow step for sending code coverage metrics to https://codecov.io/ Uses codecov/codecov-action@v3 A secret is required for private repos. Configured with `@codeCovTokenSecret`. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.codeCovTokenSecret">code_cov_token_secret</a></code> | <code>str</code> | Define the secret name for a specified https://codecov.io/ token A secret is required to send coverage for private repositories. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.copyrightOwner">copyright_owner</a></code> | <code>str</code> | License copyright owner. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.copyrightPeriod">copyright_period</a></code> | <code>str</code> | The copyright years to put in the LICENSE file. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.dependabot">dependabot</a></code> | <code>bool</code> | Use dependabot to handle dependency upgrades. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.dependabotOptions">dependabot_options</a></code> | <code>projen.github.DependabotOptions</code> | Options for dependabot. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.depsUpgrade">deps_upgrade</a></code> | <code>bool</code> | Use github workflows to handle dependency upgrades. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.depsUpgradeOptions">deps_upgrade_options</a></code> | <code>projen.javascript.UpgradeDependenciesOptions</code> | Options for `UpgradeDependencies`. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.gitignore">gitignore</a></code> | <code>typing.List[str]</code> | Additional entries to .gitignore. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.jest">jest</a></code> | <code>bool</code> | Setup jest unit tests. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.jestOptions">jest_options</a></code> | <code>projen.javascript.JestOptions</code> | Jest options. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.mutableBuild">mutable_build</a></code> | <code>bool</code> | Automatically update files modified during builds to pull-request branches. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.npmignore">npmignore</a></code> | <code>typing.List[str]</code> | Additional entries to .npmignore. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.npmignoreEnabled">npmignore_enabled</a></code> | <code>bool</code> | Defines an .npmignore file. Normally this is only needed for libraries that are packaged as tarballs. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.npmIgnoreOptions">npm_ignore_options</a></code> | <code>projen.IgnoreFileOptions</code> | Configuration options for .npmignore file. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.package">package</a></code> | <code>bool</code> | Defines a `package` task that will produce an npm tarball under the artifacts directory (e.g. `dist`). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.prettier">prettier</a></code> | <code>bool</code> | Setup prettier. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.prettierOptions">prettier_options</a></code> | <code>projen.javascript.PrettierOptions</code> | Prettier options. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.projenDevDependency">projen_dev_dependency</a></code> | <code>bool</code> | Indicates of "projen" should be installed as a devDependency. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.projenrcJs">projenrc_js</a></code> | <code>bool</code> | Generate (once) .projenrc.js (in JavaScript). Set to `false` in order to disable .projenrc.js generation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.projenrcJsOptions">projenrc_js_options</a></code> | <code>projen.javascript.ProjenrcOptions</code> | Options for .projenrc.js. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.projenVersion">projen_version</a></code> | <code>str</code> | Version of projen to install. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.pullRequestTemplate">pull_request_template</a></code> | <code>bool</code> | Include a GitHub pull request template. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.pullRequestTemplateContents">pull_request_template_contents</a></code> | <code>typing.List[str]</code> | The contents of the pull request template. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.release">release</a></code> | <code>bool</code> | Add release management to this project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.releaseToNpm">release_to_npm</a></code> | <code>bool</code> | Automatically release to npm when new versions are introduced. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.releaseWorkflow">release_workflow</a></code> | <code>bool</code> | DEPRECATED: renamed to `release`. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.workflowBootstrapSteps">workflow_bootstrap_steps</a></code> | <code>typing.List[projen.github.workflows.JobStep]</code> | Workflow steps to use in order to bootstrap this repo. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.workflowGitIdentity">workflow_git_identity</a></code> | <code>projen.github.GitIdentity</code> | The git identity to use in workflows. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.workflowNodeVersion">workflow_node_version</a></code> | <code>str</code> | The node version to use in GitHub workflows. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.workflowPackageCache">workflow_package_cache</a></code> | <code>bool</code> | Enable Node.js package cache in GitHub workflows. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.disableTsconfig">disable_tsconfig</a></code> | <code>bool</code> | Do not generate a `tsconfig.json` file (used by jsii projects since tsconfig.json is generated by the jsii compiler). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.disableTsconfigDev">disable_tsconfig_dev</a></code> | <code>bool</code> | Do not generate a `tsconfig.dev.json` file. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.docgen">docgen</a></code> | <code>bool</code> | Docgen by Typedoc. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.docsDirectory">docs_directory</a></code> | <code>str</code> | Docs directory. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.entrypointTypes">entrypoint_types</a></code> | <code>str</code> | The .d.ts file that includes the type declarations for this module. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.eslint">eslint</a></code> | <code>bool</code> | Setup eslint. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.eslintOptions">eslint_options</a></code> | <code>projen.javascript.EslintOptions</code> | Eslint options. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.libdir">libdir</a></code> | <code>str</code> | Typescript  artifacts output directory. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.projenrcTs">projenrc_ts</a></code> | <code>bool</code> | Use TypeScript for your projenrc file (`.projenrc.ts`). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.projenrcTsOptions">projenrc_ts_options</a></code> | <code>projen.typescript.ProjenrcOptions</code> | Options for .projenrc.ts. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.sampleCode">sample_code</a></code> | <code>bool</code> | Generate one-time sample in `src/` and `test/` if there are no files there. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.srcdir">srcdir</a></code> | <code>str</code> | Typescript sources directory. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.testdir">testdir</a></code> | <code>str</code> | Jest tests directory. Tests files should be named `xxx.test.ts`. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.tsconfig">tsconfig</a></code> | <code>projen.javascript.TypescriptConfigOptions</code> | Custom TSConfig. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.tsconfigDev">tsconfig_dev</a></code> | <code>projen.javascript.TypescriptConfigOptions</code> | Custom tsconfig options for the development tsconfig.json file (used for testing). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.tsconfigDevFile">tsconfig_dev_file</a></code> | <code>str</code> | The name of the development tsconfig.json file. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.typescriptVersion">typescript_version</a></code> | <code>str</code> | TypeScript version to use. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.openApiGeneratorCliConfig">open_api_generator_cli_config</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfig">OpenApiGeneratorCliConfig</a></code> | Configuration for the OpenAPI Generator CLI. |

---

##### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.name"></a>

```python
name: str
```

- *Type:* str
- *Default:* $BASEDIR

This is the name of your project.

---

##### `commit_generated`<sup>Optional</sup> <a name="commit_generated" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.commitGenerated"></a>

```python
commit_generated: bool
```

- *Type:* bool
- *Default:* true

Whether to commit the managed files by default.

---

##### `git_ignore_options`<sup>Optional</sup> <a name="git_ignore_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.gitIgnoreOptions"></a>

```python
git_ignore_options: IgnoreFileOptions
```

- *Type:* projen.IgnoreFileOptions

Configuration options for .gitignore file.

---

##### `git_options`<sup>Optional</sup> <a name="git_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.gitOptions"></a>

```python
git_options: GitOptions
```

- *Type:* projen.GitOptions

Configuration options for git.

---

##### `logging`<sup>Optional</sup> <a name="logging" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.logging"></a>

```python
logging: LoggerOptions
```

- *Type:* projen.LoggerOptions
- *Default:* {}

Configure logging options such as verbosity.

---

##### `outdir`<sup>Optional</sup> <a name="outdir" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.outdir"></a>

```python
outdir: str
```

- *Type:* str
- *Default:* "."

The root directory of the project.

Relative to this directory, all files are synthesized.

If this project has a parent, this directory is relative to the parent
directory and it cannot be the same as the parent or any of it's other
sub-projects.

---

##### `parent`<sup>Optional</sup> <a name="parent" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.parent"></a>

```python
parent: Project
```

- *Type:* projen.Project

The parent project, if this project is part of a bigger project.

---

##### `projen_command`<sup>Optional</sup> <a name="projen_command" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.projenCommand"></a>

```python
projen_command: str
```

- *Type:* str
- *Default:* "npx projen"

The shell command to use in order to run the projen CLI.

Can be used to customize in special environments.

---

##### `projenrc_json`<sup>Optional</sup> <a name="projenrc_json" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.projenrcJson"></a>

```python
projenrc_json: bool
```

- *Type:* bool
- *Default:* false

Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation.

---

##### `projenrc_json_options`<sup>Optional</sup> <a name="projenrc_json_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.projenrcJsonOptions"></a>

```python
projenrc_json_options: ProjenrcJsonOptions
```

- *Type:* projen.ProjenrcJsonOptions
- *Default:* default options

Options for .projenrc.json.

---

##### `renovatebot`<sup>Optional</sup> <a name="renovatebot" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.renovatebot"></a>

```python
renovatebot: bool
```

- *Type:* bool
- *Default:* false

Use renovatebot to handle dependency upgrades.

---

##### `renovatebot_options`<sup>Optional</sup> <a name="renovatebot_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.renovatebotOptions"></a>

```python
renovatebot_options: RenovatebotOptions
```

- *Type:* projen.RenovatebotOptions
- *Default:* default options

Options for renovatebot.

---

##### `auto_approve_options`<sup>Optional</sup> <a name="auto_approve_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.autoApproveOptions"></a>

```python
auto_approve_options: AutoApproveOptions
```

- *Type:* projen.github.AutoApproveOptions
- *Default:* auto approve is disabled

Enable and configure the 'auto approve' workflow.

---

##### `auto_merge`<sup>Optional</sup> <a name="auto_merge" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.autoMerge"></a>

```python
auto_merge: bool
```

- *Type:* bool
- *Default:* true

Enable automatic merging on GitHub.

Has no effect if `github.mergify`
is set to false.

---

##### `auto_merge_options`<sup>Optional</sup> <a name="auto_merge_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.autoMergeOptions"></a>

```python
auto_merge_options: AutoMergeOptions
```

- *Type:* projen.github.AutoMergeOptions
- *Default:* see defaults in `AutoMergeOptions`

Configure options for automatic merging on GitHub.

Has no effect if
`github.mergify` or `autoMerge` is set to false.

---

##### `clobber`<sup>Optional</sup> <a name="clobber" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.clobber"></a>

```python
clobber: bool
```

- *Type:* bool
- *Default:* true, but false for subprojects

Add a `clobber` task which resets the repo to origin.

---

##### `dev_container`<sup>Optional</sup> <a name="dev_container" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.devContainer"></a>

```python
dev_container: bool
```

- *Type:* bool
- *Default:* false

Add a VSCode development environment (used for GitHub Codespaces).

---

##### `github`<sup>Optional</sup> <a name="github" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.github"></a>

```python
github: bool
```

- *Type:* bool
- *Default:* true

Enable GitHub integration.

Enabled by default for root projects. Disabled for non-root projects.

---

##### `github_options`<sup>Optional</sup> <a name="github_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.githubOptions"></a>

```python
github_options: GitHubOptions
```

- *Type:* projen.github.GitHubOptions
- *Default:* see GitHubOptions

Options for GitHub integration.

---

##### `gitpod`<sup>Optional</sup> <a name="gitpod" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.gitpod"></a>

```python
gitpod: bool
```

- *Type:* bool
- *Default:* false

Add a Gitpod development environment.

---

##### ~~`mergify`~~<sup>Optional</sup> <a name="mergify" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.mergify"></a>

- *Deprecated:* use `githubOptions.mergify` instead

```python
mergify: bool
```

- *Type:* bool
- *Default:* true

Whether mergify should be enabled on this repository or not.

---

##### ~~`mergify_options`~~<sup>Optional</sup> <a name="mergify_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.mergifyOptions"></a>

- *Deprecated:* use `githubOptions.mergifyOptions` instead

```python
mergify_options: MergifyOptions
```

- *Type:* projen.github.MergifyOptions
- *Default:* default options

Options for mergify.

---

##### ~~`project_type`~~<sup>Optional</sup> <a name="project_type" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.projectType"></a>

- *Deprecated:* no longer supported at the base project level

```python
project_type: ProjectType
```

- *Type:* projen.ProjectType
- *Default:* ProjectType.UNKNOWN

Which type of project this is (library/app).

---

##### `projen_credentials`<sup>Optional</sup> <a name="projen_credentials" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.projenCredentials"></a>

```python
projen_credentials: GithubCredentials
```

- *Type:* projen.github.GithubCredentials
- *Default:* use a personal access token named PROJEN_GITHUB_TOKEN

Choose a method of providing GitHub API access for projen workflows.

---

##### ~~`projen_token_secret`~~<sup>Optional</sup> <a name="projen_token_secret" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.projenTokenSecret"></a>

- *Deprecated:* use `projenCredentials`

```python
projen_token_secret: str
```

- *Type:* str
- *Default:* "PROJEN_GITHUB_TOKEN"

The name of a secret which includes a GitHub Personal Access Token to be used by projen workflows.

This token needs to have the `repo`, `workflows`
and `packages` scope.

---

##### `readme`<sup>Optional</sup> <a name="readme" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.readme"></a>

```python
readme: SampleReadmeProps
```

- *Type:* projen.SampleReadmeProps
- *Default:* { filename: 'README.md', contents: '# replace this' }

The README setup.

---

*Example*

```python
"{ filename: 'readme.md', contents: '# title' }"
```


##### `stale`<sup>Optional</sup> <a name="stale" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.stale"></a>

```python
stale: bool
```

- *Type:* bool
- *Default:* false

Auto-close of stale issues and pull request.

See `staleOptions` for options.

---

##### `stale_options`<sup>Optional</sup> <a name="stale_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.staleOptions"></a>

```python
stale_options: StaleOptions
```

- *Type:* projen.github.StaleOptions
- *Default:* see defaults in `StaleOptions`

Auto-close stale issues and pull requests.

To disable set `stale` to `false`.

---

##### `vscode`<sup>Optional</sup> <a name="vscode" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.vscode"></a>

```python
vscode: bool
```

- *Type:* bool
- *Default:* true

Enable VSCode integration.

Enabled by default for root projects. Disabled for non-root projects.

---

##### `allow_library_dependencies`<sup>Optional</sup> <a name="allow_library_dependencies" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.allowLibraryDependencies"></a>

```python
allow_library_dependencies: bool
```

- *Type:* bool
- *Default:* true

Allow the project to include `peerDependencies` and `bundledDependencies`.

This is normally only allowed for libraries. For apps, there's no meaning
for specifying these.

---

##### `author_email`<sup>Optional</sup> <a name="author_email" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.authorEmail"></a>

```python
author_email: str
```

- *Type:* str

Author's e-mail.

---

##### `author_name`<sup>Optional</sup> <a name="author_name" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.authorName"></a>

```python
author_name: str
```

- *Type:* str

Author's name.

---

##### `author_organization`<sup>Optional</sup> <a name="author_organization" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.authorOrganization"></a>

```python
author_organization: bool
```

- *Type:* bool

Is the author an organization.

---

##### `author_url`<sup>Optional</sup> <a name="author_url" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.authorUrl"></a>

```python
author_url: str
```

- *Type:* str

Author's URL / Website.

---

##### `auto_detect_bin`<sup>Optional</sup> <a name="auto_detect_bin" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.autoDetectBin"></a>

```python
auto_detect_bin: bool
```

- *Type:* bool
- *Default:* true

Automatically add all executables under the `bin` directory to your `package.json` file under the `bin` section.

---

##### `bin`<sup>Optional</sup> <a name="bin" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.bin"></a>

```python
bin: typing.Mapping[str]
```

- *Type:* typing.Mapping[str]

Binary programs vended with your module.

You can use this option to add/customize how binaries are represented in
your `package.json`, but unless `autoDetectBin` is `false`, every
executable file under `bin` will automatically be added to this section.

---

##### `bugs_email`<sup>Optional</sup> <a name="bugs_email" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.bugsEmail"></a>

```python
bugs_email: str
```

- *Type:* str

The email address to which issues should be reported.

---

##### `bugs_url`<sup>Optional</sup> <a name="bugs_url" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.bugsUrl"></a>

```python
bugs_url: str
```

- *Type:* str

The url to your project's issue tracker.

---

##### `bundled_deps`<sup>Optional</sup> <a name="bundled_deps" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.bundledDeps"></a>

```python
bundled_deps: typing.List[str]
```

- *Type:* typing.List[str]

List of dependencies to bundle into this module.

These modules will be
added both to the `dependencies` section and `bundledDependencies` section of
your `package.json`.

The recommendation is to only specify the module name here (e.g.
`express`). This will behave similar to `yarn add` or `npm install` in the
sense that it will add the module as a dependency to your `package.json`
file with the latest version (`^`). You can specify semver requirements in
the same syntax passed to `npm i` or `yarn add` (e.g. `express@^2`) and
this will be what you `package.json` will eventually include.

---

##### `code_artifact_options`<sup>Optional</sup> <a name="code_artifact_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.codeArtifactOptions"></a>

```python
code_artifact_options: CodeArtifactOptions
```

- *Type:* projen.javascript.CodeArtifactOptions
- *Default:* undefined

Options for npm packages using AWS CodeArtifact.

This is required if publishing packages to, or installing scoped packages from AWS CodeArtifact

---

##### `deps`<sup>Optional</sup> <a name="deps" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.deps"></a>

```python
deps: typing.List[str]
```

- *Type:* typing.List[str]
- *Default:* []

Runtime dependencies of this module.

The recommendation is to only specify the module name here (e.g.
`express`). This will behave similar to `yarn add` or `npm install` in the
sense that it will add the module as a dependency to your `package.json`
file with the latest version (`^`). You can specify semver requirements in
the same syntax passed to `npm i` or `yarn add` (e.g. `express@^2`) and
this will be what you `package.json` will eventually include.

---

*Example*

```python
[ 'express', 'lodash', 'foo@^2' ]
```


##### `description`<sup>Optional</sup> <a name="description" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.description"></a>

```python
description: str
```

- *Type:* str

The description is just a string that helps people understand the purpose of the package.

It can be used when searching for packages in a package manager as well.
See https://classic.yarnpkg.com/en/docs/package-json/#toc-description

---

##### `dev_deps`<sup>Optional</sup> <a name="dev_deps" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.devDeps"></a>

```python
dev_deps: typing.List[str]
```

- *Type:* typing.List[str]
- *Default:* []

Build dependencies for this module.

These dependencies will only be
available in your build environment but will not be fetched when this
module is consumed.

The recommendation is to only specify the module name here (e.g.
`express`). This will behave similar to `yarn add` or `npm install` in the
sense that it will add the module as a dependency to your `package.json`
file with the latest version (`^`). You can specify semver requirements in
the same syntax passed to `npm i` or `yarn add` (e.g. `express@^2`) and
this will be what you `package.json` will eventually include.

---

*Example*

```python
[ 'typescript', '@types/express' ]
```


##### `entrypoint`<sup>Optional</sup> <a name="entrypoint" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.entrypoint"></a>

```python
entrypoint: str
```

- *Type:* str
- *Default:* "lib/index.js"

Module entrypoint (`main` in `package.json`).

Set to an empty string to not include `main` in your package.json

---

##### `homepage`<sup>Optional</sup> <a name="homepage" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.homepage"></a>

```python
homepage: str
```

- *Type:* str

Package's Homepage / Website.

---

##### `keywords`<sup>Optional</sup> <a name="keywords" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.keywords"></a>

```python
keywords: typing.List[str]
```

- *Type:* typing.List[str]

Keywords to include in `package.json`.

---

##### `license`<sup>Optional</sup> <a name="license" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.license"></a>

```python
license: str
```

- *Type:* str
- *Default:* "Apache-2.0"

License's SPDX identifier.

See https://github.com/projen/projen/tree/main/license-text for a list of supported licenses.
Use the `licensed` option if you want to no license to be specified.

---

##### `licensed`<sup>Optional</sup> <a name="licensed" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.licensed"></a>

```python
licensed: bool
```

- *Type:* bool
- *Default:* true

Indicates if a license should be added.

---

##### `max_node_version`<sup>Optional</sup> <a name="max_node_version" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.maxNodeVersion"></a>

```python
max_node_version: str
```

- *Type:* str
- *Default:* no max

Minimum node.js version to require via `engines` (inclusive).

---

##### `min_node_version`<sup>Optional</sup> <a name="min_node_version" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.minNodeVersion"></a>

```python
min_node_version: str
```

- *Type:* str
- *Default:* no "engines" specified

Minimum Node.js version to require via package.json `engines` (inclusive).

---

##### `npm_access`<sup>Optional</sup> <a name="npm_access" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.npmAccess"></a>

```python
npm_access: NpmAccess
```

- *Type:* projen.javascript.NpmAccess
- *Default:* for scoped packages (e.g. `foo@bar`), the default is `NpmAccess.RESTRICTED`, for non-scoped packages, the default is `NpmAccess.PUBLIC`.

Access level of the npm package.

---

##### ~~`npm_registry`~~<sup>Optional</sup> <a name="npm_registry" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.npmRegistry"></a>

- *Deprecated:* use `npmRegistryUrl` instead

```python
npm_registry: str
```

- *Type:* str

The host name of the npm registry to publish to.

Cannot be set together with `npmRegistryUrl`.

---

##### `npm_registry_url`<sup>Optional</sup> <a name="npm_registry_url" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.npmRegistryUrl"></a>

```python
npm_registry_url: str
```

- *Type:* str
- *Default:* "https://registry.npmjs.org"

The base URL of the npm package registry.

Must be a URL (e.g. start with "https://" or "http://")

---

##### `npm_token_secret`<sup>Optional</sup> <a name="npm_token_secret" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.npmTokenSecret"></a>

```python
npm_token_secret: str
```

- *Type:* str
- *Default:* "NPM_TOKEN"

GitHub secret which contains the NPM token to use when publishing packages.

---

##### `package_manager`<sup>Optional</sup> <a name="package_manager" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.packageManager"></a>

```python
package_manager: NodePackageManager
```

- *Type:* projen.javascript.NodePackageManager
- *Default:* NodePackageManager.YARN

The Node Package Manager used to execute scripts.

---

##### `package_name`<sup>Optional</sup> <a name="package_name" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.packageName"></a>

```python
package_name: str
```

- *Type:* str
- *Default:* defaults to project name

The "name" in package.json.

---

##### `peer_dependency_options`<sup>Optional</sup> <a name="peer_dependency_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.peerDependencyOptions"></a>

```python
peer_dependency_options: PeerDependencyOptions
```

- *Type:* projen.javascript.PeerDependencyOptions

Options for `peerDeps`.

---

##### `peer_deps`<sup>Optional</sup> <a name="peer_deps" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.peerDeps"></a>

```python
peer_deps: typing.List[str]
```

- *Type:* typing.List[str]
- *Default:* []

Peer dependencies for this module.

Dependencies listed here are required to
be installed (and satisfied) by the _consumer_ of this library. Using peer
dependencies allows you to ensure that only a single module of a certain
library exists in the `node_modules` tree of your consumers.

Note that prior to npm@7, peer dependencies are _not_ automatically
installed, which means that adding peer dependencies to a library will be a
breaking change for your customers.

Unless `peerDependencyOptions.pinnedDevDependency` is disabled (it is
enabled by default), projen will automatically add a dev dependency with a
pinned version for each peer dependency. This will ensure that you build &
test your module against the lowest peer version required.

---

##### `pnpm_version`<sup>Optional</sup> <a name="pnpm_version" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.pnpmVersion"></a>

```python
pnpm_version: str
```

- *Type:* str
- *Default:* "7"

The version of PNPM to use if using PNPM as a package manager.

---

##### `repository`<sup>Optional</sup> <a name="repository" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.repository"></a>

```python
repository: str
```

- *Type:* str

The repository is the location where the actual code for your package lives.

See https://classic.yarnpkg.com/en/docs/package-json/#toc-repository

---

##### `repository_directory`<sup>Optional</sup> <a name="repository_directory" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.repositoryDirectory"></a>

```python
repository_directory: str
```

- *Type:* str

If the package.json for your package is not in the root directory (for example if it is part of a monorepo), you can specify the directory in which it lives.

---

##### `scoped_packages_options`<sup>Optional</sup> <a name="scoped_packages_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.scopedPackagesOptions"></a>

```python
scoped_packages_options: typing.List[ScopedPackagesOptions]
```

- *Type:* typing.List[projen.javascript.ScopedPackagesOptions]
- *Default:* fetch all scoped packages from the public npm registry

Options for privately hosted scoped packages.

---

##### ~~`scripts`~~<sup>Optional</sup> <a name="scripts" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.scripts"></a>

- *Deprecated:* use `project.addTask()` or `package.setScript()`

```python
scripts: typing.Mapping[str]
```

- *Type:* typing.Mapping[str]
- *Default:* {}

npm scripts to include.

If a script has the same name as a standard script,
the standard script will be overwritten.
Also adds the script as a task.

---

##### `stability`<sup>Optional</sup> <a name="stability" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.stability"></a>

```python
stability: str
```

- *Type:* str

Package's Stability.

---

##### `jsii_release_version`<sup>Optional</sup> <a name="jsii_release_version" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.jsiiReleaseVersion"></a>

```python
jsii_release_version: str
```

- *Type:* str
- *Default:* "latest"

Version requirement of `publib` which is used to publish modules to npm.

---

##### `major_version`<sup>Optional</sup> <a name="major_version" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.majorVersion"></a>

```python
major_version: typing.Union[int, float]
```

- *Type:* typing.Union[int, float]
- *Default:* Major version is not enforced.

Major version to release from the default branch.

If this is specified, we bump the latest version of this major version line.
If not specified, we bump the global latest version.

---

##### `min_major_version`<sup>Optional</sup> <a name="min_major_version" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.minMajorVersion"></a>

```python
min_major_version: typing.Union[int, float]
```

- *Type:* typing.Union[int, float]
- *Default:* No minimum version is being enforced

Minimal Major version to release.

This can be useful to set to 1, as breaking changes before the 1.x major
release are not incrementing the major version number.

Can not be set together with `majorVersion`.

---

##### `npm_dist_tag`<sup>Optional</sup> <a name="npm_dist_tag" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.npmDistTag"></a>

```python
npm_dist_tag: str
```

- *Type:* str
- *Default:* "latest"

The npmDistTag to use when publishing from the default branch.

To set the npm dist-tag for release branches, set the `npmDistTag` property
for each branch.

---

##### `post_build_steps`<sup>Optional</sup> <a name="post_build_steps" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.postBuildSteps"></a>

```python
post_build_steps: typing.List[JobStep]
```

- *Type:* typing.List[projen.github.workflows.JobStep]
- *Default:* []

Steps to execute after build as part of the release workflow.

---

##### `prerelease`<sup>Optional</sup> <a name="prerelease" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.prerelease"></a>

```python
prerelease: str
```

- *Type:* str
- *Default:* normal semantic versions

Bump versions from the default branch as pre-releases (e.g. "beta", "alpha", "pre").

---

##### `publish_dry_run`<sup>Optional</sup> <a name="publish_dry_run" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.publishDryRun"></a>

```python
publish_dry_run: bool
```

- *Type:* bool
- *Default:* false

Instead of actually publishing to package managers, just print the publishing command.

---

##### `publish_tasks`<sup>Optional</sup> <a name="publish_tasks" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.publishTasks"></a>

```python
publish_tasks: bool
```

- *Type:* bool
- *Default:* false

Define publishing tasks that can be executed manually as well as workflows.

Normally, publishing only happens within automated workflows. Enable this
in order to create a publishing task for each publishing activity.

---

##### `release_branches`<sup>Optional</sup> <a name="release_branches" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.releaseBranches"></a>

```python
release_branches: typing.Mapping[BranchOptions]
```

- *Type:* typing.Mapping[projen.release.BranchOptions]
- *Default:* no additional branches are used for release. you can use `addBranch()` to add additional branches.

Defines additional release branches.

A workflow will be created for each
release branch which will publish releases from commits in this branch.
Each release branch _must_ be assigned a major version number which is used
to enforce that versions published from that branch always use that major
version. If multiple branches are used, the `majorVersion` field must also
be provided for the default branch.

---

##### ~~`release_every_commit`~~<sup>Optional</sup> <a name="release_every_commit" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.releaseEveryCommit"></a>

- *Deprecated:* Use `releaseTrigger: ReleaseTrigger.continuous()` instead

```python
release_every_commit: bool
```

- *Type:* bool
- *Default:* true

Automatically release new versions every commit to one of branches in `releaseBranches`.

---

##### `release_failure_issue`<sup>Optional</sup> <a name="release_failure_issue" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.releaseFailureIssue"></a>

```python
release_failure_issue: bool
```

- *Type:* bool
- *Default:* false

Create a github issue on every failed publishing task.

---

##### `release_failure_issue_label`<sup>Optional</sup> <a name="release_failure_issue_label" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.releaseFailureIssueLabel"></a>

```python
release_failure_issue_label: str
```

- *Type:* str
- *Default:* "failed-release"

The label to apply to issues indicating publish failures.

Only applies if `releaseFailureIssue` is true.

---

##### ~~`release_schedule`~~<sup>Optional</sup> <a name="release_schedule" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.releaseSchedule"></a>

- *Deprecated:* Use `releaseTrigger: ReleaseTrigger.scheduled()` instead

```python
release_schedule: str
```

- *Type:* str
- *Default:* no scheduled releases

CRON schedule to trigger new releases.

---

##### `release_tag_prefix`<sup>Optional</sup> <a name="release_tag_prefix" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.releaseTagPrefix"></a>

```python
release_tag_prefix: str
```

- *Type:* str
- *Default:* "v"

Automatically add the given prefix to release tags. Useful if you are releasing on multiple branches with overlapping version numbers.

Note: this prefix is used to detect the latest tagged version
when bumping, so if you change this on a project with an existing version
history, you may need to manually tag your latest release
with the new prefix.

---

##### `release_trigger`<sup>Optional</sup> <a name="release_trigger" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.releaseTrigger"></a>

```python
release_trigger: ReleaseTrigger
```

- *Type:* projen.release.ReleaseTrigger
- *Default:* Continuous releases (`ReleaseTrigger.continuous()`)

The release trigger to use.

---

##### `release_workflow_name`<sup>Optional</sup> <a name="release_workflow_name" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.releaseWorkflowName"></a>

```python
release_workflow_name: str
```

- *Type:* str
- *Default:* "Release"

The name of the default release workflow.

---

##### `release_workflow_setup_steps`<sup>Optional</sup> <a name="release_workflow_setup_steps" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.releaseWorkflowSetupSteps"></a>

```python
release_workflow_setup_steps: typing.List[JobStep]
```

- *Type:* typing.List[projen.github.workflows.JobStep]

A set of workflow steps to execute in order to setup the workflow container.

---

##### `versionrc_options`<sup>Optional</sup> <a name="versionrc_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.versionrcOptions"></a>

```python
versionrc_options: typing.Mapping[typing.Any]
```

- *Type:* typing.Mapping[typing.Any]
- *Default:* standard configuration applicable for GitHub repositories

Custom configuration used when creating changelog with standard-version package.

Given values either append to default configuration or overwrite values in it.

---

##### `workflow_container_image`<sup>Optional</sup> <a name="workflow_container_image" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.workflowContainerImage"></a>

```python
workflow_container_image: str
```

- *Type:* str
- *Default:* default image

Container image to use for GitHub workflows.

---

##### `workflow_runs_on`<sup>Optional</sup> <a name="workflow_runs_on" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.workflowRunsOn"></a>

```python
workflow_runs_on: typing.List[str]
```

- *Type:* typing.List[str]
- *Default:* ["ubuntu-latest"]

Github Runner selection labels.

---

##### `default_release_branch`<sup>Required</sup> <a name="default_release_branch" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.defaultReleaseBranch"></a>

```python
default_release_branch: str
```

- *Type:* str
- *Default:* "main"

The name of the main release branch.

---

##### `artifacts_directory`<sup>Optional</sup> <a name="artifacts_directory" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.artifactsDirectory"></a>

```python
artifacts_directory: str
```

- *Type:* str
- *Default:* "dist"

A directory which will contain build artifacts.

---

##### `auto_approve_upgrades`<sup>Optional</sup> <a name="auto_approve_upgrades" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.autoApproveUpgrades"></a>

```python
auto_approve_upgrades: bool
```

- *Type:* bool
- *Default:* true

Automatically approve deps upgrade PRs, allowing them to be merged by mergify (if configued).

Throw if set to true but `autoApproveOptions` are not defined.

---

##### `build_workflow`<sup>Optional</sup> <a name="build_workflow" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.buildWorkflow"></a>

```python
build_workflow: bool
```

- *Type:* bool
- *Default:* true if not a subproject

Define a GitHub workflow for building PRs.

---

##### `build_workflow_triggers`<sup>Optional</sup> <a name="build_workflow_triggers" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.buildWorkflowTriggers"></a>

```python
build_workflow_triggers: Triggers
```

- *Type:* projen.github.workflows.Triggers
- *Default:* "{ pullRequest: {}, workflowDispatch: {} }"

Build workflow triggers.

---

##### `bundler_options`<sup>Optional</sup> <a name="bundler_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.bundlerOptions"></a>

```python
bundler_options: BundlerOptions
```

- *Type:* projen.javascript.BundlerOptions

Options for `Bundler`.

---

##### `code_cov`<sup>Optional</sup> <a name="code_cov" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.codeCov"></a>

```python
code_cov: bool
```

- *Type:* bool
- *Default:* false

Define a GitHub workflow step for sending code coverage metrics to https://codecov.io/ Uses codecov/codecov-action@v3 A secret is required for private repos. Configured with `@codeCovTokenSecret`.

---

##### `code_cov_token_secret`<sup>Optional</sup> <a name="code_cov_token_secret" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.codeCovTokenSecret"></a>

```python
code_cov_token_secret: str
```

- *Type:* str
- *Default:* if this option is not specified, only public repositories are supported

Define the secret name for a specified https://codecov.io/ token A secret is required to send coverage for private repositories.

---

##### `copyright_owner`<sup>Optional</sup> <a name="copyright_owner" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.copyrightOwner"></a>

```python
copyright_owner: str
```

- *Type:* str
- *Default:* defaults to the value of authorName or "" if `authorName` is undefined.

License copyright owner.

---

##### `copyright_period`<sup>Optional</sup> <a name="copyright_period" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.copyrightPeriod"></a>

```python
copyright_period: str
```

- *Type:* str
- *Default:* current year

The copyright years to put in the LICENSE file.

---

##### `dependabot`<sup>Optional</sup> <a name="dependabot" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.dependabot"></a>

```python
dependabot: bool
```

- *Type:* bool
- *Default:* false

Use dependabot to handle dependency upgrades.

Cannot be used in conjunction with `depsUpgrade`.

---

##### `dependabot_options`<sup>Optional</sup> <a name="dependabot_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.dependabotOptions"></a>

```python
dependabot_options: DependabotOptions
```

- *Type:* projen.github.DependabotOptions
- *Default:* default options

Options for dependabot.

---

##### `deps_upgrade`<sup>Optional</sup> <a name="deps_upgrade" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.depsUpgrade"></a>

```python
deps_upgrade: bool
```

- *Type:* bool
- *Default:* true

Use github workflows to handle dependency upgrades.

Cannot be used in conjunction with `dependabot`.

---

##### `deps_upgrade_options`<sup>Optional</sup> <a name="deps_upgrade_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.depsUpgradeOptions"></a>

```python
deps_upgrade_options: UpgradeDependenciesOptions
```

- *Type:* projen.javascript.UpgradeDependenciesOptions
- *Default:* default options

Options for `UpgradeDependencies`.

---

##### `gitignore`<sup>Optional</sup> <a name="gitignore" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.gitignore"></a>

```python
gitignore: typing.List[str]
```

- *Type:* typing.List[str]

Additional entries to .gitignore.

---

##### `jest`<sup>Optional</sup> <a name="jest" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.jest"></a>

```python
jest: bool
```

- *Type:* bool
- *Default:* true

Setup jest unit tests.

---

##### `jest_options`<sup>Optional</sup> <a name="jest_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.jestOptions"></a>

```python
jest_options: JestOptions
```

- *Type:* projen.javascript.JestOptions
- *Default:* default options

Jest options.

---

##### `mutable_build`<sup>Optional</sup> <a name="mutable_build" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.mutableBuild"></a>

```python
mutable_build: bool
```

- *Type:* bool
- *Default:* true

Automatically update files modified during builds to pull-request branches.

This means
that any files synthesized by projen or e.g. test snapshots will always be up-to-date
before a PR is merged.

Implies that PR builds do not have anti-tamper checks.

---

##### ~~`npmignore`~~<sup>Optional</sup> <a name="npmignore" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.npmignore"></a>

- *Deprecated:* - use `project.addPackageIgnore`

```python
npmignore: typing.List[str]
```

- *Type:* typing.List[str]

Additional entries to .npmignore.

---

##### `npmignore_enabled`<sup>Optional</sup> <a name="npmignore_enabled" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.npmignoreEnabled"></a>

```python
npmignore_enabled: bool
```

- *Type:* bool
- *Default:* true

Defines an .npmignore file. Normally this is only needed for libraries that are packaged as tarballs.

---

##### `npm_ignore_options`<sup>Optional</sup> <a name="npm_ignore_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.npmIgnoreOptions"></a>

```python
npm_ignore_options: IgnoreFileOptions
```

- *Type:* projen.IgnoreFileOptions

Configuration options for .npmignore file.

---

##### `package`<sup>Optional</sup> <a name="package" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.package"></a>

```python
package: bool
```

- *Type:* bool
- *Default:* true

Defines a `package` task that will produce an npm tarball under the artifacts directory (e.g. `dist`).

---

##### `prettier`<sup>Optional</sup> <a name="prettier" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.prettier"></a>

```python
prettier: bool
```

- *Type:* bool
- *Default:* false

Setup prettier.

---

##### `prettier_options`<sup>Optional</sup> <a name="prettier_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.prettierOptions"></a>

```python
prettier_options: PrettierOptions
```

- *Type:* projen.javascript.PrettierOptions
- *Default:* default options

Prettier options.

---

##### `projen_dev_dependency`<sup>Optional</sup> <a name="projen_dev_dependency" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.projenDevDependency"></a>

```python
projen_dev_dependency: bool
```

- *Type:* bool
- *Default:* true

Indicates of "projen" should be installed as a devDependency.

---

##### `projenrc_js`<sup>Optional</sup> <a name="projenrc_js" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.projenrcJs"></a>

```python
projenrc_js: bool
```

- *Type:* bool
- *Default:* true if projenrcJson is false

Generate (once) .projenrc.js (in JavaScript). Set to `false` in order to disable .projenrc.js generation.

---

##### `projenrc_js_options`<sup>Optional</sup> <a name="projenrc_js_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.projenrcJsOptions"></a>

```python
projenrc_js_options: ProjenrcOptions
```

- *Type:* projen.javascript.ProjenrcOptions
- *Default:* default options

Options for .projenrc.js.

---

##### `projen_version`<sup>Optional</sup> <a name="projen_version" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.projenVersion"></a>

```python
projen_version: str
```

- *Type:* str
- *Default:* Defaults to the latest version.

Version of projen to install.

---

##### `pull_request_template`<sup>Optional</sup> <a name="pull_request_template" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.pullRequestTemplate"></a>

```python
pull_request_template: bool
```

- *Type:* bool
- *Default:* true

Include a GitHub pull request template.

---

##### `pull_request_template_contents`<sup>Optional</sup> <a name="pull_request_template_contents" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.pullRequestTemplateContents"></a>

```python
pull_request_template_contents: typing.List[str]
```

- *Type:* typing.List[str]
- *Default:* default content

The contents of the pull request template.

---

##### `release`<sup>Optional</sup> <a name="release" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.release"></a>

```python
release: bool
```

- *Type:* bool
- *Default:* true (false for subprojects)

Add release management to this project.

---

##### `release_to_npm`<sup>Optional</sup> <a name="release_to_npm" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.releaseToNpm"></a>

```python
release_to_npm: bool
```

- *Type:* bool
- *Default:* false

Automatically release to npm when new versions are introduced.

---

##### ~~`release_workflow`~~<sup>Optional</sup> <a name="release_workflow" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.releaseWorkflow"></a>

- *Deprecated:* see `release`.

```python
release_workflow: bool
```

- *Type:* bool
- *Default:* true if not a subproject

DEPRECATED: renamed to `release`.

---

##### `workflow_bootstrap_steps`<sup>Optional</sup> <a name="workflow_bootstrap_steps" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.workflowBootstrapSteps"></a>

```python
workflow_bootstrap_steps: typing.List[JobStep]
```

- *Type:* typing.List[projen.github.workflows.JobStep]
- *Default:* "yarn install --frozen-lockfile && yarn projen"

Workflow steps to use in order to bootstrap this repo.

---

##### `workflow_git_identity`<sup>Optional</sup> <a name="workflow_git_identity" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.workflowGitIdentity"></a>

```python
workflow_git_identity: GitIdentity
```

- *Type:* projen.github.GitIdentity
- *Default:* GitHub Actions

The git identity to use in workflows.

---

##### `workflow_node_version`<sup>Optional</sup> <a name="workflow_node_version" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.workflowNodeVersion"></a>

```python
workflow_node_version: str
```

- *Type:* str
- *Default:* same as `minNodeVersion`

The node version to use in GitHub workflows.

---

##### `workflow_package_cache`<sup>Optional</sup> <a name="workflow_package_cache" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.workflowPackageCache"></a>

```python
workflow_package_cache: bool
```

- *Type:* bool
- *Default:* false

Enable Node.js package cache in GitHub workflows.

---

##### `disable_tsconfig`<sup>Optional</sup> <a name="disable_tsconfig" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.disableTsconfig"></a>

```python
disable_tsconfig: bool
```

- *Type:* bool
- *Default:* false

Do not generate a `tsconfig.json` file (used by jsii projects since tsconfig.json is generated by the jsii compiler).

---

##### `disable_tsconfig_dev`<sup>Optional</sup> <a name="disable_tsconfig_dev" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.disableTsconfigDev"></a>

```python
disable_tsconfig_dev: bool
```

- *Type:* bool
- *Default:* false

Do not generate a `tsconfig.dev.json` file.

---

##### `docgen`<sup>Optional</sup> <a name="docgen" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.docgen"></a>

```python
docgen: bool
```

- *Type:* bool
- *Default:* false

Docgen by Typedoc.

---

##### `docs_directory`<sup>Optional</sup> <a name="docs_directory" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.docsDirectory"></a>

```python
docs_directory: str
```

- *Type:* str
- *Default:* "docs"

Docs directory.

---

##### `entrypoint_types`<sup>Optional</sup> <a name="entrypoint_types" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.entrypointTypes"></a>

```python
entrypoint_types: str
```

- *Type:* str
- *Default:* .d.ts file derived from the project's entrypoint (usually lib/index.d.ts)

The .d.ts file that includes the type declarations for this module.

---

##### `eslint`<sup>Optional</sup> <a name="eslint" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.eslint"></a>

```python
eslint: bool
```

- *Type:* bool
- *Default:* true

Setup eslint.

---

##### `eslint_options`<sup>Optional</sup> <a name="eslint_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.eslintOptions"></a>

```python
eslint_options: EslintOptions
```

- *Type:* projen.javascript.EslintOptions
- *Default:* opinionated default options

Eslint options.

---

##### `libdir`<sup>Optional</sup> <a name="libdir" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.libdir"></a>

```python
libdir: str
```

- *Type:* str
- *Default:* "lib"

Typescript  artifacts output directory.

---

##### `projenrc_ts`<sup>Optional</sup> <a name="projenrc_ts" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.projenrcTs"></a>

```python
projenrc_ts: bool
```

- *Type:* bool
- *Default:* false

Use TypeScript for your projenrc file (`.projenrc.ts`).

---

##### `projenrc_ts_options`<sup>Optional</sup> <a name="projenrc_ts_options" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.projenrcTsOptions"></a>

```python
projenrc_ts_options: ProjenrcOptions
```

- *Type:* projen.typescript.ProjenrcOptions

Options for .projenrc.ts.

---

##### `sample_code`<sup>Optional</sup> <a name="sample_code" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.sampleCode"></a>

```python
sample_code: bool
```

- *Type:* bool
- *Default:* true

Generate one-time sample in `src/` and `test/` if there are no files there.

---

##### `srcdir`<sup>Optional</sup> <a name="srcdir" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.srcdir"></a>

```python
srcdir: str
```

- *Type:* str
- *Default:* "src"

Typescript sources directory.

---

##### `testdir`<sup>Optional</sup> <a name="testdir" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.testdir"></a>

```python
testdir: str
```

- *Type:* str
- *Default:* "test"

Jest tests directory. Tests files should be named `xxx.test.ts`.

If this directory is under `srcdir` (e.g. `src/test`, `src/__tests__`),
then tests are going to be compiled into `lib/` and executed as javascript.
If the test directory is outside of `src`, then we configure jest to
compile the code in-memory.

---

##### `tsconfig`<sup>Optional</sup> <a name="tsconfig" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.tsconfig"></a>

```python
tsconfig: TypescriptConfigOptions
```

- *Type:* projen.javascript.TypescriptConfigOptions
- *Default:* default options

Custom TSConfig.

---

##### `tsconfig_dev`<sup>Optional</sup> <a name="tsconfig_dev" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.tsconfigDev"></a>

```python
tsconfig_dev: TypescriptConfigOptions
```

- *Type:* projen.javascript.TypescriptConfigOptions
- *Default:* use the production tsconfig options

Custom tsconfig options for the development tsconfig.json file (used for testing).

---

##### `tsconfig_dev_file`<sup>Optional</sup> <a name="tsconfig_dev_file" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.tsconfigDevFile"></a>

```python
tsconfig_dev_file: str
```

- *Type:* str
- *Default:* "tsconfig.dev.json"

The name of the development tsconfig.json file.

---

##### `typescript_version`<sup>Optional</sup> <a name="typescript_version" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.typescriptVersion"></a>

```python
typescript_version: str
```

- *Type:* str
- *Default:* "latest"

TypeScript version to use.

NOTE: Typescript is not semantically versioned and should remain on the
same minor, so we recommend using a `~` dependency (e.g. `~1.2.3`).

---

##### `open_api_generator_cli_config`<sup>Optional</sup> <a name="open_api_generator_cli_config" id="@aws-prototyping-sdk/type-safe-api.GeneratedTypeScriptRuntimeOptions.property.openApiGeneratorCliConfig"></a>

```python
open_api_generator_cli_config: OpenApiGeneratorCliConfig
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfig">OpenApiGeneratorCliConfig</a>

Configuration for the OpenAPI Generator CLI.

Overrides default values if specified.

> [https://github.com/OpenAPITools/openapi-generator-cli#configuration](https://github.com/OpenAPITools/openapi-generator-cli#configuration)

---

### GeneratedWithOpenApiGeneratorOptions <a name="GeneratedWithOpenApiGeneratorOptions" id="@aws-prototyping-sdk/type-safe-api.GeneratedWithOpenApiGeneratorOptions"></a>

Options for a code project generated with OpenAPI Generator.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.GeneratedWithOpenApiGeneratorOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.GeneratedWithOpenApiGeneratorOptions(
  open_api_generator_cli_config: OpenApiGeneratorCliConfig = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedWithOpenApiGeneratorOptions.property.openApiGeneratorCliConfig">open_api_generator_cli_config</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfig">OpenApiGeneratorCliConfig</a></code> | Configuration for the OpenAPI Generator CLI. |

---

##### `open_api_generator_cli_config`<sup>Optional</sup> <a name="open_api_generator_cli_config" id="@aws-prototyping-sdk/type-safe-api.GeneratedWithOpenApiGeneratorOptions.property.openApiGeneratorCliConfig"></a>

```python
open_api_generator_cli_config: OpenApiGeneratorCliConfig
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfig">OpenApiGeneratorCliConfig</a>

Configuration for the OpenAPI Generator CLI.

Overrides default values if specified.

> [https://github.com/OpenAPITools/openapi-generator-cli#configuration](https://github.com/OpenAPITools/openapi-generator-cli#configuration)

---

### InfrastructureConfiguration <a name="InfrastructureConfiguration" id="@aws-prototyping-sdk/type-safe-api.InfrastructureConfiguration"></a>

Configuration for generated infrastructure.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.InfrastructureConfiguration.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.InfrastructureConfiguration(
  language: Language,
  options: GeneratedInfrastructureCodeOptions = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.InfrastructureConfiguration.property.language">language</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.Language">Language</a></code> | The language to generate the type-safe CDK infrastructure in. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.InfrastructureConfiguration.property.options">options</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedInfrastructureCodeOptions">GeneratedInfrastructureCodeOptions</a></code> | Options for the infrastructure package. |

---

##### `language`<sup>Required</sup> <a name="language" id="@aws-prototyping-sdk/type-safe-api.InfrastructureConfiguration.property.language"></a>

```python
language: Language
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.Language">Language</a>

The language to generate the type-safe CDK infrastructure in.

---

##### `options`<sup>Optional</sup> <a name="options" id="@aws-prototyping-sdk/type-safe-api.InfrastructureConfiguration.property.options"></a>

```python
options: GeneratedInfrastructureCodeOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.GeneratedInfrastructureCodeOptions">GeneratedInfrastructureCodeOptions</a>

Options for the infrastructure package.

Note that only those provided for the specified language will apply.

---

### IntegrationGrantProps <a name="IntegrationGrantProps" id="@aws-prototyping-sdk/type-safe-api.IntegrationGrantProps"></a>

Properties for granting the API access to invoke the operation.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.IntegrationGrantProps.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.IntegrationGrantProps(
  method: str,
  path: str,
  content_types: typing.List[str] = None,
  api: SpecRestApi,
  operation_id: str,
  scope: Construct
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.IntegrationGrantProps.property.method">method</a></code> | <code>str</code> | The http method of this operation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.IntegrationGrantProps.property.path">path</a></code> | <code>str</code> | The path of this operation in the api. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.IntegrationGrantProps.property.contentTypes">content_types</a></code> | <code>typing.List[str]</code> | Content types accepted by this operation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.IntegrationGrantProps.property.api">api</a></code> | <code>aws_cdk.aws_apigateway.SpecRestApi</code> | The api to grant permissions for. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.IntegrationGrantProps.property.operationId">operation_id</a></code> | <code>str</code> | The ID of the operation for which permissions are being granted. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.IntegrationGrantProps.property.scope">scope</a></code> | <code>constructs.Construct</code> | The scope in which permission resources can be created. |

---

##### `method`<sup>Required</sup> <a name="method" id="@aws-prototyping-sdk/type-safe-api.IntegrationGrantProps.property.method"></a>

```python
method: str
```

- *Type:* str

The http method of this operation.

---

##### `path`<sup>Required</sup> <a name="path" id="@aws-prototyping-sdk/type-safe-api.IntegrationGrantProps.property.path"></a>

```python
path: str
```

- *Type:* str

The path of this operation in the api.

---

##### `content_types`<sup>Optional</sup> <a name="content_types" id="@aws-prototyping-sdk/type-safe-api.IntegrationGrantProps.property.contentTypes"></a>

```python
content_types: typing.List[str]
```

- *Type:* typing.List[str]
- *Default:* application/json

Content types accepted by this operation.

---

##### `api`<sup>Required</sup> <a name="api" id="@aws-prototyping-sdk/type-safe-api.IntegrationGrantProps.property.api"></a>

```python
api: SpecRestApi
```

- *Type:* aws_cdk.aws_apigateway.SpecRestApi

The api to grant permissions for.

---

##### `operation_id`<sup>Required</sup> <a name="operation_id" id="@aws-prototyping-sdk/type-safe-api.IntegrationGrantProps.property.operationId"></a>

```python
operation_id: str
```

- *Type:* str

The ID of the operation for which permissions are being granted.

---

##### `scope`<sup>Required</sup> <a name="scope" id="@aws-prototyping-sdk/type-safe-api.IntegrationGrantProps.property.scope"></a>

```python
scope: Construct
```

- *Type:* constructs.Construct

The scope in which permission resources can be created.

---

### IntegrationRenderProps <a name="IntegrationRenderProps" id="@aws-prototyping-sdk/type-safe-api.IntegrationRenderProps"></a>

Properties for rendering an integration into an API Gateway OpenAPI extension.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.IntegrationRenderProps.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.IntegrationRenderProps(
  method: str,
  path: str,
  content_types: typing.List[str] = None,
  operation_id: str,
  scope: Construct,
  cors_options: SerializedCorsOptions = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.IntegrationRenderProps.property.method">method</a></code> | <code>str</code> | The http method of this operation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.IntegrationRenderProps.property.path">path</a></code> | <code>str</code> | The path of this operation in the api. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.IntegrationRenderProps.property.contentTypes">content_types</a></code> | <code>typing.List[str]</code> | Content types accepted by this operation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.IntegrationRenderProps.property.operationId">operation_id</a></code> | <code>str</code> | The ID of the operation being rendered. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.IntegrationRenderProps.property.scope">scope</a></code> | <code>constructs.Construct</code> | The scope in which the integration is being rendered. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.IntegrationRenderProps.property.corsOptions">cors_options</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.SerializedCorsOptions">SerializedCorsOptions</a></code> | Cross Origin Resource Sharing options for the API. |

---

##### `method`<sup>Required</sup> <a name="method" id="@aws-prototyping-sdk/type-safe-api.IntegrationRenderProps.property.method"></a>

```python
method: str
```

- *Type:* str

The http method of this operation.

---

##### `path`<sup>Required</sup> <a name="path" id="@aws-prototyping-sdk/type-safe-api.IntegrationRenderProps.property.path"></a>

```python
path: str
```

- *Type:* str

The path of this operation in the api.

---

##### `content_types`<sup>Optional</sup> <a name="content_types" id="@aws-prototyping-sdk/type-safe-api.IntegrationRenderProps.property.contentTypes"></a>

```python
content_types: typing.List[str]
```

- *Type:* typing.List[str]
- *Default:* application/json

Content types accepted by this operation.

---

##### `operation_id`<sup>Required</sup> <a name="operation_id" id="@aws-prototyping-sdk/type-safe-api.IntegrationRenderProps.property.operationId"></a>

```python
operation_id: str
```

- *Type:* str

The ID of the operation being rendered.

---

##### `scope`<sup>Required</sup> <a name="scope" id="@aws-prototyping-sdk/type-safe-api.IntegrationRenderProps.property.scope"></a>

```python
scope: Construct
```

- *Type:* constructs.Construct

The scope in which the integration is being rendered.

---

##### `cors_options`<sup>Optional</sup> <a name="cors_options" id="@aws-prototyping-sdk/type-safe-api.IntegrationRenderProps.property.corsOptions"></a>

```python
cors_options: SerializedCorsOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.SerializedCorsOptions">SerializedCorsOptions</a>

Cross Origin Resource Sharing options for the API.

---

### LibraryConfiguration <a name="LibraryConfiguration" id="@aws-prototyping-sdk/type-safe-api.LibraryConfiguration"></a>

Configuration for generated libraries.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.LibraryConfiguration.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.LibraryConfiguration(
  libraries: typing.List[Library],
  options: GeneratedLibraryOptions = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.LibraryConfiguration.property.libraries">libraries</a></code> | <code>typing.List[<a href="#@aws-prototyping-sdk/type-safe-api.Library">Library</a>]</code> | The library to generate. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.LibraryConfiguration.property.options">options</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedLibraryOptions">GeneratedLibraryOptions</a></code> | Options for the generated library package. |

---

##### `libraries`<sup>Required</sup> <a name="libraries" id="@aws-prototyping-sdk/type-safe-api.LibraryConfiguration.property.libraries"></a>

```python
libraries: typing.List[Library]
```

- *Type:* typing.List[<a href="#@aws-prototyping-sdk/type-safe-api.Library">Library</a>]

The library to generate.

---

##### `options`<sup>Optional</sup> <a name="options" id="@aws-prototyping-sdk/type-safe-api.LibraryConfiguration.property.options"></a>

```python
options: GeneratedLibraryOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.GeneratedLibraryOptions">GeneratedLibraryOptions</a>

Options for the generated library package.

Note that only options for the specified libraries will apply

---

### ManagedRule <a name="ManagedRule" id="@aws-prototyping-sdk/type-safe-api.ManagedRule"></a>

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.ManagedRule.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.ManagedRule(
  name: str,
  vendor: str
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ManagedRule.property.name">name</a></code> | <code>str</code> | The name of the managed rule group. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ManagedRule.property.vendor">vendor</a></code> | <code>str</code> | The name of the managed rule group vendor. |

---

##### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/type-safe-api.ManagedRule.property.name"></a>

```python
name: str
```

- *Type:* str

The name of the managed rule group.

You use this, along with the vendor name, to identify the rule group.

---

##### `vendor`<sup>Required</sup> <a name="vendor" id="@aws-prototyping-sdk/type-safe-api.ManagedRule.property.vendor"></a>

```python
vendor: str
```

- *Type:* str

The name of the managed rule group vendor.

You use this, along with the rule group name, to identify the rule group.

---

### MethodAndPath <a name="MethodAndPath" id="@aws-prototyping-sdk/type-safe-api.MethodAndPath"></a>

Structure to contain an API operation's method and path.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.MethodAndPath.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.MethodAndPath(
  method: str,
  path: str
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.MethodAndPath.property.method">method</a></code> | <code>str</code> | The http method of this operation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.MethodAndPath.property.path">path</a></code> | <code>str</code> | The path of this operation in the api. |

---

##### `method`<sup>Required</sup> <a name="method" id="@aws-prototyping-sdk/type-safe-api.MethodAndPath.property.method"></a>

```python
method: str
```

- *Type:* str

The http method of this operation.

---

##### `path`<sup>Required</sup> <a name="path" id="@aws-prototyping-sdk/type-safe-api.MethodAndPath.property.path"></a>

```python
path: str
```

- *Type:* str

The path of this operation in the api.

---

### MockIntegrationResponse <a name="MockIntegrationResponse" id="@aws-prototyping-sdk/type-safe-api.MockIntegrationResponse"></a>

Properties for a mock integration response.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.MockIntegrationResponse.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.MockIntegrationResponse(
  status_code: typing.Union[int, float],
  body: str = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.MockIntegrationResponse.property.statusCode">status_code</a></code> | <code>typing.Union[int, float]</code> | HTTP response status code. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.MockIntegrationResponse.property.body">body</a></code> | <code>str</code> | Response body. |

---

##### `status_code`<sup>Required</sup> <a name="status_code" id="@aws-prototyping-sdk/type-safe-api.MockIntegrationResponse.property.statusCode"></a>

```python
status_code: typing.Union[int, float]
```

- *Type:* typing.Union[int, float]

HTTP response status code.

---

##### `body`<sup>Optional</sup> <a name="body" id="@aws-prototyping-sdk/type-safe-api.MockIntegrationResponse.property.body"></a>

```python
body: str
```

- *Type:* str

Response body.

---

### MockResponseDataGenerationOptions <a name="MockResponseDataGenerationOptions" id="@aws-prototyping-sdk/type-safe-api.MockResponseDataGenerationOptions"></a>

Options for generating mock data.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.MockResponseDataGenerationOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.MockResponseDataGenerationOptions(
  disable: bool = None,
  locale: str = None,
  max_array_length: typing.Union[int, float] = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.MockResponseDataGenerationOptions.property.disable">disable</a></code> | <code>bool</code> | Set to true to disable generating mock data. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.MockResponseDataGenerationOptions.property.locale">locale</a></code> | <code>str</code> | Locale of generated data. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.MockResponseDataGenerationOptions.property.maxArrayLength">max_array_length</a></code> | <code>typing.Union[int, float]</code> | Maximum length of generated arrays. |

---

##### `disable`<sup>Optional</sup> <a name="disable" id="@aws-prototyping-sdk/type-safe-api.MockResponseDataGenerationOptions.property.disable"></a>

```python
disable: bool
```

- *Type:* bool
- *Default:* false

Set to true to disable generating mock data.

---

##### `locale`<sup>Optional</sup> <a name="locale" id="@aws-prototyping-sdk/type-safe-api.MockResponseDataGenerationOptions.property.locale"></a>

```python
locale: str
```

- *Type:* str
- *Default:* en

Locale of generated data.

> [https://fakerjs.dev/guide/localization.html#available-locales](https://fakerjs.dev/guide/localization.html#available-locales)

---

##### `max_array_length`<sup>Optional</sup> <a name="max_array_length" id="@aws-prototyping-sdk/type-safe-api.MockResponseDataGenerationOptions.property.maxArrayLength"></a>

```python
max_array_length: typing.Union[int, float]
```

- *Type:* typing.Union[int, float]
- *Default:* 3

Maximum length of generated arrays.

---

### MockResponseGenerationOptions <a name="MockResponseGenerationOptions" id="@aws-prototyping-sdk/type-safe-api.MockResponseGenerationOptions"></a>

Options for generating mock data.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.MockResponseGenerationOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.MockResponseGenerationOptions(
  mock_data_options: MockResponseDataGenerationOptions = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.MockResponseGenerationOptions.property.mockDataOptions">mock_data_options</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.MockResponseDataGenerationOptions">MockResponseDataGenerationOptions</a></code> | Options for the generated mock response data. |

---

##### `mock_data_options`<sup>Optional</sup> <a name="mock_data_options" id="@aws-prototyping-sdk/type-safe-api.MockResponseGenerationOptions.property.mockDataOptions"></a>

```python
mock_data_options: MockResponseDataGenerationOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.MockResponseDataGenerationOptions">MockResponseDataGenerationOptions</a>

Options for the generated mock response data.

---

### ModelConfiguration <a name="ModelConfiguration" id="@aws-prototyping-sdk/type-safe-api.ModelConfiguration"></a>

Configuration for modelling the API.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.ModelConfiguration.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.ModelConfiguration(
  language: ModelLanguage,
  options: ModelOptions
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ModelConfiguration.property.language">language</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.ModelLanguage">ModelLanguage</a></code> | The language the API model is defined in. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ModelConfiguration.property.options">options</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.ModelOptions">ModelOptions</a></code> | Options for the API model. |

---

##### `language`<sup>Required</sup> <a name="language" id="@aws-prototyping-sdk/type-safe-api.ModelConfiguration.property.language"></a>

```python
language: ModelLanguage
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.ModelLanguage">ModelLanguage</a>

The language the API model is defined in.

---

##### `options`<sup>Required</sup> <a name="options" id="@aws-prototyping-sdk/type-safe-api.ModelConfiguration.property.options"></a>

```python
options: ModelOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.ModelOptions">ModelOptions</a>

Options for the API model.

---

### ModelOptions <a name="ModelOptions" id="@aws-prototyping-sdk/type-safe-api.ModelOptions"></a>

Options for models.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.ModelOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.ModelOptions(
  openapi: OpenApiModelOptions = None,
  smithy: SmithyModelOptions = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ModelOptions.property.openapi">openapi</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiModelOptions">OpenApiModelOptions</a></code> | Options for the OpenAPI model - required when model language is OPENAPI. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ModelOptions.property.smithy">smithy</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyModelOptions">SmithyModelOptions</a></code> | Options for the Smithy model - required when model language is SMITHY. |

---

##### `openapi`<sup>Optional</sup> <a name="openapi" id="@aws-prototyping-sdk/type-safe-api.ModelOptions.property.openapi"></a>

```python
openapi: OpenApiModelOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.OpenApiModelOptions">OpenApiModelOptions</a>

Options for the OpenAPI model - required when model language is OPENAPI.

---

##### `smithy`<sup>Optional</sup> <a name="smithy" id="@aws-prototyping-sdk/type-safe-api.ModelOptions.property.smithy"></a>

```python
smithy: SmithyModelOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.SmithyModelOptions">SmithyModelOptions</a>

Options for the Smithy model - required when model language is SMITHY.

---

### OpenApiDefinitionOptions <a name="OpenApiDefinitionOptions" id="@aws-prototyping-sdk/type-safe-api.OpenApiDefinitionOptions"></a>

Options for the OpenAPI Spec.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.OpenApiDefinitionOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.OpenApiDefinitionOptions(
  open_api_options: OpenApiModelOptions
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiDefinitionOptions.property.openApiOptions">open_api_options</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiModelOptions">OpenApiModelOptions</a></code> | Options for the openapi model. |

---

##### `open_api_options`<sup>Required</sup> <a name="open_api_options" id="@aws-prototyping-sdk/type-safe-api.OpenApiDefinitionOptions.property.openApiOptions"></a>

```python
open_api_options: OpenApiModelOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.OpenApiModelOptions">OpenApiModelOptions</a>

Options for the openapi model.

---

### OpenApiGeneratorCliConfig <a name="OpenApiGeneratorCliConfig" id="@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfig"></a>

Configuration for the OpenAPI Generator CLI.

> [https://github.com/OpenAPITools/openapi-generator-cli#configuration](https://github.com/OpenAPITools/openapi-generator-cli#configuration)

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfig.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.OpenApiGeneratorCliConfig(
  repository: OpenApiGeneratorCliConfigRepository = None,
  storage_dir: str = None,
  use_docker: bool = None,
  version: str = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfig.property.repository">repository</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfigRepository">OpenApiGeneratorCliConfigRepository</a></code> | Maven repository info for fetching the OpenAPI Generator jar. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfig.property.storageDir">storage_dir</a></code> | <code>str</code> | The directory in which OpenAPI Generator jars are cached. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfig.property.useDocker">use_docker</a></code> | <code>bool</code> | Use docker instead of your locally installed Java version. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfig.property.version">version</a></code> | <code>str</code> | OpenAPI Generator version to use. |

---

##### `repository`<sup>Optional</sup> <a name="repository" id="@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfig.property.repository"></a>

```python
repository: OpenApiGeneratorCliConfigRepository
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfigRepository">OpenApiGeneratorCliConfigRepository</a>
- *Default:* public maven repository

Maven repository info for fetching the OpenAPI Generator jar.

> [https://github.com/OpenAPITools/openapi-generator-cli#using-custom--private-maven-registry](https://github.com/OpenAPITools/openapi-generator-cli#using-custom--private-maven-registry)

---

##### `storage_dir`<sup>Optional</sup> <a name="storage_dir" id="@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfig.property.storageDir"></a>

```python
storage_dir: str
```

- *Type:* str
- *Default:* ~/.open-api-generator-cli

The directory in which OpenAPI Generator jars are cached.

---

##### `use_docker`<sup>Optional</sup> <a name="use_docker" id="@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfig.property.useDocker"></a>

```python
use_docker: bool
```

- *Type:* bool
- *Default:* false

Use docker instead of your locally installed Java version.

> [https://github.com/OpenAPITools/openapi-generator-cli#use-docker-instead-of-running-java-locally](https://github.com/OpenAPITools/openapi-generator-cli#use-docker-instead-of-running-java-locally)

---

##### `version`<sup>Optional</sup> <a name="version" id="@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfig.property.version"></a>

```python
version: str
```

- *Type:* str
- *Default:* 6.3.0

OpenAPI Generator version to use.

Edit with caution - using the non-default
version may result in broken generated code.

---

### OpenApiGeneratorCliConfigRepository <a name="OpenApiGeneratorCliConfigRepository" id="@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfigRepository"></a>

Maven repository info for fetching the OpenAPI Generator jar.

> [https://github.com/OpenAPITools/openapi-generator-cli#using-custom--private-maven-registry](https://github.com/OpenAPITools/openapi-generator-cli#using-custom--private-maven-registry)

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfigRepository.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.OpenApiGeneratorCliConfigRepository(
  download_url: str
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfigRepository.property.downloadUrl">download_url</a></code> | <code>str</code> | Maven repository URL for downloading the OpenAPI Generator jar. |

---

##### `download_url`<sup>Required</sup> <a name="download_url" id="@aws-prototyping-sdk/type-safe-api.OpenApiGeneratorCliConfigRepository.property.downloadUrl"></a>

```python
download_url: str
```

- *Type:* str

Maven repository URL for downloading the OpenAPI Generator jar.

This must specify the full url, and can include placeholders for the groupId, artifactId and versionName.
For example: https://private.maven.intern/maven2/${groupId}/${artifactId}/${versionName}/${artifactId}-${versionName}.jar

> [https://github.com/OpenAPITools/openapi-generator-cli#using-custom--private-maven-registry](https://github.com/OpenAPITools/openapi-generator-cli#using-custom--private-maven-registry)

---

### OpenApiModelOptions <a name="OpenApiModelOptions" id="@aws-prototyping-sdk/type-safe-api.OpenApiModelOptions"></a>

Options for the OpenAPI model.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.OpenApiModelOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.OpenApiModelOptions(
  title: str
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiModelOptions.property.title">title</a></code> | <code>str</code> | The title in the OpenAPI specification. |

---

##### `title`<sup>Required</sup> <a name="title" id="@aws-prototyping-sdk/type-safe-api.OpenApiModelOptions.property.title"></a>

```python
title: str
```

- *Type:* str

The title in the OpenAPI specification.

---

### OperationDetails <a name="OperationDetails" id="@aws-prototyping-sdk/type-safe-api.OperationDetails"></a>

Details about an API operation.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.OperationDetails.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.OperationDetails(
  method: str,
  path: str,
  content_types: typing.List[str] = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.OperationDetails.property.method">method</a></code> | <code>str</code> | The http method of this operation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.OperationDetails.property.path">path</a></code> | <code>str</code> | The path of this operation in the api. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.OperationDetails.property.contentTypes">content_types</a></code> | <code>typing.List[str]</code> | Content types accepted by this operation. |

---

##### `method`<sup>Required</sup> <a name="method" id="@aws-prototyping-sdk/type-safe-api.OperationDetails.property.method"></a>

```python
method: str
```

- *Type:* str

The http method of this operation.

---

##### `path`<sup>Required</sup> <a name="path" id="@aws-prototyping-sdk/type-safe-api.OperationDetails.property.path"></a>

```python
path: str
```

- *Type:* str

The path of this operation in the api.

---

##### `content_types`<sup>Optional</sup> <a name="content_types" id="@aws-prototyping-sdk/type-safe-api.OperationDetails.property.contentTypes"></a>

```python
content_types: typing.List[str]
```

- *Type:* typing.List[str]
- *Default:* application/json

Content types accepted by this operation.

---

### RuntimeConfiguration <a name="RuntimeConfiguration" id="@aws-prototyping-sdk/type-safe-api.RuntimeConfiguration"></a>

Configuration for generated runtime projects.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.RuntimeConfiguration.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.RuntimeConfiguration(
  languages: typing.List[Language],
  options: GeneratedRuntimeCodeOptions = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.RuntimeConfiguration.property.languages">languages</a></code> | <code>typing.List[<a href="#@aws-prototyping-sdk/type-safe-api.Language">Language</a>]</code> | The languages that runtime projects will be generated in. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.RuntimeConfiguration.property.options">options</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedRuntimeCodeOptions">GeneratedRuntimeCodeOptions</a></code> | Options for the generated runtimes. |

---

##### `languages`<sup>Required</sup> <a name="languages" id="@aws-prototyping-sdk/type-safe-api.RuntimeConfiguration.property.languages"></a>

```python
languages: typing.List[Language]
```

- *Type:* typing.List[<a href="#@aws-prototyping-sdk/type-safe-api.Language">Language</a>]

The languages that runtime projects will be generated in.

These projects can be used to provide type safety for
both client and server projects.

---

##### `options`<sup>Optional</sup> <a name="options" id="@aws-prototyping-sdk/type-safe-api.RuntimeConfiguration.property.options"></a>

```python
options: GeneratedRuntimeCodeOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.GeneratedRuntimeCodeOptions">GeneratedRuntimeCodeOptions</a>

Options for the generated runtimes.

Note that only options provided for the specified languages will apply.

---

### SerializedCorsOptions <a name="SerializedCorsOptions" id="@aws-prototyping-sdk/type-safe-api.SerializedCorsOptions"></a>

Cross-origin resource sharing options.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.SerializedCorsOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.SerializedCorsOptions(
  allow_headers: typing.List[str],
  allow_methods: typing.List[str],
  allow_origins: typing.List[str],
  status_code: typing.Union[int, float]
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SerializedCorsOptions.property.allowHeaders">allow_headers</a></code> | <code>typing.List[str]</code> | Headers to allow. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SerializedCorsOptions.property.allowMethods">allow_methods</a></code> | <code>typing.List[str]</code> | HTTP methods to allow. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SerializedCorsOptions.property.allowOrigins">allow_origins</a></code> | <code>typing.List[str]</code> | Origins to allow. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SerializedCorsOptions.property.statusCode">status_code</a></code> | <code>typing.Union[int, float]</code> | HTTP status code to be returned by preflight requests. |

---

##### `allow_headers`<sup>Required</sup> <a name="allow_headers" id="@aws-prototyping-sdk/type-safe-api.SerializedCorsOptions.property.allowHeaders"></a>

```python
allow_headers: typing.List[str]
```

- *Type:* typing.List[str]

Headers to allow.

---

##### `allow_methods`<sup>Required</sup> <a name="allow_methods" id="@aws-prototyping-sdk/type-safe-api.SerializedCorsOptions.property.allowMethods"></a>

```python
allow_methods: typing.List[str]
```

- *Type:* typing.List[str]

HTTP methods to allow.

---

##### `allow_origins`<sup>Required</sup> <a name="allow_origins" id="@aws-prototyping-sdk/type-safe-api.SerializedCorsOptions.property.allowOrigins"></a>

```python
allow_origins: typing.List[str]
```

- *Type:* typing.List[str]

Origins to allow.

---

##### `status_code`<sup>Required</sup> <a name="status_code" id="@aws-prototyping-sdk/type-safe-api.SerializedCorsOptions.property.statusCode"></a>

```python
status_code: typing.Union[int, float]
```

- *Type:* typing.Union[int, float]

HTTP status code to be returned by preflight requests.

---

### SmithyBuildOptions <a name="SmithyBuildOptions" id="@aws-prototyping-sdk/type-safe-api.SmithyBuildOptions"></a>

Options for the smithy build files.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.SmithyBuildOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.SmithyBuildOptions(
  imports: typing.List[str] = None,
  plugins: typing.Mapping[typing.Mapping[typing.Any]] = None,
  additional_sources: typing.List[str] = None,
  ignore_missing_plugins: bool = None,
  maven: SmithyMavenConfiguration = None,
  projections: typing.Mapping[SmithyProjection] = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyBuildOptions.property.imports">imports</a></code> | <code>typing.List[str]</code> | List of imports. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyBuildOptions.property.plugins">plugins</a></code> | <code>typing.Mapping[typing.Mapping[typing.Any]]</code> | Plugins keyed by plugin id. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyBuildOptions.property.additionalSources">additional_sources</a></code> | <code>typing.List[str]</code> | Paths to any additional model files or directories to be used as sources for the smithy build. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyBuildOptions.property.ignoreMissingPlugins">ignore_missing_plugins</a></code> | <code>bool</code> | If a plugin can't be found, Smithy will by default fail the build. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyBuildOptions.property.maven">maven</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyMavenConfiguration">SmithyMavenConfiguration</a></code> | Maven configuration for the Smithy build project, used to specify dependencies and repositories in the build.gradle and smithy-build.json files. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyBuildOptions.property.projections">projections</a></code> | <code>typing.Mapping[<a href="#@aws-prototyping-sdk/type-safe-api.SmithyProjection">SmithyProjection</a>]</code> | Map of projections name to projection configurations https://awslabs.github.io/smithy/2.0/guides/building-models/build-config.html#projections. |

---

##### `imports`<sup>Optional</sup> <a name="imports" id="@aws-prototyping-sdk/type-safe-api.SmithyBuildOptions.property.imports"></a>

```python
imports: typing.List[str]
```

- *Type:* typing.List[str]

List of imports.

---

##### `plugins`<sup>Optional</sup> <a name="plugins" id="@aws-prototyping-sdk/type-safe-api.SmithyBuildOptions.property.plugins"></a>

```python
plugins: typing.Mapping[typing.Mapping[typing.Any]]
```

- *Type:* typing.Mapping[typing.Mapping[typing.Any]]

Plugins keyed by plugin id.

---

##### `additional_sources`<sup>Optional</sup> <a name="additional_sources" id="@aws-prototyping-sdk/type-safe-api.SmithyBuildOptions.property.additionalSources"></a>

```python
additional_sources: typing.List[str]
```

- *Type:* typing.List[str]

Paths to any additional model files or directories to be used as sources for the smithy build.

The src/main/smithy directory is always included.
Paths must be relative to the model project directory. Absolute paths will
be resolved as relative paths.

---

##### `ignore_missing_plugins`<sup>Optional</sup> <a name="ignore_missing_plugins" id="@aws-prototyping-sdk/type-safe-api.SmithyBuildOptions.property.ignoreMissingPlugins"></a>

```python
ignore_missing_plugins: bool
```

- *Type:* bool
- *Default:* no ignoreMissingPlugins set in the smithy-build.json file

If a plugin can't be found, Smithy will by default fail the build.

This setting can be set to true to allow the build to progress
even if a plugin can't be found on the classpath.

---

##### `maven`<sup>Optional</sup> <a name="maven" id="@aws-prototyping-sdk/type-safe-api.SmithyBuildOptions.property.maven"></a>

```python
maven: SmithyMavenConfiguration
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.SmithyMavenConfiguration">SmithyMavenConfiguration</a>
- *Default:* the default configuration required for Smithy to OpenAPI conversion

Maven configuration for the Smithy build project, used to specify dependencies and repositories in the build.gradle and smithy-build.json files.

---

##### `projections`<sup>Optional</sup> <a name="projections" id="@aws-prototyping-sdk/type-safe-api.SmithyBuildOptions.property.projections"></a>

```python
projections: typing.Mapping[SmithyProjection]
```

- *Type:* typing.Mapping[<a href="#@aws-prototyping-sdk/type-safe-api.SmithyProjection">SmithyProjection</a>]
- *Default:* no projections

Map of projections name to projection configurations https://awslabs.github.io/smithy/2.0/guides/building-models/build-config.html#projections.

---

### SmithyCommon <a name="SmithyCommon" id="@aws-prototyping-sdk/type-safe-api.SmithyCommon"></a>

Properties common to smithy plugins and the root smithy build.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.SmithyCommon.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.SmithyCommon(
  imports: typing.List[str] = None,
  plugins: typing.Mapping[typing.Mapping[typing.Any]] = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyCommon.property.imports">imports</a></code> | <code>typing.List[str]</code> | List of imports. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyCommon.property.plugins">plugins</a></code> | <code>typing.Mapping[typing.Mapping[typing.Any]]</code> | Plugins keyed by plugin id. |

---

##### `imports`<sup>Optional</sup> <a name="imports" id="@aws-prototyping-sdk/type-safe-api.SmithyCommon.property.imports"></a>

```python
imports: typing.List[str]
```

- *Type:* typing.List[str]

List of imports.

---

##### `plugins`<sup>Optional</sup> <a name="plugins" id="@aws-prototyping-sdk/type-safe-api.SmithyCommon.property.plugins"></a>

```python
plugins: typing.Mapping[typing.Mapping[typing.Any]]
```

- *Type:* typing.Mapping[typing.Mapping[typing.Any]]

Plugins keyed by plugin id.

---

### SmithyDefinitionOptions <a name="SmithyDefinitionOptions" id="@aws-prototyping-sdk/type-safe-api.SmithyDefinitionOptions"></a>

Options for a smithy build project.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.SmithyDefinitionOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.SmithyDefinitionOptions(
  smithy_options: SmithyModelOptions
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyDefinitionOptions.property.smithyOptions">smithy_options</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyModelOptions">SmithyModelOptions</a></code> | Smithy engine options. |

---

##### `smithy_options`<sup>Required</sup> <a name="smithy_options" id="@aws-prototyping-sdk/type-safe-api.SmithyDefinitionOptions.property.smithyOptions"></a>

```python
smithy_options: SmithyModelOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.SmithyModelOptions">SmithyModelOptions</a>

Smithy engine options.

---

### SmithyMavenConfiguration <a name="SmithyMavenConfiguration" id="@aws-prototyping-sdk/type-safe-api.SmithyMavenConfiguration"></a>

Configuration for smithy maven dependencies.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.SmithyMavenConfiguration.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.SmithyMavenConfiguration(
  dependencies: typing.List[str] = None,
  repository_urls: typing.List[str] = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyMavenConfiguration.property.dependencies">dependencies</a></code> | <code>typing.List[str]</code> | The dependencies used in the build.gradle and smithy-build.json files eg. software.amazon.smithy:smithy-validation-model:1.28.0 The following required dependencies are always added: - software.amazon.smithy:smithy-cli:1.28.0 - software.amazon.smithy:smithy-model:1.28.0 - software.amazon.smithy:smithy-openapi:1.28.0 - software.amazon.smithy:smithy-aws-traits:1.28.0 You can however override the version of these dependencies if required. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyMavenConfiguration.property.repositoryUrls">repository_urls</a></code> | <code>typing.List[str]</code> | The repository urls used in the build.gradle and smithy-build.json files. |

---

##### `dependencies`<sup>Optional</sup> <a name="dependencies" id="@aws-prototyping-sdk/type-safe-api.SmithyMavenConfiguration.property.dependencies"></a>

```python
dependencies: typing.List[str]
```

- *Type:* typing.List[str]

The dependencies used in the build.gradle and smithy-build.json files eg. software.amazon.smithy:smithy-validation-model:1.28.0 The following required dependencies are always added: - software.amazon.smithy:smithy-cli:1.28.0 - software.amazon.smithy:smithy-model:1.28.0 - software.amazon.smithy:smithy-openapi:1.28.0 - software.amazon.smithy:smithy-aws-traits:1.28.0 You can however override the version of these dependencies if required.

---

##### `repository_urls`<sup>Optional</sup> <a name="repository_urls" id="@aws-prototyping-sdk/type-safe-api.SmithyMavenConfiguration.property.repositoryUrls"></a>

```python
repository_urls: typing.List[str]
```

- *Type:* typing.List[str]
- *Default:* maven central and maven local

The repository urls used in the build.gradle and smithy-build.json files.

---

### SmithyModelOptions <a name="SmithyModelOptions" id="@aws-prototyping-sdk/type-safe-api.SmithyModelOptions"></a>

Options for a Smithy model.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.SmithyModelOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.SmithyModelOptions(
  service_name: SmithyServiceName,
  ignore_gradle_wrapper: bool = None,
  ignore_smithy_build_output: bool = None,
  smithy_build_options: SmithyBuildOptions = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyModelOptions.property.serviceName">service_name</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyServiceName">SmithyServiceName</a></code> | Smithy service name. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyModelOptions.property.ignoreGradleWrapper">ignore_gradle_wrapper</a></code> | <code>bool</code> | Set to false if you would like to check in your gradle wrapper. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyModelOptions.property.ignoreSmithyBuildOutput">ignore_smithy_build_output</a></code> | <code>bool</code> | Set to false if you would like to check in your smithy build output or have more fine-grained control over what is checked in, eg if you add other projections to the smithy-build.json file. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyModelOptions.property.smithyBuildOptions">smithy_build_options</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyBuildOptions">SmithyBuildOptions</a></code> | Smithy build options. |

---

##### `service_name`<sup>Required</sup> <a name="service_name" id="@aws-prototyping-sdk/type-safe-api.SmithyModelOptions.property.serviceName"></a>

```python
service_name: SmithyServiceName
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.SmithyServiceName">SmithyServiceName</a>

Smithy service name.

---

##### `ignore_gradle_wrapper`<sup>Optional</sup> <a name="ignore_gradle_wrapper" id="@aws-prototyping-sdk/type-safe-api.SmithyModelOptions.property.ignoreGradleWrapper"></a>

```python
ignore_gradle_wrapper: bool
```

- *Type:* bool
- *Default:* true

Set to false if you would like to check in your gradle wrapper.

Do so if you would like to use a different version
of gradle to the one provided by default

---

##### `ignore_smithy_build_output`<sup>Optional</sup> <a name="ignore_smithy_build_output" id="@aws-prototyping-sdk/type-safe-api.SmithyModelOptions.property.ignoreSmithyBuildOutput"></a>

```python
ignore_smithy_build_output: bool
```

- *Type:* bool
- *Default:* true

Set to false if you would like to check in your smithy build output or have more fine-grained control over what is checked in, eg if you add other projections to the smithy-build.json file.

---

##### `smithy_build_options`<sup>Optional</sup> <a name="smithy_build_options" id="@aws-prototyping-sdk/type-safe-api.SmithyModelOptions.property.smithyBuildOptions"></a>

```python
smithy_build_options: SmithyBuildOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.SmithyBuildOptions">SmithyBuildOptions</a>

Smithy build options.

---

### SmithyProjection <a name="SmithyProjection" id="@aws-prototyping-sdk/type-safe-api.SmithyProjection"></a>

A smithy build projection.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.SmithyProjection.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.SmithyProjection(
  imports: typing.List[str] = None,
  plugins: typing.Mapping[typing.Mapping[typing.Any]] = None,
  abstract: bool = None,
  transforms: typing.List[SmithyTransform] = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyProjection.property.imports">imports</a></code> | <code>typing.List[str]</code> | List of imports. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyProjection.property.plugins">plugins</a></code> | <code>typing.Mapping[typing.Mapping[typing.Any]]</code> | Plugins keyed by plugin id. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyProjection.property.abstract">abstract</a></code> | <code>bool</code> | Whether or not the projection is abstract. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyProjection.property.transforms">transforms</a></code> | <code>typing.List[<a href="#@aws-prototyping-sdk/type-safe-api.SmithyTransform">SmithyTransform</a>]</code> | Transforms to apply to the projection. |

---

##### `imports`<sup>Optional</sup> <a name="imports" id="@aws-prototyping-sdk/type-safe-api.SmithyProjection.property.imports"></a>

```python
imports: typing.List[str]
```

- *Type:* typing.List[str]

List of imports.

---

##### `plugins`<sup>Optional</sup> <a name="plugins" id="@aws-prototyping-sdk/type-safe-api.SmithyProjection.property.plugins"></a>

```python
plugins: typing.Mapping[typing.Mapping[typing.Any]]
```

- *Type:* typing.Mapping[typing.Mapping[typing.Any]]

Plugins keyed by plugin id.

---

##### `abstract`<sup>Optional</sup> <a name="abstract" id="@aws-prototyping-sdk/type-safe-api.SmithyProjection.property.abstract"></a>

```python
abstract: bool
```

- *Type:* bool

Whether or not the projection is abstract.

---

##### `transforms`<sup>Optional</sup> <a name="transforms" id="@aws-prototyping-sdk/type-safe-api.SmithyProjection.property.transforms"></a>

```python
transforms: typing.List[SmithyTransform]
```

- *Type:* typing.List[<a href="#@aws-prototyping-sdk/type-safe-api.SmithyTransform">SmithyTransform</a>]

Transforms to apply to the projection.

---

### SmithyServiceName <a name="SmithyServiceName" id="@aws-prototyping-sdk/type-safe-api.SmithyServiceName"></a>

Represents a fully qualified name of a Smithy service.

> [https://awslabs.github.io/smithy/2.0/spec/service-types.html](https://awslabs.github.io/smithy/2.0/spec/service-types.html)

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.SmithyServiceName.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.SmithyServiceName(
  namespace: str,
  service_name: str
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyServiceName.property.namespace">namespace</a></code> | <code>str</code> | The service namespace. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyServiceName.property.serviceName">service_name</a></code> | <code>str</code> | The service name. |

---

##### `namespace`<sup>Required</sup> <a name="namespace" id="@aws-prototyping-sdk/type-safe-api.SmithyServiceName.property.namespace"></a>

```python
namespace: str
```

- *Type:* str

The service namespace.

Nested namespaces are separated by '.', for example com.company

> [https://awslabs.github.io/smithy/2.0/spec/model.html#shape-id](https://awslabs.github.io/smithy/2.0/spec/model.html#shape-id)

---

##### `service_name`<sup>Required</sup> <a name="service_name" id="@aws-prototyping-sdk/type-safe-api.SmithyServiceName.property.serviceName"></a>

```python
service_name: str
```

- *Type:* str

The service name.

Should be PascalCase, for example HelloService

> [https://awslabs.github.io/smithy/2.0/spec/model.html#shape-id](https://awslabs.github.io/smithy/2.0/spec/model.html#shape-id)

---

### SmithyTransform <a name="SmithyTransform" id="@aws-prototyping-sdk/type-safe-api.SmithyTransform"></a>

A smithy build transform.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.SmithyTransform.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.SmithyTransform(
  args: typing.Mapping[typing.Any],
  name: str
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyTransform.property.args">args</a></code> | <code>typing.Mapping[typing.Any]</code> | Arguments for the transform. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyTransform.property.name">name</a></code> | <code>str</code> | Name of the transform. |

---

##### `args`<sup>Required</sup> <a name="args" id="@aws-prototyping-sdk/type-safe-api.SmithyTransform.property.args"></a>

```python
args: typing.Mapping[typing.Any]
```

- *Type:* typing.Mapping[typing.Any]

Arguments for the transform.

---

##### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/type-safe-api.SmithyTransform.property.name"></a>

```python
name: str
```

- *Type:* str

Name of the transform.

---

### TypeSafeApiIntegration <a name="TypeSafeApiIntegration" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiIntegration"></a>

Defines an integration for an individual API operation.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiIntegration.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.TypeSafeApiIntegration(
  integration: Integration,
  authorizer: Authorizer = None,
  options: TypeSafeApiIntegrationOptions = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiIntegration.property.integration">integration</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.Integration">Integration</a></code> | The integration to service the api operation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiIntegration.property.authorizer">authorizer</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.Authorizer">Authorizer</a></code> | The authorizer to use for this api operation (overrides the default). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiIntegration.property.options">options</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiIntegrationOptions">TypeSafeApiIntegrationOptions</a></code> | Options for the integration. |

---

##### `integration`<sup>Required</sup> <a name="integration" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiIntegration.property.integration"></a>

```python
integration: Integration
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.Integration">Integration</a>

The integration to service the api operation.

---

##### `authorizer`<sup>Optional</sup> <a name="authorizer" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiIntegration.property.authorizer"></a>

```python
authorizer: Authorizer
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.Authorizer">Authorizer</a>

The authorizer to use for this api operation (overrides the default).

---

##### `options`<sup>Optional</sup> <a name="options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiIntegration.property.options"></a>

```python
options: TypeSafeApiIntegrationOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiIntegrationOptions">TypeSafeApiIntegrationOptions</a>

Options for the integration.

---

### TypeSafeApiIntegrationOptions <a name="TypeSafeApiIntegrationOptions" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiIntegrationOptions"></a>

Options for an integration.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiIntegrationOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.TypeSafeApiIntegrationOptions(
  api_key_required: bool = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiIntegrationOptions.property.apiKeyRequired">api_key_required</a></code> | <code>bool</code> | Require an API key to invoke this operation. |

---

##### `api_key_required`<sup>Optional</sup> <a name="api_key_required" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiIntegrationOptions.property.apiKeyRequired"></a>

```python
api_key_required: bool
```

- *Type:* bool
- *Default:* false

Require an API key to invoke this operation.

Overrides the default setting if present.
This is only applicable when the API key source is HEADER.

---

### TypeSafeApiModelProjectOptions <a name="TypeSafeApiModelProjectOptions" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions"></a>

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.TypeSafeApiModelProjectOptions(
  name: str,
  commit_generated: bool = None,
  git_ignore_options: IgnoreFileOptions = None,
  git_options: GitOptions = None,
  logging: LoggerOptions = None,
  outdir: str = None,
  parent: Project = None,
  projen_command: str = None,
  projenrc_json: bool = None,
  projenrc_json_options: ProjenrcJsonOptions = None,
  renovatebot: bool = None,
  renovatebot_options: RenovatebotOptions = None,
  model_language: ModelLanguage,
  model_options: ModelOptions
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.name">name</a></code> | <code>str</code> | This is the name of your project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.commitGenerated">commit_generated</a></code> | <code>bool</code> | Whether to commit the managed files by default. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.gitIgnoreOptions">git_ignore_options</a></code> | <code>projen.IgnoreFileOptions</code> | Configuration options for .gitignore file. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.gitOptions">git_options</a></code> | <code>projen.GitOptions</code> | Configuration options for git. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.logging">logging</a></code> | <code>projen.LoggerOptions</code> | Configure logging options such as verbosity. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.outdir">outdir</a></code> | <code>str</code> | The root directory of the project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.parent">parent</a></code> | <code>projen.Project</code> | The parent project, if this project is part of a bigger project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.projenCommand">projen_command</a></code> | <code>str</code> | The shell command to use in order to run the projen CLI. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.projenrcJson">projenrc_json</a></code> | <code>bool</code> | Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.projenrcJsonOptions">projenrc_json_options</a></code> | <code>projen.ProjenrcJsonOptions</code> | Options for .projenrc.json. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.renovatebot">renovatebot</a></code> | <code>bool</code> | Use renovatebot to handle dependency upgrades. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.renovatebotOptions">renovatebot_options</a></code> | <code>projen.RenovatebotOptions</code> | Options for renovatebot. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.modelLanguage">model_language</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.ModelLanguage">ModelLanguage</a></code> | Language the model is defined in. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.modelOptions">model_options</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.ModelOptions">ModelOptions</a></code> | Options for the model. |

---

##### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.name"></a>

```python
name: str
```

- *Type:* str
- *Default:* $BASEDIR

This is the name of your project.

---

##### `commit_generated`<sup>Optional</sup> <a name="commit_generated" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.commitGenerated"></a>

```python
commit_generated: bool
```

- *Type:* bool
- *Default:* true

Whether to commit the managed files by default.

---

##### `git_ignore_options`<sup>Optional</sup> <a name="git_ignore_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.gitIgnoreOptions"></a>

```python
git_ignore_options: IgnoreFileOptions
```

- *Type:* projen.IgnoreFileOptions

Configuration options for .gitignore file.

---

##### `git_options`<sup>Optional</sup> <a name="git_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.gitOptions"></a>

```python
git_options: GitOptions
```

- *Type:* projen.GitOptions

Configuration options for git.

---

##### `logging`<sup>Optional</sup> <a name="logging" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.logging"></a>

```python
logging: LoggerOptions
```

- *Type:* projen.LoggerOptions
- *Default:* {}

Configure logging options such as verbosity.

---

##### `outdir`<sup>Optional</sup> <a name="outdir" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.outdir"></a>

```python
outdir: str
```

- *Type:* str
- *Default:* "."

The root directory of the project.

Relative to this directory, all files are synthesized.

If this project has a parent, this directory is relative to the parent
directory and it cannot be the same as the parent or any of it's other
sub-projects.

---

##### `parent`<sup>Optional</sup> <a name="parent" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.parent"></a>

```python
parent: Project
```

- *Type:* projen.Project

The parent project, if this project is part of a bigger project.

---

##### `projen_command`<sup>Optional</sup> <a name="projen_command" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.projenCommand"></a>

```python
projen_command: str
```

- *Type:* str
- *Default:* "npx projen"

The shell command to use in order to run the projen CLI.

Can be used to customize in special environments.

---

##### `projenrc_json`<sup>Optional</sup> <a name="projenrc_json" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.projenrcJson"></a>

```python
projenrc_json: bool
```

- *Type:* bool
- *Default:* false

Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation.

---

##### `projenrc_json_options`<sup>Optional</sup> <a name="projenrc_json_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.projenrcJsonOptions"></a>

```python
projenrc_json_options: ProjenrcJsonOptions
```

- *Type:* projen.ProjenrcJsonOptions
- *Default:* default options

Options for .projenrc.json.

---

##### `renovatebot`<sup>Optional</sup> <a name="renovatebot" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.renovatebot"></a>

```python
renovatebot: bool
```

- *Type:* bool
- *Default:* false

Use renovatebot to handle dependency upgrades.

---

##### `renovatebot_options`<sup>Optional</sup> <a name="renovatebot_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.renovatebotOptions"></a>

```python
renovatebot_options: RenovatebotOptions
```

- *Type:* projen.RenovatebotOptions
- *Default:* default options

Options for renovatebot.

---

##### `model_language`<sup>Required</sup> <a name="model_language" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.modelLanguage"></a>

```python
model_language: ModelLanguage
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.ModelLanguage">ModelLanguage</a>

Language the model is defined in.

---

##### `model_options`<sup>Required</sup> <a name="model_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.modelOptions"></a>

```python
model_options: ModelOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.ModelOptions">ModelOptions</a>

Options for the model.

---

### TypeSafeApiOptions <a name="TypeSafeApiOptions" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiOptions"></a>

Options required alongside an Open API specification to create API Gateway resources.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.TypeSafeApiOptions(
  integrations: typing.Mapping[TypeSafeApiIntegration],
  operation_lookup: typing.Mapping[OperationDetails],
  api_key_options: ApiKeyOptions = None,
  cors_options: CorsOptions = None,
  default_authorizer: Authorizer = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiOptions.property.integrations">integrations</a></code> | <code>typing.Mapping[<a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiIntegration">TypeSafeApiIntegration</a>]</code> | A mapping of API operation to its integration. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiOptions.property.operationLookup">operation_lookup</a></code> | <code>typing.Mapping[<a href="#@aws-prototyping-sdk/type-safe-api.OperationDetails">OperationDetails</a>]</code> | Details about each operation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiOptions.property.apiKeyOptions">api_key_options</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiKeyOptions">ApiKeyOptions</a></code> | Options for API keys. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiOptions.property.corsOptions">cors_options</a></code> | <code>aws_cdk.aws_apigateway.CorsOptions</code> | Cross Origin Resource Sharing options for the API. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiOptions.property.defaultAuthorizer">default_authorizer</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.Authorizer">Authorizer</a></code> | The default authorizer to use for your api. |

---

##### `integrations`<sup>Required</sup> <a name="integrations" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiOptions.property.integrations"></a>

```python
integrations: typing.Mapping[TypeSafeApiIntegration]
```

- *Type:* typing.Mapping[<a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiIntegration">TypeSafeApiIntegration</a>]

A mapping of API operation to its integration.

---

##### `operation_lookup`<sup>Required</sup> <a name="operation_lookup" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiOptions.property.operationLookup"></a>

```python
operation_lookup: typing.Mapping[OperationDetails]
```

- *Type:* typing.Mapping[<a href="#@aws-prototyping-sdk/type-safe-api.OperationDetails">OperationDetails</a>]

Details about each operation.

---

##### `api_key_options`<sup>Optional</sup> <a name="api_key_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiOptions.property.apiKeyOptions"></a>

```python
api_key_options: ApiKeyOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.ApiKeyOptions">ApiKeyOptions</a>

Options for API keys.

---

##### `cors_options`<sup>Optional</sup> <a name="cors_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiOptions.property.corsOptions"></a>

```python
cors_options: CorsOptions
```

- *Type:* aws_cdk.aws_apigateway.CorsOptions

Cross Origin Resource Sharing options for the API.

---

##### `default_authorizer`<sup>Optional</sup> <a name="default_authorizer" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiOptions.property.defaultAuthorizer"></a>

```python
default_authorizer: Authorizer
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.Authorizer">Authorizer</a>

The default authorizer to use for your api.

When omitted, no default authorizer is used.
Authorizers specified at the integration level will override this for that operation.

---

### TypeSafeApiProjectOptions <a name="TypeSafeApiProjectOptions" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions"></a>

Options for the TypeSafeApiProject.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.TypeSafeApiProjectOptions(
  name: str,
  commit_generated: bool = None,
  git_ignore_options: IgnoreFileOptions = None,
  git_options: GitOptions = None,
  logging: LoggerOptions = None,
  outdir: str = None,
  parent: Project = None,
  projen_command: str = None,
  projenrc_json: bool = None,
  projenrc_json_options: ProjenrcJsonOptions = None,
  renovatebot: bool = None,
  renovatebot_options: RenovatebotOptions = None,
  infrastructure: InfrastructureConfiguration,
  model: ModelConfiguration,
  runtime: RuntimeConfiguration,
  documentation: DocumentationConfiguration = None,
  library: LibraryConfiguration = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.name">name</a></code> | <code>str</code> | This is the name of your project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.commitGenerated">commit_generated</a></code> | <code>bool</code> | Whether to commit the managed files by default. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.gitIgnoreOptions">git_ignore_options</a></code> | <code>projen.IgnoreFileOptions</code> | Configuration options for .gitignore file. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.gitOptions">git_options</a></code> | <code>projen.GitOptions</code> | Configuration options for git. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.logging">logging</a></code> | <code>projen.LoggerOptions</code> | Configure logging options such as verbosity. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.outdir">outdir</a></code> | <code>str</code> | The root directory of the project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.parent">parent</a></code> | <code>projen.Project</code> | The parent project, if this project is part of a bigger project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.projenCommand">projen_command</a></code> | <code>str</code> | The shell command to use in order to run the projen CLI. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.projenrcJson">projenrc_json</a></code> | <code>bool</code> | Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.projenrcJsonOptions">projenrc_json_options</a></code> | <code>projen.ProjenrcJsonOptions</code> | Options for .projenrc.json. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.renovatebot">renovatebot</a></code> | <code>bool</code> | Use renovatebot to handle dependency upgrades. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.renovatebotOptions">renovatebot_options</a></code> | <code>projen.RenovatebotOptions</code> | Options for renovatebot. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.infrastructure">infrastructure</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.InfrastructureConfiguration">InfrastructureConfiguration</a></code> | Configuration for generated infrastructure. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.model">model</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.ModelConfiguration">ModelConfiguration</a></code> | Configuration for the API model. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.runtime">runtime</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.RuntimeConfiguration">RuntimeConfiguration</a></code> | Configuration for generated runtime projects (containing types, clients and server code). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.documentation">documentation</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.DocumentationConfiguration">DocumentationConfiguration</a></code> | Configuration for generated documentation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.library">library</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.LibraryConfiguration">LibraryConfiguration</a></code> | Configuration for generated libraries. |

---

##### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.name"></a>

```python
name: str
```

- *Type:* str
- *Default:* $BASEDIR

This is the name of your project.

---

##### `commit_generated`<sup>Optional</sup> <a name="commit_generated" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.commitGenerated"></a>

```python
commit_generated: bool
```

- *Type:* bool
- *Default:* true

Whether to commit the managed files by default.

---

##### `git_ignore_options`<sup>Optional</sup> <a name="git_ignore_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.gitIgnoreOptions"></a>

```python
git_ignore_options: IgnoreFileOptions
```

- *Type:* projen.IgnoreFileOptions

Configuration options for .gitignore file.

---

##### `git_options`<sup>Optional</sup> <a name="git_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.gitOptions"></a>

```python
git_options: GitOptions
```

- *Type:* projen.GitOptions

Configuration options for git.

---

##### `logging`<sup>Optional</sup> <a name="logging" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.logging"></a>

```python
logging: LoggerOptions
```

- *Type:* projen.LoggerOptions
- *Default:* {}

Configure logging options such as verbosity.

---

##### `outdir`<sup>Optional</sup> <a name="outdir" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.outdir"></a>

```python
outdir: str
```

- *Type:* str
- *Default:* "."

The root directory of the project.

Relative to this directory, all files are synthesized.

If this project has a parent, this directory is relative to the parent
directory and it cannot be the same as the parent or any of it's other
sub-projects.

---

##### `parent`<sup>Optional</sup> <a name="parent" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.parent"></a>

```python
parent: Project
```

- *Type:* projen.Project

The parent project, if this project is part of a bigger project.

---

##### `projen_command`<sup>Optional</sup> <a name="projen_command" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.projenCommand"></a>

```python
projen_command: str
```

- *Type:* str
- *Default:* "npx projen"

The shell command to use in order to run the projen CLI.

Can be used to customize in special environments.

---

##### `projenrc_json`<sup>Optional</sup> <a name="projenrc_json" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.projenrcJson"></a>

```python
projenrc_json: bool
```

- *Type:* bool
- *Default:* false

Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation.

---

##### `projenrc_json_options`<sup>Optional</sup> <a name="projenrc_json_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.projenrcJsonOptions"></a>

```python
projenrc_json_options: ProjenrcJsonOptions
```

- *Type:* projen.ProjenrcJsonOptions
- *Default:* default options

Options for .projenrc.json.

---

##### `renovatebot`<sup>Optional</sup> <a name="renovatebot" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.renovatebot"></a>

```python
renovatebot: bool
```

- *Type:* bool
- *Default:* false

Use renovatebot to handle dependency upgrades.

---

##### `renovatebot_options`<sup>Optional</sup> <a name="renovatebot_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.renovatebotOptions"></a>

```python
renovatebot_options: RenovatebotOptions
```

- *Type:* projen.RenovatebotOptions
- *Default:* default options

Options for renovatebot.

---

##### `infrastructure`<sup>Required</sup> <a name="infrastructure" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.infrastructure"></a>

```python
infrastructure: InfrastructureConfiguration
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.InfrastructureConfiguration">InfrastructureConfiguration</a>

Configuration for generated infrastructure.

---

##### `model`<sup>Required</sup> <a name="model" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.model"></a>

```python
model: ModelConfiguration
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.ModelConfiguration">ModelConfiguration</a>

Configuration for the API model.

---

##### `runtime`<sup>Required</sup> <a name="runtime" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.runtime"></a>

```python
runtime: RuntimeConfiguration
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.RuntimeConfiguration">RuntimeConfiguration</a>

Configuration for generated runtime projects (containing types, clients and server code).

---

##### `documentation`<sup>Optional</sup> <a name="documentation" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.documentation"></a>

```python
documentation: DocumentationConfiguration
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.DocumentationConfiguration">DocumentationConfiguration</a>

Configuration for generated documentation.

---

##### `library`<sup>Optional</sup> <a name="library" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.library"></a>

```python
library: LibraryConfiguration
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.LibraryConfiguration">LibraryConfiguration</a>

Configuration for generated libraries.

Libraries are projects which are generated from your model, but are not
fully-fledged runtimes, for example react hooks or clients in languages that aren't supported as runtimes.

---

### TypeSafeApiWebAclOptions <a name="TypeSafeApiWebAclOptions" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiWebAclOptions"></a>

Configuration for the Web ACL associated with the API.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiWebAclOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.TypeSafeApiWebAclOptions(
  cidr_allow_list: CidrAllowList = None,
  disable: bool = None,
  managed_rules: typing.List[ManagedRule] = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiWebAclOptions.property.cidrAllowList">cidr_allow_list</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.CidrAllowList">CidrAllowList</a></code> | List of cidr ranges to allow. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiWebAclOptions.property.disable">disable</a></code> | <code>bool</code> | If set to true, no WebACL will be associated with the API. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiWebAclOptions.property.managedRules">managed_rules</a></code> | <code>typing.List[<a href="#@aws-prototyping-sdk/type-safe-api.ManagedRule">ManagedRule</a>]</code> | List of managed rules to apply to the web acl. |

---

##### `cidr_allow_list`<sup>Optional</sup> <a name="cidr_allow_list" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiWebAclOptions.property.cidrAllowList"></a>

```python
cidr_allow_list: CidrAllowList
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.CidrAllowList">CidrAllowList</a>
- *Default:* undefined

List of cidr ranges to allow.

---

##### `disable`<sup>Optional</sup> <a name="disable" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiWebAclOptions.property.disable"></a>

```python
disable: bool
```

- *Type:* bool
- *Default:* false

If set to true, no WebACL will be associated with the API.

You can also use this option if you would like to create
your own WebACL and associate it yourself.

---

##### `managed_rules`<sup>Optional</sup> <a name="managed_rules" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiWebAclOptions.property.managedRules"></a>

```python
managed_rules: typing.List[ManagedRule]
```

- *Type:* typing.List[<a href="#@aws-prototyping-sdk/type-safe-api.ManagedRule">ManagedRule</a>]
- *Default:* [{ vendor: "AWS", name: "AWSManagedRulesCommonRuleSet" }]

List of managed rules to apply to the web acl.

---

### TypeSafeRestApiProps <a name="TypeSafeRestApiProps" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps"></a>

Configuration for the TypeSafeRestApi construct.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.TypeSafeRestApiProps(
  cloud_watch_role: bool = None,
  deploy: bool = None,
  deploy_options: StageOptions = None,
  description: str = None,
  disable_execute_api_endpoint: bool = None,
  domain_name: DomainNameOptions = None,
  endpoint_export_name: str = None,
  endpoint_types: typing.List[EndpointType] = None,
  fail_on_warnings: bool = None,
  parameters: typing.Mapping[str] = None,
  policy: PolicyDocument = None,
  rest_api_name: str = None,
  retain_deployments: bool = None,
  integrations: typing.Mapping[TypeSafeApiIntegration],
  operation_lookup: typing.Mapping[OperationDetails],
  api_key_options: ApiKeyOptions = None,
  cors_options: CorsOptions = None,
  default_authorizer: Authorizer = None,
  spec_path: str,
  min_compression_size: Size = None,
  web_acl_options: TypeSafeApiWebAclOptions = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.cloudWatchRole">cloud_watch_role</a></code> | <code>bool</code> | Automatically configure an AWS CloudWatch role for API Gateway. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.deploy">deploy</a></code> | <code>bool</code> | Indicates if a Deployment should be automatically created for this API, and recreated when the API model (resources, methods) changes. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.deployOptions">deploy_options</a></code> | <code>aws_cdk.aws_apigateway.StageOptions</code> | Options for the API Gateway stage that will always point to the latest deployment when `deploy` is enabled. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.description">description</a></code> | <code>str</code> | A description of the RestApi construct. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.disableExecuteApiEndpoint">disable_execute_api_endpoint</a></code> | <code>bool</code> | Specifies whether clients can invoke the API using the default execute-api endpoint. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.domainName">domain_name</a></code> | <code>aws_cdk.aws_apigateway.DomainNameOptions</code> | Configure a custom domain name and map it to this API. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.endpointExportName">endpoint_export_name</a></code> | <code>str</code> | Export name for the CfnOutput containing the API endpoint. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.endpointTypes">endpoint_types</a></code> | <code>typing.List[aws_cdk.aws_apigateway.EndpointType]</code> | A list of the endpoint types of the API. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.failOnWarnings">fail_on_warnings</a></code> | <code>bool</code> | Indicates whether to roll back the resource if a warning occurs while API Gateway is creating the RestApi resource. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.parameters">parameters</a></code> | <code>typing.Mapping[str]</code> | Custom header parameters for the request. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.policy">policy</a></code> | <code>aws_cdk.aws_iam.PolicyDocument</code> | A policy document that contains the permissions for this RestApi. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.restApiName">rest_api_name</a></code> | <code>str</code> | A name for the API Gateway RestApi resource. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.retainDeployments">retain_deployments</a></code> | <code>bool</code> | Retains old deployment resources when the API changes. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.integrations">integrations</a></code> | <code>typing.Mapping[<a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiIntegration">TypeSafeApiIntegration</a>]</code> | A mapping of API operation to its integration. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.operationLookup">operation_lookup</a></code> | <code>typing.Mapping[<a href="#@aws-prototyping-sdk/type-safe-api.OperationDetails">OperationDetails</a>]</code> | Details about each operation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.apiKeyOptions">api_key_options</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiKeyOptions">ApiKeyOptions</a></code> | Options for API keys. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.corsOptions">cors_options</a></code> | <code>aws_cdk.aws_apigateway.CorsOptions</code> | Cross Origin Resource Sharing options for the API. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.defaultAuthorizer">default_authorizer</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.Authorizer">Authorizer</a></code> | The default authorizer to use for your api. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.specPath">spec_path</a></code> | <code>str</code> | Path to the JSON open api spec. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.minCompressionSize">min_compression_size</a></code> | <code>aws_cdk.Size</code> | A Size(in bytes, kibibytes, mebibytes etc) that is used to enable compression (with non-negative between 0 and 10485760 (10M) bytes, inclusive) or disable compression (when undefined) on an API. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.webAclOptions">web_acl_options</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiWebAclOptions">TypeSafeApiWebAclOptions</a></code> | Options for the AWS WAF v2 WebACL associated with the api. |

---

##### `cloud_watch_role`<sup>Optional</sup> <a name="cloud_watch_role" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.cloudWatchRole"></a>

```python
cloud_watch_role: bool
```

- *Type:* bool
- *Default:* false if `@aws-cdk/aws-apigateway:disableCloudWatchRole` is enabled, true otherwise

Automatically configure an AWS CloudWatch role for API Gateway.

---

##### `deploy`<sup>Optional</sup> <a name="deploy" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.deploy"></a>

```python
deploy: bool
```

- *Type:* bool
- *Default:* true

Indicates if a Deployment should be automatically created for this API, and recreated when the API model (resources, methods) changes.

Since API Gateway deployments are immutable, When this option is enabled
(by default), an AWS::ApiGateway::Deployment resource will automatically
created with a logical ID that hashes the API model (methods, resources
and options). This means that when the model changes, the logical ID of
this CloudFormation resource will change, and a new deployment will be
created.

If this is set, `latestDeployment` will refer to the `Deployment` object
and `deploymentStage` will refer to a `Stage` that points to this
deployment. To customize the stage options, use the `deployOptions`
property.

A CloudFormation Output will also be defined with the root URL endpoint
of this REST API.

---

##### `deploy_options`<sup>Optional</sup> <a name="deploy_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.deployOptions"></a>

```python
deploy_options: StageOptions
```

- *Type:* aws_cdk.aws_apigateway.StageOptions
- *Default:* Based on defaults of `StageOptions`.

Options for the API Gateway stage that will always point to the latest deployment when `deploy` is enabled.

If `deploy` is disabled,
this value cannot be set.

---

##### `description`<sup>Optional</sup> <a name="description" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.description"></a>

```python
description: str
```

- *Type:* str
- *Default:* 'Automatically created by the RestApi construct'

A description of the RestApi construct.

---

##### `disable_execute_api_endpoint`<sup>Optional</sup> <a name="disable_execute_api_endpoint" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.disableExecuteApiEndpoint"></a>

```python
disable_execute_api_endpoint: bool
```

- *Type:* bool
- *Default:* false

Specifies whether clients can invoke the API using the default execute-api endpoint.

To require that clients use a custom domain name to invoke the
API, disable the default endpoint.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-restapi.html](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-restapi.html)

---

##### `domain_name`<sup>Optional</sup> <a name="domain_name" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.domainName"></a>

```python
domain_name: DomainNameOptions
```

- *Type:* aws_cdk.aws_apigateway.DomainNameOptions
- *Default:* no domain name is defined, use `addDomainName` or directly define a `DomainName`.

Configure a custom domain name and map it to this API.

---

##### `endpoint_export_name`<sup>Optional</sup> <a name="endpoint_export_name" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.endpointExportName"></a>

```python
endpoint_export_name: str
```

- *Type:* str
- *Default:* when no export name is given, output will be created without export

Export name for the CfnOutput containing the API endpoint.

---

##### `endpoint_types`<sup>Optional</sup> <a name="endpoint_types" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.endpointTypes"></a>

```python
endpoint_types: typing.List[EndpointType]
```

- *Type:* typing.List[aws_cdk.aws_apigateway.EndpointType]
- *Default:* EndpointType.EDGE

A list of the endpoint types of the API.

Use this property when creating
an API.

---

##### `fail_on_warnings`<sup>Optional</sup> <a name="fail_on_warnings" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.failOnWarnings"></a>

```python
fail_on_warnings: bool
```

- *Type:* bool
- *Default:* false

Indicates whether to roll back the resource if a warning occurs while API Gateway is creating the RestApi resource.

---

##### `parameters`<sup>Optional</sup> <a name="parameters" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.parameters"></a>

```python
parameters: typing.Mapping[str]
```

- *Type:* typing.Mapping[str]
- *Default:* No parameters.

Custom header parameters for the request.

> [https://docs.aws.amazon.com/cli/latest/reference/apigateway/import-rest-api.html](https://docs.aws.amazon.com/cli/latest/reference/apigateway/import-rest-api.html)

---

##### `policy`<sup>Optional</sup> <a name="policy" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.policy"></a>

```python
policy: PolicyDocument
```

- *Type:* aws_cdk.aws_iam.PolicyDocument
- *Default:* No policy.

A policy document that contains the permissions for this RestApi.

---

##### `rest_api_name`<sup>Optional</sup> <a name="rest_api_name" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.restApiName"></a>

```python
rest_api_name: str
```

- *Type:* str
- *Default:* ID of the RestApi construct.

A name for the API Gateway RestApi resource.

---

##### `retain_deployments`<sup>Optional</sup> <a name="retain_deployments" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.retainDeployments"></a>

```python
retain_deployments: bool
```

- *Type:* bool
- *Default:* false

Retains old deployment resources when the API changes.

This allows
manually reverting stages to point to old deployments via the AWS
Console.

---

##### `integrations`<sup>Required</sup> <a name="integrations" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.integrations"></a>

```python
integrations: typing.Mapping[TypeSafeApiIntegration]
```

- *Type:* typing.Mapping[<a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiIntegration">TypeSafeApiIntegration</a>]

A mapping of API operation to its integration.

---

##### `operation_lookup`<sup>Required</sup> <a name="operation_lookup" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.operationLookup"></a>

```python
operation_lookup: typing.Mapping[OperationDetails]
```

- *Type:* typing.Mapping[<a href="#@aws-prototyping-sdk/type-safe-api.OperationDetails">OperationDetails</a>]

Details about each operation.

---

##### `api_key_options`<sup>Optional</sup> <a name="api_key_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.apiKeyOptions"></a>

```python
api_key_options: ApiKeyOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.ApiKeyOptions">ApiKeyOptions</a>

Options for API keys.

---

##### `cors_options`<sup>Optional</sup> <a name="cors_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.corsOptions"></a>

```python
cors_options: CorsOptions
```

- *Type:* aws_cdk.aws_apigateway.CorsOptions

Cross Origin Resource Sharing options for the API.

---

##### `default_authorizer`<sup>Optional</sup> <a name="default_authorizer" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.defaultAuthorizer"></a>

```python
default_authorizer: Authorizer
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.Authorizer">Authorizer</a>

The default authorizer to use for your api.

When omitted, no default authorizer is used.
Authorizers specified at the integration level will override this for that operation.

---

##### `spec_path`<sup>Required</sup> <a name="spec_path" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.specPath"></a>

```python
spec_path: str
```

- *Type:* str

Path to the JSON open api spec.

---

##### `min_compression_size`<sup>Optional</sup> <a name="min_compression_size" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.minCompressionSize"></a>

```python
min_compression_size: Size
```

- *Type:* aws_cdk.Size
- *Default:* Compression is disabled.

A Size(in bytes, kibibytes, mebibytes etc) that is used to enable compression (with non-negative between 0 and 10485760 (10M) bytes, inclusive) or disable compression (when undefined) on an API.

When compression is enabled, compression or
decompression is not applied on the payload if the payload size is
smaller than this value. Setting it to zero allows compression for any
payload size.

---

##### `web_acl_options`<sup>Optional</sup> <a name="web_acl_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.webAclOptions"></a>

```python
web_acl_options: TypeSafeApiWebAclOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiWebAclOptions">TypeSafeApiWebAclOptions</a>

Options for the AWS WAF v2 WebACL associated with the api.

By default, a Web ACL with the AWS default managed
rule set will be associated with the API. These options may disable or override the defaults.

---

## Classes <a name="Classes" id="Classes"></a>

### Authorizer <a name="Authorizer" id="@aws-prototyping-sdk/type-safe-api.Authorizer"></a>

An authorizer for authorizing API requests.

#### Initializers <a name="Initializers" id="@aws-prototyping-sdk/type-safe-api.Authorizer.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.Authorizer(
  authorization_type: AuthorizationType,
  authorizer_id: str,
  authorization_scopes: typing.List[str] = None
)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.Authorizer.Initializer.parameter.authorizationType">authorization_type</a></code> | <code>aws_cdk.aws_apigateway.AuthorizationType</code> | The type of the authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.Authorizer.Initializer.parameter.authorizerId">authorizer_id</a></code> | <code>str</code> | The unique identifier for the authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.Authorizer.Initializer.parameter.authorizationScopes">authorization_scopes</a></code> | <code>typing.List[str]</code> | Scopes for the authorizer, if any. |

---

##### `authorization_type`<sup>Required</sup> <a name="authorization_type" id="@aws-prototyping-sdk/type-safe-api.Authorizer.Initializer.parameter.authorizationType"></a>

- *Type:* aws_cdk.aws_apigateway.AuthorizationType

The type of the authorizer.

---

##### `authorizer_id`<sup>Required</sup> <a name="authorizer_id" id="@aws-prototyping-sdk/type-safe-api.Authorizer.Initializer.parameter.authorizerId"></a>

- *Type:* str

The unique identifier for the authorizer.

---

##### `authorization_scopes`<sup>Optional</sup> <a name="authorization_scopes" id="@aws-prototyping-sdk/type-safe-api.Authorizer.Initializer.parameter.authorizationScopes"></a>

- *Type:* typing.List[str]

Scopes for the authorizer, if any.

---



#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.Authorizer.property.authorizationType">authorization_type</a></code> | <code>aws_cdk.aws_apigateway.AuthorizationType</code> | The type of the authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.Authorizer.property.authorizerId">authorizer_id</a></code> | <code>str</code> | The unique identifier for the authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.Authorizer.property.authorizationScopes">authorization_scopes</a></code> | <code>typing.List[str]</code> | Scopes for the authorizer, if any. |

---

##### `authorization_type`<sup>Required</sup> <a name="authorization_type" id="@aws-prototyping-sdk/type-safe-api.Authorizer.property.authorizationType"></a>

```python
authorization_type: AuthorizationType
```

- *Type:* aws_cdk.aws_apigateway.AuthorizationType

The type of the authorizer.

---

##### `authorizer_id`<sup>Required</sup> <a name="authorizer_id" id="@aws-prototyping-sdk/type-safe-api.Authorizer.property.authorizerId"></a>

```python
authorizer_id: str
```

- *Type:* str

The unique identifier for the authorizer.

---

##### `authorization_scopes`<sup>Optional</sup> <a name="authorization_scopes" id="@aws-prototyping-sdk/type-safe-api.Authorizer.property.authorizationScopes"></a>

```python
authorization_scopes: typing.List[str]
```

- *Type:* typing.List[str]

Scopes for the authorizer, if any.

---


### Authorizers <a name="Authorizers" id="@aws-prototyping-sdk/type-safe-api.Authorizers"></a>

Class used to construct authorizers for use in the OpenApiGatewayLambdaApi construct.

#### Initializers <a name="Initializers" id="@aws-prototyping-sdk/type-safe-api.Authorizers.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.Authorizers()
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |

---


#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.Authorizers.cognito">cognito</a></code> | A Cognito User Pools authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.Authorizers.custom">custom</a></code> | A custom authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.Authorizers.iam">iam</a></code> | An IAM authorizer which uses AWS signature version 4 to authorize requests. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.Authorizers.none">none</a></code> | No authorizer. |

---

##### `cognito` <a name="cognito" id="@aws-prototyping-sdk/type-safe-api.Authorizers.cognito"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.Authorizers.cognito(
  authorizer_id: str,
  user_pools: typing.List[IUserPool],
  authorization_scopes: typing.List[str] = None
)
```

A Cognito User Pools authorizer.

###### `authorizer_id`<sup>Required</sup> <a name="authorizer_id" id="@aws-prototyping-sdk/type-safe-api.Authorizers.cognito.parameter.authorizerId"></a>

- *Type:* str

Unique identifier for this authorizer.

---

###### `user_pools`<sup>Required</sup> <a name="user_pools" id="@aws-prototyping-sdk/type-safe-api.Authorizers.cognito.parameter.userPools"></a>

- *Type:* typing.List[aws_cdk.aws_cognito.IUserPool]

The Cognito user pools associated with this authorizer.

---

###### `authorization_scopes`<sup>Optional</sup> <a name="authorization_scopes" id="@aws-prototyping-sdk/type-safe-api.Authorizers.cognito.parameter.authorizationScopes"></a>

- *Type:* typing.List[str]
- *Default:* []

A list of authorization scopes configured on the method.

When used as the default authorizer, these scopes will be
applied to all methods without an authorizer at the integration level.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-method.html#cfn-apigateway-method-authorizationscopes](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-method.html#cfn-apigateway-method-authorizationscopes)

---

##### `custom` <a name="custom" id="@aws-prototyping-sdk/type-safe-api.Authorizers.custom"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.Authorizers.custom(
  authorizer_id: str,
  function: IFunction,
  authorizer_result_ttl_in_seconds: typing.Union[int, float] = None,
  identity_source: str = None,
  type: CustomAuthorizerType = None
)
```

A custom authorizer.

###### `authorizer_id`<sup>Required</sup> <a name="authorizer_id" id="@aws-prototyping-sdk/type-safe-api.Authorizers.custom.parameter.authorizerId"></a>

- *Type:* str

Unique identifier for this authorizer.

---

###### `function`<sup>Required</sup> <a name="function" id="@aws-prototyping-sdk/type-safe-api.Authorizers.custom.parameter.function"></a>

- *Type:* aws_cdk.aws_lambda.IFunction

The lambda function used to authorize requests.

---

###### `authorizer_result_ttl_in_seconds`<sup>Optional</sup> <a name="authorizer_result_ttl_in_seconds" id="@aws-prototyping-sdk/type-safe-api.Authorizers.custom.parameter.authorizerResultTtlInSeconds"></a>

- *Type:* typing.Union[int, float]
- *Default:* 300

The number of seconds during which the authorizer result is cached.

---

###### `identity_source`<sup>Optional</sup> <a name="identity_source" id="@aws-prototyping-sdk/type-safe-api.Authorizers.custom.parameter.identitySource"></a>

- *Type:* str
- *Default:* "method.request.header.Authorization"

The source of the identity in an incoming request.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-authorizer.html#cfn-apigateway-authorizer-identitysource](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-authorizer.html#cfn-apigateway-authorizer-identitysource)

---

###### `type`<sup>Optional</sup> <a name="type" id="@aws-prototyping-sdk/type-safe-api.Authorizers.custom.parameter.type"></a>

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizerType">CustomAuthorizerType</a>
- *Default:* CustomAuthorizerType.TOKEN

The type of custom authorizer.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-authorizer.html#cfn-apigateway-authorizer-type](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-authorizer.html#cfn-apigateway-authorizer-type)

---

##### `iam` <a name="iam" id="@aws-prototyping-sdk/type-safe-api.Authorizers.iam"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.Authorizers.iam()
```

An IAM authorizer which uses AWS signature version 4 to authorize requests.

##### `none` <a name="none" id="@aws-prototyping-sdk/type-safe-api.Authorizers.none"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.Authorizers.none()
```

No authorizer.



### CognitoAuthorizer <a name="CognitoAuthorizer" id="@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer"></a>

An authorizer that uses Cognito identity or access tokens.

#### Initializers <a name="Initializers" id="@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.CognitoAuthorizer(
  authorizer_id: str,
  user_pools: typing.List[IUserPool],
  authorization_scopes: typing.List[str] = None
)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer.Initializer.parameter.authorizerId">authorizer_id</a></code> | <code>str</code> | Unique identifier for this authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer.Initializer.parameter.userPools">user_pools</a></code> | <code>typing.List[aws_cdk.aws_cognito.IUserPool]</code> | The Cognito user pools associated with this authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer.Initializer.parameter.authorizationScopes">authorization_scopes</a></code> | <code>typing.List[str]</code> | A list of authorization scopes configured on the method. |

---

##### `authorizer_id`<sup>Required</sup> <a name="authorizer_id" id="@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer.Initializer.parameter.authorizerId"></a>

- *Type:* str

Unique identifier for this authorizer.

---

##### `user_pools`<sup>Required</sup> <a name="user_pools" id="@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer.Initializer.parameter.userPools"></a>

- *Type:* typing.List[aws_cdk.aws_cognito.IUserPool]

The Cognito user pools associated with this authorizer.

---

##### `authorization_scopes`<sup>Optional</sup> <a name="authorization_scopes" id="@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer.Initializer.parameter.authorizationScopes"></a>

- *Type:* typing.List[str]
- *Default:* []

A list of authorization scopes configured on the method.

When used as the default authorizer, these scopes will be
applied to all methods without an authorizer at the integration level.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-method.html#cfn-apigateway-method-authorizationscopes](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-method.html#cfn-apigateway-method-authorizationscopes)

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer.withScopes">with_scopes</a></code> | Returns this authorizer with scopes applied, intended for usage in individual operations where scopes may differ on a per-operation basis. |

---

##### `with_scopes` <a name="with_scopes" id="@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer.withScopes"></a>

```python
def with_scopes(
  authorization_scopes: str
) -> CognitoAuthorizer
```

Returns this authorizer with scopes applied, intended for usage in individual operations where scopes may differ on a per-operation basis.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-method.html#cfn-apigateway-method-authorizationscopes](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-method.html#cfn-apigateway-method-authorizationscopes)

###### `authorization_scopes`<sup>Required</sup> <a name="authorization_scopes" id="@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer.withScopes.parameter.authorizationScopes"></a>

- *Type:* str

the scopes to apply.

---


#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer.property.authorizationType">authorization_type</a></code> | <code>aws_cdk.aws_apigateway.AuthorizationType</code> | The type of the authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer.property.authorizerId">authorizer_id</a></code> | <code>str</code> | The unique identifier for the authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer.property.authorizationScopes">authorization_scopes</a></code> | <code>typing.List[str]</code> | Scopes for the authorizer, if any. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer.property.userPools">user_pools</a></code> | <code>typing.List[aws_cdk.aws_cognito.IUserPool]</code> | The Cognito user pools associated with this authorizer. |

---

##### `authorization_type`<sup>Required</sup> <a name="authorization_type" id="@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer.property.authorizationType"></a>

```python
authorization_type: AuthorizationType
```

- *Type:* aws_cdk.aws_apigateway.AuthorizationType

The type of the authorizer.

---

##### `authorizer_id`<sup>Required</sup> <a name="authorizer_id" id="@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer.property.authorizerId"></a>

```python
authorizer_id: str
```

- *Type:* str

The unique identifier for the authorizer.

---

##### `authorization_scopes`<sup>Optional</sup> <a name="authorization_scopes" id="@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer.property.authorizationScopes"></a>

```python
authorization_scopes: typing.List[str]
```

- *Type:* typing.List[str]

Scopes for the authorizer, if any.

---

##### `user_pools`<sup>Required</sup> <a name="user_pools" id="@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer.property.userPools"></a>

```python
user_pools: typing.List[IUserPool]
```

- *Type:* typing.List[aws_cdk.aws_cognito.IUserPool]

The Cognito user pools associated with this authorizer.

---


### CustomAuthorizer <a name="CustomAuthorizer" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizer"></a>

An authorizer that uses a lambda function to authorize requests.

#### Initializers <a name="Initializers" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.CustomAuthorizer(
  authorizer_id: str,
  function: IFunction,
  authorizer_result_ttl_in_seconds: typing.Union[int, float] = None,
  identity_source: str = None,
  type: CustomAuthorizerType = None
)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.Initializer.parameter.authorizerId">authorizer_id</a></code> | <code>str</code> | Unique identifier for this authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.Initializer.parameter.function">function</a></code> | <code>aws_cdk.aws_lambda.IFunction</code> | The lambda function used to authorize requests. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.Initializer.parameter.authorizerResultTtlInSeconds">authorizer_result_ttl_in_seconds</a></code> | <code>typing.Union[int, float]</code> | The number of seconds during which the authorizer result is cached. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.Initializer.parameter.identitySource">identity_source</a></code> | <code>str</code> | The source of the identity in an incoming request. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.Initializer.parameter.type">type</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizerType">CustomAuthorizerType</a></code> | The type of custom authorizer. |

---

##### `authorizer_id`<sup>Required</sup> <a name="authorizer_id" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.Initializer.parameter.authorizerId"></a>

- *Type:* str

Unique identifier for this authorizer.

---

##### `function`<sup>Required</sup> <a name="function" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.Initializer.parameter.function"></a>

- *Type:* aws_cdk.aws_lambda.IFunction

The lambda function used to authorize requests.

---

##### `authorizer_result_ttl_in_seconds`<sup>Optional</sup> <a name="authorizer_result_ttl_in_seconds" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.Initializer.parameter.authorizerResultTtlInSeconds"></a>

- *Type:* typing.Union[int, float]
- *Default:* 300

The number of seconds during which the authorizer result is cached.

---

##### `identity_source`<sup>Optional</sup> <a name="identity_source" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.Initializer.parameter.identitySource"></a>

- *Type:* str
- *Default:* "method.request.header.Authorization"

The source of the identity in an incoming request.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-authorizer.html#cfn-apigateway-authorizer-identitysource](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-authorizer.html#cfn-apigateway-authorizer-identitysource)

---

##### `type`<sup>Optional</sup> <a name="type" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.Initializer.parameter.type"></a>

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizerType">CustomAuthorizerType</a>
- *Default:* CustomAuthorizerType.TOKEN

The type of custom authorizer.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-authorizer.html#cfn-apigateway-authorizer-type](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-authorizer.html#cfn-apigateway-authorizer-type)

---



#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.property.authorizationType">authorization_type</a></code> | <code>aws_cdk.aws_apigateway.AuthorizationType</code> | The type of the authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.property.authorizerId">authorizer_id</a></code> | <code>str</code> | The unique identifier for the authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.property.authorizationScopes">authorization_scopes</a></code> | <code>typing.List[str]</code> | Scopes for the authorizer, if any. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.property.authorizerResultTtlInSeconds">authorizer_result_ttl_in_seconds</a></code> | <code>typing.Union[int, float]</code> | The number of seconds during which the authorizer result is cached. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.property.function">function</a></code> | <code>aws_cdk.aws_lambda.IFunction</code> | The lambda function used to authorize requests. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.property.identitySource">identity_source</a></code> | <code>str</code> | The source of the identity in an incoming request. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.property.type">type</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizerType">CustomAuthorizerType</a></code> | The type of custom authorizer. |

---

##### `authorization_type`<sup>Required</sup> <a name="authorization_type" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.property.authorizationType"></a>

```python
authorization_type: AuthorizationType
```

- *Type:* aws_cdk.aws_apigateway.AuthorizationType

The type of the authorizer.

---

##### `authorizer_id`<sup>Required</sup> <a name="authorizer_id" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.property.authorizerId"></a>

```python
authorizer_id: str
```

- *Type:* str

The unique identifier for the authorizer.

---

##### `authorization_scopes`<sup>Optional</sup> <a name="authorization_scopes" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.property.authorizationScopes"></a>

```python
authorization_scopes: typing.List[str]
```

- *Type:* typing.List[str]

Scopes for the authorizer, if any.

---

##### `authorizer_result_ttl_in_seconds`<sup>Required</sup> <a name="authorizer_result_ttl_in_seconds" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.property.authorizerResultTtlInSeconds"></a>

```python
authorizer_result_ttl_in_seconds: typing.Union[int, float]
```

- *Type:* typing.Union[int, float]

The number of seconds during which the authorizer result is cached.

---

##### `function`<sup>Required</sup> <a name="function" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.property.function"></a>

```python
function: IFunction
```

- *Type:* aws_cdk.aws_lambda.IFunction

The lambda function used to authorize requests.

---

##### `identity_source`<sup>Required</sup> <a name="identity_source" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.property.identitySource"></a>

```python
identity_source: str
```

- *Type:* str

The source of the identity in an incoming request.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-authorizer.html#cfn-apigateway-authorizer-identitysource](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-authorizer.html#cfn-apigateway-authorizer-identitysource)

---

##### `type`<sup>Required</sup> <a name="type" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.property.type"></a>

```python
type: CustomAuthorizerType
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizerType">CustomAuthorizerType</a>

The type of custom authorizer.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-authorizer.html#cfn-apigateway-authorizer-type](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-authorizer.html#cfn-apigateway-authorizer-type)

---


### IamAuthorizer <a name="IamAuthorizer" id="@aws-prototyping-sdk/type-safe-api.IamAuthorizer"></a>

An IAM authorizer.

#### Initializers <a name="Initializers" id="@aws-prototyping-sdk/type-safe-api.IamAuthorizer.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.IamAuthorizer()
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |

---



#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.IamAuthorizer.property.authorizationType">authorization_type</a></code> | <code>aws_cdk.aws_apigateway.AuthorizationType</code> | The type of the authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.IamAuthorizer.property.authorizerId">authorizer_id</a></code> | <code>str</code> | The unique identifier for the authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.IamAuthorizer.property.authorizationScopes">authorization_scopes</a></code> | <code>typing.List[str]</code> | Scopes for the authorizer, if any. |

---

##### `authorization_type`<sup>Required</sup> <a name="authorization_type" id="@aws-prototyping-sdk/type-safe-api.IamAuthorizer.property.authorizationType"></a>

```python
authorization_type: AuthorizationType
```

- *Type:* aws_cdk.aws_apigateway.AuthorizationType

The type of the authorizer.

---

##### `authorizer_id`<sup>Required</sup> <a name="authorizer_id" id="@aws-prototyping-sdk/type-safe-api.IamAuthorizer.property.authorizerId"></a>

```python
authorizer_id: str
```

- *Type:* str

The unique identifier for the authorizer.

---

##### `authorization_scopes`<sup>Optional</sup> <a name="authorization_scopes" id="@aws-prototyping-sdk/type-safe-api.IamAuthorizer.property.authorizationScopes"></a>

```python
authorization_scopes: typing.List[str]
```

- *Type:* typing.List[str]

Scopes for the authorizer, if any.

---


### Integration <a name="Integration" id="@aws-prototyping-sdk/type-safe-api.Integration"></a>

An integration for an API operation.

You can extend this to implement your own integration if you like.

#### Initializers <a name="Initializers" id="@aws-prototyping-sdk/type-safe-api.Integration.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.Integration()
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.Integration.grant">grant</a></code> | Grant permissions for the API to invoke the integration. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.Integration.render">render</a></code> | Render the integration into an API Gateway OpenAPI extension. |

---

##### `grant` <a name="grant" id="@aws-prototyping-sdk/type-safe-api.Integration.grant"></a>

```python
def grant(
  method: str,
  path: str,
  content_types: typing.List[str] = None,
  api: SpecRestApi,
  operation_id: str,
  scope: Construct
) -> None
```

Grant permissions for the API to invoke the integration.

###### `method`<sup>Required</sup> <a name="method" id="@aws-prototyping-sdk/type-safe-api.Integration.grant.parameter.method"></a>

- *Type:* str

The http method of this operation.

---

###### `path`<sup>Required</sup> <a name="path" id="@aws-prototyping-sdk/type-safe-api.Integration.grant.parameter.path"></a>

- *Type:* str

The path of this operation in the api.

---

###### `content_types`<sup>Optional</sup> <a name="content_types" id="@aws-prototyping-sdk/type-safe-api.Integration.grant.parameter.contentTypes"></a>

- *Type:* typing.List[str]
- *Default:* application/json

Content types accepted by this operation.

---

###### `api`<sup>Required</sup> <a name="api" id="@aws-prototyping-sdk/type-safe-api.Integration.grant.parameter.api"></a>

- *Type:* aws_cdk.aws_apigateway.SpecRestApi

The api to grant permissions for.

---

###### `operation_id`<sup>Required</sup> <a name="operation_id" id="@aws-prototyping-sdk/type-safe-api.Integration.grant.parameter.operationId"></a>

- *Type:* str

The ID of the operation for which permissions are being granted.

---

###### `scope`<sup>Required</sup> <a name="scope" id="@aws-prototyping-sdk/type-safe-api.Integration.grant.parameter.scope"></a>

- *Type:* constructs.Construct

The scope in which permission resources can be created.

---

##### `render` <a name="render" id="@aws-prototyping-sdk/type-safe-api.Integration.render"></a>

```python
def render(
  method: str,
  path: str,
  content_types: typing.List[str] = None,
  operation_id: str,
  scope: Construct,
  cors_options: SerializedCorsOptions = None
) -> ApiGatewayIntegration
```

Render the integration into an API Gateway OpenAPI extension.

###### `method`<sup>Required</sup> <a name="method" id="@aws-prototyping-sdk/type-safe-api.Integration.render.parameter.method"></a>

- *Type:* str

The http method of this operation.

---

###### `path`<sup>Required</sup> <a name="path" id="@aws-prototyping-sdk/type-safe-api.Integration.render.parameter.path"></a>

- *Type:* str

The path of this operation in the api.

---

###### `content_types`<sup>Optional</sup> <a name="content_types" id="@aws-prototyping-sdk/type-safe-api.Integration.render.parameter.contentTypes"></a>

- *Type:* typing.List[str]
- *Default:* application/json

Content types accepted by this operation.

---

###### `operation_id`<sup>Required</sup> <a name="operation_id" id="@aws-prototyping-sdk/type-safe-api.Integration.render.parameter.operationId"></a>

- *Type:* str

The ID of the operation being rendered.

---

###### `scope`<sup>Required</sup> <a name="scope" id="@aws-prototyping-sdk/type-safe-api.Integration.render.parameter.scope"></a>

- *Type:* constructs.Construct

The scope in which the integration is being rendered.

---

###### `cors_options`<sup>Optional</sup> <a name="cors_options" id="@aws-prototyping-sdk/type-safe-api.Integration.render.parameter.corsOptions"></a>

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.SerializedCorsOptions">SerializedCorsOptions</a>

Cross Origin Resource Sharing options for the API.

---




### Integrations <a name="Integrations" id="@aws-prototyping-sdk/type-safe-api.Integrations"></a>

A collection of integrations to connect API operations with a backend to service requests.

#### Initializers <a name="Initializers" id="@aws-prototyping-sdk/type-safe-api.Integrations.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.Integrations()
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |

---


#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.Integrations.lambda">lambda</a></code> | An integration that invokes a lambda function to service the request. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.Integrations.mock">mock</a></code> | An integration that returns a hardcoded response. |

---

##### `lambda` <a name="lambda" id="@aws-prototyping-sdk/type-safe-api.Integrations.lambda"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.Integrations.lambda(
  lambda_function: IFunction
)
```

An integration that invokes a lambda function to service the request.

###### `lambda_function`<sup>Required</sup> <a name="lambda_function" id="@aws-prototyping-sdk/type-safe-api.Integrations.lambda.parameter.lambdaFunction"></a>

- *Type:* aws_cdk.aws_lambda.IFunction

the function to invoke.

---

##### `mock` <a name="mock" id="@aws-prototyping-sdk/type-safe-api.Integrations.mock"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.Integrations.mock(
  status_code: typing.Union[int, float],
  body: str = None
)
```

An integration that returns a hardcoded response.

###### `status_code`<sup>Required</sup> <a name="status_code" id="@aws-prototyping-sdk/type-safe-api.Integrations.mock.parameter.statusCode"></a>

- *Type:* typing.Union[int, float]

HTTP response status code.

---

###### `body`<sup>Optional</sup> <a name="body" id="@aws-prototyping-sdk/type-safe-api.Integrations.mock.parameter.body"></a>

- *Type:* str

Response body.

---



### LambdaIntegration <a name="LambdaIntegration" id="@aws-prototyping-sdk/type-safe-api.LambdaIntegration"></a>

A lambda integration.

#### Initializers <a name="Initializers" id="@aws-prototyping-sdk/type-safe-api.LambdaIntegration.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.LambdaIntegration(
  lambda_function: IFunction
)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.LambdaIntegration.Initializer.parameter.lambdaFunction">lambda_function</a></code> | <code>aws_cdk.aws_lambda.IFunction</code> | *No description.* |

---

##### `lambda_function`<sup>Required</sup> <a name="lambda_function" id="@aws-prototyping-sdk/type-safe-api.LambdaIntegration.Initializer.parameter.lambdaFunction"></a>

- *Type:* aws_cdk.aws_lambda.IFunction

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.LambdaIntegration.grant">grant</a></code> | Grant API Gateway permissions to invoke the lambda. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.LambdaIntegration.render">render</a></code> | Render the lambda integration as a snippet of OpenAPI. |

---

##### `grant` <a name="grant" id="@aws-prototyping-sdk/type-safe-api.LambdaIntegration.grant"></a>

```python
def grant(
  method: str,
  path: str,
  content_types: typing.List[str] = None,
  api: SpecRestApi,
  operation_id: str,
  scope: Construct
) -> None
```

Grant API Gateway permissions to invoke the lambda.

###### `method`<sup>Required</sup> <a name="method" id="@aws-prototyping-sdk/type-safe-api.LambdaIntegration.grant.parameter.method"></a>

- *Type:* str

The http method of this operation.

---

###### `path`<sup>Required</sup> <a name="path" id="@aws-prototyping-sdk/type-safe-api.LambdaIntegration.grant.parameter.path"></a>

- *Type:* str

The path of this operation in the api.

---

###### `content_types`<sup>Optional</sup> <a name="content_types" id="@aws-prototyping-sdk/type-safe-api.LambdaIntegration.grant.parameter.contentTypes"></a>

- *Type:* typing.List[str]
- *Default:* application/json

Content types accepted by this operation.

---

###### `api`<sup>Required</sup> <a name="api" id="@aws-prototyping-sdk/type-safe-api.LambdaIntegration.grant.parameter.api"></a>

- *Type:* aws_cdk.aws_apigateway.SpecRestApi

The api to grant permissions for.

---

###### `operation_id`<sup>Required</sup> <a name="operation_id" id="@aws-prototyping-sdk/type-safe-api.LambdaIntegration.grant.parameter.operationId"></a>

- *Type:* str

The ID of the operation for which permissions are being granted.

---

###### `scope`<sup>Required</sup> <a name="scope" id="@aws-prototyping-sdk/type-safe-api.LambdaIntegration.grant.parameter.scope"></a>

- *Type:* constructs.Construct

The scope in which permission resources can be created.

---

##### `render` <a name="render" id="@aws-prototyping-sdk/type-safe-api.LambdaIntegration.render"></a>

```python
def render(
  method: str,
  path: str,
  content_types: typing.List[str] = None,
  operation_id: str,
  scope: Construct,
  cors_options: SerializedCorsOptions = None
) -> ApiGatewayIntegration
```

Render the lambda integration as a snippet of OpenAPI.

###### `method`<sup>Required</sup> <a name="method" id="@aws-prototyping-sdk/type-safe-api.LambdaIntegration.render.parameter.method"></a>

- *Type:* str

The http method of this operation.

---

###### `path`<sup>Required</sup> <a name="path" id="@aws-prototyping-sdk/type-safe-api.LambdaIntegration.render.parameter.path"></a>

- *Type:* str

The path of this operation in the api.

---

###### `content_types`<sup>Optional</sup> <a name="content_types" id="@aws-prototyping-sdk/type-safe-api.LambdaIntegration.render.parameter.contentTypes"></a>

- *Type:* typing.List[str]
- *Default:* application/json

Content types accepted by this operation.

---

###### `operation_id`<sup>Required</sup> <a name="operation_id" id="@aws-prototyping-sdk/type-safe-api.LambdaIntegration.render.parameter.operationId"></a>

- *Type:* str

The ID of the operation being rendered.

---

###### `scope`<sup>Required</sup> <a name="scope" id="@aws-prototyping-sdk/type-safe-api.LambdaIntegration.render.parameter.scope"></a>

- *Type:* constructs.Construct

The scope in which the integration is being rendered.

---

###### `cors_options`<sup>Optional</sup> <a name="cors_options" id="@aws-prototyping-sdk/type-safe-api.LambdaIntegration.render.parameter.corsOptions"></a>

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.SerializedCorsOptions">SerializedCorsOptions</a>

Cross Origin Resource Sharing options for the API.

---




### MockIntegration <a name="MockIntegration" id="@aws-prototyping-sdk/type-safe-api.MockIntegration"></a>

A mock integration to return a hardcoded response.

> [https://docs.aws.amazon.com/apigateway/latest/developerguide/how-to-mock-integration.html](https://docs.aws.amazon.com/apigateway/latest/developerguide/how-to-mock-integration.html)

#### Initializers <a name="Initializers" id="@aws-prototyping-sdk/type-safe-api.MockIntegration.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.MockIntegration(
  status_code: typing.Union[int, float],
  body: str = None
)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.MockIntegration.Initializer.parameter.statusCode">status_code</a></code> | <code>typing.Union[int, float]</code> | HTTP response status code. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.MockIntegration.Initializer.parameter.body">body</a></code> | <code>str</code> | Response body. |

---

##### `status_code`<sup>Required</sup> <a name="status_code" id="@aws-prototyping-sdk/type-safe-api.MockIntegration.Initializer.parameter.statusCode"></a>

- *Type:* typing.Union[int, float]

HTTP response status code.

---

##### `body`<sup>Optional</sup> <a name="body" id="@aws-prototyping-sdk/type-safe-api.MockIntegration.Initializer.parameter.body"></a>

- *Type:* str

Response body.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.MockIntegration.grant">grant</a></code> | Grant permissions for the API to invoke the integration. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.MockIntegration.render">render</a></code> | Render the integration into an API Gateway OpenAPI extension. |

---

##### `grant` <a name="grant" id="@aws-prototyping-sdk/type-safe-api.MockIntegration.grant"></a>

```python
def grant(
  method: str,
  path: str,
  content_types: typing.List[str] = None,
  api: SpecRestApi,
  operation_id: str,
  scope: Construct
) -> None
```

Grant permissions for the API to invoke the integration.

###### `method`<sup>Required</sup> <a name="method" id="@aws-prototyping-sdk/type-safe-api.MockIntegration.grant.parameter.method"></a>

- *Type:* str

The http method of this operation.

---

###### `path`<sup>Required</sup> <a name="path" id="@aws-prototyping-sdk/type-safe-api.MockIntegration.grant.parameter.path"></a>

- *Type:* str

The path of this operation in the api.

---

###### `content_types`<sup>Optional</sup> <a name="content_types" id="@aws-prototyping-sdk/type-safe-api.MockIntegration.grant.parameter.contentTypes"></a>

- *Type:* typing.List[str]
- *Default:* application/json

Content types accepted by this operation.

---

###### `api`<sup>Required</sup> <a name="api" id="@aws-prototyping-sdk/type-safe-api.MockIntegration.grant.parameter.api"></a>

- *Type:* aws_cdk.aws_apigateway.SpecRestApi

The api to grant permissions for.

---

###### `operation_id`<sup>Required</sup> <a name="operation_id" id="@aws-prototyping-sdk/type-safe-api.MockIntegration.grant.parameter.operationId"></a>

- *Type:* str

The ID of the operation for which permissions are being granted.

---

###### `scope`<sup>Required</sup> <a name="scope" id="@aws-prototyping-sdk/type-safe-api.MockIntegration.grant.parameter.scope"></a>

- *Type:* constructs.Construct

The scope in which permission resources can be created.

---

##### `render` <a name="render" id="@aws-prototyping-sdk/type-safe-api.MockIntegration.render"></a>

```python
def render(
  method: str,
  path: str,
  content_types: typing.List[str] = None,
  operation_id: str,
  scope: Construct,
  cors_options: SerializedCorsOptions = None
) -> ApiGatewayIntegration
```

Render the integration into an API Gateway OpenAPI extension.

###### `method`<sup>Required</sup> <a name="method" id="@aws-prototyping-sdk/type-safe-api.MockIntegration.render.parameter.method"></a>

- *Type:* str

The http method of this operation.

---

###### `path`<sup>Required</sup> <a name="path" id="@aws-prototyping-sdk/type-safe-api.MockIntegration.render.parameter.path"></a>

- *Type:* str

The path of this operation in the api.

---

###### `content_types`<sup>Optional</sup> <a name="content_types" id="@aws-prototyping-sdk/type-safe-api.MockIntegration.render.parameter.contentTypes"></a>

- *Type:* typing.List[str]
- *Default:* application/json

Content types accepted by this operation.

---

###### `operation_id`<sup>Required</sup> <a name="operation_id" id="@aws-prototyping-sdk/type-safe-api.MockIntegration.render.parameter.operationId"></a>

- *Type:* str

The ID of the operation being rendered.

---

###### `scope`<sup>Required</sup> <a name="scope" id="@aws-prototyping-sdk/type-safe-api.MockIntegration.render.parameter.scope"></a>

- *Type:* constructs.Construct

The scope in which the integration is being rendered.

---

###### `cors_options`<sup>Optional</sup> <a name="cors_options" id="@aws-prototyping-sdk/type-safe-api.MockIntegration.render.parameter.corsOptions"></a>

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.SerializedCorsOptions">SerializedCorsOptions</a>

Cross Origin Resource Sharing options for the API.

---




### NoneAuthorizer <a name="NoneAuthorizer" id="@aws-prototyping-sdk/type-safe-api.NoneAuthorizer"></a>

No authorizer.

#### Initializers <a name="Initializers" id="@aws-prototyping-sdk/type-safe-api.NoneAuthorizer.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.NoneAuthorizer()
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |

---



#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.NoneAuthorizer.property.authorizationType">authorization_type</a></code> | <code>aws_cdk.aws_apigateway.AuthorizationType</code> | The type of the authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.NoneAuthorizer.property.authorizerId">authorizer_id</a></code> | <code>str</code> | The unique identifier for the authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.NoneAuthorizer.property.authorizationScopes">authorization_scopes</a></code> | <code>typing.List[str]</code> | Scopes for the authorizer, if any. |

---

##### `authorization_type`<sup>Required</sup> <a name="authorization_type" id="@aws-prototyping-sdk/type-safe-api.NoneAuthorizer.property.authorizationType"></a>

```python
authorization_type: AuthorizationType
```

- *Type:* aws_cdk.aws_apigateway.AuthorizationType

The type of the authorizer.

---

##### `authorizer_id`<sup>Required</sup> <a name="authorizer_id" id="@aws-prototyping-sdk/type-safe-api.NoneAuthorizer.property.authorizerId"></a>

```python
authorizer_id: str
```

- *Type:* str

The unique identifier for the authorizer.

---

##### `authorization_scopes`<sup>Optional</sup> <a name="authorization_scopes" id="@aws-prototyping-sdk/type-safe-api.NoneAuthorizer.property.authorizationScopes"></a>

```python
authorization_scopes: typing.List[str]
```

- *Type:* typing.List[str]

Scopes for the authorizer, if any.

---


### OpenApiDefinition <a name="OpenApiDefinition" id="@aws-prototyping-sdk/type-safe-api.OpenApiDefinition"></a>

The OpenAPI Spec.

#### Initializers <a name="Initializers" id="@aws-prototyping-sdk/type-safe-api.OpenApiDefinition.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.OpenApiDefinition(
  project: TypeSafeApiModelProject,
  open_api_options: OpenApiModelOptions
)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiDefinition.Initializer.parameter.project">project</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject">TypeSafeApiModelProject</a></code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiDefinition.Initializer.parameter.openApiOptions">open_api_options</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiModelOptions">OpenApiModelOptions</a></code> | Options for the openapi model. |

---

##### `project`<sup>Required</sup> <a name="project" id="@aws-prototyping-sdk/type-safe-api.OpenApiDefinition.Initializer.parameter.project"></a>

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject">TypeSafeApiModelProject</a>

---

##### `open_api_options`<sup>Required</sup> <a name="open_api_options" id="@aws-prototyping-sdk/type-safe-api.OpenApiDefinition.Initializer.parameter.openApiOptions"></a>

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.OpenApiModelOptions">OpenApiModelOptions</a>

Options for the openapi model.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiDefinition.postSynthesize">post_synthesize</a></code> | Called after synthesis. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiDefinition.preSynthesize">pre_synthesize</a></code> | Called before synthesis. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiDefinition.synthesize">synthesize</a></code> | Synthesizes files to the project output directory. |

---

##### `post_synthesize` <a name="post_synthesize" id="@aws-prototyping-sdk/type-safe-api.OpenApiDefinition.postSynthesize"></a>

```python
def post_synthesize() -> None
```

Called after synthesis.

Order is *not* guaranteed.

##### `pre_synthesize` <a name="pre_synthesize" id="@aws-prototyping-sdk/type-safe-api.OpenApiDefinition.preSynthesize"></a>

```python
def pre_synthesize() -> None
```

Called before synthesis.

##### `synthesize` <a name="synthesize" id="@aws-prototyping-sdk/type-safe-api.OpenApiDefinition.synthesize"></a>

```python
def synthesize() -> None
```

Synthesizes files to the project output directory.


#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiDefinition.property.project">project</a></code> | <code>projen.Project</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiDefinition.property.openApiSpecificationPath">open_api_specification_path</a></code> | <code>str</code> | Path to the root OpenAPI specification file. |

---

##### `project`<sup>Required</sup> <a name="project" id="@aws-prototyping-sdk/type-safe-api.OpenApiDefinition.property.project"></a>

```python
project: Project
```

- *Type:* projen.Project

---

##### `open_api_specification_path`<sup>Required</sup> <a name="open_api_specification_path" id="@aws-prototyping-sdk/type-safe-api.OpenApiDefinition.property.openApiSpecificationPath"></a>

```python
open_api_specification_path: str
```

- *Type:* str

Path to the root OpenAPI specification file.

---


### SmithyDefinition <a name="SmithyDefinition" id="@aws-prototyping-sdk/type-safe-api.SmithyDefinition"></a>

Creates a project which transforms a Smithy model to OpenAPI.

#### Initializers <a name="Initializers" id="@aws-prototyping-sdk/type-safe-api.SmithyDefinition.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.SmithyDefinition(
  project: TypeSafeApiModelProject,
  smithy_options: SmithyModelOptions
)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyDefinition.Initializer.parameter.project">project</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject">TypeSafeApiModelProject</a></code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyDefinition.Initializer.parameter.smithyOptions">smithy_options</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyModelOptions">SmithyModelOptions</a></code> | Smithy engine options. |

---

##### `project`<sup>Required</sup> <a name="project" id="@aws-prototyping-sdk/type-safe-api.SmithyDefinition.Initializer.parameter.project"></a>

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject">TypeSafeApiModelProject</a>

---

##### `smithy_options`<sup>Required</sup> <a name="smithy_options" id="@aws-prototyping-sdk/type-safe-api.SmithyDefinition.Initializer.parameter.smithyOptions"></a>

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.SmithyModelOptions">SmithyModelOptions</a>

Smithy engine options.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyDefinition.postSynthesize">post_synthesize</a></code> | Called after synthesis. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyDefinition.preSynthesize">pre_synthesize</a></code> | Called before synthesis. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyDefinition.synthesize">synthesize</a></code> | Synthesizes files to the project output directory. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyDefinition.addDeps">add_deps</a></code> | Add maven-style or local file dependencies to the smithy model project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyDefinition.addSmithyDeps">add_smithy_deps</a></code> | Add dependencies on other smithy models, such that their shapes can be imported in this project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyDefinition.addSources">add_sources</a></code> | Add additional paths to model source files or directories. |

---

##### `post_synthesize` <a name="post_synthesize" id="@aws-prototyping-sdk/type-safe-api.SmithyDefinition.postSynthesize"></a>

```python
def post_synthesize() -> None
```

Called after synthesis.

Order is *not* guaranteed.

##### `pre_synthesize` <a name="pre_synthesize" id="@aws-prototyping-sdk/type-safe-api.SmithyDefinition.preSynthesize"></a>

```python
def pre_synthesize() -> None
```

Called before synthesis.

##### `synthesize` <a name="synthesize" id="@aws-prototyping-sdk/type-safe-api.SmithyDefinition.synthesize"></a>

```python
def synthesize() -> None
```

Synthesizes files to the project output directory.

##### `add_deps` <a name="add_deps" id="@aws-prototyping-sdk/type-safe-api.SmithyDefinition.addDeps"></a>

```python
def add_deps(
  deps: str
) -> None
```

Add maven-style or local file dependencies to the smithy model project.

###### `deps`<sup>Required</sup> <a name="deps" id="@aws-prototyping-sdk/type-safe-api.SmithyDefinition.addDeps.parameter.deps"></a>

- *Type:* str

dependencies to add, eg "software.amazon.smithy:smithy-validation-model:1.27.2" or "file://../some/path/build/lib/my-shapes.jar.

---

##### `add_smithy_deps` <a name="add_smithy_deps" id="@aws-prototyping-sdk/type-safe-api.SmithyDefinition.addSmithyDeps"></a>

```python
def add_smithy_deps(
  deps: SmithyDefinition
) -> None
```

Add dependencies on other smithy models, such that their shapes can be imported in this project.

###### `deps`<sup>Required</sup> <a name="deps" id="@aws-prototyping-sdk/type-safe-api.SmithyDefinition.addSmithyDeps.parameter.deps"></a>

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.SmithyDefinition">SmithyDefinition</a>

smithy definitions to depend on.

---

##### `add_sources` <a name="add_sources" id="@aws-prototyping-sdk/type-safe-api.SmithyDefinition.addSources"></a>

```python
def add_sources(
  sources: str
) -> None
```

Add additional paths to model source files or directories.

Paths should be relative to the project outdir. Any absolute paths will be
resolved as relative paths.

###### `sources`<sup>Required</sup> <a name="sources" id="@aws-prototyping-sdk/type-safe-api.SmithyDefinition.addSources.parameter.sources"></a>

- *Type:* str

---


#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyDefinition.property.project">project</a></code> | <code>projen.Project</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyDefinition.property.gradleProjectName">gradle_project_name</a></code> | <code>str</code> | Name of the gradle project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyDefinition.property.openApiSpecificationPath">open_api_specification_path</a></code> | <code>str</code> | Path to the generated OpenAPI specification, relative to the project outdir. |

---

##### `project`<sup>Required</sup> <a name="project" id="@aws-prototyping-sdk/type-safe-api.SmithyDefinition.property.project"></a>

```python
project: Project
```

- *Type:* projen.Project

---

##### `gradle_project_name`<sup>Required</sup> <a name="gradle_project_name" id="@aws-prototyping-sdk/type-safe-api.SmithyDefinition.property.gradleProjectName"></a>

```python
gradle_project_name: str
```

- *Type:* str

Name of the gradle project.

---

##### `open_api_specification_path`<sup>Required</sup> <a name="open_api_specification_path" id="@aws-prototyping-sdk/type-safe-api.SmithyDefinition.property.openApiSpecificationPath"></a>

```python
open_api_specification_path: str
```

- *Type:* str

Path to the generated OpenAPI specification, relative to the project outdir.

---


### TypeSafeApiModelProject <a name="TypeSafeApiModelProject" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject"></a>

#### Initializers <a name="Initializers" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.TypeSafeApiModelProject(
  name: str,
  commit_generated: bool = None,
  git_ignore_options: IgnoreFileOptions = None,
  git_options: GitOptions = None,
  logging: LoggerOptions = None,
  outdir: str = None,
  parent: Project = None,
  projen_command: str = None,
  projenrc_json: bool = None,
  projenrc_json_options: ProjenrcJsonOptions = None,
  renovatebot: bool = None,
  renovatebot_options: RenovatebotOptions = None,
  model_language: ModelLanguage,
  model_options: ModelOptions
)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.name">name</a></code> | <code>str</code> | This is the name of your project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.commitGenerated">commit_generated</a></code> | <code>bool</code> | Whether to commit the managed files by default. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.gitIgnoreOptions">git_ignore_options</a></code> | <code>projen.IgnoreFileOptions</code> | Configuration options for .gitignore file. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.gitOptions">git_options</a></code> | <code>projen.GitOptions</code> | Configuration options for git. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.logging">logging</a></code> | <code>projen.LoggerOptions</code> | Configure logging options such as verbosity. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.outdir">outdir</a></code> | <code>str</code> | The root directory of the project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.parent">parent</a></code> | <code>projen.Project</code> | The parent project, if this project is part of a bigger project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.projenCommand">projen_command</a></code> | <code>str</code> | The shell command to use in order to run the projen CLI. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.projenrcJson">projenrc_json</a></code> | <code>bool</code> | Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.projenrcJsonOptions">projenrc_json_options</a></code> | <code>projen.ProjenrcJsonOptions</code> | Options for .projenrc.json. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.renovatebot">renovatebot</a></code> | <code>bool</code> | Use renovatebot to handle dependency upgrades. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.renovatebotOptions">renovatebot_options</a></code> | <code>projen.RenovatebotOptions</code> | Options for renovatebot. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.modelLanguage">model_language</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.ModelLanguage">ModelLanguage</a></code> | Language the model is defined in. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.modelOptions">model_options</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.ModelOptions">ModelOptions</a></code> | Options for the model. |

---

##### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.name"></a>

- *Type:* str
- *Default:* $BASEDIR

This is the name of your project.

---

##### `commit_generated`<sup>Optional</sup> <a name="commit_generated" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.commitGenerated"></a>

- *Type:* bool
- *Default:* true

Whether to commit the managed files by default.

---

##### `git_ignore_options`<sup>Optional</sup> <a name="git_ignore_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.gitIgnoreOptions"></a>

- *Type:* projen.IgnoreFileOptions

Configuration options for .gitignore file.

---

##### `git_options`<sup>Optional</sup> <a name="git_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.gitOptions"></a>

- *Type:* projen.GitOptions

Configuration options for git.

---

##### `logging`<sup>Optional</sup> <a name="logging" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.logging"></a>

- *Type:* projen.LoggerOptions
- *Default:* {}

Configure logging options such as verbosity.

---

##### `outdir`<sup>Optional</sup> <a name="outdir" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.outdir"></a>

- *Type:* str
- *Default:* "."

The root directory of the project.

Relative to this directory, all files are synthesized.

If this project has a parent, this directory is relative to the parent
directory and it cannot be the same as the parent or any of it's other
sub-projects.

---

##### `parent`<sup>Optional</sup> <a name="parent" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.parent"></a>

- *Type:* projen.Project

The parent project, if this project is part of a bigger project.

---

##### `projen_command`<sup>Optional</sup> <a name="projen_command" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.projenCommand"></a>

- *Type:* str
- *Default:* "npx projen"

The shell command to use in order to run the projen CLI.

Can be used to customize in special environments.

---

##### `projenrc_json`<sup>Optional</sup> <a name="projenrc_json" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.projenrcJson"></a>

- *Type:* bool
- *Default:* false

Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation.

---

##### `projenrc_json_options`<sup>Optional</sup> <a name="projenrc_json_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.projenrcJsonOptions"></a>

- *Type:* projen.ProjenrcJsonOptions
- *Default:* default options

Options for .projenrc.json.

---

##### `renovatebot`<sup>Optional</sup> <a name="renovatebot" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.renovatebot"></a>

- *Type:* bool
- *Default:* false

Use renovatebot to handle dependency upgrades.

---

##### `renovatebot_options`<sup>Optional</sup> <a name="renovatebot_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.renovatebotOptions"></a>

- *Type:* projen.RenovatebotOptions
- *Default:* default options

Options for renovatebot.

---

##### `model_language`<sup>Required</sup> <a name="model_language" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.modelLanguage"></a>

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.ModelLanguage">ModelLanguage</a>

Language the model is defined in.

---

##### `model_options`<sup>Required</sup> <a name="model_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.modelOptions"></a>

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.ModelOptions">ModelOptions</a>

Options for the model.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addExcludeFromCleanup">add_exclude_from_cleanup</a></code> | Exclude the matching files from pre-synth cleanup. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addGitIgnore">add_git_ignore</a></code> | Adds a .gitignore pattern. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addPackageIgnore">add_package_ignore</a></code> | Exclude these files from the bundled package. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addTask">add_task</a></code> | Adds a new task to this project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addTip">add_tip</a></code> | Prints a "tip" message during synthesis. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.annotateGenerated">annotate_generated</a></code> | Consider a set of files as "generated". |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.postSynthesize">post_synthesize</a></code> | Called after all components are synthesized. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.preSynthesize">pre_synthesize</a></code> | Called before all components are synthesized. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.removeTask">remove_task</a></code> | Removes a task from a project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.runTaskCommand">run_task_command</a></code> | Returns the shell command to execute in order to run a task. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.synth">synth</a></code> | Synthesize all project files into `outdir`. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.tryFindFile">try_find_file</a></code> | Finds a file at the specified relative path within this project and all its subprojects. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.tryFindJsonFile">try_find_json_file</a></code> | Finds a json file by name. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.tryFindObjectFile">try_find_object_file</a></code> | Finds an object file (like JsonFile, YamlFile, etc.) by name. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.tryRemoveFile">try_remove_file</a></code> | Finds a file at the specified relative path within this project and removes it. |

---

##### `add_exclude_from_cleanup` <a name="add_exclude_from_cleanup" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addExcludeFromCleanup"></a>

```python
def add_exclude_from_cleanup(
  globs: str
) -> None
```

Exclude the matching files from pre-synth cleanup.

Can be used when, for example, some
source files include the projen marker and we don't want them to be erased during synth.

###### `globs`<sup>Required</sup> <a name="globs" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addExcludeFromCleanup.parameter.globs"></a>

- *Type:* str

The glob patterns to match.

---

##### `add_git_ignore` <a name="add_git_ignore" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addGitIgnore"></a>

```python
def add_git_ignore(
  pattern: str
) -> None
```

Adds a .gitignore pattern.

###### `pattern`<sup>Required</sup> <a name="pattern" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addGitIgnore.parameter.pattern"></a>

- *Type:* str

The glob pattern to ignore.

---

##### `add_package_ignore` <a name="add_package_ignore" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addPackageIgnore"></a>

```python
def add_package_ignore(
  _pattern: str
) -> None
```

Exclude these files from the bundled package.

Implemented by project types based on the
packaging mechanism. For example, `NodeProject` delegates this to `.npmignore`.

###### `_pattern`<sup>Required</sup> <a name="_pattern" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addPackageIgnore.parameter._pattern"></a>

- *Type:* str

The glob pattern to exclude.

---

##### `add_task` <a name="add_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addTask"></a>

```python
def add_task(
  name: str,
  condition: str = None,
  cwd: str = None,
  description: str = None,
  env: typing.Mapping[str] = None,
  required_env: typing.List[str] = None,
  args: typing.List[str] = None,
  exec: str = None,
  receive_args: bool = None,
  steps: typing.List[TaskStep] = None
) -> Task
```

Adds a new task to this project.

This will fail if the project already has
a task with this name.

###### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addTask.parameter.name"></a>

- *Type:* str

The task name to add.

---

###### `condition`<sup>Optional</sup> <a name="condition" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addTask.parameter.condition"></a>

- *Type:* str

A shell command which determines if the this task should be executed.

If
the program exits with a zero exit code, steps will be executed. A non-zero
code means that task will be skipped.

---

###### `cwd`<sup>Optional</sup> <a name="cwd" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addTask.parameter.cwd"></a>

- *Type:* str
- *Default:* process.cwd()

The working directory for all steps in this task (unless overridden by the step).

---

###### `description`<sup>Optional</sup> <a name="description" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addTask.parameter.description"></a>

- *Type:* str
- *Default:* the task name

The description of this build command.

---

###### `env`<sup>Optional</sup> <a name="env" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addTask.parameter.env"></a>

- *Type:* typing.Mapping[str]
- *Default:* {}

Defines environment variables for the execution of this task.

Values in this map will be evaluated in a shell, so you can do stuff like `$(echo "foo")`.

---

###### `required_env`<sup>Optional</sup> <a name="required_env" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addTask.parameter.requiredEnv"></a>

- *Type:* typing.List[str]

A set of environment variables that must be defined in order to execute this task.

Task execution will fail if one of these is not defined.

---

###### `args`<sup>Optional</sup> <a name="args" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addTask.parameter.args"></a>

- *Type:* typing.List[str]
- *Default:* no arguments are passed to the step

Should the provided `exec` shell command receive fixed args.

> [{@link TaskStepOptions.args }]({@link TaskStepOptions.args })

---

###### `exec`<sup>Optional</sup> <a name="exec" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addTask.parameter.exec"></a>

- *Type:* str
- *Default:* add steps using `task.exec(command)` or `task.spawn(subtask)`

Shell command to execute as the first command of the task.

---

###### `receive_args`<sup>Optional</sup> <a name="receive_args" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addTask.parameter.receiveArgs"></a>

- *Type:* bool
- *Default:* false

Should the provided `exec` shell command receive args passed to the task.

> [{@link TaskStepOptions.receiveArgs }]({@link TaskStepOptions.receiveArgs })

---

###### `steps`<sup>Optional</sup> <a name="steps" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addTask.parameter.steps"></a>

- *Type:* typing.List[projen.TaskStep]

List of task steps to run.

---

##### ~~`add_tip`~~ <a name="add_tip" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addTip"></a>

```python
def add_tip(
  message: str
) -> None
```

Prints a "tip" message during synthesis.

###### `message`<sup>Required</sup> <a name="message" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addTip.parameter.message"></a>

- *Type:* str

The message.

---

##### `annotate_generated` <a name="annotate_generated" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.annotateGenerated"></a>

```python
def annotate_generated(
  _glob: str
) -> None
```

Consider a set of files as "generated".

This method is implemented by
derived classes and used for example, to add git attributes to tell GitHub
that certain files are generated.

###### `_glob`<sup>Required</sup> <a name="_glob" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.annotateGenerated.parameter._glob"></a>

- *Type:* str

the glob pattern to match (could be a file path).

---

##### `post_synthesize` <a name="post_synthesize" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.postSynthesize"></a>

```python
def post_synthesize() -> None
```

Called after all components are synthesized.

Order is *not* guaranteed.

##### `pre_synthesize` <a name="pre_synthesize" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.preSynthesize"></a>

```python
def pre_synthesize() -> None
```

Called before all components are synthesized.

##### `remove_task` <a name="remove_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.removeTask"></a>

```python
def remove_task(
  name: str
) -> Task
```

Removes a task from a project.

###### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.removeTask.parameter.name"></a>

- *Type:* str

The name of the task to remove.

---

##### `run_task_command` <a name="run_task_command" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.runTaskCommand"></a>

```python
def run_task_command(
  task: Task
) -> str
```

Returns the shell command to execute in order to run a task.

By default, this is `npx projen@<version> <task>`

###### `task`<sup>Required</sup> <a name="task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.runTaskCommand.parameter.task"></a>

- *Type:* projen.Task

The task for which the command is required.

---

##### `synth` <a name="synth" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.synth"></a>

```python
def synth() -> None
```

Synthesize all project files into `outdir`.

1. Call "this.preSynthesize()"
2. Delete all generated files
3. Synthesize all sub-projects
4. Synthesize all components of this project
5. Call "postSynthesize()" for all components of this project
6. Call "this.postSynthesize()"

##### `try_find_file` <a name="try_find_file" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.tryFindFile"></a>

```python
def try_find_file(
  file_path: str
) -> FileBase
```

Finds a file at the specified relative path within this project and all its subprojects.

###### `file_path`<sup>Required</sup> <a name="file_path" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.tryFindFile.parameter.filePath"></a>

- *Type:* str

The file path.

If this path is relative, it will be resolved
from the root of _this_ project.

---

##### ~~`try_find_json_file`~~ <a name="try_find_json_file" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.tryFindJsonFile"></a>

```python
def try_find_json_file(
  file_path: str
) -> JsonFile
```

Finds a json file by name.

###### `file_path`<sup>Required</sup> <a name="file_path" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.tryFindJsonFile.parameter.filePath"></a>

- *Type:* str

The file path.

---

##### `try_find_object_file` <a name="try_find_object_file" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.tryFindObjectFile"></a>

```python
def try_find_object_file(
  file_path: str
) -> ObjectFile
```

Finds an object file (like JsonFile, YamlFile, etc.) by name.

###### `file_path`<sup>Required</sup> <a name="file_path" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.tryFindObjectFile.parameter.filePath"></a>

- *Type:* str

The file path.

---

##### `try_remove_file` <a name="try_remove_file" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.tryRemoveFile"></a>

```python
def try_remove_file(
  file_path: str
) -> FileBase
```

Finds a file at the specified relative path within this project and removes it.

###### `file_path`<sup>Required</sup> <a name="file_path" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.tryRemoveFile.parameter.filePath"></a>

- *Type:* str

The file path.

If this path is relative, it will be
resolved from the root of _this_ project.

---


#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.buildTask">build_task</a></code> | <code>projen.Task</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.commitGenerated">commit_generated</a></code> | <code>bool</code> | Whether to commit the managed files by default. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.compileTask">compile_task</a></code> | <code>projen.Task</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.components">components</a></code> | <code>typing.List[projen.Component]</code> | Returns all the components within this project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.deps">deps</a></code> | <code>projen.Dependencies</code> | Project dependencies. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.ejected">ejected</a></code> | <code>bool</code> | Whether or not the project is being ejected. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.files">files</a></code> | <code>typing.List[projen.FileBase]</code> | All files in this project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.gitattributes">gitattributes</a></code> | <code>projen.GitAttributesFile</code> | The .gitattributes file for this repository. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.gitignore">gitignore</a></code> | <code>projen.IgnoreFile</code> | .gitignore. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.logger">logger</a></code> | <code>projen.Logger</code> | Logging utilities. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.name">name</a></code> | <code>str</code> | Project name. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.outdir">outdir</a></code> | <code>str</code> | Absolute output directory of this project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.packageTask">package_task</a></code> | <code>projen.Task</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.postCompileTask">post_compile_task</a></code> | <code>projen.Task</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.preCompileTask">pre_compile_task</a></code> | <code>projen.Task</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.projectBuild">project_build</a></code> | <code>projen.ProjectBuild</code> | Manages the build process of the project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.projenCommand">projen_command</a></code> | <code>str</code> | The command to use in order to run the projen CLI. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.root">root</a></code> | <code>projen.Project</code> | The root project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.subprojects">subprojects</a></code> | <code>typing.List[projen.Project]</code> | Returns all the subprojects within this project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.tasks">tasks</a></code> | <code>projen.Tasks</code> | Project tasks. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.testTask">test_task</a></code> | <code>projen.Task</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.defaultTask">default_task</a></code> | <code>projen.Task</code> | This is the "default" task, the one that executes "projen". |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.initProject">init_project</a></code> | <code>projen.InitProject</code> | The options used when this project is bootstrapped via `projen new`. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.parent">parent</a></code> | <code>projen.Project</code> | A parent project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.generateTask">generate_task</a></code> | <code>projen.Task</code> | Reference to the task used for generating the final bundled OpenAPI specification. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.parsedSpecFile">parsed_spec_file</a></code> | <code>str</code> | Name of the final bundled OpenAPI specification. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.openapi">openapi</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiDefinition">OpenApiDefinition</a></code> | Reference to the OpenAPI definition component. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.smithy">smithy</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyDefinition">SmithyDefinition</a></code> | Reference to the Smithy definition component. |

---

##### `build_task`<sup>Required</sup> <a name="build_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.buildTask"></a>

```python
build_task: Task
```

- *Type:* projen.Task

---

##### `commit_generated`<sup>Required</sup> <a name="commit_generated" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.commitGenerated"></a>

```python
commit_generated: bool
```

- *Type:* bool

Whether to commit the managed files by default.

---

##### `compile_task`<sup>Required</sup> <a name="compile_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.compileTask"></a>

```python
compile_task: Task
```

- *Type:* projen.Task

---

##### `components`<sup>Required</sup> <a name="components" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.components"></a>

```python
components: typing.List[Component]
```

- *Type:* typing.List[projen.Component]

Returns all the components within this project.

---

##### `deps`<sup>Required</sup> <a name="deps" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.deps"></a>

```python
deps: Dependencies
```

- *Type:* projen.Dependencies

Project dependencies.

---

##### `ejected`<sup>Required</sup> <a name="ejected" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.ejected"></a>

```python
ejected: bool
```

- *Type:* bool

Whether or not the project is being ejected.

---

##### `files`<sup>Required</sup> <a name="files" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.files"></a>

```python
files: typing.List[FileBase]
```

- *Type:* typing.List[projen.FileBase]

All files in this project.

---

##### `gitattributes`<sup>Required</sup> <a name="gitattributes" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.gitattributes"></a>

```python
gitattributes: GitAttributesFile
```

- *Type:* projen.GitAttributesFile

The .gitattributes file for this repository.

---

##### `gitignore`<sup>Required</sup> <a name="gitignore" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.gitignore"></a>

```python
gitignore: IgnoreFile
```

- *Type:* projen.IgnoreFile

.gitignore.

---

##### `logger`<sup>Required</sup> <a name="logger" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.logger"></a>

```python
logger: Logger
```

- *Type:* projen.Logger

Logging utilities.

---

##### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.name"></a>

```python
name: str
```

- *Type:* str

Project name.

---

##### `outdir`<sup>Required</sup> <a name="outdir" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.outdir"></a>

```python
outdir: str
```

- *Type:* str

Absolute output directory of this project.

---

##### `package_task`<sup>Required</sup> <a name="package_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.packageTask"></a>

```python
package_task: Task
```

- *Type:* projen.Task

---

##### `post_compile_task`<sup>Required</sup> <a name="post_compile_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.postCompileTask"></a>

```python
post_compile_task: Task
```

- *Type:* projen.Task

---

##### `pre_compile_task`<sup>Required</sup> <a name="pre_compile_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.preCompileTask"></a>

```python
pre_compile_task: Task
```

- *Type:* projen.Task

---

##### `project_build`<sup>Required</sup> <a name="project_build" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.projectBuild"></a>

```python
project_build: ProjectBuild
```

- *Type:* projen.ProjectBuild

Manages the build process of the project.

---

##### `projen_command`<sup>Required</sup> <a name="projen_command" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.projenCommand"></a>

```python
projen_command: str
```

- *Type:* str

The command to use in order to run the projen CLI.

---

##### `root`<sup>Required</sup> <a name="root" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.root"></a>

```python
root: Project
```

- *Type:* projen.Project

The root project.

---

##### `subprojects`<sup>Required</sup> <a name="subprojects" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.subprojects"></a>

```python
subprojects: typing.List[Project]
```

- *Type:* typing.List[projen.Project]

Returns all the subprojects within this project.

---

##### `tasks`<sup>Required</sup> <a name="tasks" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.tasks"></a>

```python
tasks: Tasks
```

- *Type:* projen.Tasks

Project tasks.

---

##### `test_task`<sup>Required</sup> <a name="test_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.testTask"></a>

```python
test_task: Task
```

- *Type:* projen.Task

---

##### `default_task`<sup>Optional</sup> <a name="default_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.defaultTask"></a>

```python
default_task: Task
```

- *Type:* projen.Task

This is the "default" task, the one that executes "projen".

Undefined if
the project is being ejected.

---

##### `init_project`<sup>Optional</sup> <a name="init_project" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.initProject"></a>

```python
init_project: InitProject
```

- *Type:* projen.InitProject

The options used when this project is bootstrapped via `projen new`.

It
includes the original set of options passed to the CLI and also the JSII
FQN of the project type.

---

##### `parent`<sup>Optional</sup> <a name="parent" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.parent"></a>

```python
parent: Project
```

- *Type:* projen.Project

A parent project.

If undefined, this is the root project.

---

##### `generate_task`<sup>Required</sup> <a name="generate_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.generateTask"></a>

```python
generate_task: Task
```

- *Type:* projen.Task

Reference to the task used for generating the final bundled OpenAPI specification.

---

##### `parsed_spec_file`<sup>Required</sup> <a name="parsed_spec_file" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.parsedSpecFile"></a>

```python
parsed_spec_file: str
```

- *Type:* str

Name of the final bundled OpenAPI specification.

---

##### `openapi`<sup>Optional</sup> <a name="openapi" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.openapi"></a>

```python
openapi: OpenApiDefinition
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.OpenApiDefinition">OpenApiDefinition</a>

Reference to the OpenAPI definition component.

Will be defined if the model language is OpenAPI

---

##### `smithy`<sup>Optional</sup> <a name="smithy" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.smithy"></a>

```python
smithy: SmithyDefinition
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.SmithyDefinition">SmithyDefinition</a>

Reference to the Smithy definition component.

Will be defined if the model language is Smithy

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.DEFAULT_TASK">DEFAULT_TASK</a></code> | <code>str</code> | The name of the default task (the task executed when `projen` is run without arguments). |

---

##### `DEFAULT_TASK`<sup>Required</sup> <a name="DEFAULT_TASK" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.DEFAULT_TASK"></a>

```python
DEFAULT_TASK: str
```

- *Type:* str

The name of the default task (the task executed when `projen` is run without arguments).

Normally
this task should synthesize the project files.

---

### TypeSafeApiProject <a name="TypeSafeApiProject" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject"></a>

Project for a type-safe API, defined using Smithy or OpenAPI.

Generates a CDK construct to deploy your API, as well as client and server code to help build your API quickly.

#### Initializers <a name="Initializers" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.TypeSafeApiProject(
  name: str,
  commit_generated: bool = None,
  git_ignore_options: IgnoreFileOptions = None,
  git_options: GitOptions = None,
  logging: LoggerOptions = None,
  outdir: str = None,
  parent: Project = None,
  projen_command: str = None,
  projenrc_json: bool = None,
  projenrc_json_options: ProjenrcJsonOptions = None,
  renovatebot: bool = None,
  renovatebot_options: RenovatebotOptions = None,
  infrastructure: InfrastructureConfiguration,
  model: ModelConfiguration,
  runtime: RuntimeConfiguration,
  documentation: DocumentationConfiguration = None,
  library: LibraryConfiguration = None
)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.name">name</a></code> | <code>str</code> | This is the name of your project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.commitGenerated">commit_generated</a></code> | <code>bool</code> | Whether to commit the managed files by default. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.gitIgnoreOptions">git_ignore_options</a></code> | <code>projen.IgnoreFileOptions</code> | Configuration options for .gitignore file. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.gitOptions">git_options</a></code> | <code>projen.GitOptions</code> | Configuration options for git. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.logging">logging</a></code> | <code>projen.LoggerOptions</code> | Configure logging options such as verbosity. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.outdir">outdir</a></code> | <code>str</code> | The root directory of the project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.parent">parent</a></code> | <code>projen.Project</code> | The parent project, if this project is part of a bigger project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.projenCommand">projen_command</a></code> | <code>str</code> | The shell command to use in order to run the projen CLI. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.projenrcJson">projenrc_json</a></code> | <code>bool</code> | Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.projenrcJsonOptions">projenrc_json_options</a></code> | <code>projen.ProjenrcJsonOptions</code> | Options for .projenrc.json. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.renovatebot">renovatebot</a></code> | <code>bool</code> | Use renovatebot to handle dependency upgrades. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.renovatebotOptions">renovatebot_options</a></code> | <code>projen.RenovatebotOptions</code> | Options for renovatebot. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.infrastructure">infrastructure</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.InfrastructureConfiguration">InfrastructureConfiguration</a></code> | Configuration for generated infrastructure. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.model">model</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.ModelConfiguration">ModelConfiguration</a></code> | Configuration for the API model. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.runtime">runtime</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.RuntimeConfiguration">RuntimeConfiguration</a></code> | Configuration for generated runtime projects (containing types, clients and server code). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.documentation">documentation</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.DocumentationConfiguration">DocumentationConfiguration</a></code> | Configuration for generated documentation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.library">library</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.LibraryConfiguration">LibraryConfiguration</a></code> | Configuration for generated libraries. |

---

##### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.name"></a>

- *Type:* str
- *Default:* $BASEDIR

This is the name of your project.

---

##### `commit_generated`<sup>Optional</sup> <a name="commit_generated" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.commitGenerated"></a>

- *Type:* bool
- *Default:* true

Whether to commit the managed files by default.

---

##### `git_ignore_options`<sup>Optional</sup> <a name="git_ignore_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.gitIgnoreOptions"></a>

- *Type:* projen.IgnoreFileOptions

Configuration options for .gitignore file.

---

##### `git_options`<sup>Optional</sup> <a name="git_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.gitOptions"></a>

- *Type:* projen.GitOptions

Configuration options for git.

---

##### `logging`<sup>Optional</sup> <a name="logging" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.logging"></a>

- *Type:* projen.LoggerOptions
- *Default:* {}

Configure logging options such as verbosity.

---

##### `outdir`<sup>Optional</sup> <a name="outdir" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.outdir"></a>

- *Type:* str
- *Default:* "."

The root directory of the project.

Relative to this directory, all files are synthesized.

If this project has a parent, this directory is relative to the parent
directory and it cannot be the same as the parent or any of it's other
sub-projects.

---

##### `parent`<sup>Optional</sup> <a name="parent" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.parent"></a>

- *Type:* projen.Project

The parent project, if this project is part of a bigger project.

---

##### `projen_command`<sup>Optional</sup> <a name="projen_command" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.projenCommand"></a>

- *Type:* str
- *Default:* "npx projen"

The shell command to use in order to run the projen CLI.

Can be used to customize in special environments.

---

##### `projenrc_json`<sup>Optional</sup> <a name="projenrc_json" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.projenrcJson"></a>

- *Type:* bool
- *Default:* false

Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation.

---

##### `projenrc_json_options`<sup>Optional</sup> <a name="projenrc_json_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.projenrcJsonOptions"></a>

- *Type:* projen.ProjenrcJsonOptions
- *Default:* default options

Options for .projenrc.json.

---

##### `renovatebot`<sup>Optional</sup> <a name="renovatebot" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.renovatebot"></a>

- *Type:* bool
- *Default:* false

Use renovatebot to handle dependency upgrades.

---

##### `renovatebot_options`<sup>Optional</sup> <a name="renovatebot_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.renovatebotOptions"></a>

- *Type:* projen.RenovatebotOptions
- *Default:* default options

Options for renovatebot.

---

##### `infrastructure`<sup>Required</sup> <a name="infrastructure" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.infrastructure"></a>

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.InfrastructureConfiguration">InfrastructureConfiguration</a>

Configuration for generated infrastructure.

---

##### `model`<sup>Required</sup> <a name="model" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.model"></a>

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.ModelConfiguration">ModelConfiguration</a>

Configuration for the API model.

---

##### `runtime`<sup>Required</sup> <a name="runtime" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.runtime"></a>

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.RuntimeConfiguration">RuntimeConfiguration</a>

Configuration for generated runtime projects (containing types, clients and server code).

---

##### `documentation`<sup>Optional</sup> <a name="documentation" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.documentation"></a>

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.DocumentationConfiguration">DocumentationConfiguration</a>

Configuration for generated documentation.

---

##### `library`<sup>Optional</sup> <a name="library" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.library"></a>

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.LibraryConfiguration">LibraryConfiguration</a>

Configuration for generated libraries.

Libraries are projects which are generated from your model, but are not
fully-fledged runtimes, for example react hooks or clients in languages that aren't supported as runtimes.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addExcludeFromCleanup">add_exclude_from_cleanup</a></code> | Exclude the matching files from pre-synth cleanup. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addGitIgnore">add_git_ignore</a></code> | Adds a .gitignore pattern. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addPackageIgnore">add_package_ignore</a></code> | Exclude these files from the bundled package. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addTask">add_task</a></code> | Adds a new task to this project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addTip">add_tip</a></code> | Prints a "tip" message during synthesis. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.annotateGenerated">annotate_generated</a></code> | Consider a set of files as "generated". |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.postSynthesize">post_synthesize</a></code> | Called after all components are synthesized. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.preSynthesize">pre_synthesize</a></code> | Called before all components are synthesized. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.removeTask">remove_task</a></code> | Removes a task from a project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.runTaskCommand">run_task_command</a></code> | Returns the shell command to execute in order to run a task. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.synth">synth</a></code> | Synthesize all project files into `outdir`. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.tryFindFile">try_find_file</a></code> | Finds a file at the specified relative path within this project and all its subprojects. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.tryFindJsonFile">try_find_json_file</a></code> | Finds a json file by name. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.tryFindObjectFile">try_find_object_file</a></code> | Finds an object file (like JsonFile, YamlFile, etc.) by name. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.tryRemoveFile">try_remove_file</a></code> | Finds a file at the specified relative path within this project and removes it. |

---

##### `add_exclude_from_cleanup` <a name="add_exclude_from_cleanup" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addExcludeFromCleanup"></a>

```python
def add_exclude_from_cleanup(
  globs: str
) -> None
```

Exclude the matching files from pre-synth cleanup.

Can be used when, for example, some
source files include the projen marker and we don't want them to be erased during synth.

###### `globs`<sup>Required</sup> <a name="globs" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addExcludeFromCleanup.parameter.globs"></a>

- *Type:* str

The glob patterns to match.

---

##### `add_git_ignore` <a name="add_git_ignore" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addGitIgnore"></a>

```python
def add_git_ignore(
  pattern: str
) -> None
```

Adds a .gitignore pattern.

###### `pattern`<sup>Required</sup> <a name="pattern" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addGitIgnore.parameter.pattern"></a>

- *Type:* str

The glob pattern to ignore.

---

##### `add_package_ignore` <a name="add_package_ignore" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addPackageIgnore"></a>

```python
def add_package_ignore(
  _pattern: str
) -> None
```

Exclude these files from the bundled package.

Implemented by project types based on the
packaging mechanism. For example, `NodeProject` delegates this to `.npmignore`.

###### `_pattern`<sup>Required</sup> <a name="_pattern" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addPackageIgnore.parameter._pattern"></a>

- *Type:* str

The glob pattern to exclude.

---

##### `add_task` <a name="add_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addTask"></a>

```python
def add_task(
  name: str,
  condition: str = None,
  cwd: str = None,
  description: str = None,
  env: typing.Mapping[str] = None,
  required_env: typing.List[str] = None,
  args: typing.List[str] = None,
  exec: str = None,
  receive_args: bool = None,
  steps: typing.List[TaskStep] = None
) -> Task
```

Adds a new task to this project.

This will fail if the project already has
a task with this name.

###### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addTask.parameter.name"></a>

- *Type:* str

The task name to add.

---

###### `condition`<sup>Optional</sup> <a name="condition" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addTask.parameter.condition"></a>

- *Type:* str

A shell command which determines if the this task should be executed.

If
the program exits with a zero exit code, steps will be executed. A non-zero
code means that task will be skipped.

---

###### `cwd`<sup>Optional</sup> <a name="cwd" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addTask.parameter.cwd"></a>

- *Type:* str
- *Default:* process.cwd()

The working directory for all steps in this task (unless overridden by the step).

---

###### `description`<sup>Optional</sup> <a name="description" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addTask.parameter.description"></a>

- *Type:* str
- *Default:* the task name

The description of this build command.

---

###### `env`<sup>Optional</sup> <a name="env" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addTask.parameter.env"></a>

- *Type:* typing.Mapping[str]
- *Default:* {}

Defines environment variables for the execution of this task.

Values in this map will be evaluated in a shell, so you can do stuff like `$(echo "foo")`.

---

###### `required_env`<sup>Optional</sup> <a name="required_env" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addTask.parameter.requiredEnv"></a>

- *Type:* typing.List[str]

A set of environment variables that must be defined in order to execute this task.

Task execution will fail if one of these is not defined.

---

###### `args`<sup>Optional</sup> <a name="args" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addTask.parameter.args"></a>

- *Type:* typing.List[str]
- *Default:* no arguments are passed to the step

Should the provided `exec` shell command receive fixed args.

> [{@link TaskStepOptions.args }]({@link TaskStepOptions.args })

---

###### `exec`<sup>Optional</sup> <a name="exec" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addTask.parameter.exec"></a>

- *Type:* str
- *Default:* add steps using `task.exec(command)` or `task.spawn(subtask)`

Shell command to execute as the first command of the task.

---

###### `receive_args`<sup>Optional</sup> <a name="receive_args" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addTask.parameter.receiveArgs"></a>

- *Type:* bool
- *Default:* false

Should the provided `exec` shell command receive args passed to the task.

> [{@link TaskStepOptions.receiveArgs }]({@link TaskStepOptions.receiveArgs })

---

###### `steps`<sup>Optional</sup> <a name="steps" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addTask.parameter.steps"></a>

- *Type:* typing.List[projen.TaskStep]

List of task steps to run.

---

##### ~~`add_tip`~~ <a name="add_tip" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addTip"></a>

```python
def add_tip(
  message: str
) -> None
```

Prints a "tip" message during synthesis.

###### `message`<sup>Required</sup> <a name="message" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addTip.parameter.message"></a>

- *Type:* str

The message.

---

##### `annotate_generated` <a name="annotate_generated" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.annotateGenerated"></a>

```python
def annotate_generated(
  _glob: str
) -> None
```

Consider a set of files as "generated".

This method is implemented by
derived classes and used for example, to add git attributes to tell GitHub
that certain files are generated.

###### `_glob`<sup>Required</sup> <a name="_glob" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.annotateGenerated.parameter._glob"></a>

- *Type:* str

the glob pattern to match (could be a file path).

---

##### `post_synthesize` <a name="post_synthesize" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.postSynthesize"></a>

```python
def post_synthesize() -> None
```

Called after all components are synthesized.

Order is *not* guaranteed.

##### `pre_synthesize` <a name="pre_synthesize" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.preSynthesize"></a>

```python
def pre_synthesize() -> None
```

Called before all components are synthesized.

##### `remove_task` <a name="remove_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.removeTask"></a>

```python
def remove_task(
  name: str
) -> Task
```

Removes a task from a project.

###### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.removeTask.parameter.name"></a>

- *Type:* str

The name of the task to remove.

---

##### `run_task_command` <a name="run_task_command" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.runTaskCommand"></a>

```python
def run_task_command(
  task: Task
) -> str
```

Returns the shell command to execute in order to run a task.

By default, this is `npx projen@<version> <task>`

###### `task`<sup>Required</sup> <a name="task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.runTaskCommand.parameter.task"></a>

- *Type:* projen.Task

The task for which the command is required.

---

##### `synth` <a name="synth" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.synth"></a>

```python
def synth() -> None
```

Synthesize all project files into `outdir`.

1. Call "this.preSynthesize()"
2. Delete all generated files
3. Synthesize all sub-projects
4. Synthesize all components of this project
5. Call "postSynthesize()" for all components of this project
6. Call "this.postSynthesize()"

##### `try_find_file` <a name="try_find_file" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.tryFindFile"></a>

```python
def try_find_file(
  file_path: str
) -> FileBase
```

Finds a file at the specified relative path within this project and all its subprojects.

###### `file_path`<sup>Required</sup> <a name="file_path" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.tryFindFile.parameter.filePath"></a>

- *Type:* str

The file path.

If this path is relative, it will be resolved
from the root of _this_ project.

---

##### ~~`try_find_json_file`~~ <a name="try_find_json_file" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.tryFindJsonFile"></a>

```python
def try_find_json_file(
  file_path: str
) -> JsonFile
```

Finds a json file by name.

###### `file_path`<sup>Required</sup> <a name="file_path" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.tryFindJsonFile.parameter.filePath"></a>

- *Type:* str

The file path.

---

##### `try_find_object_file` <a name="try_find_object_file" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.tryFindObjectFile"></a>

```python
def try_find_object_file(
  file_path: str
) -> ObjectFile
```

Finds an object file (like JsonFile, YamlFile, etc.) by name.

###### `file_path`<sup>Required</sup> <a name="file_path" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.tryFindObjectFile.parameter.filePath"></a>

- *Type:* str

The file path.

---

##### `try_remove_file` <a name="try_remove_file" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.tryRemoveFile"></a>

```python
def try_remove_file(
  file_path: str
) -> FileBase
```

Finds a file at the specified relative path within this project and removes it.

###### `file_path`<sup>Required</sup> <a name="file_path" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.tryRemoveFile.parameter.filePath"></a>

- *Type:* str

The file path.

If this path is relative, it will be
resolved from the root of _this_ project.

---


#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.buildTask">build_task</a></code> | <code>projen.Task</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.commitGenerated">commit_generated</a></code> | <code>bool</code> | Whether to commit the managed files by default. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.compileTask">compile_task</a></code> | <code>projen.Task</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.components">components</a></code> | <code>typing.List[projen.Component]</code> | Returns all the components within this project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.deps">deps</a></code> | <code>projen.Dependencies</code> | Project dependencies. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.ejected">ejected</a></code> | <code>bool</code> | Whether or not the project is being ejected. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.files">files</a></code> | <code>typing.List[projen.FileBase]</code> | All files in this project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.gitattributes">gitattributes</a></code> | <code>projen.GitAttributesFile</code> | The .gitattributes file for this repository. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.gitignore">gitignore</a></code> | <code>projen.IgnoreFile</code> | .gitignore. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.logger">logger</a></code> | <code>projen.Logger</code> | Logging utilities. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.name">name</a></code> | <code>str</code> | Project name. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.outdir">outdir</a></code> | <code>str</code> | Absolute output directory of this project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.packageTask">package_task</a></code> | <code>projen.Task</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.postCompileTask">post_compile_task</a></code> | <code>projen.Task</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.preCompileTask">pre_compile_task</a></code> | <code>projen.Task</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.projectBuild">project_build</a></code> | <code>projen.ProjectBuild</code> | Manages the build process of the project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.projenCommand">projen_command</a></code> | <code>str</code> | The command to use in order to run the projen CLI. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.root">root</a></code> | <code>projen.Project</code> | The root project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.subprojects">subprojects</a></code> | <code>typing.List[projen.Project]</code> | Returns all the subprojects within this project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.tasks">tasks</a></code> | <code>projen.Tasks</code> | Project tasks. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.testTask">test_task</a></code> | <code>projen.Task</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.defaultTask">default_task</a></code> | <code>projen.Task</code> | This is the "default" task, the one that executes "projen". |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.initProject">init_project</a></code> | <code>projen.InitProject</code> | The options used when this project is bootstrapped via `projen new`. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.parent">parent</a></code> | <code>projen.Project</code> | A parent project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.documentation">documentation</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedDocumentationProjects">GeneratedDocumentationProjects</a></code> | Generated documentation projects. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.infrastructure">infrastructure</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedCodeProjects">GeneratedCodeProjects</a></code> | Generated infrastructure projects. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.library">library</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedLibraryProjects">GeneratedLibraryProjects</a></code> | Generated library projects. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.model">model</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject">TypeSafeApiModelProject</a></code> | Project for the api model. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.runtime">runtime</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedCodeProjects">GeneratedCodeProjects</a></code> | Generated runtime projects. |

---

##### `build_task`<sup>Required</sup> <a name="build_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.buildTask"></a>

```python
build_task: Task
```

- *Type:* projen.Task

---

##### `commit_generated`<sup>Required</sup> <a name="commit_generated" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.commitGenerated"></a>

```python
commit_generated: bool
```

- *Type:* bool

Whether to commit the managed files by default.

---

##### `compile_task`<sup>Required</sup> <a name="compile_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.compileTask"></a>

```python
compile_task: Task
```

- *Type:* projen.Task

---

##### `components`<sup>Required</sup> <a name="components" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.components"></a>

```python
components: typing.List[Component]
```

- *Type:* typing.List[projen.Component]

Returns all the components within this project.

---

##### `deps`<sup>Required</sup> <a name="deps" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.deps"></a>

```python
deps: Dependencies
```

- *Type:* projen.Dependencies

Project dependencies.

---

##### `ejected`<sup>Required</sup> <a name="ejected" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.ejected"></a>

```python
ejected: bool
```

- *Type:* bool

Whether or not the project is being ejected.

---

##### `files`<sup>Required</sup> <a name="files" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.files"></a>

```python
files: typing.List[FileBase]
```

- *Type:* typing.List[projen.FileBase]

All files in this project.

---

##### `gitattributes`<sup>Required</sup> <a name="gitattributes" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.gitattributes"></a>

```python
gitattributes: GitAttributesFile
```

- *Type:* projen.GitAttributesFile

The .gitattributes file for this repository.

---

##### `gitignore`<sup>Required</sup> <a name="gitignore" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.gitignore"></a>

```python
gitignore: IgnoreFile
```

- *Type:* projen.IgnoreFile

.gitignore.

---

##### `logger`<sup>Required</sup> <a name="logger" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.logger"></a>

```python
logger: Logger
```

- *Type:* projen.Logger

Logging utilities.

---

##### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.name"></a>

```python
name: str
```

- *Type:* str

Project name.

---

##### `outdir`<sup>Required</sup> <a name="outdir" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.outdir"></a>

```python
outdir: str
```

- *Type:* str

Absolute output directory of this project.

---

##### `package_task`<sup>Required</sup> <a name="package_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.packageTask"></a>

```python
package_task: Task
```

- *Type:* projen.Task

---

##### `post_compile_task`<sup>Required</sup> <a name="post_compile_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.postCompileTask"></a>

```python
post_compile_task: Task
```

- *Type:* projen.Task

---

##### `pre_compile_task`<sup>Required</sup> <a name="pre_compile_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.preCompileTask"></a>

```python
pre_compile_task: Task
```

- *Type:* projen.Task

---

##### `project_build`<sup>Required</sup> <a name="project_build" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.projectBuild"></a>

```python
project_build: ProjectBuild
```

- *Type:* projen.ProjectBuild

Manages the build process of the project.

---

##### `projen_command`<sup>Required</sup> <a name="projen_command" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.projenCommand"></a>

```python
projen_command: str
```

- *Type:* str

The command to use in order to run the projen CLI.

---

##### `root`<sup>Required</sup> <a name="root" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.root"></a>

```python
root: Project
```

- *Type:* projen.Project

The root project.

---

##### `subprojects`<sup>Required</sup> <a name="subprojects" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.subprojects"></a>

```python
subprojects: typing.List[Project]
```

- *Type:* typing.List[projen.Project]

Returns all the subprojects within this project.

---

##### `tasks`<sup>Required</sup> <a name="tasks" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.tasks"></a>

```python
tasks: Tasks
```

- *Type:* projen.Tasks

Project tasks.

---

##### `test_task`<sup>Required</sup> <a name="test_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.testTask"></a>

```python
test_task: Task
```

- *Type:* projen.Task

---

##### `default_task`<sup>Optional</sup> <a name="default_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.defaultTask"></a>

```python
default_task: Task
```

- *Type:* projen.Task

This is the "default" task, the one that executes "projen".

Undefined if
the project is being ejected.

---

##### `init_project`<sup>Optional</sup> <a name="init_project" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.initProject"></a>

```python
init_project: InitProject
```

- *Type:* projen.InitProject

The options used when this project is bootstrapped via `projen new`.

It
includes the original set of options passed to the CLI and also the JSII
FQN of the project type.

---

##### `parent`<sup>Optional</sup> <a name="parent" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.parent"></a>

```python
parent: Project
```

- *Type:* projen.Project

A parent project.

If undefined, this is the root project.

---

##### `documentation`<sup>Required</sup> <a name="documentation" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.documentation"></a>

```python
documentation: GeneratedDocumentationProjects
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.GeneratedDocumentationProjects">GeneratedDocumentationProjects</a>

Generated documentation projects.

Only the properties corresponding to specified `documentation.formats` will be defined.

---

##### `infrastructure`<sup>Required</sup> <a name="infrastructure" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.infrastructure"></a>

```python
infrastructure: GeneratedCodeProjects
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.GeneratedCodeProjects">GeneratedCodeProjects</a>

Generated infrastructure projects.

Only the property corresponding to `infrastructure.language` will be defined.

---

##### `library`<sup>Required</sup> <a name="library" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.library"></a>

```python
library: GeneratedLibraryProjects
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.GeneratedLibraryProjects">GeneratedLibraryProjects</a>

Generated library projects.

Only the properties corresponding to specified `library.libraries` will be defined.

---

##### `model`<sup>Required</sup> <a name="model" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.model"></a>

```python
model: TypeSafeApiModelProject
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject">TypeSafeApiModelProject</a>

Project for the api model.

---

##### `runtime`<sup>Required</sup> <a name="runtime" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.runtime"></a>

```python
runtime: GeneratedCodeProjects
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.GeneratedCodeProjects">GeneratedCodeProjects</a>

Generated runtime projects.

When `runtime.languages` includes the corresponding language, the project can be
assumed to be defined.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.DEFAULT_TASK">DEFAULT_TASK</a></code> | <code>str</code> | The name of the default task (the task executed when `projen` is run without arguments). |

---

##### `DEFAULT_TASK`<sup>Required</sup> <a name="DEFAULT_TASK" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.DEFAULT_TASK"></a>

```python
DEFAULT_TASK: str
```

- *Type:* str

The name of the default task (the task executed when `projen` is run without arguments).

Normally
this task should synthesize the project files.

---


## Enums <a name="Enums" id="Enums"></a>

### CustomAuthorizerType <a name="CustomAuthorizerType" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizerType"></a>

The type of custom authorizer.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-authorizer.html#cfn-apigateway-authorizer-type](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-authorizer.html#cfn-apigateway-authorizer-type)

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizerType.TOKEN">TOKEN</a></code> | A custom authorizer that uses a Lambda function. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizerType.REQUEST">REQUEST</a></code> | An authorizer that uses a Lambda function using incoming request parameters. |

---

##### `TOKEN` <a name="TOKEN" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizerType.TOKEN"></a>

A custom authorizer that uses a Lambda function.

---


##### `REQUEST` <a name="REQUEST" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizerType.REQUEST"></a>

An authorizer that uses a Lambda function using incoming request parameters.

---


### DocumentationFormat <a name="DocumentationFormat" id="@aws-prototyping-sdk/type-safe-api.DocumentationFormat"></a>

Formats for documentation generation.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.DocumentationFormat.HTML_REDOC">HTML_REDOC</a></code> | HTML Documentation generated by redoc. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.DocumentationFormat.HTML2">HTML2</a></code> | OpenAPI Generator 'html2' documentation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.DocumentationFormat.MARKDOWN">MARKDOWN</a></code> | OpenAPI Generator 'markdown' documentation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.DocumentationFormat.PLANTUML">PLANTUML</a></code> | OpenAPI Generator 'plantuml' documentation. |

---

##### `HTML_REDOC` <a name="HTML_REDOC" id="@aws-prototyping-sdk/type-safe-api.DocumentationFormat.HTML_REDOC"></a>

HTML Documentation generated by redoc.

> [https://github.com/Redocly/redoc](https://github.com/Redocly/redoc)

---


##### `HTML2` <a name="HTML2" id="@aws-prototyping-sdk/type-safe-api.DocumentationFormat.HTML2"></a>

OpenAPI Generator 'html2' documentation.

> [https://github.com/OpenAPITools/openapi-generator/blob/master/docs/generators/html2.md](https://github.com/OpenAPITools/openapi-generator/blob/master/docs/generators/html2.md)

---


##### `MARKDOWN` <a name="MARKDOWN" id="@aws-prototyping-sdk/type-safe-api.DocumentationFormat.MARKDOWN"></a>

OpenAPI Generator 'markdown' documentation.

> [https://github.com/OpenAPITools/openapi-generator/blob/master/docs/generators/markdown.md](https://github.com/OpenAPITools/openapi-generator/blob/master/docs/generators/markdown.md)

---


##### `PLANTUML` <a name="PLANTUML" id="@aws-prototyping-sdk/type-safe-api.DocumentationFormat.PLANTUML"></a>

OpenAPI Generator 'plantuml' documentation.

> [https://github.com/OpenAPITools/openapi-generator/blob/master/docs/generators/plantuml.md](https://github.com/OpenAPITools/openapi-generator/blob/master/docs/generators/plantuml.md)

---


### Language <a name="Language" id="@aws-prototyping-sdk/type-safe-api.Language"></a>

Supported languages for runtimes and infrastructure.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.Language.TYPESCRIPT">TYPESCRIPT</a></code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.Language.PYTHON">PYTHON</a></code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.Language.JAVA">JAVA</a></code> | *No description.* |

---

##### `TYPESCRIPT` <a name="TYPESCRIPT" id="@aws-prototyping-sdk/type-safe-api.Language.TYPESCRIPT"></a>

---


##### `PYTHON` <a name="PYTHON" id="@aws-prototyping-sdk/type-safe-api.Language.PYTHON"></a>

---


##### `JAVA` <a name="JAVA" id="@aws-prototyping-sdk/type-safe-api.Language.JAVA"></a>

---


### Library <a name="Library" id="@aws-prototyping-sdk/type-safe-api.Library"></a>

Supported libraries for code generation.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.Library.TYPESCRIPT_REACT_QUERY_HOOKS">TYPESCRIPT_REACT_QUERY_HOOKS</a></code> | *No description.* |

---

##### `TYPESCRIPT_REACT_QUERY_HOOKS` <a name="TYPESCRIPT_REACT_QUERY_HOOKS" id="@aws-prototyping-sdk/type-safe-api.Library.TYPESCRIPT_REACT_QUERY_HOOKS"></a>

---


### ModelLanguage <a name="ModelLanguage" id="@aws-prototyping-sdk/type-safe-api.ModelLanguage"></a>

The model definition language.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ModelLanguage.SMITHY">SMITHY</a></code> | Smithy. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ModelLanguage.OPENAPI">OPENAPI</a></code> | OpenAPI. |

---

##### `SMITHY` <a name="SMITHY" id="@aws-prototyping-sdk/type-safe-api.ModelLanguage.SMITHY"></a>

Smithy.

> [https://smithy.io/2.0/](https://smithy.io/2.0/)

---


##### `OPENAPI` <a name="OPENAPI" id="@aws-prototyping-sdk/type-safe-api.ModelLanguage.OPENAPI"></a>

OpenAPI.

> [https://www.openapis.org/](https://www.openapis.org/)

---

